""" Cisco_IOS_XR_ipv4_pim_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv4\-pim package operational data.

This module contains definitions
for the following management objects\:
  pim\-ma\: PIM MA operational data
  pim\: pim
  ipv6\-pim\: ipv6 pim
  pim6\-ma\: pim6 ma

Copyright (c) 2013\-2017 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class PimAfi(Enum):
    """
    PimAfi

    Address family

    .. data:: ipv4_unicast = 0

    	IP v4 unicast

    .. data:: ipv6_unicast = 1

    	IP v6 unicast

    """

    ipv4_unicast = Enum.YLeaf(0, "ipv4-unicast")

    ipv6_unicast = Enum.YLeaf(1, "ipv6-unicast")


class PimClient(Enum):
    """
    PimClient

    Pim client

    .. data:: none = 0

    	No Client

    .. data:: configured_embedded_rp = 1

    	Embedded RP from configuration

    .. data:: embedded = 2

    	Embedded RP learnt from the Group addr

    .. data:: permanent = 3

    	Permanent

    .. data:: auto_rp = 4

    	AutoRP

    .. data:: bsr = 5

    	BSR

    .. data:: configured = 6

    	Configured

    .. data:: static = 7

    	Static

    """

    none = Enum.YLeaf(0, "none")

    configured_embedded_rp = Enum.YLeaf(1, "configured-embedded-rp")

    embedded = Enum.YLeaf(2, "embedded")

    permanent = Enum.YLeaf(3, "permanent")

    auto_rp = Enum.YLeaf(4, "auto-rp")

    bsr = Enum.YLeaf(5, "bsr")

    configured = Enum.YLeaf(6, "configured")

    static = Enum.YLeaf(7, "static")


class PimInterface(Enum):
    """
    PimInterface

    Interface Type

    .. data:: encap_interface = 0

    	Encap Interface

    .. data:: decap_interface = 1

    	Decap Interface

    .. data:: mdt_interface = 2

    	MDT Interface

    """

    encap_interface = Enum.YLeaf(0, "encap-interface")

    decap_interface = Enum.YLeaf(1, "decap-interface")

    mdt_interface = Enum.YLeaf(2, "mdt-interface")


class PimInternalInterestInfo(Enum):
    """
    PimInternalInterestInfo

    Pim internal interest info

    .. data:: null = 21

    	null

    .. data:: ii = 22

    	Internal Interest

    .. data:: id = 23

    	Internal Disinterest

    """

    null = Enum.YLeaf(21, "null")

    ii = Enum.YLeaf(22, "ii")

    id = Enum.YLeaf(23, "id")


class PimProtocol(Enum):
    """
    PimProtocol

    Pim protocol

    .. data:: non_routable = 0

    	Non Routable

    .. data:: sparse_mode = 1

    	Sparse Mode

    .. data:: dense_mode = 2

    	Dense Mode

    .. data:: bidir = 3

    	Bidirectional Mode

    .. data:: ssm = 4

    	Source Specific Multicast Mode

    .. data:: maximum = 5

    	Maximum

    .. data:: any = 6

    	Any

    """

    non_routable = Enum.YLeaf(0, "non-routable")

    sparse_mode = Enum.YLeaf(1, "sparse-mode")

    dense_mode = Enum.YLeaf(2, "dense-mode")

    bidir = Enum.YLeaf(3, "bidir")

    ssm = Enum.YLeaf(4, "ssm")

    maximum = Enum.YLeaf(5, "maximum")

    any = Enum.YLeaf(6, "any")


class PimSafi(Enum):
    """
    PimSafi

    Pim safi

    .. data:: unicast = 1

    	SAFI unicast

    .. data:: multicast = 2

    	SAFI Multicast

    .. data:: all = 3

    	SAFI all

    .. data:: default = 4

    	SAFI default

    """

    unicast = Enum.YLeaf(1, "unicast")

    multicast = Enum.YLeaf(2, "multicast")

    all = Enum.YLeaf(3, "all")

    default = Enum.YLeaf(4, "default")


class PimShowLocalInterest(Enum):
    """
    PimShowLocalInterest

    Pim show local interest

    .. data:: null = 1

    	null

    .. data:: li = 2

    	Local Interest

    .. data:: ld = 3

    	Local Disinterest

    """

    null = Enum.YLeaf(1, "null")

    li = Enum.YLeaf(2, "li")

    ld = Enum.YLeaf(3, "ld")


class PimShowProtocol(Enum):
    """
    PimShowProtocol

    Pim show protocol

    .. data:: no_route = 0

    	no route

    .. data:: sm = 1

    	sm

    .. data:: dm = 2

    	dm

    .. data:: bidir = 3

    	bidir

    .. data:: ssm = 4

    	ssm

    .. data:: maximum = 5

    	maximum

    .. data:: any = 6

    	any

    """

    no_route = Enum.YLeaf(0, "no-route")

    sm = Enum.YLeaf(1, "sm")

    dm = Enum.YLeaf(2, "dm")

    bidir = Enum.YLeaf(3, "bidir")

    ssm = Enum.YLeaf(4, "ssm")

    maximum = Enum.YLeaf(5, "maximum")

    any = Enum.YLeaf(6, "any")


class PimShowRangeClient(Enum):
    """
    PimShowRangeClient

    Pim show range client

    .. data:: no_client = 0

    	no client

    .. data:: embedded_config = 1

    	embedded config

    .. data:: embedded = 2

    	embedded

    .. data:: permanent = 3

    	permanent

    .. data:: auto_rp = 4

    	auto rp

    .. data:: bsr = 5

    	bsr

    .. data:: config = 6

    	config

    .. data:: static = 7

    	static

    """

    no_client = Enum.YLeaf(0, "no-client")

    embedded_config = Enum.YLeaf(1, "embedded-config")

    embedded = Enum.YLeaf(2, "embedded")

    permanent = Enum.YLeaf(3, "permanent")

    auto_rp = Enum.YLeaf(4, "auto-rp")

    bsr = Enum.YLeaf(5, "bsr")

    config = Enum.YLeaf(6, "config")

    static = Enum.YLeaf(7, "static")


class PimTopologyEntryFlag(Enum):
    """
    PimTopologyEntryFlag

    Pim topology entry flag

    .. data:: kat = 0

    	KAT

    .. data:: aa = 1

    	AA

    .. data:: pa = 2

    	PA

    .. data:: ra = 3

    	RA

    .. data:: ia = 4

    	IA

    .. data:: rr = 5

    	RR

    .. data:: lh = 6

    	LH

    .. data:: dss = 7

    	DSS

    .. data:: dcc = 8

    	DCC

    .. data:: sr = 9

    	SR

    .. data:: e = 10

    	E

    .. data:: ex = 11

    	EX

    .. data:: ma = 12

    	MA

    .. data:: mt = 13

    	MT

    .. data:: mfa = 14

    	MFA

    .. data:: mfp = 15

    	MFP

    .. data:: mfb = 16

    	MFB

    """

    kat = Enum.YLeaf(0, "kat")

    aa = Enum.YLeaf(1, "aa")

    pa = Enum.YLeaf(2, "pa")

    ra = Enum.YLeaf(3, "ra")

    ia = Enum.YLeaf(4, "ia")

    rr = Enum.YLeaf(5, "rr")

    lh = Enum.YLeaf(6, "lh")

    dss = Enum.YLeaf(7, "dss")

    dcc = Enum.YLeaf(8, "dcc")

    sr = Enum.YLeaf(9, "sr")

    e = Enum.YLeaf(10, "e")

    ex = Enum.YLeaf(11, "ex")

    ma = Enum.YLeaf(12, "ma")

    mt = Enum.YLeaf(13, "mt")

    mfa = Enum.YLeaf(14, "mfa")

    mfp = Enum.YLeaf(15, "mfp")

    mfb = Enum.YLeaf(16, "mfb")


class PimTopologyInterfaceFlag(Enum):
    """
    PimTopologyInterfaceFlag

    Pim topology interface flag

    .. data:: lh = 0

    	LH

    .. data:: ld = 1

    	LD

    .. data:: li = 2

    	LI

    .. data:: ii = 3

    	II

    .. data:: id = 4

    	ID

    .. data:: as_ = 5

    	AS

    .. data:: ab = 6

    	AB

    .. data:: ex = 7

    	EX

    """

    lh = Enum.YLeaf(0, "lh")

    ld = Enum.YLeaf(1, "ld")

    li = Enum.YLeaf(2, "li")

    ii = Enum.YLeaf(3, "ii")

    id = Enum.YLeaf(4, "id")

    as_ = Enum.YLeaf(5, "as")

    ab = Enum.YLeaf(6, "ab")

    ex = Enum.YLeaf(7, "ex")



class Ipv6Pim(Entity):
    """
    ipv6 pim
    
    .. attribute:: active
    
    	Active Process
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active>`
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby>`
    
    

    """

    _prefix = 'ipv4-pim-oper'
    _revision = '2017-06-26'

    def __init__(self):
        super(Ipv6Pim, self).__init__()
        self._top_entity = None

        self.yang_name = "ipv6-pim"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-pim-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"active" : ("active", Ipv6Pim.Active), "standby" : ("standby", Ipv6Pim.Standby)}
        self._child_list_classes = {}

        self.active = Ipv6Pim.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"
        self._children_yang_names.add("active")

        self.standby = Ipv6Pim.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"
        self._children_yang_names.add("standby")
        self._segment_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim"


    class Active(Entity):
        """
        Active Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2017-06-26'

        def __init__(self):
            super(Ipv6Pim.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "ipv6-pim"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"default-context" : ("default_context", Ipv6Pim.Active.DefaultContext), "process" : ("process", Ipv6Pim.Active.Process), "vrfs" : ("vrfs", Ipv6Pim.Active.Vrfs)}
            self._child_list_classes = {}

            self.default_context = Ipv6Pim.Active.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"
            self._children_yang_names.add("default-context")

            self.process = Ipv6Pim.Active.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"
            self._children_yang_names.add("process")

            self.vrfs = Ipv6Pim.Active.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._children_yang_names.add("vrfs")
            self._segment_path = lambda: "active"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/%s" % self._segment_path()


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: auto_rp
            
            	PIM Auto\-RP information
            	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.AutoRp>`
            
            .. attribute:: bgp_afs
            
            	PIM BGP SAFI table
            	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs>`
            
            .. attribute:: bidir_df_states
            
            	Bidirectional PIM DF election state table
            	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfStates>`
            
            .. attribute:: bidir_df_winners
            
            	Bidirectional PIM DF election winner table
            	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfWinners>`
            
            .. attribute:: bsr
            
            	PIM BSR information
            	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr>`
            
            .. attribute:: context
            
            	PIM context information
            	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context>`
            
            .. attribute:: global_interfaces
            
            	PIM global interface table
            	**type**\:   :py:class:`GlobalInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GlobalInterfaces>`
            
            .. attribute:: gre
            
            	GRE information
            	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre>`
            
            .. attribute:: group_map_rpfs
            
            	PIM group mapping information
            	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs>`
            
            .. attribute:: group_map_sources
            
            	PIM group\-mapping with source information
            	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources>`
            
            .. attribute:: ifrs_interfaces
            
            	PIM interfaces in forward reference store table
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: ifrs_summary
            
            	PIM interfaces in forward reference store summary
            	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsSummary>`
            
            .. attribute:: interface_old_formats
            
            	PIM interfaces in old format
            	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceOldFormats>`
            
            .. attribute:: interface_statistics
            
            	PIM interface statistics
            	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceStatistics>`
            
            .. attribute:: interfaces
            
            	PIM interfaces
            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Interfaces>`
            
            .. attribute:: jp_statistics
            
            	PIM join prune statistics table
            	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.JpStatistics>`
            
            .. attribute:: mib_databases
            
            	PIM group database for mroute mibs table
            	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases>`
            
            .. attribute:: multicast_static_routes
            
            	PIM multicast static route table
            	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes>`
            
            .. attribute:: neighbor_old_formats
            
            	PIM neighbor table old format
            	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborOldFormats>`
            
            .. attribute:: neighbor_summaries
            
            	PIM neighbor summary table
            	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborSummaries>`
            
            .. attribute:: neighbors
            
            	PIM neighbor table
            	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Neighbors>`
            
            .. attribute:: net_io_tunnels
            
            	Tunnel information that NETIO has 
            	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels>`
            
            .. attribute:: ranges
            
            	PIM range list information
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges>`
            
            .. attribute:: route_policy
            
            	PIM route policy
            	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy>`
            
            .. attribute:: rpf_redirect
            
            	PIM ECMP RPF\-redirect bundle
            	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect>`
            
            .. attribute:: rpf_summary
            
            	PIM RPF registration summary
            	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfSummary>`
            
            .. attribute:: safs
            
            	SAFI table and type
            	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs>`
            
            .. attribute:: summary
            
            	PIM summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Summary>`
            
            .. attribute:: table_contexts
            
            	PIM table context list
            	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TableContexts>`
            
            .. attribute:: topologies
            
            	PIM topology table
            	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies>`
            
            .. attribute:: topology_entry_flag_route_counts
            
            	Route count for topology with entry flag set
            	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts>`
            
            .. attribute:: topology_interface_flag_route_counts
            
            	Route count for topology with interface flag set
            	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts>`
            
            .. attribute:: topology_route_count
            
            	Topology route count information from PIM topology table
            	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyRouteCount>`
            
            .. attribute:: traffic_counters
            
            	PIM message traffic counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TrafficCounters>`
            
            .. attribute:: tunnels
            
            	Tunnels information that PIM has
            	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Ipv6Pim.Active.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"auto-rp" : ("auto_rp", Ipv6Pim.Active.DefaultContext.AutoRp), "bgp-afs" : ("bgp_afs", Ipv6Pim.Active.DefaultContext.BgpAfs), "bidir-df-states" : ("bidir_df_states", Ipv6Pim.Active.DefaultContext.BidirDfStates), "bidir-df-winners" : ("bidir_df_winners", Ipv6Pim.Active.DefaultContext.BidirDfWinners), "bsr" : ("bsr", Ipv6Pim.Active.DefaultContext.Bsr), "context" : ("context", Ipv6Pim.Active.DefaultContext.Context), "global-interfaces" : ("global_interfaces", Ipv6Pim.Active.DefaultContext.GlobalInterfaces), "gre" : ("gre", Ipv6Pim.Active.DefaultContext.Gre), "group-map-rpfs" : ("group_map_rpfs", Ipv6Pim.Active.DefaultContext.GroupMapRpfs), "group-map-sources" : ("group_map_sources", Ipv6Pim.Active.DefaultContext.GroupMapSources), "ifrs-interfaces" : ("ifrs_interfaces", Ipv6Pim.Active.DefaultContext.IfrsInterfaces), "ifrs-summary" : ("ifrs_summary", Ipv6Pim.Active.DefaultContext.IfrsSummary), "interface-old-formats" : ("interface_old_formats", Ipv6Pim.Active.DefaultContext.InterfaceOldFormats), "interface-statistics" : ("interface_statistics", Ipv6Pim.Active.DefaultContext.InterfaceStatistics), "interfaces" : ("interfaces", Ipv6Pim.Active.DefaultContext.Interfaces), "jp-statistics" : ("jp_statistics", Ipv6Pim.Active.DefaultContext.JpStatistics), "mib-databases" : ("mib_databases", Ipv6Pim.Active.DefaultContext.MibDatabases), "multicast-static-routes" : ("multicast_static_routes", Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes), "neighbor-old-formats" : ("neighbor_old_formats", Ipv6Pim.Active.DefaultContext.NeighborOldFormats), "neighbor-summaries" : ("neighbor_summaries", Ipv6Pim.Active.DefaultContext.NeighborSummaries), "neighbors" : ("neighbors", Ipv6Pim.Active.DefaultContext.Neighbors), "net-io-tunnels" : ("net_io_tunnels", Ipv6Pim.Active.DefaultContext.NetIoTunnels), "ranges" : ("ranges", Ipv6Pim.Active.DefaultContext.Ranges), "route-policy" : ("route_policy", Ipv6Pim.Active.DefaultContext.RoutePolicy), "rpf-redirect" : ("rpf_redirect", Ipv6Pim.Active.DefaultContext.RpfRedirect), "rpf-summary" : ("rpf_summary", Ipv6Pim.Active.DefaultContext.RpfSummary), "safs" : ("safs", Ipv6Pim.Active.DefaultContext.Safs), "summary" : ("summary", Ipv6Pim.Active.DefaultContext.Summary), "table-contexts" : ("table_contexts", Ipv6Pim.Active.DefaultContext.TableContexts), "topologies" : ("topologies", Ipv6Pim.Active.DefaultContext.Topologies), "topology-entry-flag-route-counts" : ("topology_entry_flag_route_counts", Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts), "topology-interface-flag-route-counts" : ("topology_interface_flag_route_counts", Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts), "topology-route-count" : ("topology_route_count", Ipv6Pim.Active.DefaultContext.TopologyRouteCount), "traffic-counters" : ("traffic_counters", Ipv6Pim.Active.DefaultContext.TrafficCounters), "tunnels" : ("tunnels", Ipv6Pim.Active.DefaultContext.Tunnels)}
                self._child_list_classes = {}

                self.auto_rp = Ipv6Pim.Active.DefaultContext.AutoRp()
                self.auto_rp.parent = self
                self._children_name_map["auto_rp"] = "auto-rp"
                self._children_yang_names.add("auto-rp")

                self.bgp_afs = Ipv6Pim.Active.DefaultContext.BgpAfs()
                self.bgp_afs.parent = self
                self._children_name_map["bgp_afs"] = "bgp-afs"
                self._children_yang_names.add("bgp-afs")

                self.bidir_df_states = Ipv6Pim.Active.DefaultContext.BidirDfStates()
                self.bidir_df_states.parent = self
                self._children_name_map["bidir_df_states"] = "bidir-df-states"
                self._children_yang_names.add("bidir-df-states")

                self.bidir_df_winners = Ipv6Pim.Active.DefaultContext.BidirDfWinners()
                self.bidir_df_winners.parent = self
                self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                self._children_yang_names.add("bidir-df-winners")

                self.bsr = Ipv6Pim.Active.DefaultContext.Bsr()
                self.bsr.parent = self
                self._children_name_map["bsr"] = "bsr"
                self._children_yang_names.add("bsr")

                self.context = Ipv6Pim.Active.DefaultContext.Context()
                self.context.parent = self
                self._children_name_map["context"] = "context"
                self._children_yang_names.add("context")

                self.global_interfaces = Ipv6Pim.Active.DefaultContext.GlobalInterfaces()
                self.global_interfaces.parent = self
                self._children_name_map["global_interfaces"] = "global-interfaces"
                self._children_yang_names.add("global-interfaces")

                self.gre = Ipv6Pim.Active.DefaultContext.Gre()
                self.gre.parent = self
                self._children_name_map["gre"] = "gre"
                self._children_yang_names.add("gre")

                self.group_map_rpfs = Ipv6Pim.Active.DefaultContext.GroupMapRpfs()
                self.group_map_rpfs.parent = self
                self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                self._children_yang_names.add("group-map-rpfs")

                self.group_map_sources = Ipv6Pim.Active.DefaultContext.GroupMapSources()
                self.group_map_sources.parent = self
                self._children_name_map["group_map_sources"] = "group-map-sources"
                self._children_yang_names.add("group-map-sources")

                self.ifrs_interfaces = Ipv6Pim.Active.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                self._children_yang_names.add("ifrs-interfaces")

                self.ifrs_summary = Ipv6Pim.Active.DefaultContext.IfrsSummary()
                self.ifrs_summary.parent = self
                self._children_name_map["ifrs_summary"] = "ifrs-summary"
                self._children_yang_names.add("ifrs-summary")

                self.interface_old_formats = Ipv6Pim.Active.DefaultContext.InterfaceOldFormats()
                self.interface_old_formats.parent = self
                self._children_name_map["interface_old_formats"] = "interface-old-formats"
                self._children_yang_names.add("interface-old-formats")

                self.interface_statistics = Ipv6Pim.Active.DefaultContext.InterfaceStatistics()
                self.interface_statistics.parent = self
                self._children_name_map["interface_statistics"] = "interface-statistics"
                self._children_yang_names.add("interface-statistics")

                self.interfaces = Ipv6Pim.Active.DefaultContext.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"
                self._children_yang_names.add("interfaces")

                self.jp_statistics = Ipv6Pim.Active.DefaultContext.JpStatistics()
                self.jp_statistics.parent = self
                self._children_name_map["jp_statistics"] = "jp-statistics"
                self._children_yang_names.add("jp-statistics")

                self.mib_databases = Ipv6Pim.Active.DefaultContext.MibDatabases()
                self.mib_databases.parent = self
                self._children_name_map["mib_databases"] = "mib-databases"
                self._children_yang_names.add("mib-databases")

                self.multicast_static_routes = Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes()
                self.multicast_static_routes.parent = self
                self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                self._children_yang_names.add("multicast-static-routes")

                self.neighbor_old_formats = Ipv6Pim.Active.DefaultContext.NeighborOldFormats()
                self.neighbor_old_formats.parent = self
                self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                self._children_yang_names.add("neighbor-old-formats")

                self.neighbor_summaries = Ipv6Pim.Active.DefaultContext.NeighborSummaries()
                self.neighbor_summaries.parent = self
                self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                self._children_yang_names.add("neighbor-summaries")

                self.neighbors = Ipv6Pim.Active.DefaultContext.Neighbors()
                self.neighbors.parent = self
                self._children_name_map["neighbors"] = "neighbors"
                self._children_yang_names.add("neighbors")

                self.net_io_tunnels = Ipv6Pim.Active.DefaultContext.NetIoTunnels()
                self.net_io_tunnels.parent = self
                self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                self._children_yang_names.add("net-io-tunnels")

                self.ranges = Ipv6Pim.Active.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"
                self._children_yang_names.add("ranges")

                self.route_policy = Ipv6Pim.Active.DefaultContext.RoutePolicy()
                self.route_policy.parent = self
                self._children_name_map["route_policy"] = "route-policy"
                self._children_yang_names.add("route-policy")

                self.rpf_redirect = Ipv6Pim.Active.DefaultContext.RpfRedirect()
                self.rpf_redirect.parent = self
                self._children_name_map["rpf_redirect"] = "rpf-redirect"
                self._children_yang_names.add("rpf-redirect")

                self.rpf_summary = Ipv6Pim.Active.DefaultContext.RpfSummary()
                self.rpf_summary.parent = self
                self._children_name_map["rpf_summary"] = "rpf-summary"
                self._children_yang_names.add("rpf-summary")

                self.safs = Ipv6Pim.Active.DefaultContext.Safs()
                self.safs.parent = self
                self._children_name_map["safs"] = "safs"
                self._children_yang_names.add("safs")

                self.summary = Ipv6Pim.Active.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.table_contexts = Ipv6Pim.Active.DefaultContext.TableContexts()
                self.table_contexts.parent = self
                self._children_name_map["table_contexts"] = "table-contexts"
                self._children_yang_names.add("table-contexts")

                self.topologies = Ipv6Pim.Active.DefaultContext.Topologies()
                self.topologies.parent = self
                self._children_name_map["topologies"] = "topologies"
                self._children_yang_names.add("topologies")

                self.topology_entry_flag_route_counts = Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts()
                self.topology_entry_flag_route_counts.parent = self
                self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                self._children_yang_names.add("topology-entry-flag-route-counts")

                self.topology_interface_flag_route_counts = Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts()
                self.topology_interface_flag_route_counts.parent = self
                self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                self._children_yang_names.add("topology-interface-flag-route-counts")

                self.topology_route_count = Ipv6Pim.Active.DefaultContext.TopologyRouteCount()
                self.topology_route_count.parent = self
                self._children_name_map["topology_route_count"] = "topology-route-count"
                self._children_yang_names.add("topology-route-count")

                self.traffic_counters = Ipv6Pim.Active.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"
                self._children_yang_names.add("traffic-counters")

                self.tunnels = Ipv6Pim.Active.DefaultContext.Tunnels()
                self.tunnels.parent = self
                self._children_name_map["tunnels"] = "tunnels"
                self._children_yang_names.add("tunnels")
                self._segment_path = lambda: "default-context"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/%s" % self._segment_path()


            class AutoRp(Entity):
                """
                PIM Auto\-RP information
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.AutoRp, self).__init__()

                    self.yang_name = "auto-rp"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self._segment_path = lambda: "auto-rp"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()


            class BgpAfs(Entity):
                """
                PIM BGP SAFI table
                
                .. attribute:: bgp_af
                
                	PIM BGP SAFI information
                	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.BgpAfs, self).__init__()

                    self.yang_name = "bgp-afs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"bgp-af" : ("bgp_af", Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf)}

                    self.bgp_af = YList(self)
                    self._segment_path = lambda: "bgp-afs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.BgpAfs, [], name, value)


                class BgpAf(Entity):
                    """
                    PIM BGP SAFI information
                    
                    .. attribute:: extranet_path_count
                    
                    	Count of dependent extranet paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group
                    
                    	Group address
                    	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group>`
                    
                    .. attribute:: group_address
                    
                    	Group IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: is_bgp_added
                    
                    	SAFI learnt from BGP
                    	**type**\:  bool
                    
                    .. attribute:: next_hop
                    
                    	Next hop address
                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop>`
                    
                    .. attribute:: route_distinguisher
                    
                    	Router ID
                    	**type**\:  str
                    
                    	**length:** 0..256
                    
                    .. attribute:: source
                    
                    	Source address
                    	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf, self).__init__()

                        self.yang_name = "bgp-af"
                        self.yang_parent_name = "bgp-afs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group" : ("group", Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group), "next-hop" : ("next_hop", Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop), "source" : ("source", Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source)}
                        self._child_list_classes = {}

                        self.extranet_path_count = YLeaf(YType.uint32, "extranet-path-count")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.is_bgp_added = YLeaf(YType.boolean, "is-bgp-added")

                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group = Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group()
                        self.group.parent = self
                        self._children_name_map["group"] = "group"
                        self._children_yang_names.add("group")

                        self.next_hop = Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._children_yang_names.add("next-hop")

                        self.source = Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"
                        self._children_yang_names.add("source")
                        self._segment_path = lambda: "bgp-af"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bgp-afs/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf, ['extranet_path_count', 'group_address', 'is_bgp_added', 'route_distinguisher', 'source_address'], name, value)


                    class Group(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bgp-afs/bgp-af/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class NextHop(Entity):
                        """
                        Next hop address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "next-hop"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bgp-afs/bgp-af/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Source(Entity):
                        """
                        Source address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bgp-afs/bgp-af/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class BidirDfStates(Entity):
                """
                Bidirectional PIM DF election state table
                
                .. attribute:: bidir_df_state
                
                	Bidirectional PIM DF Election Table Entry
                	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.BidirDfStates, self).__init__()

                    self.yang_name = "bidir-df-states"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"bidir-df-state" : ("bidir_df_state", Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState)}

                    self.bidir_df_state = YList(self)
                    self._segment_path = lambda: "bidir-df-states"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.BidirDfStates, [], name, value)


                class BidirDfState(Entity):
                    """
                    Bidirectional PIM DF Election Table Entry
                    
                    .. attribute:: election_state
                    
                    	DF Election State
                    	**type**\:  str
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: our_metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: our_metric_preference
                    
                    	MetricPreference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr>`
                    
                    .. attribute:: time_nano_seconds
                    
                    	Timer expires (nseconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: time_seconds
                    
                    	Timer expires (seconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState, self).__init__()

                        self.yang_name = "bidir-df-state"
                        self.yang_parent_name = "bidir-df-states"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rp-address-xr" : ("rp_address_xr", Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr)}
                        self._child_list_classes = {}

                        self.election_state = YLeaf(YType.str, "election-state")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.our_metric = YLeaf(YType.uint32, "our-metric")

                        self.our_metric_preference = YLeaf(YType.uint32, "our-metric-preference")

                        self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.time_nano_seconds = YLeaf(YType.uint64, "time-nano-seconds")

                        self.time_seconds = YLeaf(YType.uint64, "time-seconds")

                        self.rp_address_xr = Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")
                        self._segment_path = lambda: "bidir-df-state"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bidir-df-states/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState, ['election_state', 'interface_name', 'our_metric', 'our_metric_preference', 'pim_interface_name', 'rp_address', 'time_nano_seconds', 'time_seconds'], name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-state"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bidir-df-states/bidir-df-state/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class BidirDfWinners(Entity):
                """
                Bidirectional PIM DF election winner table
                
                .. attribute:: bidir_df_winner
                
                	Bidirectional PIM DF election table entry
                	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.BidirDfWinners, self).__init__()

                    self.yang_name = "bidir-df-winners"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"bidir-df-winner" : ("bidir_df_winner", Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner)}

                    self.bidir_df_winner = YList(self)
                    self._segment_path = lambda: "bidir-df-winners"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.BidirDfWinners, [], name, value)


                class BidirDfWinner(Entity):
                    """
                    Bidirectional PIM DF election table entry
                    
                    .. attribute:: are_we_df
                    
                    	Are we DF
                    	**type**\:  bool
                    
                    .. attribute:: df_winner
                    
                    	DF Winner
                    	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner>`
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_preference
                    
                    	Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                    
                    .. attribute:: rp_lan
                    
                    	Is this the RP LAN
                    	**type**\:  bool
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner, self).__init__()

                        self.yang_name = "bidir-df-winner"
                        self.yang_parent_name = "bidir-df-winners"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"df-winner" : ("df_winner", Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner), "rp-address-xr" : ("rp_address_xr", Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr)}
                        self._child_list_classes = {}

                        self.are_we_df = YLeaf(YType.boolean, "are-we-df")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.metric = YLeaf(YType.uint32, "metric")

                        self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                        self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_lan = YLeaf(YType.boolean, "rp-lan")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.df_winner = Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                        self.df_winner.parent = self
                        self._children_name_map["df_winner"] = "df-winner"
                        self._children_yang_names.add("df-winner")

                        self.rp_address_xr = Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")
                        self._segment_path = lambda: "bidir-df-winner"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bidir-df-winners/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner, ['are_we_df', 'interface_name', 'metric', 'metric_preference', 'pim_interface_name', 'rp_address', 'rp_lan', 'uptime'], name, value)


                    class DfWinner(Entity):
                        """
                        DF Winner
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                            self.yang_name = "df-winner"
                            self.yang_parent_name = "bidir-df-winner"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "df-winner"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bidir-df-winners/bidir-df-winner/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-winner"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bidir-df-winners/bidir-df-winner/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Bsr(Entity):
                """
                PIM BSR information
                
                .. attribute:: bsr_elections
                
                	PIM BSR election state
                	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.BsrElections>`
                
                .. attribute:: candidate_rps
                
                	PIM candidate\-RP
                	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps>`
                
                .. attribute:: rp_caches
                
                	PIM BSR RP cache table
                	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Bsr, self).__init__()

                    self.yang_name = "bsr"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"bsr-elections" : ("bsr_elections", Ipv6Pim.Active.DefaultContext.Bsr.BsrElections), "candidate-rps" : ("candidate_rps", Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps), "rp-caches" : ("rp_caches", Ipv6Pim.Active.DefaultContext.Bsr.RpCaches)}
                    self._child_list_classes = {}

                    self.bsr_elections = Ipv6Pim.Active.DefaultContext.Bsr.BsrElections()
                    self.bsr_elections.parent = self
                    self._children_name_map["bsr_elections"] = "bsr-elections"
                    self._children_yang_names.add("bsr-elections")

                    self.candidate_rps = Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps()
                    self.candidate_rps.parent = self
                    self._children_name_map["candidate_rps"] = "candidate-rps"
                    self._children_yang_names.add("candidate-rps")

                    self.rp_caches = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches()
                    self.rp_caches.parent = self
                    self._children_name_map["rp_caches"] = "rp-caches"
                    self._children_yang_names.add("rp-caches")
                    self._segment_path = lambda: "bsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()


                class BsrElections(Entity):
                    """
                    PIM BSR election state
                    
                    .. attribute:: bsr_election
                    
                    	PIM BSR information
                    	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections, self).__init__()

                        self.yang_name = "bsr-elections"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"bsr-election" : ("bsr_election", Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection)}

                        self.bsr_election = YList(self)
                        self._segment_path = lambda: "bsr-elections"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bsr/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections, [], name, value)


                    class BsrElection(Entity):
                        """
                        PIM BSR information
                        
                        .. attribute:: pim_scope  <key>
                        
                        	BSR information
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: bootstrap_timeout
                        
                        	Bootstrap Timeout
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_address
                        
                        	BSR address
                        	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress>`
                        
                        .. attribute:: bsr_election_state
                        
                        	BSR Election State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_mask_length
                        
                        	Hash Function Mask Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_priority
                        
                        	BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_scope
                        
                        	BSR Scope
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_up_time
                        
                        	BSR Uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_address
                        
                        	C\-BSR address
                        	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                        
                        .. attribute:: candidate_bsr_flag
                        
                        	BSR Candidate Config Flag
                        	**type**\:  bool
                        
                        .. attribute:: candidate_bsr_mask_length
                        
                        	C\-BSR Hash Func. Mask Len
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_priority
                        
                        	C\-BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_state
                        
                        	BSR Candidate State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection, self).__init__()

                            self.yang_name = "bsr-election"
                            self.yang_parent_name = "bsr-elections"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"bsr-address" : ("bsr_address", Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress), "candidate-bsr-address" : ("candidate_bsr_address", Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress)}
                            self._child_list_classes = {}

                            self.pim_scope = YLeaf(YType.int32, "pim-scope")

                            self.bootstrap_timeout = YLeaf(YType.uint16, "bootstrap-timeout")

                            self.bsr_election_state = YLeaf(YType.uint32, "bsr-election-state")

                            self.bsr_mask_length = YLeaf(YType.uint8, "bsr-mask-length")

                            self.bsr_priority = YLeaf(YType.uint8, "bsr-priority")

                            self.bsr_scope = YLeaf(YType.uint16, "bsr-scope")

                            self.bsr_up_time = YLeaf(YType.uint16, "bsr-up-time")

                            self.candidate_bsr_flag = YLeaf(YType.boolean, "candidate-bsr-flag")

                            self.candidate_bsr_mask_length = YLeaf(YType.uint8, "candidate-bsr-mask-length")

                            self.candidate_bsr_priority = YLeaf(YType.uint8, "candidate-bsr-priority")

                            self.candidate_bsr_state = YLeaf(YType.uint32, "candidate-bsr-state")

                            self.bsr_address = Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                            self.bsr_address.parent = self
                            self._children_name_map["bsr_address"] = "bsr-address"
                            self._children_yang_names.add("bsr-address")

                            self.candidate_bsr_address = Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                            self.candidate_bsr_address.parent = self
                            self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                            self._children_yang_names.add("candidate-bsr-address")
                            self._segment_path = lambda: "bsr-election" + "[pim-scope='" + self.pim_scope.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bsr/bsr-elections/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection, ['pim_scope', 'bootstrap_timeout', 'bsr_election_state', 'bsr_mask_length', 'bsr_priority', 'bsr_scope', 'bsr_up_time', 'candidate_bsr_flag', 'candidate_bsr_mask_length', 'candidate_bsr_priority', 'candidate_bsr_state'], name, value)


                        class BsrAddress(Entity):
                            """
                            BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                self.yang_name = "bsr-address"
                                self.yang_parent_name = "bsr-election"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "bsr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class CandidateBsrAddress(Entity):
                            """
                            C\-BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                self.yang_name = "candidate-bsr-address"
                                self.yang_parent_name = "bsr-election"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "candidate-bsr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class CandidateRps(Entity):
                    """
                    PIM candidate\-RP
                    
                    .. attribute:: candidate_rp
                    
                    	PIM BSR candidate RP information
                    	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps, self).__init__()

                        self.yang_name = "candidate-rps"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"candidate-rp" : ("candidate_rp", Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp)}

                        self.candidate_rp = YList(self)
                        self._segment_path = lambda: "candidate-rps"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bsr/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps, [], name, value)


                    class CandidateRp(Entity):
                        """
                        PIM BSR candidate RP information
                        
                        .. attribute:: rp_address  <key>
                        
                        	Candidate\-RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: acl_name
                        
                        	Group Access\-List Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: candidate_rp
                        
                        	Cand\-RP Address
                        	**type**\:   :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp>`
                        
                        .. attribute:: candidate_rp_advance_interval
                        
                        	Cand\-RP Adv Interval in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: candidate_rp_mode
                        
                        	Cand\-RP Mode
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: candidate_rp_scope
                        
                        	Cand\-RP Scope
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: candidate_rp_uptime
                        
                        	Cand\-RP uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_access
                        
                        	Group Ranges Using this Cand\-RP
                        	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                        
                        .. attribute:: crp_holdtime
                        
                        	Cand\-RP Holdtime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_priority
                        
                        	Cand\-RP Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__init__()

                            self.yang_name = "candidate-rp"
                            self.yang_parent_name = "candidate-rps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"candidate-rp" : ("candidate_rp", Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp)}
                            self._child_list_classes = {"crp-access" : ("crp_access", Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess)}

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.acl_name = YLeaf(YType.str, "acl-name")

                            self.candidate_rp_advance_interval = YLeaf(YType.uint16, "candidate-rp-advance-interval")

                            self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                            self.candidate_rp_scope = YLeaf(YType.int32, "candidate-rp-scope")

                            self.candidate_rp_uptime = YLeaf(YType.uint16, "candidate-rp-uptime")

                            self.crp_holdtime = YLeaf(YType.uint16, "crp-holdtime")

                            self.crp_priority = YLeaf(YType.uint8, "crp-priority")

                            self.candidate_rp = Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp()
                            self.candidate_rp.parent = self
                            self._children_name_map["candidate_rp"] = "candidate-rp"
                            self._children_yang_names.add("candidate-rp")

                            self.crp_access = YList(self)
                            self._segment_path = lambda: "candidate-rp" + "[rp-address='" + self.rp_address.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bsr/candidate-rps/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp, ['rp_address', 'acl_name', 'candidate_rp_advance_interval', 'candidate_rp_mode', 'candidate_rp_scope', 'candidate_rp_uptime', 'crp_holdtime', 'crp_priority'], name, value)


                        class CandidateRp(Entity):
                            """
                            Cand\-RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "candidate-rp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class CrpAccess(Entity):
                            """
                            Group Ranges Using this Cand\-RP
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                self.yang_name = "crp-access"
                                self.yang_parent_name = "candidate-rp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.acl_name = YLeaf(YType.str, "acl-name")

                                self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")
                                self._segment_path = lambda: "crp-access"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, ['acl_name', 'candidate_rp_mode'], name, value)


                class RpCaches(Entity):
                    """
                    PIM BSR RP cache table
                    
                    .. attribute:: rp_cache
                    
                    	PIM BSR RP cache
                    	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches, self).__init__()

                        self.yang_name = "rp-caches"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"rp-cache" : ("rp_cache", Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache)}

                        self.rp_cache = YList(self)
                        self._segment_path = lambda: "rp-caches"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bsr/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches, [], name, value)


                    class RpCache(Entity):
                        """
                        PIM BSR RP cache
                        
                        .. attribute:: group_prefix  <key>
                        
                        	Group prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: candidate_rp_group_count
                        
                        	C\-RP count for this Prefix
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: candidate_rp_list
                        
                        	C\-RP list for this prefix
                        	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList>`
                        
                        .. attribute:: group_prefix_length
                        
                        	Group Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_prefix_xr
                        
                        	Group Prefix
                        	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache, self).__init__()

                            self.yang_name = "rp-cache"
                            self.yang_parent_name = "rp-caches"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"candidate-rp-list" : ("candidate_rp_list", Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList), "group-prefix-xr" : ("group_prefix_xr", Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr)}
                            self._child_list_classes = {}

                            self.group_prefix = YLeaf(YType.str, "group-prefix")

                            self.candidate_rp_group_count = YLeaf(YType.uint32, "candidate-rp-group-count")

                            self.group_prefix_length = YLeaf(YType.uint32, "group-prefix-length")

                            self.candidate_rp_list = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                            self.candidate_rp_list.parent = self
                            self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                            self._children_yang_names.add("candidate-rp-list")

                            self.group_prefix_xr = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                            self.group_prefix_xr.parent = self
                            self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                            self._children_yang_names.add("group-prefix-xr")
                            self._segment_path = lambda: "rp-cache" + "[group-prefix='" + self.group_prefix.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bsr/rp-caches/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache, ['group_prefix', 'candidate_rp_group_count', 'group_prefix_length'], name, value)


                        class CandidateRpList(Entity):
                            """
                            C\-RP list for this prefix
                            
                            .. attribute:: pim_bsr_crp_bag
                            
                            	pim bsr crp bag
                            	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                self.yang_name = "candidate-rp-list"
                                self.yang_parent_name = "rp-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"pim-bsr-crp-bag" : ("pim_bsr_crp_bag", Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag)}

                                self.pim_bsr_crp_bag = YList(self)
                                self._segment_path = lambda: "candidate-rp-list"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, [], name, value)


                            class PimBsrCrpBag(Entity):
                                """
                                pim bsr crp bag
                                
                                .. attribute:: candidate_rp_address
                                
                                	C\-RP address
                                	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                
                                .. attribute:: candidate_rp_expires
                                
                                	C\-RP Expires
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_holdtime
                                
                                	C\-RP Holdtime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_priority
                                
                                	C\-RP Priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: candidate_rp_up_time
                                
                                	C\-RP Uptime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: protocol
                                
                                	PIM Protocol
                                	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                    self.yang_name = "pim-bsr-crp-bag"
                                    self.yang_parent_name = "candidate-rp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"candidate-rp-address" : ("candidate_rp_address", Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress)}
                                    self._child_list_classes = {}

                                    self.candidate_rp_expires = YLeaf(YType.uint16, "candidate-rp-expires")

                                    self.candidate_rp_holdtime = YLeaf(YType.uint16, "candidate-rp-holdtime")

                                    self.candidate_rp_priority = YLeaf(YType.uint8, "candidate-rp-priority")

                                    self.candidate_rp_up_time = YLeaf(YType.uint16, "candidate-rp-up-time")

                                    self.protocol = YLeaf(YType.enumeration, "protocol")

                                    self.candidate_rp_address = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                    self.candidate_rp_address.parent = self
                                    self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                    self._children_yang_names.add("candidate-rp-address")
                                    self._segment_path = lambda: "pim-bsr-crp-bag"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, ['candidate_rp_expires', 'candidate_rp_holdtime', 'candidate_rp_priority', 'candidate_rp_up_time', 'protocol'], name, value)


                                class CandidateRpAddress(Entity):
                                    """
                                    C\-RP address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                        self.yang_name = "candidate-rp-address"
                                        self.yang_parent_name = "pim-bsr-crp-bag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "candidate-rp-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class GroupPrefixXr(Entity):
                            """
                            Group Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                self.yang_name = "group-prefix-xr"
                                self.yang_parent_name = "rp-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-prefix-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Context(Entity):
                """
                PIM context information
                
                .. attribute:: active_table_count
                
                	Number of active Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: allow_rp_configured
                
                	Allow RP Configured
                	**type**\:  bool
                
                .. attribute:: allow_rp_group_list
                
                	Allow RP Group\-List ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: allow_rp_rp_list
                
                	Allow RP RP\-list ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: anycast_rp_configured
                
                	Anycast\-RP config
                	**type**\:  bool
                
                .. attribute:: anycast_rp_policy_name
                
                	Anycast\-RP Policy Name
                	**type**\:  str
                
                .. attribute:: anycast_rp_range
                
                	Anycast\-RP Ranges
                	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange>`
                
                .. attribute:: bgp_auto_discovery_configured
                
                	BGP Auto\-Discovery configured
                	**type**\:  bool
                
                .. attribute:: bgp_auto_discovery_type
                
                	BGP Auto Discovery Type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_i_pmsi_added
                
                	BGP I\-PMSI Added
                	**type**\:  bool
                
                .. attribute:: bgp_remote_address
                
                	BGP remote interface address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: bgp_remote_interface
                
                	BGP remote interface handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: bgp_remote_interface_name
                
                	BGP remote interface name
                	**type**\:  str
                
                .. attribute:: bgp_remote_on
                
                	BGP remote interface status
                	**type**\:  bool
                
                .. attribute:: bgp_remote_state
                
                	BGP remote interface state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_source_active_announce
                
                	Send BGP Source\-Active Announcements
                	**type**\:  bool
                
                .. attribute:: export_route_target
                
                	Export Route Targets
                	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.ExportRouteTarget>`
                
                .. attribute:: gin_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: gin_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: gin_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: import_route_target
                
                	Import Route Targets
                	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.ImportRouteTarget>`
                
                .. attribute:: in_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: in_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: in_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_signaling_local_enabled
                
                	Inband signaling Local enabled
                	**type**\:  bool
                
                .. attribute:: in_band_signaling_remote_enabled
                
                	Inband signaling Remote enabled
                	**type**\:  bool
                
                .. attribute:: inter_autonomous_system_enabled
                
                	Inter\-AS Enabled
                	**type**\:  bool
                
                .. attribute:: ir_maximum_mdt_aggregation
                
                	IR MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_announce_interval
                
                	IR Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_switchover_interval
                
                	IR Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_interface
                
                	IRMDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: ir_mdt_mtu
                
                	IRMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_name
                
                	IR MDT Name
                	**type**\:  str
                
                .. attribute:: ir_mdt_rpf_identifier
                
                	IR RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_tail_label
                
                	IR Tail Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_active
                
                	Active
                	**type**\:  bool
                
                .. attribute:: is_active_ital
                
                	Active ITAL
                	**type**\:  bool
                
                .. attribute:: is_all_interface_disable_operation
                
                	PIM all interface disable operation
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_enabled
                
                	Auto RP Listen Enabled
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_sock_add
                
                	Auto RP listen sock add
                	**type**\:  bool
                
                .. attribute:: is_create_gin_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_in_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_ir_mdt_interface
                
                	Create IR MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mdt_interface
                
                	Create MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mldp_mdt_interface
                
                	Create MLDP MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_rsvp_te_mdt_interface
                
                	Create RSVP\-TE MDT interface
                	**type**\:  bool
                
                .. attribute:: is_default_granges
                
                	Default granges
                	**type**\:  bool
                
                .. attribute:: is_gin_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_in_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_ir_mdt_owner
                
                	IR MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_add_required
                
                	VRF LPTS filter required on Socket
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_added
                
                	VRF LPTS filter added on Socket
                	**type**\:  bool
                
                .. attribute:: is_m_host_publish_pending
                
                	Publish pending for MHost Default interface
                	**type**\:  bool
                
                .. attribute:: is_mdt_owner
                
                	MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mldp_mdt_owner
                
                	MLDP MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mrib_register
                
                	MRIB Register
                	**type**\:  bool
                
                .. attribute:: is_multicast_rib_registration
                
                	Mcast RIB Registration
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converge_received
                
                	PIM NSF RIB converge received
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converged
                
                	PIM NSF RIB converged
                	**type**\:  bool
                
                .. attribute:: is_redistribution_reset
                
                	Pending redist reset
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_add_required
                
                	VRF LPTS filter required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_added
                
                	VRF LPTS filter added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_add_required
                
                	VRF required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_added
                
                	VRF added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_enabled
                
                	PIM RIB multiplath enabled
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_interface_hash
                
                	PIM RIB multipath interface hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_hash
                
                	PIM RIB multipath source based hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_next_hop_hash
                
                	PIM RIB multipath source\-nexthop hash
                	**type**\:  bool
                
                .. attribute:: is_routing_enabled
                
                	Routing Enabled
                	**type**\:  bool
                
                .. attribute:: is_rsvp_te_mdt_owner
                
                	RSVP\-TE MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_socket_add_required
                
                	VRF required on Socket
                	**type**\:  bool
                
                .. attribute:: is_socket_added
                
                	VRF added on Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_add_required
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_added
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind
                
                	VRF bound on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind_required
                
                	VRF bind required on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_unicast_rib_registration
                
                	Ucast RIB Registration
                	**type**\:  bool
                
                .. attribute:: maximum_mdt_aggregation
                
                	MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_announce_interval
                
                	Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_switchover_interval
                
                	Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_default_group
                
                	MDT Default group
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_gre_remote_rpf_identifier
                
                	GRE\-MDT Remote RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_gre_rpf_identifier
                
                	GRE\-MDT RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_immediate_switch
                
                	MDT Immediate Switch
                	**type**\:  bool
                
                .. attribute:: mdt_interface
                
                	MDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: mdt_mtu
                
                	MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_neighbor_filter_name
                
                	MDT Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: mdt_partitioned_ir_control_identifier
                
                	Partitioned IR MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_mdt_control_identifier
                
                	Partitioned MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_source
                
                	MDT source
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_source_interface
                
                	MDT Source Interface Name
                	**type**\:  str
                
                .. attribute:: mhost_default_interface_config
                
                	Configured Mhost Defint
                	**type**\:  str
                
                .. attribute:: mhost_interface
                
                	MHost handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: mldp_auto_rp_announce_tree_added
                
                	MLDP Autorp Announce Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_auto_rp_discovery_tree_added
                
                	MLDP Autorp Discovery Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_bsr_control_tree_added
                
                	MLDP BSR Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_control_head_lsm_identifier
                
                	MLDP MVPN Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_local_label
                
                	Partitioned MDT Head local label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_lsm_identifier
                
                	MLDP Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_maximum_mdt_aggregation
                
                	MLDP MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_announce_interval
                
                	MLDP Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_switchover_interval
                
                	MLDP Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_interface
                
                	MLDP MDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: mldp_mdt_mtu
                
                	MLDP MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_name
                
                	MLDP MDT Name
                	**type**\:  str
                
                .. attribute:: mldp_mdt_remote_rpf_identifier
                
                	MLDP Remote RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_rpf_identifier
                
                	MLDP RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partioned_mp2m_ptree
                
                	MP2MP Partitioned MDT tree
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_head_lsm_identifier
                
                	Partitioned MDT Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_configured
                
                	MLDP Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_mdt_identifier
                
                	MLDP Partitioned MDT Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_head_lsm_identifier
                
                	MLDP Remote Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_partitioned_mdt_configured
                
                	MLDP Remote Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_root_address
                
                	MLDP Root addresses
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_root_count
                
                	MLDP Root count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: murib_id
                
                	MURIB ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_filter_name
                
                	Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: non_default_vrf_count_on_socket
                
                	Count of non\-default vrfs on raw socket
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: organization_unique_identifier
                
                	OUI for VPN\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mpte_li_drop
                
                	Route LI updates dropped for P2MP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: physical_interface_count
                
                	Enabled Physical Interface Count
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: redistribution_reset_count
                
                	Redist reset count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_default_group
                
                	Remote Default Group
                	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup>`
                
                .. attribute:: remote_table_id
                
                	Remote Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_distinguisher
                
                	RD value
                	**type**\:  str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: rpf_default_table
                
                	RPF Default Table
                	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable>`
                
                .. attribute:: rpf_id
                
                	RPF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_policy_name
                
                	RPF topology selection route\-policy name
                	**type**\:  str
                
                .. attribute:: rsvp_te_maximum_mdt_aggregation
                
                	RSVP\-TE MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_announce_interval
                
                	RSVP\-TE Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_switchover_interval
                
                	RSVP\-TE Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_interface
                
                	RSVP\-TEMDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: rsvp_te_mdt_mtu
                
                	RSVP\-TEMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_name
                
                	RSVP\-TE MDT Name
                	**type**\:  str
                
                .. attribute:: rsvp_te_mdt_rpf_identifier
                
                	RSVP\-TE RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_static_p2mp_count
                
                	Number of Static P2MP\-TE MDT
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	PIM is using MuRIB
                	**type**\:  bool
                
                .. attribute:: sg_expiry_time
                
                	S,G Expiry Time Configured, in seconds
                	**type**\:  int
                
                	**range:** 0..65535
                
                	**units**\: second
                
                .. attribute:: sg_expiry_timer_configured
                
                	S,G Expiry Timer Configured
                	**type**\:  bool
                
                .. attribute:: sg_expiry_timer_sg_list
                
                	S,G expiry timer ACL name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: stale_rd_present
                
                	RD is stale
                	**type**\:  bool
                
                .. attribute:: suppress_pim_data_mdt_tlv
                
                	Suppress PIM Data\-MDT TLV Announcements
                	**type**\:  bool
                
                .. attribute:: suppress_shared_tree_join
                
                	Suppress Shared\-Tree Joins
                	**type**\:  bool
                
                .. attribute:: table_count
                
                	Number of configured Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_id
                
                	Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: umh
                
                	Join UMH Core\-Tree
                	**type**\:  bool
                
                .. attribute:: valid_rd_present
                
                	RD is valid
                	**type**\:  bool
                
                .. attribute:: virtual_interface_count
                
                	Enabled Virtual Interface Count
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: virtual_mlc_interface_name
                
                	Virtual master line card Interface
                	**type**\:  str
                
                .. attribute:: vpn_index
                
                	VPN Index
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf_id
                
                	VRF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Context, self).__init__()

                    self.yang_name = "context"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"remote-default-group" : ("remote_default_group", Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup), "rpf-default-table" : ("rpf_default_table", Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable)}
                    self._child_list_classes = {"anycast-rp-range" : ("anycast_rp_range", Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange), "export-route-target" : ("export_route_target", Ipv6Pim.Active.DefaultContext.Context.ExportRouteTarget), "import-route-target" : ("import_route_target", Ipv6Pim.Active.DefaultContext.Context.ImportRouteTarget)}

                    self.active_table_count = YLeaf(YType.uint32, "active-table-count")

                    self.allow_rp_configured = YLeaf(YType.boolean, "allow-rp-configured")

                    self.allow_rp_group_list = YLeaf(YType.str, "allow-rp-group-list")

                    self.allow_rp_rp_list = YLeaf(YType.str, "allow-rp-rp-list")

                    self.anycast_rp_configured = YLeaf(YType.boolean, "anycast-rp-configured")

                    self.anycast_rp_policy_name = YLeaf(YType.str, "anycast-rp-policy-name")

                    self.bgp_auto_discovery_configured = YLeaf(YType.boolean, "bgp-auto-discovery-configured")

                    self.bgp_auto_discovery_type = YLeaf(YType.uint32, "bgp-auto-discovery-type")

                    self.bgp_i_pmsi_added = YLeaf(YType.boolean, "bgp-i-pmsi-added")

                    self.bgp_remote_address = YLeaf(YType.str, "bgp-remote-address")

                    self.bgp_remote_interface = YLeaf(YType.str, "bgp-remote-interface")

                    self.bgp_remote_interface_name = YLeaf(YType.str, "bgp-remote-interface-name")

                    self.bgp_remote_on = YLeaf(YType.boolean, "bgp-remote-on")

                    self.bgp_remote_state = YLeaf(YType.uint32, "bgp-remote-state")

                    self.bgp_source_active_announce = YLeaf(YType.boolean, "bgp-source-active-announce")

                    self.gin_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-announce-interval")

                    self.gin_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-switchover-interval")

                    self.gin_b_and_mdt_interface = YLeaf(YType.str, "gin-b-and-mdt-interface")

                    self.gin_b_and_mdt_mtu = YLeaf(YType.uint32, "gin-b-and-mdt-mtu")

                    self.gin_b_and_mdt_name = YLeaf(YType.str, "gin-b-and-mdt-name")

                    self.gin_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "gin-b-and-mdt-rpf-identifier")

                    self.gin_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "gin-band-maximum-mdt-aggregation")

                    self.in_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-announce-interval")

                    self.in_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-switchover-interval")

                    self.in_b_and_mdt_interface = YLeaf(YType.str, "in-b-and-mdt-interface")

                    self.in_b_and_mdt_mtu = YLeaf(YType.uint32, "in-b-and-mdt-mtu")

                    self.in_b_and_mdt_name = YLeaf(YType.str, "in-b-and-mdt-name")

                    self.in_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "in-b-and-mdt-rpf-identifier")

                    self.in_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "in-band-maximum-mdt-aggregation")

                    self.in_band_signaling_local_enabled = YLeaf(YType.boolean, "in-band-signaling-local-enabled")

                    self.in_band_signaling_remote_enabled = YLeaf(YType.boolean, "in-band-signaling-remote-enabled")

                    self.inter_autonomous_system_enabled = YLeaf(YType.boolean, "inter-autonomous-system-enabled")

                    self.ir_maximum_mdt_aggregation = YLeaf(YType.uint32, "ir-maximum-mdt-aggregation")

                    self.ir_mdt_data_announce_interval = YLeaf(YType.uint32, "ir-mdt-data-announce-interval")

                    self.ir_mdt_data_switchover_interval = YLeaf(YType.uint32, "ir-mdt-data-switchover-interval")

                    self.ir_mdt_interface = YLeaf(YType.str, "ir-mdt-interface")

                    self.ir_mdt_mtu = YLeaf(YType.uint32, "ir-mdt-mtu")

                    self.ir_mdt_name = YLeaf(YType.str, "ir-mdt-name")

                    self.ir_mdt_rpf_identifier = YLeaf(YType.uint32, "ir-mdt-rpf-identifier")

                    self.ir_mdt_tail_label = YLeaf(YType.uint32, "ir-mdt-tail-label")

                    self.is_active = YLeaf(YType.boolean, "is-active")

                    self.is_active_ital = YLeaf(YType.boolean, "is-active-ital")

                    self.is_all_interface_disable_operation = YLeaf(YType.boolean, "is-all-interface-disable-operation")

                    self.is_auto_rp_listen_enabled = YLeaf(YType.boolean, "is-auto-rp-listen-enabled")

                    self.is_auto_rp_listen_sock_add = YLeaf(YType.boolean, "is-auto-rp-listen-sock-add")

                    self.is_create_gin_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-gin-b-and-mdt-interface")

                    self.is_create_in_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-in-b-and-mdt-interface")

                    self.is_create_ir_mdt_interface = YLeaf(YType.boolean, "is-create-ir-mdt-interface")

                    self.is_create_mdt_interface = YLeaf(YType.boolean, "is-create-mdt-interface")

                    self.is_create_mldp_mdt_interface = YLeaf(YType.boolean, "is-create-mldp-mdt-interface")

                    self.is_create_rsvp_te_mdt_interface = YLeaf(YType.boolean, "is-create-rsvp-te-mdt-interface")

                    self.is_default_granges = YLeaf(YType.boolean, "is-default-granges")

                    self.is_gin_b_and_mdt_owner = YLeaf(YType.boolean, "is-gin-b-and-mdt-owner")

                    self.is_in_b_and_mdt_owner = YLeaf(YType.boolean, "is-in-b-and-mdt-owner")

                    self.is_ir_mdt_owner = YLeaf(YType.boolean, "is-ir-mdt-owner")

                    self.is_lpts_socket_add_required = YLeaf(YType.boolean, "is-lpts-socket-add-required")

                    self.is_lpts_socket_added = YLeaf(YType.boolean, "is-lpts-socket-added")

                    self.is_m_host_publish_pending = YLeaf(YType.boolean, "is-m-host-publish-pending")

                    self.is_mdt_owner = YLeaf(YType.boolean, "is-mdt-owner")

                    self.is_mldp_mdt_owner = YLeaf(YType.boolean, "is-mldp-mdt-owner")

                    self.is_mrib_register = YLeaf(YType.boolean, "is-mrib-register")

                    self.is_multicast_rib_registration = YLeaf(YType.boolean, "is-multicast-rib-registration")

                    self.is_pim_nsf_rib_converge_received = YLeaf(YType.boolean, "is-pim-nsf-rib-converge-received")

                    self.is_pim_nsf_rib_converged = YLeaf(YType.boolean, "is-pim-nsf-rib-converged")

                    self.is_redistribution_reset = YLeaf(YType.boolean, "is-redistribution-reset")

                    self.is_register_injection_lpts_socket_add_required = YLeaf(YType.boolean, "is-register-injection-lpts-socket-add-required")

                    self.is_register_injection_lpts_socket_added = YLeaf(YType.boolean, "is-register-injection-lpts-socket-added")

                    self.is_register_injection_socket_add_required = YLeaf(YType.boolean, "is-register-injection-socket-add-required")

                    self.is_register_injection_socket_added = YLeaf(YType.boolean, "is-register-injection-socket-added")

                    self.is_rib_multipath_enabled = YLeaf(YType.boolean, "is-rib-multipath-enabled")

                    self.is_rib_multipath_interface_hash = YLeaf(YType.boolean, "is-rib-multipath-interface-hash")

                    self.is_rib_multipath_source_hash = YLeaf(YType.boolean, "is-rib-multipath-source-hash")

                    self.is_rib_multipath_source_next_hop_hash = YLeaf(YType.boolean, "is-rib-multipath-source-next-hop-hash")

                    self.is_routing_enabled = YLeaf(YType.boolean, "is-routing-enabled")

                    self.is_rsvp_te_mdt_owner = YLeaf(YType.boolean, "is-rsvp-te-mdt-owner")

                    self.is_socket_add_required = YLeaf(YType.boolean, "is-socket-add-required")

                    self.is_socket_added = YLeaf(YType.boolean, "is-socket-added")

                    self.is_udp_socket_add_required = YLeaf(YType.boolean, "is-udp-socket-add-required")

                    self.is_udp_socket_added = YLeaf(YType.boolean, "is-udp-socket-added")

                    self.is_udp_socket_bind = YLeaf(YType.boolean, "is-udp-socket-bind")

                    self.is_udp_socket_bind_required = YLeaf(YType.boolean, "is-udp-socket-bind-required")

                    self.is_unicast_rib_registration = YLeaf(YType.boolean, "is-unicast-rib-registration")

                    self.maximum_mdt_aggregation = YLeaf(YType.uint32, "maximum-mdt-aggregation")

                    self.mdt_data_announce_interval = YLeaf(YType.uint32, "mdt-data-announce-interval")

                    self.mdt_data_switchover_interval = YLeaf(YType.uint32, "mdt-data-switchover-interval")

                    self.mdt_default_group = YLeaf(YType.str, "mdt-default-group")

                    self.mdt_gre_remote_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-remote-rpf-identifier")

                    self.mdt_gre_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-rpf-identifier")

                    self.mdt_immediate_switch = YLeaf(YType.boolean, "mdt-immediate-switch")

                    self.mdt_interface = YLeaf(YType.str, "mdt-interface")

                    self.mdt_mtu = YLeaf(YType.uint32, "mdt-mtu")

                    self.mdt_neighbor_filter_name = YLeaf(YType.str, "mdt-neighbor-filter-name")

                    self.mdt_partitioned_ir_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-ir-control-identifier")

                    self.mdt_partitioned_mdt_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-mdt-control-identifier")

                    self.mdt_source = YLeaf(YType.str, "mdt-source")

                    self.mdt_source_interface = YLeaf(YType.str, "mdt-source-interface")

                    self.mhost_default_interface_config = YLeaf(YType.str, "mhost-default-interface-config")

                    self.mhost_interface = YLeaf(YType.str, "mhost-interface")

                    self.mldp_auto_rp_announce_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-announce-tree-added")

                    self.mldp_auto_rp_discovery_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-discovery-tree-added")

                    self.mldp_bsr_control_tree_added = YLeaf(YType.boolean, "mldp-bsr-control-tree-added")

                    self.mldp_control_head_lsm_identifier = YLeaf(YType.uint32, "mldp-control-head-lsm-identifier")

                    self.mldp_head_local_label = YLeaf(YType.uint32, "mldp-head-local-label")

                    self.mldp_head_lsm_identifier = YLeaf(YType.uint32, "mldp-head-lsm-identifier")

                    self.mldp_maximum_mdt_aggregation = YLeaf(YType.uint32, "mldp-maximum-mdt-aggregation")

                    self.mldp_mdt_data_announce_interval = YLeaf(YType.uint32, "mldp-mdt-data-announce-interval")

                    self.mldp_mdt_data_switchover_interval = YLeaf(YType.uint32, "mldp-mdt-data-switchover-interval")

                    self.mldp_mdt_interface = YLeaf(YType.str, "mldp-mdt-interface")

                    self.mldp_mdt_mtu = YLeaf(YType.uint32, "mldp-mdt-mtu")

                    self.mldp_mdt_name = YLeaf(YType.str, "mldp-mdt-name")

                    self.mldp_mdt_remote_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-remote-rpf-identifier")

                    self.mldp_mdt_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-rpf-identifier")

                    self.mldp_partioned_mp2m_ptree = YLeaf(YType.boolean, "mldp-partioned-mp2m-ptree")

                    self.mldp_partitioned_head_lsm_identifier = YLeaf(YType.uint32, "mldp-partitioned-head-lsm-identifier")

                    self.mldp_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-partitioned-mdt-configured")

                    self.mldp_partitioned_mdt_identifier = YLeaf(YType.uint32, "mldp-partitioned-mdt-identifier")

                    self.mldp_remote_head_lsm_identifier = YLeaf(YType.uint32, "mldp-remote-head-lsm-identifier")

                    self.mldp_remote_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-remote-partitioned-mdt-configured")

                    self.mldp_root_address = YLeafList(YType.uint32, "mldp-root-address")

                    self.mldp_root_count = YLeaf(YType.uint32, "mldp-root-count")

                    self.murib_id = YLeaf(YType.uint32, "murib-id")

                    self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                    self.non_default_vrf_count_on_socket = YLeaf(YType.uint32, "non-default-vrf-count-on-socket")

                    self.organization_unique_identifier = YLeaf(YType.uint32, "organization-unique-identifier")

                    self.p2mpte_li_drop = YLeaf(YType.uint32, "p2mpte-li-drop")

                    self.physical_interface_count = YLeaf(YType.uint64, "physical-interface-count")

                    self.redistribution_reset_count = YLeaf(YType.uint32, "redistribution-reset-count")

                    self.remote_table_id = YLeaf(YType.uint32, "remote-table-id")

                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                    self.rpf_id = YLeaf(YType.uint32, "rpf-id")

                    self.rpf_policy_name = YLeaf(YType.str, "rpf-policy-name")

                    self.rsvp_te_maximum_mdt_aggregation = YLeaf(YType.uint32, "rsvp-te-maximum-mdt-aggregation")

                    self.rsvp_te_mdt_data_announce_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-announce-interval")

                    self.rsvp_te_mdt_data_switchover_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-switchover-interval")

                    self.rsvp_te_mdt_interface = YLeaf(YType.str, "rsvp-te-mdt-interface")

                    self.rsvp_te_mdt_mtu = YLeaf(YType.uint32, "rsvp-te-mdt-mtu")

                    self.rsvp_te_mdt_name = YLeaf(YType.str, "rsvp-te-mdt-name")

                    self.rsvp_te_mdt_rpf_identifier = YLeaf(YType.uint32, "rsvp-te-mdt-rpf-identifier")

                    self.rsvp_te_mdt_static_p2mp_count = YLeaf(YType.uint32, "rsvp-te-mdt-static-p2mp-count")

                    self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                    self.sg_expiry_time = YLeaf(YType.uint16, "sg-expiry-time")

                    self.sg_expiry_timer_configured = YLeaf(YType.boolean, "sg-expiry-timer-configured")

                    self.sg_expiry_timer_sg_list = YLeaf(YType.str, "sg-expiry-timer-sg-list")

                    self.stale_rd_present = YLeaf(YType.boolean, "stale-rd-present")

                    self.suppress_pim_data_mdt_tlv = YLeaf(YType.boolean, "suppress-pim-data-mdt-tlv")

                    self.suppress_shared_tree_join = YLeaf(YType.boolean, "suppress-shared-tree-join")

                    self.table_count = YLeaf(YType.uint32, "table-count")

                    self.table_id = YLeaf(YType.uint32, "table-id")

                    self.umh = YLeaf(YType.boolean, "umh")

                    self.valid_rd_present = YLeaf(YType.boolean, "valid-rd-present")

                    self.virtual_interface_count = YLeaf(YType.uint64, "virtual-interface-count")

                    self.virtual_mlc_interface_name = YLeaf(YType.str, "virtual-mlc-interface-name")

                    self.vpn_index = YLeaf(YType.uint32, "vpn-index")

                    self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                    self.remote_default_group = Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup()
                    self.remote_default_group.parent = self
                    self._children_name_map["remote_default_group"] = "remote-default-group"
                    self._children_yang_names.add("remote-default-group")

                    self.rpf_default_table = Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable()
                    self.rpf_default_table.parent = self
                    self._children_name_map["rpf_default_table"] = "rpf-default-table"
                    self._children_yang_names.add("rpf-default-table")

                    self.anycast_rp_range = YList(self)
                    self.export_route_target = YList(self)
                    self.import_route_target = YList(self)
                    self._segment_path = lambda: "context"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Context, ['active_table_count', 'allow_rp_configured', 'allow_rp_group_list', 'allow_rp_rp_list', 'anycast_rp_configured', 'anycast_rp_policy_name', 'bgp_auto_discovery_configured', 'bgp_auto_discovery_type', 'bgp_i_pmsi_added', 'bgp_remote_address', 'bgp_remote_interface', 'bgp_remote_interface_name', 'bgp_remote_on', 'bgp_remote_state', 'bgp_source_active_announce', 'gin_b_and_mdt_data_announce_interval', 'gin_b_and_mdt_data_switchover_interval', 'gin_b_and_mdt_interface', 'gin_b_and_mdt_mtu', 'gin_b_and_mdt_name', 'gin_b_and_mdt_rpf_identifier', 'gin_band_maximum_mdt_aggregation', 'in_b_and_mdt_data_announce_interval', 'in_b_and_mdt_data_switchover_interval', 'in_b_and_mdt_interface', 'in_b_and_mdt_mtu', 'in_b_and_mdt_name', 'in_b_and_mdt_rpf_identifier', 'in_band_maximum_mdt_aggregation', 'in_band_signaling_local_enabled', 'in_band_signaling_remote_enabled', 'inter_autonomous_system_enabled', 'ir_maximum_mdt_aggregation', 'ir_mdt_data_announce_interval', 'ir_mdt_data_switchover_interval', 'ir_mdt_interface', 'ir_mdt_mtu', 'ir_mdt_name', 'ir_mdt_rpf_identifier', 'ir_mdt_tail_label', 'is_active', 'is_active_ital', 'is_all_interface_disable_operation', 'is_auto_rp_listen_enabled', 'is_auto_rp_listen_sock_add', 'is_create_gin_b_and_mdt_interface', 'is_create_in_b_and_mdt_interface', 'is_create_ir_mdt_interface', 'is_create_mdt_interface', 'is_create_mldp_mdt_interface', 'is_create_rsvp_te_mdt_interface', 'is_default_granges', 'is_gin_b_and_mdt_owner', 'is_in_b_and_mdt_owner', 'is_ir_mdt_owner', 'is_lpts_socket_add_required', 'is_lpts_socket_added', 'is_m_host_publish_pending', 'is_mdt_owner', 'is_mldp_mdt_owner', 'is_mrib_register', 'is_multicast_rib_registration', 'is_pim_nsf_rib_converge_received', 'is_pim_nsf_rib_converged', 'is_redistribution_reset', 'is_register_injection_lpts_socket_add_required', 'is_register_injection_lpts_socket_added', 'is_register_injection_socket_add_required', 'is_register_injection_socket_added', 'is_rib_multipath_enabled', 'is_rib_multipath_interface_hash', 'is_rib_multipath_source_hash', 'is_rib_multipath_source_next_hop_hash', 'is_routing_enabled', 'is_rsvp_te_mdt_owner', 'is_socket_add_required', 'is_socket_added', 'is_udp_socket_add_required', 'is_udp_socket_added', 'is_udp_socket_bind', 'is_udp_socket_bind_required', 'is_unicast_rib_registration', 'maximum_mdt_aggregation', 'mdt_data_announce_interval', 'mdt_data_switchover_interval', 'mdt_default_group', 'mdt_gre_remote_rpf_identifier', 'mdt_gre_rpf_identifier', 'mdt_immediate_switch', 'mdt_interface', 'mdt_mtu', 'mdt_neighbor_filter_name', 'mdt_partitioned_ir_control_identifier', 'mdt_partitioned_mdt_control_identifier', 'mdt_source', 'mdt_source_interface', 'mhost_default_interface_config', 'mhost_interface', 'mldp_auto_rp_announce_tree_added', 'mldp_auto_rp_discovery_tree_added', 'mldp_bsr_control_tree_added', 'mldp_control_head_lsm_identifier', 'mldp_head_local_label', 'mldp_head_lsm_identifier', 'mldp_maximum_mdt_aggregation', 'mldp_mdt_data_announce_interval', 'mldp_mdt_data_switchover_interval', 'mldp_mdt_interface', 'mldp_mdt_mtu', 'mldp_mdt_name', 'mldp_mdt_remote_rpf_identifier', 'mldp_mdt_rpf_identifier', 'mldp_partioned_mp2m_ptree', 'mldp_partitioned_head_lsm_identifier', 'mldp_partitioned_mdt_configured', 'mldp_partitioned_mdt_identifier', 'mldp_remote_head_lsm_identifier', 'mldp_remote_partitioned_mdt_configured', 'mldp_root_address', 'mldp_root_count', 'murib_id', 'neighbor_filter_name', 'non_default_vrf_count_on_socket', 'organization_unique_identifier', 'p2mpte_li_drop', 'physical_interface_count', 'redistribution_reset_count', 'remote_table_id', 'route_distinguisher', 'rpf_id', 'rpf_policy_name', 'rsvp_te_maximum_mdt_aggregation', 'rsvp_te_mdt_data_announce_interval', 'rsvp_te_mdt_data_switchover_interval', 'rsvp_te_mdt_interface', 'rsvp_te_mdt_mtu', 'rsvp_te_mdt_name', 'rsvp_te_mdt_rpf_identifier', 'rsvp_te_mdt_static_p2mp_count', 'rump_enabled', 'sg_expiry_time', 'sg_expiry_timer_configured', 'sg_expiry_timer_sg_list', 'stale_rd_present', 'suppress_pim_data_mdt_tlv', 'suppress_shared_tree_join', 'table_count', 'table_id', 'umh', 'valid_rd_present', 'virtual_interface_count', 'virtual_mlc_interface_name', 'vpn_index', 'vrf_id'], name, value)


                class AnycastRpRange(Entity):
                    """
                    Anycast\-RP Ranges
                    
                    .. attribute:: ancast_rp_marked
                    
                    	Anycast\-RP Range marked
                    	**type**\:  bool
                    
                    .. attribute:: prefix
                    
                    	Anycast\-RP Range Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Anycast\-RP Range Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange, self).__init__()

                        self.yang_name = "anycast-rp-range"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"prefix" : ("prefix", Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix)}
                        self._child_list_classes = {}

                        self.ancast_rp_marked = YLeaf(YType.boolean, "ancast-rp-marked")

                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                        self.prefix = Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._children_yang_names.add("prefix")
                        self._segment_path = lambda: "anycast-rp-range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange, ['ancast_rp_marked', 'prefix_length'], name, value)


                    class Prefix(Entity):
                        """
                        Anycast\-RP Range Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "anycast-rp-range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "prefix"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/context/anycast-rp-range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class ExportRouteTarget(Entity):
                    """
                    Export Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Context.ExportRouteTarget, self).__init__()

                        self.yang_name = "export-route-target"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                        self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                        self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                        self.configured = YLeaf(YType.boolean, "configured")

                        self.route_target = YLeaf(YType.str, "route-target")

                        self.segment_border = YLeaf(YType.boolean, "segment-border")

                        self.update_pending = YLeaf(YType.boolean, "update-pending")
                        self._segment_path = lambda: "export-route-target"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Context.ExportRouteTarget, ['anycast_rp', 'anycast_rp_marked', 'bgp_auto_discovery', 'configured', 'route_target', 'segment_border', 'update_pending'], name, value)


                class ImportRouteTarget(Entity):
                    """
                    Import Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Context.ImportRouteTarget, self).__init__()

                        self.yang_name = "import-route-target"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                        self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                        self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                        self.configured = YLeaf(YType.boolean, "configured")

                        self.route_target = YLeaf(YType.str, "route-target")

                        self.segment_border = YLeaf(YType.boolean, "segment-border")

                        self.update_pending = YLeaf(YType.boolean, "update-pending")
                        self._segment_path = lambda: "import-route-target"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Context.ImportRouteTarget, ['anycast_rp', 'anycast_rp_marked', 'bgp_auto_discovery', 'configured', 'route_target', 'segment_border', 'update_pending'], name, value)


                class RemoteDefaultGroup(Entity):
                    """
                    Remote Default Group
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup, self).__init__()

                        self.yang_name = "remote-default-group"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.af_name = YLeaf(YType.enumeration, "af-name")

                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                        self._segment_path = lambda: "remote-default-group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class RpfDefaultTable(Entity):
                    """
                    RPF Default Table
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable, self).__init__()

                        self.yang_name = "rpf-default-table"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.uint32, "afi")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                        self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.safi = YLeaf(YType.uint32, "safi")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.table_name = YLeaf(YType.str, "table-name")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")
                        self._segment_path = lambda: "rpf-default-table"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable, ['afi', 'is_active', 'is_ital_registration_done', 'is_rib_convergence', 'is_rib_convergence_received', 'is_rib_registration_done', 'rpf_registrations', 'safi', 'table_id', 'table_name', 'vrf_id'], name, value)


            class GlobalInterfaces(Entity):
                """
                PIM global interface table
                
                .. attribute:: global_interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`GlobalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces, self).__init__()

                    self.yang_name = "global-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"global-interface" : ("global_interface", Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface)}

                    self.global_interface = YList(self)
                    self._segment_path = lambda: "global-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.GlobalInterfaces, [], name, value)


                class GlobalInterface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface, self).__init__()

                        self.yang_name = "global-interface"
                        self.yang_parent_name = "global-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"dr-address" : ("dr_address", Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress)}
                        self._child_list_classes = {"interface-address" : ("interface_address", Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "global-interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/global-interfaces/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "global-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "dr-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "global-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "interface-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Gre(Entity):
                """
                GRE information
                
                .. attribute:: gre_hashes
                
                	GRE hash
                	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreHashes>`
                
                .. attribute:: gre_next_hops
                
                	GRE destination neighbor table
                	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Gre, self).__init__()

                    self.yang_name = "gre"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"gre-hashes" : ("gre_hashes", Ipv6Pim.Active.DefaultContext.Gre.GreHashes), "gre-next-hops" : ("gre_next_hops", Ipv6Pim.Active.DefaultContext.Gre.GreNextHops)}
                    self._child_list_classes = {}

                    self.gre_hashes = Ipv6Pim.Active.DefaultContext.Gre.GreHashes()
                    self.gre_hashes.parent = self
                    self._children_name_map["gre_hashes"] = "gre-hashes"
                    self._children_yang_names.add("gre-hashes")

                    self.gre_next_hops = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops()
                    self.gre_next_hops.parent = self
                    self._children_name_map["gre_next_hops"] = "gre-next-hops"
                    self._children_yang_names.add("gre-next-hops")
                    self._segment_path = lambda: "gre"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()


                class GreHashes(Entity):
                    """
                    GRE hash
                    
                    .. attribute:: gre_hash
                    
                    	PIM GRE Hashed Underlying Interface
                    	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreHashes.GreHash>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Gre.GreHashes, self).__init__()

                        self.yang_name = "gre-hashes"
                        self.yang_parent_name = "gre"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"gre-hash" : ("gre_hash", Ipv6Pim.Active.DefaultContext.Gre.GreHashes.GreHash)}

                        self.gre_hash = YList(self)
                        self._segment_path = lambda: "gre-hashes"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/gre/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Gre.GreHashes, [], name, value)


                    class GreHash(Entity):
                        """
                        PIM GRE Hashed Underlying Interface
                        
                        .. attribute:: source_address  <key>
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: destination_address  <key>
                        
                        	Destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: ifname  <key>
                        
                        	GRE Tunnel Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: next_hop_interface
                        
                        	Next hop neighbor interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Gre.GreHashes.GreHash, self).__init__()

                            self.yang_name = "gre-hash"
                            self.yang_parent_name = "gre-hashes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.ifname = YLeaf(YType.str, "ifname")

                            self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")
                            self._segment_path = lambda: "gre-hash" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[ifname='" + self.ifname.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/gre/gre-hashes/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Gre.GreHashes.GreHash, ['source_address', 'destination_address', 'ifname', 'next_hop_interface'], name, value)


                class GreNextHops(Entity):
                    """
                    GRE destination neighbor table
                    
                    .. attribute:: gre_next_hop
                    
                    	PIM GRE address next\-hop information
                    	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops, self).__init__()

                        self.yang_name = "gre-next-hops"
                        self.yang_parent_name = "gre"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"gre-next-hop" : ("gre_next_hop", Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop)}

                        self.gre_next_hop = YList(self)
                        self._segment_path = lambda: "gre-next-hops"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/gre/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops, [], name, value)


                    class GreNextHop(Entity):
                        """
                        PIM GRE address next\-hop information
                        
                        .. attribute:: destination_address  <key>
                        
                        	GRE destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: gre_path
                        
                        	GRE Paths list
                        	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath>`
                        
                        .. attribute:: is_connected
                        
                        	Are we connected ?
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: registered_address
                        
                        	Address registered
                        	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop, self).__init__()

                            self.yang_name = "gre-next-hop"
                            self.yang_parent_name = "gre-next-hops"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"registered-address" : ("registered_address", Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress)}
                            self._child_list_classes = {"gre-path" : ("gre_path", Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath)}

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.is_connected = YLeaf(YType.uint8, "is-connected")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                            self.registered_address = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                            self.registered_address.parent = self
                            self._children_name_map["registered_address"] = "registered-address"
                            self._children_yang_names.add("registered-address")

                            self.gre_path = YList(self)
                            self._segment_path = lambda: "gre-next-hop" + "[destination-address='" + self.destination_address.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/gre/gre-next-hops/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop, ['destination_address', 'is_connected', 'metric', 'metric_preference'], name, value)


                        class GrePath(Entity):
                            """
                            GRE Paths list
                            
                            .. attribute:: extranet_vrf_name
                            
                            	Extranet VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: gre_interface_name
                            
                            	GRE Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: gre_neighbor
                            
                            	GRE neighbor
                            	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                            
                            .. attribute:: gre_next_hop
                            
                            	GRE nexthop
                            	**type**\:   :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop>`
                            
                            .. attribute:: is_connector_attribute_present
                            
                            	Connector attribute present
                            	**type**\:  bool
                            
                            .. attribute:: is_gre_interface_disabled
                            
                            	Is the gre interface disabled ?
                            	**type**\:  bool
                            
                            .. attribute:: is_via_lsm
                            
                            	Via LSM
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                self.yang_name = "gre-path"
                                self.yang_parent_name = "gre-next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"gre-neighbor" : ("gre_neighbor", Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor), "gre-next-hop" : ("gre_next_hop", Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop)}
                                self._child_list_classes = {}

                                self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                self.gre_interface_name = YLeaf(YType.str, "gre-interface-name")

                                self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                self.is_gre_interface_disabled = YLeaf(YType.boolean, "is-gre-interface-disabled")

                                self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                self.gre_neighbor = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                self.gre_neighbor.parent = self
                                self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                self._children_yang_names.add("gre-neighbor")

                                self.gre_next_hop = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                self.gre_next_hop.parent = self
                                self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                self._children_yang_names.add("gre-next-hop")
                                self._segment_path = lambda: "gre-path"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, ['extranet_vrf_name', 'gre_interface_name', 'is_connector_attribute_present', 'is_gre_interface_disabled', 'is_via_lsm'], name, value)


                            class GreNeighbor(Entity):
                                """
                                GRE neighbor
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                    self.yang_name = "gre-neighbor"
                                    self.yang_parent_name = "gre-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "gre-neighbor"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class GreNextHop(Entity):
                                """
                                GRE nexthop
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__init__()

                                    self.yang_name = "gre-next-hop"
                                    self.yang_parent_name = "gre-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "gre-next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RegisteredAddress(Entity):
                            """
                            Address registered
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                self.yang_name = "registered-address"
                                self.yang_parent_name = "gre-next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "registered-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class GroupMapRpfs(Entity):
                """
                PIM group mapping information
                
                .. attribute:: group_map_rpf
                
                	PIM group mapping entry
                	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs, self).__init__()

                    self.yang_name = "group-map-rpfs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"group-map-rpf" : ("group_map_rpf", Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf)}

                    self.group_map_rpf = YList(self)
                    self._segment_path = lambda: "group-map-rpfs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapRpfs, [], name, value)


                class GroupMapRpf(Entity):
                    """
                    PIM group mapping entry
                    
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_priority
                    
                    	RP priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__init__()

                        self.yang_name = "group-map-rpf"
                        self.yang_parent_name = "group-map-rpfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-map-information" : ("group_map_information", Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation), "rpf-neighbor" : ("rpf_neighbor", Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor)}
                        self._child_list_classes = {}

                        self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                        self.client = YLeaf(YType.enumeration, "client")

                        self.prefix = YLeaf(YType.str, "prefix")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_priority = YLeaf(YType.int32, "rp-priority")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.group_map_information = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")
                        self._segment_path = lambda: "group-map-rpf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-rpfs/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf, ['are_we_rp', 'client', 'prefix', 'prefix_length', 'protocol', 'rp_address', 'rp_priority', 'rpf_interface_name', 'rpf_vrf_name'], name, value)


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-rpf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"prefix" : ("prefix", Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix), "rp-address" : ("rp_address", Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress)}
                            self._child_list_classes = {}

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")
                            self._segment_path = lambda: "group-map-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-rpfs/group-map-rpf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, ['client', 'group_count', 'is_override', 'is_used', 'mrib_active', 'prefix_length', 'priority', 'protocol'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "group-map-rpf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-rpfs/group-map-rpf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class GroupMapSources(Entity):
                """
                PIM group\-mapping with source information
                
                .. attribute:: group_map_source
                
                	PIM Group Mapping Entry with source information
                	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.GroupMapSources, self).__init__()

                    self.yang_name = "group-map-sources"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"group-map-source" : ("group_map_source", Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource)}

                    self.group_map_source = YList(self)
                    self._segment_path = lambda: "group-map-sources"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapSources, [], name, value)


                class GroupMapSource(Entity):
                    """
                    PIM Group Mapping Entry with source information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: priority
                    
                    	RP Priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource, self).__init__()

                        self.yang_name = "group-map-source"
                        self.yang_parent_name = "group-map-sources"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-map-information" : ("group_map_information", Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation), "source-of-information" : ("source_of_information", Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation)}
                        self._child_list_classes = {}

                        self.client = YLeaf(YType.enumeration, "client")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.holdtime = YLeaf(YType.int32, "holdtime")

                        self.prefix = YLeaf(YType.str, "prefix")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.priority = YLeaf(YType.int32, "priority")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_map_information = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.source_of_information = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")
                        self._segment_path = lambda: "group-map-source"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-sources/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource, ['client', 'expires', 'holdtime', 'prefix', 'prefix_length', 'priority', 'protocol', 'rp_address', 'uptime'], name, value)


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"prefix" : ("prefix", Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix), "rp-address" : ("rp_address", Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress)}
                            self._child_list_classes = {}

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")
                            self._segment_path = lambda: "group-map-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-sources/group-map-source/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, ['client', 'group_count', 'is_override', 'is_used', 'mrib_active', 'prefix_length', 'priority', 'protocol'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-sources/group-map-source/group-map-information/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-sources/group-map-source/group-map-information/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceOfInformation(Entity):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "group-map-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-of-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-sources/group-map-source/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class IfrsInterfaces(Entity):
                """
                PIM interfaces in forward reference store table
                
                .. attribute:: ifrs_interface
                
                	PIM IFRS interface information
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"ifrs-interface" : ("ifrs_interface", Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface)}

                    self.ifrs_interface = YList(self)
                    self._segment_path = lambda: "ifrs-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.IfrsInterfaces, [], name, value)


                class IfrsInterface(Entity):
                    """
                    PIM IFRS interface information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"dr-address" : ("dr_address", Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress)}
                        self._child_list_classes = {"interface-address" : ("interface_address", Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ifrs-interfaces/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "dr-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "interface-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class IfrsSummary(Entity):
                """
                PIM interfaces in forward reference store
                summary
                
                .. attribute:: configuration_count
                
                	Configuration counts
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Number of interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.IfrsSummary, self).__init__()

                    self.yang_name = "ifrs-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                    self.interface_count = YLeaf(YType.uint32, "interface-count")
                    self._segment_path = lambda: "ifrs-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.IfrsSummary, ['configuration_count', 'interface_count'], name, value)


            class InterfaceOldFormats(Entity):
                """
                PIM interfaces in old format
                
                .. attribute:: interface_old_format
                
                	PIM interface name
                	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats, self).__init__()

                    self.yang_name = "interface-old-formats"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-old-format" : ("interface_old_format", Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat)}

                    self.interface_old_format = YList(self)
                    self._segment_path = lambda: "interface-old-formats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats, [], name, value)


                class InterfaceOldFormat(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                        self.yang_name = "interface-old-format"
                        self.yang_parent_name = "interface-old-formats"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"dr-address" : ("dr_address", Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress)}
                        self._child_list_classes = {"interface-address" : ("interface_address", Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "interface-old-format" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/interface-old-formats/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "dr-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "interface-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceStatistics(Entity):
                """
                PIM interface statistics
                
                .. attribute:: interface_statistic
                
                	PIM interface statistics
                	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.InterfaceStatistics, self).__init__()

                    self.yang_name = "interface-statistics"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-statistic" : ("interface_statistic", Ipv6Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic)}

                    self.interface_statistic = YList(self)
                    self._segment_path = lambda: "interface-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.InterfaceStatistics, [], name, value)


                class InterfaceStatistic(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_ack_message
                    
                    	Input Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_message
                    
                    	Input Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_miscellaneous
                    
                    	Miscellaneous packet in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register
                    
                    	Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_ack_message
                    
                    	Output Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_message
                    
                    	Output Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register
                    
                    	Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__init__()

                        self.yang_name = "interface-statistic"
                        self.yang_parent_name = "interface-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.input_assert = YLeaf(YType.uint32, "input-assert")

                        self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                        self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                        self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                        self.input_graft_ack_message = YLeaf(YType.uint32, "input-graft-ack-message")

                        self.input_graft_message = YLeaf(YType.uint32, "input-graft-message")

                        self.input_hello = YLeaf(YType.uint32, "input-hello")

                        self.input_jp = YLeaf(YType.uint32, "input-jp")

                        self.input_miscellaneous = YLeaf(YType.uint32, "input-miscellaneous")

                        self.input_register = YLeaf(YType.uint32, "input-register")

                        self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                        self.output_assert = YLeaf(YType.uint32, "output-assert")

                        self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                        self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                        self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                        self.output_graft_ack_message = YLeaf(YType.uint32, "output-graft-ack-message")

                        self.output_graft_message = YLeaf(YType.uint32, "output-graft-message")

                        self.output_hello = YLeaf(YType.uint32, "output-hello")

                        self.output_jp = YLeaf(YType.uint32, "output-jp")

                        self.output_register = YLeaf(YType.uint32, "output-register")

                        self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")
                        self._segment_path = lambda: "interface-statistic" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/interface-statistics/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic, ['interface_name', 'input_assert', 'input_bsr_message', 'input_candidate_rp_advertisement', 'input_df_election', 'input_graft_ack_message', 'input_graft_message', 'input_hello', 'input_jp', 'input_miscellaneous', 'input_register', 'input_register_stop', 'output_assert', 'output_bsr_message', 'output_candidate_rp_advertisement', 'output_df_election', 'output_graft_ack_message', 'output_graft_message', 'output_hello', 'output_jp', 'output_register', 'output_register_stop'], name, value)


            class Interfaces(Entity):
                """
                PIM interfaces
                
                .. attribute:: interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Interfaces.Interface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface" : ("interface", Ipv6Pim.Active.DefaultContext.Interfaces.Interface)}

                    self.interface = YList(self)
                    self._segment_path = lambda: "interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Interfaces, [], name, value)


                class Interface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Interfaces.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"dr-address" : ("dr_address", Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress)}
                        self._child_list_classes = {"interface-address" : ("interface_address", Ipv6Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/interfaces/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Interfaces.Interface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "dr-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "interface-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class JpStatistics(Entity):
                """
                PIM join prune statistics table
                
                .. attribute:: jp_statistic
                
                	PIM Join Prune Statistics
                	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.JpStatistics.JpStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.JpStatistics, self).__init__()

                    self.yang_name = "jp-statistics"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"jp-statistic" : ("jp_statistic", Ipv6Pim.Active.DefaultContext.JpStatistics.JpStatistic)}

                    self.jp_statistic = YList(self)
                    self._segment_path = lambda: "jp-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.JpStatistics, [], name, value)


                class JpStatistic(Entity):
                    """
                    PIM Join Prune Statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mtu
                    
                    	Interface MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received
                    
                    	Received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received100
                    
                    	Received 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_10k
                    
                    	Received 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_1k
                    
                    	Received 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_50k
                    
                    	Deprecated by Received100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted
                    
                    	Transmitted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted100
                    
                    	Transmitted 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_10k
                    
                    	Transmitted 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_1k
                    
                    	Transmitted 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_50k
                    
                    	Deprecated by Transmitted100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.JpStatistics.JpStatistic, self).__init__()

                        self.yang_name = "jp-statistic"
                        self.yang_parent_name = "jp-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.received = YLeaf(YType.uint32, "received")

                        self.received100 = YLeaf(YType.uint16, "received100")

                        self.received_10k = YLeaf(YType.uint16, "received-10k")

                        self.received_1k = YLeaf(YType.uint16, "received-1k")

                        self.received_50k = YLeaf(YType.uint16, "received-50k")

                        self.transmitted = YLeaf(YType.uint32, "transmitted")

                        self.transmitted100 = YLeaf(YType.uint16, "transmitted100")

                        self.transmitted_10k = YLeaf(YType.uint16, "transmitted-10k")

                        self.transmitted_1k = YLeaf(YType.uint16, "transmitted-1k")

                        self.transmitted_50k = YLeaf(YType.uint16, "transmitted-50k")
                        self._segment_path = lambda: "jp-statistic" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/jp-statistics/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.JpStatistics.JpStatistic, ['interface_name', 'interface_name_xr', 'mtu', 'received', 'received100', 'received_10k', 'received_1k', 'received_50k', 'transmitted', 'transmitted100', 'transmitted_10k', 'transmitted_1k', 'transmitted_50k'], name, value)


            class MibDatabases(Entity):
                """
                PIM group database for mroute mibs table
                
                .. attribute:: mib_database
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.MibDatabases, self).__init__()

                    self.yang_name = "mib-databases"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"mib-database" : ("mib_database", Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase)}

                    self.mib_database = YList(self)
                    self._segment_path = lambda: "mib-databases"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.MibDatabases, [], name, value)


                class MibDatabase(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: assert_metric
                    
                    	Assert Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_metric_preference
                    
                    	Assert Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_rpt_bit
                    
                    	Assert RPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: bidirectional_route
                    
                    	Is this Bidir ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Multicast satic route group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr>`
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface name 
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: rpf_mask
                    
                    	Mask of the multicast root
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_neighbor
                    
                    	The RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: source_address
                    
                    	Multicast static route source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr>`
                    
                    .. attribute:: source_netmask
                    
                    	Source mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: spt_bit
                    
                    	Is SPT bit set ?
                    	**type**\:  bool
                    
                    .. attribute:: upstream_assert_timer
                    
                    	Upstream Assert Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime of route
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase, self).__init__()

                        self.yang_name = "mib-database"
                        self.yang_parent_name = "mib-databases"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr), "rpf-neighbor" : ("rpf_neighbor", Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor), "rpf-root" : ("rpf_root", Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot), "source-address-xr" : ("source_address_xr", Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr)}
                        self._child_list_classes = {}

                        self.assert_metric = YLeaf(YType.uint32, "assert-metric")

                        self.assert_metric_preference = YLeaf(YType.uint32, "assert-metric-preference")

                        self.assert_rpt_bit = YLeaf(YType.boolean, "assert-rpt-bit")

                        self.bidirectional_route = YLeaf(YType.boolean, "bidirectional-route")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                        self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_mask = YLeaf(YType.uint32, "rpf-mask")

                        self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                        self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.source_netmask = YLeaf(YType.int32, "source-netmask")

                        self.spt_bit = YLeaf(YType.boolean, "spt-bit")

                        self.upstream_assert_timer = YLeaf(YType.int32, "upstream-assert-timer")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_address_xr = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                        self.rpf_root = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._children_yang_names.add("rpf-root")

                        self.source_address_xr = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"
                        self._children_yang_names.add("source-address-xr")
                        self._segment_path = lambda: "mib-database"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/mib-databases/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase, ['assert_metric', 'assert_metric_preference', 'assert_rpt_bit', 'bidirectional_route', 'group_address', 'protocol', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_mask', 'rpf_safi', 'rpf_table_name', 'rpf_vrf_name', 'source_address', 'source_netmask', 'spt_bit', 'upstream_assert_timer', 'uptime'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/mib-databases/mib-database/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        The RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/mib-databases/mib-database/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-root"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/mib-databases/mib-database/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/mib-databases/mib-database/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class MulticastStaticRoutes(Entity):
                """
                PIM multicast static route table
                
                .. attribute:: multicast_static_route
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes, self).__init__()

                    self.yang_name = "multicast-static-routes"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"multicast-static-route" : ("multicast_static_route", Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute)}

                    self.multicast_static_route = YList(self)
                    self._segment_path = lambda: "multicast-static-routes"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes, [], name, value)


                class MulticastStaticRoute(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: address
                    
                    	Network address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: distance
                    
                    	Distance
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_via_lsm
                    
                    	LSM flag
                    	**type**\:  bool
                    
                    .. attribute:: nexthop
                    
                    	Next Hop
                    	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: prefix_length_xr
                    
                    	Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                        self.yang_name = "multicast-static-route"
                        self.yang_parent_name = "multicast-static-routes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"nexthop" : ("nexthop", Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop), "prefix" : ("prefix", Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix)}
                        self._child_list_classes = {}

                        self.address = YLeaf(YType.str, "address")

                        self.distance = YLeaf(YType.uint32, "distance")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                        self.nexthop = Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                        self.nexthop.parent = self
                        self._children_name_map["nexthop"] = "nexthop"
                        self._children_yang_names.add("nexthop")

                        self.prefix = Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._children_yang_names.add("prefix")
                        self._segment_path = lambda: "multicast-static-route"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/multicast-static-routes/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, ['address', 'distance', 'interface_name', 'is_via_lsm', 'prefix_length', 'prefix_length_xr'], name, value)


                    class Nexthop(Entity):
                        """
                        Next Hop
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                            self.yang_name = "nexthop"
                            self.yang_parent_name = "multicast-static-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "nexthop"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/multicast-static-routes/multicast-static-route/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Prefix(Entity):
                        """
                        Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "multicast-static-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "prefix"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/multicast-static-routes/multicast-static-route/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class NeighborOldFormats(Entity):
                """
                PIM neighbor table old format
                
                .. attribute:: neighbor_old_format
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.NeighborOldFormats, self).__init__()

                    self.yang_name = "neighbor-old-formats"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"neighbor-old-format" : ("neighbor_old_format", Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat)}

                    self.neighbor_old_format = YList(self)
                    self._segment_path = lambda: "neighbor-old-formats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.NeighborOldFormats, [], name, value)


                class NeighborOldFormat(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__init__()

                        self.yang_name = "neighbor-old-format"
                        self.yang_parent_name = "neighbor-old-formats"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr)}

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                        self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                        self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.neighbor_address_xr = YList(self)
                        self._segment_path = lambda: "neighbor-old-format"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/neighbor-old-formats/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat, ['dr_priority', 'expires', 'expiry_timer', 'interface_name', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bfd_state', 'is_bidirectional_capable', 'is_dr_priority_capable', 'is_ecmp_redirect_capable', 'is_proxy_capable', 'is_this_neighbor_dr', 'is_this_neighbor_us', 'neighbor_address', 'override_interval', 'propagation_delay', 'uptime'], name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "neighbor-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/neighbor-old-formats/neighbor-old-format/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class NeighborSummaries(Entity):
                """
                PIM neighbor summary table
                
                .. attribute:: neighbor_summary
                
                	PIM neighbor summary information
                	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.NeighborSummaries, self).__init__()

                    self.yang_name = "neighbor-summaries"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"neighbor-summary" : ("neighbor_summary", Ipv6Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary)}

                    self.neighbor_summary = YList(self)
                    self._segment_path = lambda: "neighbor-summaries"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.NeighborSummaries, [], name, value)


                class NeighborSummary(Entity):
                    """
                    PIM neighbor summary information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: number_of_external_neighbors
                    
                    	Number of external neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary, self).__init__()

                        self.yang_name = "neighbor-summary"
                        self.yang_parent_name = "neighbor-summaries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.number_of_external_neighbors = YLeaf(YType.int32, "number-of-external-neighbors")

                        self.number_of_neighbors = YLeaf(YType.int32, "number-of-neighbors")
                        self._segment_path = lambda: "neighbor-summary" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/neighbor-summaries/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary, ['interface_name', 'number_of_external_neighbors', 'number_of_neighbors'], name, value)


            class Neighbors(Entity):
                """
                PIM neighbor table
                
                .. attribute:: neighbor
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Neighbors, self).__init__()

                    self.yang_name = "neighbors"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"neighbor" : ("neighbor", Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor)}

                    self.neighbor = YList(self)
                    self._segment_path = lambda: "neighbors"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Neighbors, [], name, value)


                class Neighbor(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "neighbors"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr)}

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                        self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                        self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.neighbor_address_xr = YList(self)
                        self._segment_path = lambda: "neighbor"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/neighbors/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor, ['dr_priority', 'expires', 'expiry_timer', 'interface_name', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bfd_state', 'is_bidirectional_capable', 'is_dr_priority_capable', 'is_ecmp_redirect_capable', 'is_proxy_capable', 'is_this_neighbor_dr', 'is_this_neighbor_us', 'neighbor_address', 'override_interval', 'propagation_delay', 'uptime'], name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "neighbor-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/neighbors/neighbor/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class NetIoTunnels(Entity):
                """
                Tunnel information that NETIO has 
                
                .. attribute:: net_io_tunnel
                
                	PIM netio tunnel information
                	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.NetIoTunnels, self).__init__()

                    self.yang_name = "net-io-tunnels"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"net-io-tunnel" : ("net_io_tunnel", Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel)}

                    self.net_io_tunnel = YList(self)
                    self._segment_path = lambda: "net-io-tunnels"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.NetIoTunnels, [], name, value)


                class NetIoTunnel(Entity):
                    """
                    PIM netio tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel, self).__init__()

                        self.yang_name = "net-io-tunnel"
                        self.yang_parent_name = "net-io-tunnels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-netio" : ("group_address_netio", Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio), "rp-address" : ("rp_address", Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress), "source-address" : ("source_address", Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress), "source-address-netio" : ("source_address_netio", Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio)}
                        self._child_list_classes = {}

                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.group_address_netio = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._children_yang_names.add("group-address-netio")

                        self.rp_address = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                        self.source_address_netio = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"
                        self._children_yang_names.add("source-address-netio")
                        self._segment_path = lambda: "net-io-tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/net-io-tunnels/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel, ['tunnel_name', 'vrf_name'], name, value)


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-netio"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address-netio"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Ranges(Entity):
                """
                PIM range list information
                
                .. attribute:: range
                
                	PIM range list information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"range" : ("range", Ipv6Pim.Active.DefaultContext.Ranges.Range)}

                    self.range = YList(self)
                    self._segment_path = lambda: "ranges"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Ranges, [], name, value)


                class Range(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: client_xr
                    
                    	Client mapping learnt via
                    	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                    
                    .. attribute:: expires
                    
                    	When mapping expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: group_range
                    
                    	List of group ranges
                    	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange>`
                    
                    .. attribute:: protocol
                    
                    	PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	Rendezvous point address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr>`
                    
                    .. attribute:: source_of_information
                    
                    	Source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rp-address-xr" : ("rp_address_xr", Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr), "source-of-information" : ("source_of_information", Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation)}
                        self._child_list_classes = {"group-range" : ("group_range", Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange)}

                        self.client = YLeaf(YType.enumeration, "client")

                        self.client_xr = YLeaf(YType.enumeration, "client-xr")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_address_xr = Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")

                        self.source_of_information = Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")

                        self.group_range = YList(self)
                        self._segment_path = lambda: "range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ranges/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Ranges.Range, ['client', 'client_xr', 'expires', 'protocol', 'rp_address'], name, value)


                    class GroupRange(Entity):
                        """
                        List of group ranges
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange, self).__init__()

                            self.yang_name = "group-range"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"prefix" : ("prefix", Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix), "source-of-information" : ("source_of_information", Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation)}
                            self._child_list_classes = {}

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.prefix = Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.source_of_information = Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")
                            self._segment_path = lambda: "group-range"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ranges/range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange, ['expires', 'prefix_length', 'uptime'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ranges/range/group-range/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-of-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ranges/range/group-range/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddressXr(Entity):
                        """
                        Rendezvous point address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ranges/range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceOfInformation(Entity):
                        """
                        Source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-of-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ranges/range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class RoutePolicy(Entity):
                """
                PIM route policy
                
                .. attribute:: route_policy_statistics
                
                	PIM route policy statistics
                	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics>`
                
                .. attribute:: route_policy_tests
                
                	PIM route policy test run table
                	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.RoutePolicy, self).__init__()

                    self.yang_name = "route-policy"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"route-policy-statistics" : ("route_policy_statistics", Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics), "route-policy-tests" : ("route_policy_tests", Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests)}
                    self._child_list_classes = {}

                    self.route_policy_statistics = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                    self.route_policy_statistics.parent = self
                    self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                    self._children_yang_names.add("route-policy-statistics")

                    self.route_policy_tests = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests()
                    self.route_policy_tests.parent = self
                    self._children_name_map["route_policy_tests"] = "route-policy-tests"
                    self._children_yang_names.add("route-policy-tests")
                    self._segment_path = lambda: "route-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()


                class RoutePolicyStatistics(Entity):
                    """
                    PIM route policy statistics
                    
                    .. attribute:: any_table
                    
                    	Number of RPF lookup in any Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table
                    
                    	Number of RPF lookup in default\-only Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop
                    
                    	Number of RPF drops
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pass_
                    
                    	Number of RPF pass
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: policy_name
                    
                    	RPF policy name
                    	**type**\:  str
                    
                    .. attribute:: requests
                    
                    	Number of RPF lookup requests
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__init__()

                        self.yang_name = "route-policy-statistics"
                        self.yang_parent_name = "route-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.any_table = YLeaf(YType.uint32, "any-table")

                        self.default_table = YLeaf(YType.uint32, "default-table")

                        self.drop = YLeaf(YType.uint32, "drop")

                        self.pass_ = YLeaf(YType.uint32, "pass")

                        self.policy_name = YLeaf(YType.str, "policy-name")

                        self.requests = YLeaf(YType.uint32, "requests")
                        self._segment_path = lambda: "route-policy-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/route-policy/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics, ['any_table', 'default_table', 'drop', 'pass_', 'policy_name', 'requests'], name, value)


                class RoutePolicyTests(Entity):
                    """
                    PIM route policy test run table
                    
                    .. attribute:: route_policy_test
                    
                    	PIM route policy test run
                    	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests, self).__init__()

                        self.yang_name = "route-policy-tests"
                        self.yang_parent_name = "route-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"route-policy-test" : ("route_policy_test", Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest)}

                        self.route_policy_test = YList(self)
                        self._segment_path = lambda: "route-policy-tests"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/route-policy/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests, [], name, value)


                    class RoutePolicyTest(Entity):
                        """
                        PIM route policy test run
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Default table selected
                        	**type**\:  bool
                        
                        .. attribute:: ext_comm
                        
                        	Extended Community
                        	**type**\:  str
                        
                        	**length:** 1..8
                        
                        .. attribute:: extended_community_rt
                        
                        	Route Target
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                        
                        .. attribute:: pass_
                        
                        	Pass
                        	**type**\:  bool
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                        
                        .. attribute:: table_active
                        
                        	Table active
                        	**type**\:  bool
                        
                        .. attribute:: table_exists
                        
                        	Table exists
                        	**type**\:  bool
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_name
                        
                        	VRF name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                            self.yang_name = "route-policy-test"
                            self.yang_parent_name = "route-policy-tests"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr), "source-address-xr" : ("source_address_xr", Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr)}
                            self._child_list_classes = {}

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.default_table = YLeaf(YType.boolean, "default-table")

                            self.ext_comm = YLeaf(YType.str, "ext-comm")

                            self.extended_community_rt = YLeaf(YType.str, "extended-community-rt")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.pass_ = YLeaf(YType.boolean, "pass")

                            self.policy_name = YLeaf(YType.str, "policy-name")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.table_active = YLeaf(YType.boolean, "table-active")

                            self.table_exists = YLeaf(YType.boolean, "table-exists")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_xr = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.source_address_xr = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")
                            self._segment_path = lambda: "route-policy-test"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/route-policy/route-policy-tests/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, ['afi', 'default_table', 'ext_comm', 'extended_community_rt', 'group_address', 'pass_', 'policy_name', 'safi', 'source_address', 'table_active', 'table_exists', 'table_name', 'vrf_name'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "route-policy-test"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "route-policy-test"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class RpfRedirect(Entity):
                """
                PIM ECMP RPF\-redirect bundle
                
                .. attribute:: bundle_interfaces
                
                	PIM ECMP RPF\-redirect bundle information
                	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces>`
                
                .. attribute:: redirect_route_databases
                
                	PIM ECMP RPF\-redirect route database
                	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.RpfRedirect, self).__init__()

                    self.yang_name = "rpf-redirect"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"bundle-interfaces" : ("bundle_interfaces", Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces), "redirect-route-databases" : ("redirect_route_databases", Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases)}
                    self._child_list_classes = {}

                    self.bundle_interfaces = Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces()
                    self.bundle_interfaces.parent = self
                    self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                    self._children_yang_names.add("bundle-interfaces")

                    self.redirect_route_databases = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                    self.redirect_route_databases.parent = self
                    self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                    self._children_yang_names.add("redirect-route-databases")
                    self._segment_path = lambda: "rpf-redirect"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()


                class BundleInterfaces(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle information
                    
                    .. attribute:: bundle_interface
                    
                    	PIM ECMP RPF\-redirect bundle interface information
                    	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces, self).__init__()

                        self.yang_name = "bundle-interfaces"
                        self.yang_parent_name = "rpf-redirect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"bundle-interface" : ("bundle_interface", Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface)}

                        self.bundle_interface = YList(self)
                        self._segment_path = lambda: "bundle-interfaces"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces, [], name, value)


                    class BundleInterface(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle interface
                        information
                        
                        .. attribute:: allocated_bandwidth
                        
                        	Bandwidth allocated in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_threshold_bandwidth
                        
                        	Configured threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_threshold_bandwidth
                        
                        	Available threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: bundle_name
                        
                        	Bundle name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: interface_name
                        
                        	Bundle interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: rpf_redirect_bundle_name
                        
                        	RPF redirect bundle name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_redirect_interface_name
                        
                        	RPF redirect interface name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: snooping_bandwidth_used
                        
                        	Bandwidth used by snooped entries in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: topology_bandwidth_used
                        
                        	Bandwidth used by topology in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: total_bandwidth
                        
                        	Total bandwidth used in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                            self.yang_name = "bundle-interface"
                            self.yang_parent_name = "bundle-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.allocated_bandwidth = YLeaf(YType.int32, "allocated-bandwidth")

                            self.allocated_threshold_bandwidth = YLeaf(YType.int32, "allocated-threshold-bandwidth")

                            self.available_bandwidth = YLeaf(YType.int32, "available-bandwidth")

                            self.available_threshold_bandwidth = YLeaf(YType.int32, "available-threshold-bandwidth")

                            self.bundle_name = YLeaf(YType.str, "bundle-name")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.rpf_redirect_bundle_name = YLeaf(YType.str, "rpf-redirect-bundle-name")

                            self.rpf_redirect_interface_name = YLeaf(YType.str, "rpf-redirect-interface-name")

                            self.snooping_bandwidth_used = YLeaf(YType.int32, "snooping-bandwidth-used")

                            self.topology_bandwidth_used = YLeaf(YType.int32, "topology-bandwidth-used")

                            self.total_bandwidth = YLeaf(YType.int32, "total-bandwidth")
                            self._segment_path = lambda: "bundle-interface"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/bundle-interfaces/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, ['allocated_bandwidth', 'allocated_threshold_bandwidth', 'available_bandwidth', 'available_threshold_bandwidth', 'bundle_name', 'interface_name', 'rpf_redirect_bundle_name', 'rpf_redirect_interface_name', 'snooping_bandwidth_used', 'topology_bandwidth_used', 'total_bandwidth'], name, value)


                class RedirectRouteDatabases(Entity):
                    """
                    PIM ECMP RPF\-redirect route database
                    
                    .. attribute:: redirect_route_database
                    
                    	PIM ECMP RPF\-redirect route information
                    	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__init__()

                        self.yang_name = "redirect-route-databases"
                        self.yang_parent_name = "rpf-redirect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"redirect-route-database" : ("redirect_route_database", Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase)}

                        self.redirect_route_database = YList(self)
                        self._segment_path = lambda: "redirect-route-databases"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases, [], name, value)


                    class RedirectRouteDatabase(Entity):
                        """
                        PIM ECMP RPF\-redirect route information
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group ddress
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                        
                        .. attribute:: interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                            self.yang_name = "redirect-route-database"
                            self.yang_parent_name = "redirect-route-databases"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr), "source-address-xr" : ("source_address_xr", Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr)}
                            self._child_list_classes = {"interface" : ("interface", Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface)}

                            self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.source_address_xr = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                            self.interface = YList(self)
                            self._segment_path = lambda: "redirect-route-database"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/redirect-route-databases/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, ['bandwidth', 'group_address', 'source_address', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group ddress
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Interface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_outgoing_interface
                            
                            	Is outgoing Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_rpf_interface
                            
                            	Is RPF Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_snoop_interface
                            
                            	Is snooping Interface
                            	**type**\:  bool
                            
                            .. attribute:: rpf_address
                            
                            	RPF Address
                            	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"rpf-address" : ("rpf_address", Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress)}
                                self._child_list_classes = {}

                                self.expiry = YLeaf(YType.uint64, "expiry")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.is_outgoing_interface = YLeaf(YType.boolean, "is-outgoing-interface")

                                self.is_rpf_interface = YLeaf(YType.boolean, "is-rpf-interface")

                                self.is_snoop_interface = YLeaf(YType.boolean, "is-snoop-interface")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.rpf_address = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                self.rpf_address.parent = self
                                self._children_name_map["rpf_address"] = "rpf-address"
                                self._children_yang_names.add("rpf-address")
                                self._segment_path = lambda: "interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, ['expiry', 'interface_name', 'is_outgoing_interface', 'is_rpf_interface', 'is_snoop_interface', 'uptime'], name, value)


                            class RpfAddress(Entity):
                                """
                                RPF Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                    self.yang_name = "rpf-address"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "rpf-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class RpfSummary(Entity):
                """
                PIM RPF registration summary
                
                .. attribute:: default_safi
                
                	Default RPF Table SAFI
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: default_table_name
                
                	Default RPF Table Name
                	**type**\:  str
                
                .. attribute:: is_isis_mtr_configured
                
                	Is ISIS MTR configured?
                	**type**\:  bool
                
                .. attribute:: is_isis_te_configured
                
                	Is ISIS TE configured?
                	**type**\:  bool
                
                .. attribute:: is_mbgp_configured
                
                	Is MBGP configured?
                	**type**\:  bool
                
                .. attribute:: is_multipath_enabled
                
                	Is Multipath Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_interface_hash_enabled
                
                	Is Multipath Interface Hash Extension Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_hash_enabled
                
                	Is Multipath Source based Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_next_hop_hash_enabled
                
                	Is Multipath Source\-Nexthop Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_ospf_te_configured
                
                	Is OSPF TE configured?
                	**type**\:  bool
                
                .. attribute:: is_rib_convergence
                
                	RIB Convergence status
                	**type**\:  bool
                
                .. attribute:: mo_frr_configured
                
                	Is MoFRR configured?
                	**type**\:  bool
                
                .. attribute:: rib_convergence_time_left
                
                	RIB convergence time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_convergence_timeout
                
                	RIB convergence timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_mo_frr_configured
                
                	Is MoFRR RIB configured?
                	**type**\:  bool
                
                .. attribute:: rpf_registrations
                
                	RPF Registration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	Is RUMP MuRIB enabled?
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.RpfSummary, self).__init__()

                    self.yang_name = "rpf-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.default_safi = YLeaf(YType.uint32, "default-safi")

                    self.default_table_name = YLeaf(YType.str, "default-table-name")

                    self.is_isis_mtr_configured = YLeaf(YType.boolean, "is-isis-mtr-configured")

                    self.is_isis_te_configured = YLeaf(YType.boolean, "is-isis-te-configured")

                    self.is_mbgp_configured = YLeaf(YType.boolean, "is-mbgp-configured")

                    self.is_multipath_enabled = YLeaf(YType.boolean, "is-multipath-enabled")

                    self.is_multipath_interface_hash_enabled = YLeaf(YType.boolean, "is-multipath-interface-hash-enabled")

                    self.is_multipath_source_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-hash-enabled")

                    self.is_multipath_source_next_hop_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-next-hop-hash-enabled")

                    self.is_ospf_te_configured = YLeaf(YType.boolean, "is-ospf-te-configured")

                    self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                    self.mo_frr_configured = YLeaf(YType.boolean, "mo-frr-configured")

                    self.rib_convergence_time_left = YLeaf(YType.uint32, "rib-convergence-time-left")

                    self.rib_convergence_timeout = YLeaf(YType.uint32, "rib-convergence-timeout")

                    self.rib_mo_frr_configured = YLeaf(YType.boolean, "rib-mo-frr-configured")

                    self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                    self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")
                    self._segment_path = lambda: "rpf-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfSummary, ['default_safi', 'default_table_name', 'is_isis_mtr_configured', 'is_isis_te_configured', 'is_mbgp_configured', 'is_multipath_enabled', 'is_multipath_interface_hash_enabled', 'is_multipath_source_hash_enabled', 'is_multipath_source_next_hop_hash_enabled', 'is_ospf_te_configured', 'is_rib_convergence', 'mo_frr_configured', 'rib_convergence_time_left', 'rib_convergence_timeout', 'rib_mo_frr_configured', 'rpf_registrations', 'rump_enabled'], name, value)


            class Safs(Entity):
                """
                SAFI table and type
                
                .. attribute:: saf
                
                	SAF name 
                	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Safs, self).__init__()

                    self.yang_name = "safs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"saf" : ("saf", Ipv6Pim.Active.DefaultContext.Safs.Saf)}

                    self.saf = YList(self)
                    self._segment_path = lambda: "safs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs, [], name, value)


                class Saf(Entity):
                    """
                    SAF name 
                    
                    .. attribute:: rpf_hash_source_groups
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups>`
                    
                    .. attribute:: rpf_hash_sources
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources>`
                    
                    .. attribute:: rpfs
                    
                    	PIM RPF information table
                    	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs>`
                    
                    .. attribute:: saf_name
                    
                    	SAF name 
                    	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name 
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Safs.Saf, self).__init__()

                        self.yang_name = "saf"
                        self.yang_parent_name = "safs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rpf-hash-source-groups" : ("rpf_hash_source_groups", Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups), "rpf-hash-sources" : ("rpf_hash_sources", Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources), "rpfs" : ("rpfs", Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs)}
                        self._child_list_classes = {}

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                        self.topology_name = YLeaf(YType.str, "topology-name")

                        self.rpf_hash_source_groups = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                        self.rpf_hash_source_groups.parent = self
                        self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                        self._children_yang_names.add("rpf-hash-source-groups")

                        self.rpf_hash_sources = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources()
                        self.rpf_hash_sources.parent = self
                        self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                        self._children_yang_names.add("rpf-hash-sources")

                        self.rpfs = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs()
                        self.rpfs.parent = self
                        self._children_name_map["rpfs"] = "rpfs"
                        self._children_yang_names.add("rpfs")
                        self._segment_path = lambda: "saf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf, ['saf_name', 'topology_name'], name, value)


                    class RpfHashSourceGroups(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source_group
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__init__()

                            self.yang_name = "rpf-hash-source-groups"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"rpf-hash-source-group" : ("rpf_hash_source_group", Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup)}

                            self.rpf_hash_source_group = YList(self)
                            self._segment_path = lambda: "rpf-hash-source-groups"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups, [], name, value)


                        class RpfHashSourceGroup(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: mask_length
                            
                            	Hash mask length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                self.yang_name = "rpf-hash-source-group"
                                self.yang_parent_name = "rpf-hash-source-groups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"next-hop-address" : ("next_hop_address", Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress), "secondary-next-hop-address" : ("secondary_next_hop_address", Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress)}
                                self._child_list_classes = {}

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.mask_length = YLeaf(YType.int32, "mask-length")

                                self.mofrr = YLeaf(YType.int32, "mofrr")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                self._children_yang_names.add("next-hop-address")

                                self.secondary_next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._children_yang_names.add("secondary-next-hop-address")
                                self._segment_path = lambda: "rpf-hash-source-group"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpf-hash-source-groups/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, ['group_address', 'mask_length', 'mofrr', 'next_hop_interface', 'next_hop_multipath_enabled', 'secondary_next_hop_interface', 'source_address'], name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "secondary-next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfHashSources(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources, self).__init__()

                            self.yang_name = "rpf-hash-sources"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"rpf-hash-source" : ("rpf_hash_source", Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource)}

                            self.rpf_hash_source = YList(self)
                            self._segment_path = lambda: "rpf-hash-sources"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources, [], name, value)


                        class RpfHashSource(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                self.yang_name = "rpf-hash-source"
                                self.yang_parent_name = "rpf-hash-sources"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"next-hop-address" : ("next_hop_address", Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress), "secondary-next-hop-address" : ("secondary_next_hop_address", Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress)}
                                self._child_list_classes = {}

                                self.mofrr = YLeaf(YType.int32, "mofrr")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                self._children_yang_names.add("next-hop-address")

                                self.secondary_next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._children_yang_names.add("secondary-next-hop-address")
                                self._segment_path = lambda: "rpf-hash-source"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpf-hash-sources/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, ['mofrr', 'next_hop_interface', 'next_hop_multipath_enabled', 'secondary_next_hop_interface', 'source_address'], name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "secondary-next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Rpfs(Entity):
                        """
                        PIM RPF information table
                        
                        .. attribute:: rpf
                        
                        	PIM RPF information
                        	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs, self).__init__()

                            self.yang_name = "rpfs"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"rpf" : ("rpf", Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf)}

                            self.rpf = YList(self)
                            self._segment_path = lambda: "rpfs"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs, [], name, value)


                        class Rpf(Entity):
                            """
                            PIM RPF information
                            
                            .. attribute:: registered_address  <key>
                            
                            	Address for which RPF lookup
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_rpf_bgp_route
                            
                            	Is RPF through BGP route
                            	**type**\:  bool
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address_xr
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                            
                            .. attribute:: rpf_path
                            
                            	RPF Paths list
                            	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__init__()

                                self.yang_name = "rpf"
                                self.yang_parent_name = "rpfs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"registered-address-xr" : ("registered_address_xr", Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr)}
                                self._child_list_classes = {"rpf-path" : ("rpf_path", Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath)}

                                self.registered_address = YLeaf(YType.str, "registered-address")

                                self.is_connected = YLeaf(YType.uint8, "is-connected")

                                self.is_rpf_bgp_route = YLeaf(YType.boolean, "is-rpf-bgp-route")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                self.registered_address_xr = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                self.registered_address_xr.parent = self
                                self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                self._children_yang_names.add("registered-address-xr")

                                self.rpf_path = YList(self)
                                self._segment_path = lambda: "rpf" + "[registered-address='" + self.registered_address.get() + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpfs/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf, ['registered_address', 'is_connected', 'is_rpf_bgp_route', 'metric', 'metric_preference'], name, value)


                            class RegisteredAddressXr(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                    self.yang_name = "registered-address-xr"
                                    self.yang_parent_name = "rpf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "registered-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class RpfPath(Entity):
                                """
                                RPF Paths list
                                
                                .. attribute:: connector
                                
                                	Connector Attribute
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface_disabled
                                
                                	Is the rpf interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                .. attribute:: is_via_mlsm
                                
                                	Via Mstatic LSM
                                	**type**\:  bool
                                
                                .. attribute:: rpf_interface_name
                                
                                	RPF Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: rpf_neighbor
                                
                                	RPF neighbor
                                	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                
                                .. attribute:: rpf_nexthop
                                
                                	RPF nexthop
                                	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                    self.yang_name = "rpf-path"
                                    self.yang_parent_name = "rpf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"rpf-neighbor" : ("rpf_neighbor", Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor), "rpf-nexthop" : ("rpf_nexthop", Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop)}
                                    self._child_list_classes = {}

                                    self.connector = YLeaf(YType.str, "connector")

                                    self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                    self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                    self.is_rpf_interface_disabled = YLeaf(YType.boolean, "is-rpf-interface-disabled")

                                    self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                    self.is_via_mlsm = YLeaf(YType.boolean, "is-via-mlsm")

                                    self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                                    self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                    self._children_yang_names.add("rpf-neighbor")

                                    self.rpf_nexthop = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                    self.rpf_nexthop.parent = self
                                    self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                    self._children_yang_names.add("rpf-nexthop")
                                    self._segment_path = lambda: "rpf-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, ['connector', 'extranet_vrf_name', 'is_connector_attribute_present', 'is_rpf_interface_disabled', 'is_via_lsm', 'is_via_mlsm', 'rpf_interface_name'], name, value)


                                class RpfNeighbor(Entity):
                                    """
                                    RPF neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                        self.yang_name = "rpf-neighbor"
                                        self.yang_parent_name = "rpf-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "rpf-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class RpfNexthop(Entity):
                                    """
                                    RPF nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                        self.yang_name = "rpf-nexthop"
                                        self.yang_parent_name = "rpf-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "rpf-nexthop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Summary(Entity):
                """
                PIM summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                    self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                    self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                    self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                    self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                    self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                    self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                    self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                    self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                    self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                    self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                    self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                    self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                    self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                    self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                    self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                    self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                    self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                    self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                    self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                    self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                    self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                    self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                    self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                    self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                    self.register_count = YLeaf(YType.uint32, "register-count")

                    self.register_limit = YLeaf(YType.uint32, "register-limit")

                    self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                    self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                    self.route_count = YLeaf(YType.uint32, "route-count")

                    self.route_limit = YLeaf(YType.uint32, "route-limit")

                    self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                    self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                    self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                    self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                    self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                    self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                    self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Summary, ['bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_threshold', 'bsr_range_threshold', 'bsr_ranges_count', 'bsr_ranges_limit', 'global_auto_rp_ranges_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_threshold', 'global_bsr_ranges_count', 'global_bsr_ranges_limit', 'global_bsr_ranges_threshold', 'global_register_limit', 'is_bsr_ranges_threshold_reached', 'is_global_auto_rp_ranges_limit_reached', 'is_global_bsr_ranges_limit_reached', 'is_global_register_limit_reached', 'is_global_route_limit_reached', 'is_global_rxi_limit_reached', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'is_ranges_limit_reached', 'is_route_limit_reached', 'ranges_count', 'ranges_limit', 'ranges_threshold', 'register_count', 'register_limit', 'register_limit_reached', 'register_threshold', 'route_count', 'route_limit', 'route_low_water_mark', 'route_threshold', 'rxi_limit_reached', 'rxi_low_water_mark', 'topology_interface_state_count', 'topology_interface_state_limit', 'topology_interface_state_threshold'], name, value)


            class TableContexts(Entity):
                """
                PIM table context list
                
                .. attribute:: table_context
                
                	PIM table context information
                	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TableContexts.TableContext>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.TableContexts, self).__init__()

                    self.yang_name = "table-contexts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"table-context" : ("table_context", Ipv6Pim.Active.DefaultContext.TableContexts.TableContext)}

                    self.table_context = YList(self)
                    self._segment_path = lambda: "table-contexts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.TableContexts, [], name, value)


                class TableContext(Entity):
                    """
                    PIM table context information
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saf_name
                    
                    	SAF name
                    	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: topology_name
                    
                    	Topology name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.TableContexts.TableContext, self).__init__()

                        self.yang_name = "table-context"
                        self.yang_parent_name = "table-contexts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.uint32, "afi")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                        self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                        self.safi = YLeaf(YType.uint32, "safi")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.table_name = YLeaf(YType.str, "table-name")

                        self.topology_name = YLeaf(YType.str, "topology-name")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")
                        self._segment_path = lambda: "table-context"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/table-contexts/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.TableContexts.TableContext, ['afi', 'is_active', 'is_ital_registration_done', 'is_rib_convergence', 'is_rib_convergence_received', 'is_rib_registration_done', 'rpf_registrations', 'saf_name', 'safi', 'table_id', 'table_name', 'topology_name', 'vrf_id'], name, value)


            class Topologies(Entity):
                """
                PIM topology table
                
                .. attribute:: topology
                
                	PIM topology information
                	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Topologies, self).__init__()

                    self.yang_name = "topologies"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"topology" : ("topology", Ipv6Pim.Active.DefaultContext.Topologies.Topology)}

                    self.topology = YList(self)
                    self._segment_path = lambda: "topologies"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies, [], name, value)


                class Topology(Entity):
                    """
                    PIM topology information
                    
                    .. attribute:: alive
                    
                    	Alive time in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: anycast_rp_match
                    
                    	Group matches Anycast\-RP policy
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_route_target
                    
                    	Anycast\-RP RT
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: assume_alive
                    
                    	The Assume Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: bgp_join
                    
                    	BGP C JOIN
                    	**type**\:  bool
                    
                    .. attribute:: bgp_jp_time
                    
                    	BGP C JP Time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: connected
                    
                    	Is Connected ?
                    	**type**\:  bool
                    
                    .. attribute:: crossed_threshold
                    
                    	Incoming traffic crossed threshold. MT flag set
                    	**type**\:  bool
                    
                    .. attribute:: customer_routing_type
                    
                    	Type of Customer Routing in the MVPN
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: data_mdt_addr_assigned
                    
                    	PIM has assigned a Data MDT Address
                    	**type**\:  bool
                    
                    .. attribute:: dont_check_connected
                    
                    	Do we need to make the connected check on this route ?
                    	**type**\:  bool
                    
                    .. attribute:: expiry
                    
                    	When this entry expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: extranet_route
                    
                    	Is a Extranet route ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr>`
                    
                    .. attribute:: inherit_alive
                    
                    	The Inherit Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: inherit_spt
                    
                    	The Inherit SPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: is_via_lsm
                    
                    	Via LSM
                    	**type**\:  bool
                    
                    .. attribute:: jp_status
                    
                    	Join\-Prune Status
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: jp_timer
                    
                    	Join\-Prune Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: kat_state
                    
                    	Keep Alive Timer State
                    	**type**\:  bool
                    
                    .. attribute:: last_hop
                    
                    	Are we last hop ?
                    	**type**\:  bool
                    
                    .. attribute:: limit_reached
                    
                    	Have we throttled the creation of routes or interfaces ?
                    	**type**\:  bool
                    
                    .. attribute:: low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_active
                    
                    	Is MoFRR Active?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_backup
                    
                    	Is this Mofrr Backup?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_primary
                    
                    	Is this Mofrr Primary?
                    	**type**\:  bool
                    
                    .. attribute:: orig_src_address
                    
                    	Orig Src Address
                    	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress>`
                    
                    .. attribute:: outgoing_interface
                    
                    	Outgoing interface list
                    	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface>`
                    
                    .. attribute:: probe_alive
                    
                    	The Probe Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: proxy
                    
                    	Is the RPF target a proxy?
                    	**type**\:  bool
                    
                    .. attribute:: proxy_address
                    
                    	RPF Proxy address
                    	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress>`
                    
                    .. attribute:: really_alive
                    
                    	The Really Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: register_received
                    
                    	Have registers been received for this source ?
                    	**type**\:  bool
                    
                    .. attribute:: register_received_timer
                    
                    	Register Received Timer in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: remote_source
                    
                    	MSDP told us
                    	**type**\:  bool
                    
                    .. attribute:: rib_mo_frr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rp_address
                    
                    	RP Address (If rpt)
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor>`
                    
                    .. attribute:: rpf_proxy_enabled
                    
                    	Is rpf if proxy enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: rpt
                    
                    	RPT bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpt_xr
                    
                    	Is this on the RPT ?
                    	**type**\:  bool
                    
                    .. attribute:: sa_joined
                    
                    	BGP SA join
                    	**type**\:  bool
                    
                    .. attribute:: sa_received
                    
                    	BGP SA received
                    	**type**\:  bool
                    
                    .. attribute:: sa_sent
                    
                    	BGP SA sent
                    	**type**\:  bool
                    
                    .. attribute:: secondary_rpf_interface_name
                    
                    	Secondary Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: secondary_rpf_neighbor
                    
                    	Secondary RPF Neighbor
                    	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor>`
                    
                    .. attribute:: sending_null_registers
                    
                    	Are we sending null registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: sending_registers
                    
                    	Are we sending registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: signal_sources
                    
                    	Signal Sources on route?
                    	**type**\:  bool
                    
                    .. attribute:: source_address
                    
                    	Source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr>`
                    
                    .. attribute:: spt
                    
                    	Is this on the SPT ?
                    	**type**\:  bool
                    
                    .. attribute:: suppress_registers
                    
                    	When the Null register probe expires
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: vxlan
                    
                    	Is this VXLAN?
                    	**type**\:  bool
                    
                    .. attribute:: wildcard
                    
                    	WC \-Wildcard
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Topologies.Topology, self).__init__()

                        self.yang_name = "topology"
                        self.yang_parent_name = "topologies"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr), "orig-src-address" : ("orig_src_address", Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress), "proxy-address" : ("proxy_address", Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress), "rp-address" : ("rp_address", Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress), "rpf-neighbor" : ("rpf_neighbor", Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor), "rpf-root" : ("rpf_root", Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot), "secondary-rpf-neighbor" : ("secondary_rpf_neighbor", Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor), "source-address-xr" : ("source_address_xr", Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr)}
                        self._child_list_classes = {"outgoing-interface" : ("outgoing_interface", Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface)}

                        self.alive = YLeaf(YType.int32, "alive")

                        self.anycast_rp_match = YLeaf(YType.boolean, "anycast-rp-match")

                        self.anycast_rp_route_target = YLeaf(YType.str, "anycast-rp-route-target")

                        self.assume_alive = YLeaf(YType.boolean, "assume-alive")

                        self.bgp_join = YLeaf(YType.boolean, "bgp-join")

                        self.bgp_jp_time = YLeaf(YType.uint64, "bgp-jp-time")

                        self.connected = YLeaf(YType.boolean, "connected")

                        self.crossed_threshold = YLeaf(YType.boolean, "crossed-threshold")

                        self.customer_routing_type = YLeaf(YType.int32, "customer-routing-type")

                        self.data_mdt_addr_assigned = YLeaf(YType.boolean, "data-mdt-addr-assigned")

                        self.dont_check_connected = YLeaf(YType.boolean, "dont-check-connected")

                        self.expiry = YLeaf(YType.uint64, "expiry")

                        self.extranet_route = YLeaf(YType.boolean, "extranet-route")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.inherit_alive = YLeaf(YType.boolean, "inherit-alive")

                        self.inherit_spt = YLeaf(YType.boolean, "inherit-spt")

                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                        self.jp_status = YLeaf(YType.int32, "jp-status")

                        self.jp_timer = YLeaf(YType.int32, "jp-timer")

                        self.kat_state = YLeaf(YType.boolean, "kat-state")

                        self.last_hop = YLeaf(YType.boolean, "last-hop")

                        self.limit_reached = YLeaf(YType.boolean, "limit-reached")

                        self.low_memory = YLeaf(YType.boolean, "low-memory")

                        self.mofrr_active = YLeaf(YType.boolean, "mofrr-active")

                        self.mofrr_backup = YLeaf(YType.boolean, "mofrr-backup")

                        self.mofrr_enabled = YLeaf(YType.boolean, "mofrr-enabled")

                        self.mofrr_primary = YLeaf(YType.boolean, "mofrr-primary")

                        self.probe_alive = YLeaf(YType.boolean, "probe-alive")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.proxy = YLeaf(YType.boolean, "proxy")

                        self.really_alive = YLeaf(YType.boolean, "really-alive")

                        self.register_received = YLeaf(YType.boolean, "register-received")

                        self.register_received_timer = YLeaf(YType.int32, "register-received-timer")

                        self.remote_source = YLeaf(YType.boolean, "remote-source")

                        self.rib_mo_frr_enabled = YLeaf(YType.boolean, "rib-mo-frr-enabled")

                        self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                        self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_proxy_enabled = YLeaf(YType.boolean, "rpf-proxy-enabled")

                        self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                        self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.rpt = YLeaf(YType.int32, "rpt")

                        self.rpt_xr = YLeaf(YType.boolean, "rpt-xr")

                        self.sa_joined = YLeaf(YType.boolean, "sa-joined")

                        self.sa_received = YLeaf(YType.boolean, "sa-received")

                        self.sa_sent = YLeaf(YType.boolean, "sa-sent")

                        self.secondary_rpf_interface_name = YLeaf(YType.str, "secondary-rpf-interface-name")

                        self.sending_null_registers = YLeaf(YType.boolean, "sending-null-registers")

                        self.sending_registers = YLeaf(YType.boolean, "sending-registers")

                        self.signal_sources = YLeaf(YType.boolean, "signal-sources")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.spt = YLeaf(YType.boolean, "spt")

                        self.suppress_registers = YLeaf(YType.int32, "suppress-registers")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.vxlan = YLeaf(YType.boolean, "vxlan")

                        self.wildcard = YLeaf(YType.boolean, "wildcard")

                        self.group_address_xr = Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.orig_src_address = Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress()
                        self.orig_src_address.parent = self
                        self._children_name_map["orig_src_address"] = "orig-src-address"
                        self._children_yang_names.add("orig-src-address")

                        self.proxy_address = Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress()
                        self.proxy_address.parent = self
                        self._children_name_map["proxy_address"] = "proxy-address"
                        self._children_yang_names.add("proxy-address")

                        self.rp_address = Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                        self.rpf_root = Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._children_yang_names.add("rpf-root")

                        self.secondary_rpf_neighbor = Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                        self.secondary_rpf_neighbor.parent = self
                        self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                        self._children_yang_names.add("secondary-rpf-neighbor")

                        self.source_address_xr = Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"
                        self._children_yang_names.add("source-address-xr")

                        self.outgoing_interface = YList(self)
                        self._segment_path = lambda: "topology"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology, ['alive', 'anycast_rp_match', 'anycast_rp_route_target', 'assume_alive', 'bgp_join', 'bgp_jp_time', 'connected', 'crossed_threshold', 'customer_routing_type', 'data_mdt_addr_assigned', 'dont_check_connected', 'expiry', 'extranet_route', 'group_address', 'inherit_alive', 'inherit_spt', 'is_via_lsm', 'jp_status', 'jp_timer', 'kat_state', 'last_hop', 'limit_reached', 'low_memory', 'mofrr_active', 'mofrr_backup', 'mofrr_enabled', 'mofrr_primary', 'probe_alive', 'protocol', 'proxy', 'really_alive', 'register_received', 'register_received_timer', 'remote_source', 'rib_mo_frr_enabled', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_proxy_enabled', 'rpf_safi', 'rpf_table_name', 'rpf_vrf_name', 'rpt', 'rpt_xr', 'sa_joined', 'sa_received', 'sa_sent', 'secondary_rpf_interface_name', 'sending_null_registers', 'sending_registers', 'signal_sources', 'source_address', 'spt', 'suppress_registers', 'uptime', 'vxlan', 'wildcard'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class OrigSrcAddress(Entity):
                        """
                        Orig Src Address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__init__()

                            self.yang_name = "orig-src-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "orig-src-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class OutgoingInterface(Entity):
                        """
                        Outgoing interface list
                        
                        .. attribute:: admin_boundary
                        
                        	Is this an administrative boundary ?
                        	**type**\:  bool
                        
                        .. attribute:: assert_state
                        
                        	Assert State
                        	**type**\:  bool
                        
                        .. attribute:: assert_timer
                        
                        	Assert Timer in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: assert_winner
                        
                        	Assert Winner
                        	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner>`
                        
                        .. attribute:: bgp_c_mcast_join
                        
                        	BGP C\-Mcast join
                        	**type**\:  bool
                        
                        .. attribute:: bgp_c_mcast_prune_delay_timer
                        
                        	BGP C\-MCAST Prune Suppression in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: data_mdt_join
                        
                        	Data MDT join
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	Expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: extranet_interface
                        
                        	Is this an Extranet Interface ?
                        	**type**\:  bool
                        
                        .. attribute:: forwarding_state
                        
                        	Forward or Prune
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: igmp_membership
                        
                        	IGMP membership
                        	**type**\:  bool
                        
                        .. attribute:: immediate_state
                        
                        	Immediate fwding state
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: internal_interest_info
                        
                        	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: internal_interest_information
                        
                        	Internal Interest. Replaces internal\-interest\-info
                        	**type**\:   :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                        
                        .. attribute:: jp_state
                        
                        	Join\-Prune State
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer (secs)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: local_mdt_join
                        
                        	Default MDT Join
                        	**type**\:  bool
                        
                        .. attribute:: local_members
                        
                        	Local Information. Deprecated \- use 'local\-members\-information' instead
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: local_members_information
                        
                        	Local Information. Replaces local\-members
                        	**type**\:   :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                        
                        .. attribute:: mdt_safi_join
                        
                        	MDT Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mldp_inband_mdt
                        
                        	MLDP Inband MDT interface
                        	**type**\:  bool
                        
                        .. attribute:: mldp_stale
                        
                        	OLE is stale
                        	**type**\:  bool
                        
                        .. attribute:: mvpn_safi_join
                        
                        	MVPN Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mvpnv6_safi_join
                        
                        	MVPN IPv6 Safi join
                        	**type**\:  bool
                        
                        .. attribute:: sa_prune
                        
                        	BGP SA Prune state
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vrf_name
                        
                        	VRF which physically owns
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface, self).__init__()

                            self.yang_name = "outgoing-interface"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"assert-winner" : ("assert_winner", Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner)}
                            self._child_list_classes = {}

                            self.admin_boundary = YLeaf(YType.boolean, "admin-boundary")

                            self.assert_state = YLeaf(YType.boolean, "assert-state")

                            self.assert_timer = YLeaf(YType.int32, "assert-timer")

                            self.bgp_c_mcast_join = YLeaf(YType.boolean, "bgp-c-mcast-join")

                            self.bgp_c_mcast_prune_delay_timer = YLeaf(YType.uint64, "bgp-c-mcast-prune-delay-timer")

                            self.data_mdt_join = YLeaf(YType.boolean, "data-mdt-join")

                            self.expiry = YLeaf(YType.uint64, "expiry")

                            self.extranet_interface = YLeaf(YType.boolean, "extranet-interface")

                            self.forwarding_state = YLeaf(YType.int32, "forwarding-state")

                            self.igmp_membership = YLeaf(YType.boolean, "igmp-membership")

                            self.immediate_state = YLeaf(YType.int32, "immediate-state")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.internal_interest_info = YLeaf(YType.int32, "internal-interest-info")

                            self.internal_interest_information = YLeaf(YType.enumeration, "internal-interest-information")

                            self.jp_state = YLeaf(YType.int32, "jp-state")

                            self.jp_timer = YLeaf(YType.int32, "jp-timer")

                            self.last_hop = YLeaf(YType.boolean, "last-hop")

                            self.local_mdt_join = YLeaf(YType.boolean, "local-mdt-join")

                            self.local_members = YLeaf(YType.int32, "local-members")

                            self.local_members_information = YLeaf(YType.enumeration, "local-members-information")

                            self.mdt_safi_join = YLeaf(YType.boolean, "mdt-safi-join")

                            self.mldp_inband_mdt = YLeaf(YType.boolean, "mldp-inband-mdt")

                            self.mldp_stale = YLeaf(YType.boolean, "mldp-stale")

                            self.mvpn_safi_join = YLeaf(YType.boolean, "mvpn-safi-join")

                            self.mvpnv6_safi_join = YLeaf(YType.boolean, "mvpnv6-safi-join")

                            self.sa_prune = YLeaf(YType.boolean, "sa-prune")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.assert_winner = Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                            self.assert_winner.parent = self
                            self._children_name_map["assert_winner"] = "assert-winner"
                            self._children_yang_names.add("assert-winner")
                            self._segment_path = lambda: "outgoing-interface"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface, ['admin_boundary', 'assert_state', 'assert_timer', 'bgp_c_mcast_join', 'bgp_c_mcast_prune_delay_timer', 'data_mdt_join', 'expiry', 'extranet_interface', 'forwarding_state', 'igmp_membership', 'immediate_state', 'interface_name', 'internal_interest_info', 'internal_interest_information', 'jp_state', 'jp_timer', 'last_hop', 'local_mdt_join', 'local_members', 'local_members_information', 'mdt_safi_join', 'mldp_inband_mdt', 'mldp_stale', 'mvpn_safi_join', 'mvpnv6_safi_join', 'sa_prune', 'uptime', 'vrf_name'], name, value)


                        class AssertWinner(Entity):
                            """
                            Assert Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                self.yang_name = "assert-winner"
                                self.yang_parent_name = "outgoing-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "assert-winner"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/outgoing-interface/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class ProxyAddress(Entity):
                        """
                        RPF Proxy address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress, self).__init__()

                            self.yang_name = "proxy-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "proxy-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address (If rpt)
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-root"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SecondaryRpfNeighbor(Entity):
                        """
                        Secondary RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                            self.yang_name = "secondary-rpf-neighbor"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "secondary-rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class TopologyEntryFlagRouteCounts(Entity):
                """
                Route count for topology with entry flag set
                
                .. attribute:: topology_entry_flag_route_count
                
                	Route count for topology with entry flag set
                	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-entry-flag-route-counts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"topology-entry-flag-route-count" : ("topology_entry_flag_route_count", Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount)}

                    self.topology_entry_flag_route_count = YList(self)
                    self._segment_path = lambda: "topology-entry-flag-route-counts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts, [], name, value)


                class TopologyEntryFlagRouteCount(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: entry_flag  <key>
                    
                    	entry flag
                    	**type**\:   :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                        self.yang_name = "topology-entry-flag-route-count"
                        self.yang_parent_name = "topology-entry-flag-route-counts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.entry_flag = YLeaf(YType.enumeration, "entry-flag")

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                        self._segment_path = lambda: "topology-entry-flag-route-count" + "[entry-flag='" + self.entry_flag.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topology-entry-flag-route-counts/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, ['entry_flag', 'active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


            class TopologyInterfaceFlagRouteCounts(Entity):
                """
                Route count for topology with interface flag set
                
                .. attribute:: topology_interface_flag_route_count
                
                	Route count for topology with interface flag set
                	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-interface-flag-route-counts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"topology-interface-flag-route-count" : ("topology_interface_flag_route_count", Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount)}

                    self.topology_interface_flag_route_count = YList(self)
                    self._segment_path = lambda: "topology-interface-flag-route-counts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts, [], name, value)


                class TopologyInterfaceFlagRouteCount(Entity):
                    """
                    Route count for topology with interface flag
                    set
                    
                    .. attribute:: interface_flag  <key>
                    
                    	Interface flag
                    	**type**\:   :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                        self.yang_name = "topology-interface-flag-route-count"
                        self.yang_parent_name = "topology-interface-flag-route-counts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.interface_flag = YLeaf(YType.enumeration, "interface-flag")

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                        self._segment_path = lambda: "topology-interface-flag-route-count" + "[interface-flag='" + self.interface_flag.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topology-interface-flag-route-counts/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, ['interface_flag', 'active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


            class TopologyRouteCount(Entity):
                """
                Topology route count information from PIM
                topology table
                
                .. attribute:: active_group_ranges
                
                	No. of (\*,G/M) routes active in mrib
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_ranges
                
                	No. of (\*,G/M) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groute_count
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: sg_route_count
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sgr_route_count
                
                	No. of (S,G)RPT routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.TopologyRouteCount, self).__init__()

                    self.yang_name = "topology-route-count"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                    self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                    self.groute_count = YLeaf(YType.uint32, "groute-count")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                    self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                    self._segment_path = lambda: "topology-route-count"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.TopologyRouteCount, ['active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


            class TrafficCounters(Entity):
                """
                PIM message traffic counters
                
                .. attribute:: boundary_acl_rx_drop
                
                	Inc. JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_tx_drop
                
                	Out JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_error
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: format_error
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert
                
                	Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert_batched
                
                	Batched Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_bsr_message
                
                	Input BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_candidate_rp_advertisement
                
                	Input Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_data_register
                
                	Data Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_df_election
                
                	DF Election packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_ecmp_redirect
                
                	Input Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_hello
                
                	Hello packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_jp
                
                	Join Prune packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb_error
                
                	No IDB for intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_pim_error
                
                	PIM Disabled on intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_error
                
                	No VRF for idb error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_null_register
                
                	Null Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim_version_error
                
                	Invalid PIM version error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_register_stop
                
                	Register Stop packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: inputs
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_destination_packets
                
                	Control Packets with Invalid Destination
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_join_prunes
                
                	PIM invalid Join/Prunes received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_registers
                
                	PIM invalid registers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_local_source_address
                
                	Data MDT Join msgs dropped due to local source addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_idb
                
                	Data MDT Join msgs dropped due to idb missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_vrf
                
                	Data MDT Join msgs dropped due to vrf missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_null_local_address
                
                	Data MDT Join msgs dropped due to null local addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_bad_type
                
                	Data MDT TLV bad type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_received
                
                	Data MDT Join Msgs received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_sent
                
                	Data MDT Join Msgs sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_joins_drop_multiple_encapsulation
                
                	MDT Join msgs dropped due to multiple Encap limitation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_send_queue_full
                
                	Packets dropped since mdt send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_socket_error
                
                	MDT Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_invalid_lsm_identifier
                
                	 Invalid LSM ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_mdt_socket_connection
                
                	Packets dropped since no mdt socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_source_address
                
                	Packets dropped since no source address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: non_supported_packets
                
                	PIM non supported pckets
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert
                
                	Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert_batched
                
                	Batched Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_bsr_message
                
                	Output BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_candidate_rp_advertisement
                
                	Output Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_data_register
                
                	Data Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_df_election
                
                	DF Election packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_ecmp_redirect
                
                	Output Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello
                
                	Hello packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello_bytes
                
                	Output Hello Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_join_group
                
                	Output Join Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_prune_bytes
                
                	Output JP Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_jp
                
                	Join Prune packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_loop_error
                
                	Output on loopback error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_null_register
                
                	Null Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_prune_group
                
                	Output Prune Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_register_stop
                
                	Register Stop packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outputs
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_packman_error
                
                	Packets Dropped due to Pakman Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue
                
                	Packet queue state and statistics
                	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue>`
                
                .. attribute:: packet_queue_last_clear
                
                	Time in seconds since the last clear of all packet queues stats
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: packet_read_socket_error
                
                	Packet Read Socket Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_standby
                
                	Packets Dropped due to Standby Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pakman_error
                
                	Pakman packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_queue_full
                
                	Packets dropped since send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_error
                
                	Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_packets_error
                
                	Packets received in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: truncated_pim_packets
                
                	Packets dropped due to truncated Joins or Prunes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"packet-queue" : ("packet_queue", Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue)}

                    self.boundary_acl_rx_drop = YLeaf(YType.uint32, "boundary-acl-rx-drop")

                    self.boundary_acl_tx_drop = YLeaf(YType.uint32, "boundary-acl-tx-drop")

                    self.checksum_error = YLeaf(YType.uint32, "checksum-error")

                    self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                    self.format_error = YLeaf(YType.uint32, "format-error")

                    self.input_assert = YLeaf(YType.uint32, "input-assert")

                    self.input_assert_batched = YLeaf(YType.uint32, "input-assert-batched")

                    self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                    self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                    self.input_data_register = YLeaf(YType.uint32, "input-data-register")

                    self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                    self.input_ecmp_redirect = YLeaf(YType.uint32, "input-ecmp-redirect")

                    self.input_hello = YLeaf(YType.uint32, "input-hello")

                    self.input_jp = YLeaf(YType.uint32, "input-jp")

                    self.input_no_idb_error = YLeaf(YType.uint32, "input-no-idb-error")

                    self.input_no_pim_error = YLeaf(YType.uint32, "input-no-pim-error")

                    self.input_no_vrf_error = YLeaf(YType.uint32, "input-no-vrf-error")

                    self.input_null_register = YLeaf(YType.uint32, "input-null-register")

                    self.input_pim_version_error = YLeaf(YType.uint32, "input-pim-version-error")

                    self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                    self.inputs = YLeaf(YType.uint32, "inputs")

                    self.invalid_destination_packets = YLeaf(YType.uint32, "invalid-destination-packets")

                    self.invalid_join_prunes = YLeaf(YType.uint32, "invalid-join-prunes")

                    self.invalid_registers = YLeaf(YType.uint32, "invalid-registers")

                    self.mdt_drop_local_source_address = YLeaf(YType.uint32, "mdt-drop-local-source-address")

                    self.mdt_drop_no_idb = YLeaf(YType.uint32, "mdt-drop-no-idb")

                    self.mdt_drop_no_vrf = YLeaf(YType.uint32, "mdt-drop-no-vrf")

                    self.mdt_drop_null_local_address = YLeaf(YType.uint32, "mdt-drop-null-local-address")

                    self.mdt_join_bad_type = YLeaf(YType.uint32, "mdt-join-bad-type")

                    self.mdt_join_tlv_received = YLeaf(YType.uint32, "mdt-join-tlv-received")

                    self.mdt_join_tlv_sent = YLeaf(YType.uint32, "mdt-join-tlv-sent")

                    self.mdt_joins_drop_multiple_encapsulation = YLeaf(YType.uint32, "mdt-joins-drop-multiple-encapsulation")

                    self.mdt_send_queue_full = YLeaf(YType.uint32, "mdt-send-queue-full")

                    self.mdt_socket_error = YLeaf(YType.uint32, "mdt-socket-error")

                    self.mldp_mdt_invalid_lsm_identifier = YLeaf(YType.uint32, "mldp-mdt-invalid-lsm-identifier")

                    self.no_mdt_socket_connection = YLeaf(YType.uint32, "no-mdt-socket-connection")

                    self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                    self.no_source_address = YLeaf(YType.uint32, "no-source-address")

                    self.non_supported_packets = YLeaf(YType.uint32, "non-supported-packets")

                    self.output_assert = YLeaf(YType.uint32, "output-assert")

                    self.output_assert_batched = YLeaf(YType.uint32, "output-assert-batched")

                    self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                    self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                    self.output_data_register = YLeaf(YType.uint32, "output-data-register")

                    self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                    self.output_ecmp_redirect = YLeaf(YType.uint32, "output-ecmp-redirect")

                    self.output_hello = YLeaf(YType.uint32, "output-hello")

                    self.output_hello_bytes = YLeaf(YType.uint32, "output-hello-bytes")

                    self.output_join_group = YLeaf(YType.uint32, "output-join-group")

                    self.output_join_prune_bytes = YLeaf(YType.uint32, "output-join-prune-bytes")

                    self.output_jp = YLeaf(YType.uint32, "output-jp")

                    self.output_loop_error = YLeaf(YType.uint32, "output-loop-error")

                    self.output_null_register = YLeaf(YType.uint32, "output-null-register")

                    self.output_prune_group = YLeaf(YType.uint32, "output-prune-group")

                    self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                    self.outputs = YLeaf(YType.uint32, "outputs")

                    self.packet_packman_error = YLeaf(YType.uint32, "packet-packman-error")

                    self.packet_queue_last_clear = YLeaf(YType.uint32, "packet-queue-last-clear")

                    self.packet_read_socket_error = YLeaf(YType.uint32, "packet-read-socket-error")

                    self.packets_standby = YLeaf(YType.uint32, "packets-standby")

                    self.pakman_error = YLeaf(YType.uint32, "pakman-error")

                    self.send_queue_full = YLeaf(YType.uint32, "send-queue-full")

                    self.socket_error = YLeaf(YType.uint32, "socket-error")

                    self.standby_packets_error = YLeaf(YType.uint32, "standby-packets-error")

                    self.truncated_pim_packets = YLeaf(YType.uint32, "truncated-pim-packets")

                    self.packet_queue = YList(self)
                    self._segment_path = lambda: "traffic-counters"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.TrafficCounters, ['boundary_acl_rx_drop', 'boundary_acl_tx_drop', 'checksum_error', 'elapsed_time', 'format_error', 'input_assert', 'input_assert_batched', 'input_bsr_message', 'input_candidate_rp_advertisement', 'input_data_register', 'input_df_election', 'input_ecmp_redirect', 'input_hello', 'input_jp', 'input_no_idb_error', 'input_no_pim_error', 'input_no_vrf_error', 'input_null_register', 'input_pim_version_error', 'input_register_stop', 'inputs', 'invalid_destination_packets', 'invalid_join_prunes', 'invalid_registers', 'mdt_drop_local_source_address', 'mdt_drop_no_idb', 'mdt_drop_no_vrf', 'mdt_drop_null_local_address', 'mdt_join_bad_type', 'mdt_join_tlv_received', 'mdt_join_tlv_sent', 'mdt_joins_drop_multiple_encapsulation', 'mdt_send_queue_full', 'mdt_socket_error', 'mldp_mdt_invalid_lsm_identifier', 'no_mdt_socket_connection', 'no_socket_connection', 'no_source_address', 'non_supported_packets', 'output_assert', 'output_assert_batched', 'output_bsr_message', 'output_candidate_rp_advertisement', 'output_data_register', 'output_df_election', 'output_ecmp_redirect', 'output_hello', 'output_hello_bytes', 'output_join_group', 'output_join_prune_bytes', 'output_jp', 'output_loop_error', 'output_null_register', 'output_prune_group', 'output_register_stop', 'outputs', 'packet_packman_error', 'packet_queue_last_clear', 'packet_read_socket_error', 'packets_standby', 'pakman_error', 'send_queue_full', 'socket_error', 'standby_packets_error', 'truncated_pim_packets'], name, value)


                class PacketQueue(Entity):
                    """
                    Packet queue state and statistics
                    
                    .. attribute:: packet_queue_priority
                    
                    	Priority of this packet queue
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_state
                    
                    	State of the queue
                    	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState>`
                    
                    .. attribute:: packet_queue_stats
                    
                    	Statistics about the queue
                    	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue, self).__init__()

                        self.yang_name = "packet-queue"
                        self.yang_parent_name = "traffic-counters"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"packet-queue-state" : ("packet_queue_state", Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState), "packet-queue-stats" : ("packet_queue_stats", Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats)}
                        self._child_list_classes = {}

                        self.packet_queue_priority = YLeaf(YType.uint32, "packet-queue-priority")

                        self.packet_queue_state = Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                        self.packet_queue_state.parent = self
                        self._children_name_map["packet_queue_state"] = "packet-queue-state"
                        self._children_yang_names.add("packet-queue-state")

                        self.packet_queue_stats = Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                        self.packet_queue_stats.parent = self
                        self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                        self._children_yang_names.add("packet-queue-stats")
                        self._segment_path = lambda: "packet-queue"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/traffic-counters/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue, ['packet_queue_priority'], name, value)


                    class PacketQueueState(Entity):
                        """
                        State of the queue
                        
                        .. attribute:: max_queue_size
                        
                        	Maximum size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_bytes
                        
                        	Size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_packets
                        
                        	Size of queue in number of packets
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                            self.yang_name = "packet-queue-state"
                            self.yang_parent_name = "packet-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.max_queue_size = YLeaf(YType.uint32, "max-queue-size")

                            self.queue_size_bytes = YLeaf(YType.uint32, "queue-size-bytes")

                            self.queue_size_packets = YLeaf(YType.uint32, "queue-size-packets")
                            self._segment_path = lambda: "packet-queue-state"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/traffic-counters/packet-queue/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, ['max_queue_size', 'queue_size_bytes', 'queue_size_packets'], name, value)


                    class PacketQueueStats(Entity):
                        """
                        Statistics about the queue
                        
                        .. attribute:: dequeued_packets
                        
                        	Total number of packets dequeued from this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: enqueued_packets
                        
                        	Total number of packets enqueued to this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_bytes
                        
                        	Highest number of bytes enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: high_water_mark_packets
                        
                        	Highest number of packets enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tail_drops
                        
                        	Number packets dropped from this queue due to max size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                            self.yang_name = "packet-queue-stats"
                            self.yang_parent_name = "packet-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.dequeued_packets = YLeaf(YType.uint32, "dequeued-packets")

                            self.enqueued_packets = YLeaf(YType.uint32, "enqueued-packets")

                            self.high_water_mark_bytes = YLeaf(YType.uint32, "high-water-mark-bytes")

                            self.high_water_mark_packets = YLeaf(YType.uint32, "high-water-mark-packets")

                            self.tail_drops = YLeaf(YType.uint32, "tail-drops")
                            self._segment_path = lambda: "packet-queue-stats"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/traffic-counters/packet-queue/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, ['dequeued_packets', 'enqueued_packets', 'high_water_mark_bytes', 'high_water_mark_packets', 'tail_drops'], name, value)


            class Tunnels(Entity):
                """
                Tunnels information that PIM has
                
                .. attribute:: tunnel
                
                	PIM tunnel information
                	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Tunnels, self).__init__()

                    self.yang_name = "tunnels"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"tunnel" : ("tunnel", Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel)}

                    self.tunnel = YList(self)
                    self._segment_path = lambda: "tunnels"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Tunnels, [], name, value)


                class Tunnel(Entity):
                    """
                    PIM tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel, self).__init__()

                        self.yang_name = "tunnel"
                        self.yang_parent_name = "tunnels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-netio" : ("group_address_netio", Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio), "rp-address" : ("rp_address", Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress), "source-address" : ("source_address", Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress), "source-address-netio" : ("source_address_netio", Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio)}
                        self._child_list_classes = {}

                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.group_address_netio = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._children_yang_names.add("group-address-netio")

                        self.rp_address = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                        self.source_address_netio = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"
                        self._children_yang_names.add("source-address-netio")
                        self._segment_path = lambda: "tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/tunnels/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel, ['tunnel_name', 'vrf_name'], name, value)


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-netio"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address-netio"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


        class Process(Entity):
            """
            Process
            
            .. attribute:: issu
            
            	ISSU Information
            	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.Issu>`
            
            .. attribute:: nsf
            
            	PIM NSF information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.Nsr>`
            
            .. attribute:: summary
            
            	PIM Global Summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.Summary>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Ipv6Pim.Active.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"issu" : ("issu", Ipv6Pim.Active.Process.Issu), "nsf" : ("nsf", Ipv6Pim.Active.Process.Nsf), "nsr" : ("nsr", Ipv6Pim.Active.Process.Nsr), "summary" : ("summary", Ipv6Pim.Active.Process.Summary)}
                self._child_list_classes = {}

                self.issu = Ipv6Pim.Active.Process.Issu()
                self.issu.parent = self
                self._children_name_map["issu"] = "issu"
                self._children_yang_names.add("issu")

                self.nsf = Ipv6Pim.Active.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"
                self._children_yang_names.add("nsf")

                self.nsr = Ipv6Pim.Active.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
                self._children_yang_names.add("nsr")

                self.summary = Ipv6Pim.Active.Process.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")
                self._segment_path = lambda: "process"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/%s" % self._segment_path()


            class Issu(Entity):
                """
                ISSU Information
                
                .. attribute:: checkpoint_idt_timestamp
                
                	Time when Checkpoint IDT done
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: eoc_received_timestamp
                
                	Time when EOC was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: ihms_received_timestamp
                
                	Time when IHMS done was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: informationvalid
                
                	Is Information valid ?
                	**type**\:  bool
                
                .. attribute:: is_checkpoint_idt_done
                
                	Was Checkpoint IDT done ?
                	**type**\:  bool
                
                .. attribute:: is_eoc_received
                
                	Was EOC received ?
                	**type**\:  bool
                
                .. attribute:: is_ihms_done_received
                
                	Was IHMS done received ?
                	**type**\:  bool
                
                .. attribute:: is_nbr_sync_received
                
                	Was NBR Sync achieved ?
                	**type**\:  bool
                
                .. attribute:: is_rib_sync_received
                
                	Was RIB Sync received ?
                	**type**\:  bool
                
                .. attribute:: last_ha_role_notification_received
                
                	Time when last HA role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_phase_notification_received
                
                	Time when last ISSU Phase nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_role_notification_received
                
                	Time when last ISSU role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: nbr_sync_received_timestamp
                
                	Time when NBR Sync was achieved
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: phase_issu
                
                	ISSU Phase
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: rib_sync_received_timestamp
                
                	Time when RIB Sync was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: role_ha
                
                	HA role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: role_issu
                
                	ISSU role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.Process.Issu, self).__init__()

                    self.yang_name = "issu"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.checkpoint_idt_timestamp = YLeaf(YType.uint64, "checkpoint-idt-timestamp")

                    self.eoc_received_timestamp = YLeaf(YType.uint64, "eoc-received-timestamp")

                    self.ihms_received_timestamp = YLeaf(YType.uint64, "ihms-received-timestamp")

                    self.informationvalid = YLeaf(YType.boolean, "informationvalid")

                    self.is_checkpoint_idt_done = YLeaf(YType.boolean, "is-checkpoint-idt-done")

                    self.is_eoc_received = YLeaf(YType.boolean, "is-eoc-received")

                    self.is_ihms_done_received = YLeaf(YType.boolean, "is-ihms-done-received")

                    self.is_nbr_sync_received = YLeaf(YType.boolean, "is-nbr-sync-received")

                    self.is_rib_sync_received = YLeaf(YType.boolean, "is-rib-sync-received")

                    self.last_ha_role_notification_received = YLeaf(YType.uint64, "last-ha-role-notification-received")

                    self.last_issu_phase_notification_received = YLeaf(YType.uint64, "last-issu-phase-notification-received")

                    self.last_issu_role_notification_received = YLeaf(YType.uint64, "last-issu-role-notification-received")

                    self.nbr_sync_received_timestamp = YLeaf(YType.uint64, "nbr-sync-received-timestamp")

                    self.phase_issu = YLeaf(YType.int32, "phase-issu")

                    self.rib_sync_received_timestamp = YLeaf(YType.uint64, "rib-sync-received-timestamp")

                    self.role_ha = YLeaf(YType.int32, "role-ha")

                    self.role_issu = YLeaf(YType.int32, "role-issu")
                    self._segment_path = lambda: "issu"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.Process.Issu, ['checkpoint_idt_timestamp', 'eoc_received_timestamp', 'ihms_received_timestamp', 'informationvalid', 'is_checkpoint_idt_done', 'is_eoc_received', 'is_ihms_done_received', 'is_nbr_sync_received', 'is_rib_sync_received', 'last_ha_role_notification_received', 'last_issu_phase_notification_received', 'last_issu_role_notification_received', 'nbr_sync_received_timestamp', 'phase_issu', 'rib_sync_received_timestamp', 'role_ha', 'role_issu'], name, value)


            class Nsf(Entity):
                """
                PIM NSF information
                
                .. attribute:: configured_state
                
                	Is Multicast NSF Configured
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_sec
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_sec
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_sec
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: nsf_state
                
                	Are we currently in NSF
                	**type**\:  bool
                
                .. attribute:: nsf_time_left
                
                	Multicast NSF time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: nsf_timeout
                
                	Multicast NSF timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: waiting_membership
                
                	Waiting for IGMP/MLD
                	**type**\:  bool
                
                .. attribute:: waiting_timer
                
                	Waiting for NSF timer expiry
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.configured_state = YLeaf(YType.boolean, "configured-state")

                    self.last_icd_notif_recv = YLeaf(YType.int64, "last-icd-notif-recv")

                    self.last_icd_notif_recv_sec = YLeaf(YType.int32, "last-icd-notif-recv-sec")

                    self.last_nsf_off = YLeaf(YType.int64, "last-nsf-off")

                    self.last_nsf_off_sec = YLeaf(YType.int32, "last-nsf-off-sec")

                    self.last_nsf_on = YLeaf(YType.int64, "last-nsf-on")

                    self.last_nsf_on_sec = YLeaf(YType.int32, "last-nsf-on-sec")

                    self.nsf_state = YLeaf(YType.boolean, "nsf-state")

                    self.nsf_time_left = YLeaf(YType.uint32, "nsf-time-left")

                    self.nsf_timeout = YLeaf(YType.uint32, "nsf-timeout")

                    self.respawn_count = YLeaf(YType.uint32, "respawn-count")

                    self.waiting_membership = YLeaf(YType.boolean, "waiting-membership")

                    self.waiting_timer = YLeaf(YType.boolean, "waiting-timer")
                    self._segment_path = lambda: "nsf"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.Process.Nsf, ['configured_state', 'last_icd_notif_recv', 'last_icd_notif_recv_sec', 'last_nsf_off', 'last_nsf_off_sec', 'last_nsf_on', 'last_nsf_on_sec', 'nsf_state', 'nsf_time_left', 'nsf_timeout', 'respawn_count', 'waiting_membership', 'waiting_timer'], name, value)


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: count_connection_dn
                
                	No. of times connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_connection_up
                
                	No. of times connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_connection_dn
                
                	Time when connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_up
                
                	Time when connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: rmf_timer_expiry
                
                	Time for RMF timer to expire
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: rmf_timer_valid
                
                	Is RMF timer running ?
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.count_connection_dn = YLeaf(YType.uint32, "count-connection-dn")

                    self.count_connection_up = YLeaf(YType.uint32, "count-connection-up")

                    self.count_rmf_not_ready = YLeaf(YType.uint32, "count-rmf-not-ready")

                    self.count_rmf_ready = YLeaf(YType.uint32, "count-rmf-ready")

                    self.last_connection_dn = YLeaf(YType.uint64, "last-connection-dn")

                    self.last_connection_up = YLeaf(YType.uint64, "last-connection-up")

                    self.last_rmf_not_ready = YLeaf(YType.uint64, "last-rmf-not-ready")

                    self.last_rmf_ready = YLeaf(YType.uint64, "last-rmf-ready")

                    self.partner_connected = YLeaf(YType.boolean, "partner-connected")

                    self.rmf_notification_done = YLeaf(YType.boolean, "rmf-notification-done")

                    self.rmf_timer_expiry = YLeaf(YType.uint64, "rmf-timer-expiry")

                    self.rmf_timer_valid = YLeaf(YType.boolean, "rmf-timer-valid")

                    self.state = YLeaf(YType.uint8, "state")
                    self._segment_path = lambda: "nsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.Process.Nsr, ['count_connection_dn', 'count_connection_up', 'count_rmf_not_ready', 'count_rmf_ready', 'last_connection_dn', 'last_connection_up', 'last_rmf_not_ready', 'last_rmf_ready', 'partner_connected', 'rmf_notification_done', 'rmf_timer_expiry', 'rmf_timer_valid', 'state'], name, value)


            class Summary(Entity):
                """
                PIM Global Summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.Process.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                    self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                    self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                    self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                    self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                    self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                    self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                    self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                    self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                    self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                    self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                    self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                    self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                    self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                    self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                    self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                    self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                    self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                    self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                    self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                    self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                    self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                    self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                    self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                    self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                    self.register_count = YLeaf(YType.uint32, "register-count")

                    self.register_limit = YLeaf(YType.uint32, "register-limit")

                    self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                    self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                    self.route_count = YLeaf(YType.uint32, "route-count")

                    self.route_limit = YLeaf(YType.uint32, "route-limit")

                    self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                    self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                    self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                    self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                    self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                    self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                    self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.Process.Summary, ['bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_threshold', 'bsr_range_threshold', 'bsr_ranges_count', 'bsr_ranges_limit', 'global_auto_rp_ranges_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_threshold', 'global_bsr_ranges_count', 'global_bsr_ranges_limit', 'global_bsr_ranges_threshold', 'global_register_limit', 'is_bsr_ranges_threshold_reached', 'is_global_auto_rp_ranges_limit_reached', 'is_global_bsr_ranges_limit_reached', 'is_global_register_limit_reached', 'is_global_route_limit_reached', 'is_global_rxi_limit_reached', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'is_ranges_limit_reached', 'is_route_limit_reached', 'ranges_count', 'ranges_limit', 'ranges_threshold', 'register_count', 'register_limit', 'register_limit_reached', 'register_threshold', 'route_count', 'route_limit', 'route_low_water_mark', 'route_threshold', 'rxi_limit_reached', 'rxi_low_water_mark', 'topology_interface_state_count', 'topology_interface_state_limit', 'topology_interface_state_threshold'], name, value)


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF name
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Ipv6Pim.Active.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"vrf" : ("vrf", Ipv6Pim.Active.Vrfs.Vrf)}

                self.vrf = YList(self)
                self._segment_path = lambda: "vrfs"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Ipv6Pim.Active.Vrfs, [], name, value)


            class Vrf(Entity):
                """
                VRF name
                
                .. attribute:: vrf_name  <key>
                
                	VRF name 
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: auto_rp
                
                	PIM Auto\-RP information
                	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.AutoRp>`
                
                .. attribute:: bgp_afs
                
                	PIM BGP SAFI table
                	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs>`
                
                .. attribute:: bidir_df_states
                
                	Bidirectional PIM DF election state table
                	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates>`
                
                .. attribute:: bidir_df_winners
                
                	Bidirectional PIM DF election winner table
                	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners>`
                
                .. attribute:: bsr
                
                	PIM BSR information
                	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr>`
                
                .. attribute:: context
                
                	PIM context information
                	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context>`
                
                .. attribute:: gre
                
                	GRE information
                	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre>`
                
                .. attribute:: group_map_rpfs
                
                	PIM group mapping information
                	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs>`
                
                .. attribute:: group_map_sources
                
                	PIM group\-mapping with source information
                	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources>`
                
                .. attribute:: ifrs_interfaces
                
                	PIM interfaces in forward reference store table
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: ifrs_summary
                
                	PIM interfaces in forward reference store summary
                	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary>`
                
                .. attribute:: interface_old_formats
                
                	PIM interfaces in old format
                	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats>`
                
                .. attribute:: interface_statistics
                
                	PIM interface statistics
                	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics>`
                
                .. attribute:: interfaces
                
                	PIM interfaces
                	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Interfaces>`
                
                .. attribute:: jp_statistics
                
                	PIM join prune statistics table
                	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.JpStatistics>`
                
                .. attribute:: mib_databases
                
                	PIM group database for mroute mibs table
                	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases>`
                
                .. attribute:: multicast_static_routes
                
                	PIM multicast static route table
                	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes>`
                
                .. attribute:: neighbor_old_formats
                
                	PIM neighbor table old format
                	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats>`
                
                .. attribute:: neighbor_summaries
                
                	PIM neighbor summary table
                	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries>`
                
                .. attribute:: neighbors
                
                	PIM neighbor table
                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Neighbors>`
                
                .. attribute:: net_io_tunnels
                
                	Tunnel information that NETIO has 
                	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels>`
                
                .. attribute:: ranges
                
                	PIM range list information
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges>`
                
                .. attribute:: route_policy
                
                	PIM route policy
                	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy>`
                
                .. attribute:: rpf_redirect
                
                	PIM ECMP RPF\-redirect bundle
                	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect>`
                
                .. attribute:: rpf_summary
                
                	PIM RPF registration summary
                	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfSummary>`
                
                .. attribute:: safs
                
                	SAFI table and type
                	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs>`
                
                .. attribute:: summary
                
                	PIM summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Summary>`
                
                .. attribute:: table_contexts
                
                	PIM table context list
                	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TableContexts>`
                
                .. attribute:: topologies
                
                	PIM topology table
                	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies>`
                
                .. attribute:: topology_entry_flag_route_counts
                
                	Route count for topology with entry flag set
                	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts>`
                
                .. attribute:: topology_interface_flag_route_counts
                
                	Route count for topology with interface flag set
                	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts>`
                
                .. attribute:: topology_route_count
                
                	Topology route count information from PIM topology table
                	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount>`
                
                .. attribute:: traffic_counters
                
                	PIM message traffic counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters>`
                
                .. attribute:: tunnels
                
                	Tunnels information that PIM has
                	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Active.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"auto-rp" : ("auto_rp", Ipv6Pim.Active.Vrfs.Vrf.AutoRp), "bgp-afs" : ("bgp_afs", Ipv6Pim.Active.Vrfs.Vrf.BgpAfs), "bidir-df-states" : ("bidir_df_states", Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates), "bidir-df-winners" : ("bidir_df_winners", Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners), "bsr" : ("bsr", Ipv6Pim.Active.Vrfs.Vrf.Bsr), "context" : ("context", Ipv6Pim.Active.Vrfs.Vrf.Context), "gre" : ("gre", Ipv6Pim.Active.Vrfs.Vrf.Gre), "group-map-rpfs" : ("group_map_rpfs", Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs), "group-map-sources" : ("group_map_sources", Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources), "ifrs-interfaces" : ("ifrs_interfaces", Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces), "ifrs-summary" : ("ifrs_summary", Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary), "interface-old-formats" : ("interface_old_formats", Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats), "interface-statistics" : ("interface_statistics", Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics), "interfaces" : ("interfaces", Ipv6Pim.Active.Vrfs.Vrf.Interfaces), "jp-statistics" : ("jp_statistics", Ipv6Pim.Active.Vrfs.Vrf.JpStatistics), "mib-databases" : ("mib_databases", Ipv6Pim.Active.Vrfs.Vrf.MibDatabases), "multicast-static-routes" : ("multicast_static_routes", Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes), "neighbor-old-formats" : ("neighbor_old_formats", Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats), "neighbor-summaries" : ("neighbor_summaries", Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries), "neighbors" : ("neighbors", Ipv6Pim.Active.Vrfs.Vrf.Neighbors), "net-io-tunnels" : ("net_io_tunnels", Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels), "ranges" : ("ranges", Ipv6Pim.Active.Vrfs.Vrf.Ranges), "route-policy" : ("route_policy", Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy), "rpf-redirect" : ("rpf_redirect", Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect), "rpf-summary" : ("rpf_summary", Ipv6Pim.Active.Vrfs.Vrf.RpfSummary), "safs" : ("safs", Ipv6Pim.Active.Vrfs.Vrf.Safs), "summary" : ("summary", Ipv6Pim.Active.Vrfs.Vrf.Summary), "table-contexts" : ("table_contexts", Ipv6Pim.Active.Vrfs.Vrf.TableContexts), "topologies" : ("topologies", Ipv6Pim.Active.Vrfs.Vrf.Topologies), "topology-entry-flag-route-counts" : ("topology_entry_flag_route_counts", Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts), "topology-interface-flag-route-counts" : ("topology_interface_flag_route_counts", Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts), "topology-route-count" : ("topology_route_count", Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount), "traffic-counters" : ("traffic_counters", Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters), "tunnels" : ("tunnels", Ipv6Pim.Active.Vrfs.Vrf.Tunnels)}
                    self._child_list_classes = {}

                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                    self.auto_rp = Ipv6Pim.Active.Vrfs.Vrf.AutoRp()
                    self.auto_rp.parent = self
                    self._children_name_map["auto_rp"] = "auto-rp"
                    self._children_yang_names.add("auto-rp")

                    self.bgp_afs = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs()
                    self.bgp_afs.parent = self
                    self._children_name_map["bgp_afs"] = "bgp-afs"
                    self._children_yang_names.add("bgp-afs")

                    self.bidir_df_states = Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates()
                    self.bidir_df_states.parent = self
                    self._children_name_map["bidir_df_states"] = "bidir-df-states"
                    self._children_yang_names.add("bidir-df-states")

                    self.bidir_df_winners = Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners()
                    self.bidir_df_winners.parent = self
                    self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                    self._children_yang_names.add("bidir-df-winners")

                    self.bsr = Ipv6Pim.Active.Vrfs.Vrf.Bsr()
                    self.bsr.parent = self
                    self._children_name_map["bsr"] = "bsr"
                    self._children_yang_names.add("bsr")

                    self.context = Ipv6Pim.Active.Vrfs.Vrf.Context()
                    self.context.parent = self
                    self._children_name_map["context"] = "context"
                    self._children_yang_names.add("context")

                    self.gre = Ipv6Pim.Active.Vrfs.Vrf.Gre()
                    self.gre.parent = self
                    self._children_name_map["gre"] = "gre"
                    self._children_yang_names.add("gre")

                    self.group_map_rpfs = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs()
                    self.group_map_rpfs.parent = self
                    self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                    self._children_yang_names.add("group-map-rpfs")

                    self.group_map_sources = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources()
                    self.group_map_sources.parent = self
                    self._children_name_map["group_map_sources"] = "group-map-sources"
                    self._children_yang_names.add("group-map-sources")

                    self.ifrs_interfaces = Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    self._children_yang_names.add("ifrs-interfaces")

                    self.ifrs_summary = Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary()
                    self.ifrs_summary.parent = self
                    self._children_name_map["ifrs_summary"] = "ifrs-summary"
                    self._children_yang_names.add("ifrs-summary")

                    self.interface_old_formats = Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats()
                    self.interface_old_formats.parent = self
                    self._children_name_map["interface_old_formats"] = "interface-old-formats"
                    self._children_yang_names.add("interface-old-formats")

                    self.interface_statistics = Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics()
                    self.interface_statistics.parent = self
                    self._children_name_map["interface_statistics"] = "interface-statistics"
                    self._children_yang_names.add("interface-statistics")

                    self.interfaces = Ipv6Pim.Active.Vrfs.Vrf.Interfaces()
                    self.interfaces.parent = self
                    self._children_name_map["interfaces"] = "interfaces"
                    self._children_yang_names.add("interfaces")

                    self.jp_statistics = Ipv6Pim.Active.Vrfs.Vrf.JpStatistics()
                    self.jp_statistics.parent = self
                    self._children_name_map["jp_statistics"] = "jp-statistics"
                    self._children_yang_names.add("jp-statistics")

                    self.mib_databases = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases()
                    self.mib_databases.parent = self
                    self._children_name_map["mib_databases"] = "mib-databases"
                    self._children_yang_names.add("mib-databases")

                    self.multicast_static_routes = Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes()
                    self.multicast_static_routes.parent = self
                    self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                    self._children_yang_names.add("multicast-static-routes")

                    self.neighbor_old_formats = Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats()
                    self.neighbor_old_formats.parent = self
                    self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                    self._children_yang_names.add("neighbor-old-formats")

                    self.neighbor_summaries = Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries()
                    self.neighbor_summaries.parent = self
                    self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                    self._children_yang_names.add("neighbor-summaries")

                    self.neighbors = Ipv6Pim.Active.Vrfs.Vrf.Neighbors()
                    self.neighbors.parent = self
                    self._children_name_map["neighbors"] = "neighbors"
                    self._children_yang_names.add("neighbors")

                    self.net_io_tunnels = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels()
                    self.net_io_tunnels.parent = self
                    self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                    self._children_yang_names.add("net-io-tunnels")

                    self.ranges = Ipv6Pim.Active.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"
                    self._children_yang_names.add("ranges")

                    self.route_policy = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy()
                    self.route_policy.parent = self
                    self._children_name_map["route_policy"] = "route-policy"
                    self._children_yang_names.add("route-policy")

                    self.rpf_redirect = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect()
                    self.rpf_redirect.parent = self
                    self._children_name_map["rpf_redirect"] = "rpf-redirect"
                    self._children_yang_names.add("rpf-redirect")

                    self.rpf_summary = Ipv6Pim.Active.Vrfs.Vrf.RpfSummary()
                    self.rpf_summary.parent = self
                    self._children_name_map["rpf_summary"] = "rpf-summary"
                    self._children_yang_names.add("rpf-summary")

                    self.safs = Ipv6Pim.Active.Vrfs.Vrf.Safs()
                    self.safs.parent = self
                    self._children_name_map["safs"] = "safs"
                    self._children_yang_names.add("safs")

                    self.summary = Ipv6Pim.Active.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.table_contexts = Ipv6Pim.Active.Vrfs.Vrf.TableContexts()
                    self.table_contexts.parent = self
                    self._children_name_map["table_contexts"] = "table-contexts"
                    self._children_yang_names.add("table-contexts")

                    self.topologies = Ipv6Pim.Active.Vrfs.Vrf.Topologies()
                    self.topologies.parent = self
                    self._children_name_map["topologies"] = "topologies"
                    self._children_yang_names.add("topologies")

                    self.topology_entry_flag_route_counts = Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                    self.topology_entry_flag_route_counts.parent = self
                    self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                    self._children_yang_names.add("topology-entry-flag-route-counts")

                    self.topology_interface_flag_route_counts = Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                    self.topology_interface_flag_route_counts.parent = self
                    self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                    self._children_yang_names.add("topology-interface-flag-route-counts")

                    self.topology_route_count = Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount()
                    self.topology_route_count.parent = self
                    self._children_name_map["topology_route_count"] = "topology-route-count"
                    self._children_yang_names.add("topology-route-count")

                    self.traffic_counters = Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"
                    self._children_yang_names.add("traffic-counters")

                    self.tunnels = Ipv6Pim.Active.Vrfs.Vrf.Tunnels()
                    self.tunnels.parent = self
                    self._children_name_map["tunnels"] = "tunnels"
                    self._children_yang_names.add("tunnels")
                    self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/vrfs/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf, ['vrf_name'], name, value)


                class AutoRp(Entity):
                    """
                    PIM Auto\-RP information
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.AutoRp, self).__init__()

                        self.yang_name = "auto-rp"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self._segment_path = lambda: "auto-rp"


                class BgpAfs(Entity):
                    """
                    PIM BGP SAFI table
                    
                    .. attribute:: bgp_af
                    
                    	PIM BGP SAFI information
                    	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs, self).__init__()

                        self.yang_name = "bgp-afs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"bgp-af" : ("bgp_af", Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf)}

                        self.bgp_af = YList(self)
                        self._segment_path = lambda: "bgp-afs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs, [], name, value)


                    class BgpAf(Entity):
                        """
                        PIM BGP SAFI information
                        
                        .. attribute:: extranet_path_count
                        
                        	Count of dependent extranet paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group
                        
                        	Group address
                        	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group>`
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: is_bgp_added
                        
                        	SAFI learnt from BGP
                        	**type**\:  bool
                        
                        .. attribute:: next_hop
                        
                        	Next hop address
                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop>`
                        
                        .. attribute:: route_distinguisher
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**length:** 0..256
                        
                        .. attribute:: source
                        
                        	Source address
                        	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf, self).__init__()

                            self.yang_name = "bgp-af"
                            self.yang_parent_name = "bgp-afs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group" : ("group", Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group), "next-hop" : ("next_hop", Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop), "source" : ("source", Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source)}
                            self._child_list_classes = {}

                            self.extranet_path_count = YLeaf(YType.uint32, "extranet-path-count")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.is_bgp_added = YLeaf(YType.boolean, "is-bgp-added")

                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                            self.group.parent = self
                            self._children_name_map["group"] = "group"
                            self._children_yang_names.add("group")

                            self.next_hop = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"
                            self._children_yang_names.add("next-hop")

                            self.source = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._children_yang_names.add("source")
                            self._segment_path = lambda: "bgp-af"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf, ['extranet_path_count', 'group_address', 'is_bgp_added', 'route_distinguisher', 'source_address'], name, value)


                        class Group(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__init__()

                                self.yang_name = "group"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class NextHop(Entity):
                            """
                            Next hop address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "next-hop"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Source(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class BidirDfStates(Entity):
                    """
                    Bidirectional PIM DF election state table
                    
                    .. attribute:: bidir_df_state
                    
                    	Bidirectional PIM DF Election Table Entry
                    	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates, self).__init__()

                        self.yang_name = "bidir-df-states"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"bidir-df-state" : ("bidir_df_state", Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState)}

                        self.bidir_df_state = YList(self)
                        self._segment_path = lambda: "bidir-df-states"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates, [], name, value)


                    class BidirDfState(Entity):
                        """
                        Bidirectional PIM DF Election Table Entry
                        
                        .. attribute:: election_state
                        
                        	DF Election State
                        	**type**\:  str
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: our_metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: our_metric_preference
                        
                        	MetricPreference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr>`
                        
                        .. attribute:: time_nano_seconds
                        
                        	Timer expires (nseconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: time_seconds
                        
                        	Timer expires (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__init__()

                            self.yang_name = "bidir-df-state"
                            self.yang_parent_name = "bidir-df-states"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"rp-address-xr" : ("rp_address_xr", Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr)}
                            self._child_list_classes = {}

                            self.election_state = YLeaf(YType.str, "election-state")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.our_metric = YLeaf(YType.uint32, "our-metric")

                            self.our_metric_preference = YLeaf(YType.uint32, "our-metric-preference")

                            self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.time_nano_seconds = YLeaf(YType.uint64, "time-nano-seconds")

                            self.time_seconds = YLeaf(YType.uint64, "time-seconds")

                            self.rp_address_xr = Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")
                            self._segment_path = lambda: "bidir-df-state"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState, ['election_state', 'interface_name', 'our_metric', 'our_metric_preference', 'pim_interface_name', 'rp_address', 'time_nano_seconds', 'time_seconds'], name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class BidirDfWinners(Entity):
                    """
                    Bidirectional PIM DF election winner table
                    
                    .. attribute:: bidir_df_winner
                    
                    	Bidirectional PIM DF election table entry
                    	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners, self).__init__()

                        self.yang_name = "bidir-df-winners"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"bidir-df-winner" : ("bidir_df_winner", Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner)}

                        self.bidir_df_winner = YList(self)
                        self._segment_path = lambda: "bidir-df-winners"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners, [], name, value)


                    class BidirDfWinner(Entity):
                        """
                        Bidirectional PIM DF election table entry
                        
                        .. attribute:: are_we_df
                        
                        	Are we DF
                        	**type**\:  bool
                        
                        .. attribute:: df_winner
                        
                        	DF Winner
                        	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner>`
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                        
                        .. attribute:: rp_lan
                        
                        	Is this the RP LAN
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__init__()

                            self.yang_name = "bidir-df-winner"
                            self.yang_parent_name = "bidir-df-winners"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"df-winner" : ("df_winner", Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner), "rp-address-xr" : ("rp_address_xr", Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr)}
                            self._child_list_classes = {}

                            self.are_we_df = YLeaf(YType.boolean, "are-we-df")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                            self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_lan = YLeaf(YType.boolean, "rp-lan")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.df_winner = Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                            self.df_winner.parent = self
                            self._children_name_map["df_winner"] = "df-winner"
                            self._children_yang_names.add("df-winner")

                            self.rp_address_xr = Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")
                            self._segment_path = lambda: "bidir-df-winner"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, ['are_we_df', 'interface_name', 'metric', 'metric_preference', 'pim_interface_name', 'rp_address', 'rp_lan', 'uptime'], name, value)


                        class DfWinner(Entity):
                            """
                            DF Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                                self.yang_name = "df-winner"
                                self.yang_parent_name = "bidir-df-winner"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "df-winner"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-winner"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Bsr(Entity):
                    """
                    PIM BSR information
                    
                    .. attribute:: bsr_elections
                    
                    	PIM BSR election state
                    	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections>`
                    
                    .. attribute:: candidate_rps
                    
                    	PIM candidate\-RP
                    	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps>`
                    
                    .. attribute:: rp_caches
                    
                    	PIM BSR RP cache table
                    	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Bsr, self).__init__()

                        self.yang_name = "bsr"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"bsr-elections" : ("bsr_elections", Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections), "candidate-rps" : ("candidate_rps", Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps), "rp-caches" : ("rp_caches", Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches)}
                        self._child_list_classes = {}

                        self.bsr_elections = Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections()
                        self.bsr_elections.parent = self
                        self._children_name_map["bsr_elections"] = "bsr-elections"
                        self._children_yang_names.add("bsr-elections")

                        self.candidate_rps = Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps()
                        self.candidate_rps.parent = self
                        self._children_name_map["candidate_rps"] = "candidate-rps"
                        self._children_yang_names.add("candidate-rps")

                        self.rp_caches = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches()
                        self.rp_caches.parent = self
                        self._children_name_map["rp_caches"] = "rp-caches"
                        self._children_yang_names.add("rp-caches")
                        self._segment_path = lambda: "bsr"


                    class BsrElections(Entity):
                        """
                        PIM BSR election state
                        
                        .. attribute:: bsr_election
                        
                        	PIM BSR information
                        	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections, self).__init__()

                            self.yang_name = "bsr-elections"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"bsr-election" : ("bsr_election", Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection)}

                            self.bsr_election = YList(self)
                            self._segment_path = lambda: "bsr-elections"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections, [], name, value)


                        class BsrElection(Entity):
                            """
                            PIM BSR information
                            
                            .. attribute:: pim_scope  <key>
                            
                            	BSR information
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: bootstrap_timeout
                            
                            	Bootstrap Timeout
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_address
                            
                            	BSR address
                            	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress>`
                            
                            .. attribute:: bsr_election_state
                            
                            	BSR Election State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_mask_length
                            
                            	Hash Function Mask Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_priority
                            
                            	BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_scope
                            
                            	BSR Scope
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_up_time
                            
                            	BSR Uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_address
                            
                            	C\-BSR address
                            	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                            
                            .. attribute:: candidate_bsr_flag
                            
                            	BSR Candidate Config Flag
                            	**type**\:  bool
                            
                            .. attribute:: candidate_bsr_mask_length
                            
                            	C\-BSR Hash Func. Mask Len
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_priority
                            
                            	C\-BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_state
                            
                            	BSR Candidate State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__init__()

                                self.yang_name = "bsr-election"
                                self.yang_parent_name = "bsr-elections"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"bsr-address" : ("bsr_address", Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress), "candidate-bsr-address" : ("candidate_bsr_address", Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress)}
                                self._child_list_classes = {}

                                self.pim_scope = YLeaf(YType.int32, "pim-scope")

                                self.bootstrap_timeout = YLeaf(YType.uint16, "bootstrap-timeout")

                                self.bsr_election_state = YLeaf(YType.uint32, "bsr-election-state")

                                self.bsr_mask_length = YLeaf(YType.uint8, "bsr-mask-length")

                                self.bsr_priority = YLeaf(YType.uint8, "bsr-priority")

                                self.bsr_scope = YLeaf(YType.uint16, "bsr-scope")

                                self.bsr_up_time = YLeaf(YType.uint16, "bsr-up-time")

                                self.candidate_bsr_flag = YLeaf(YType.boolean, "candidate-bsr-flag")

                                self.candidate_bsr_mask_length = YLeaf(YType.uint8, "candidate-bsr-mask-length")

                                self.candidate_bsr_priority = YLeaf(YType.uint8, "candidate-bsr-priority")

                                self.candidate_bsr_state = YLeaf(YType.uint32, "candidate-bsr-state")

                                self.bsr_address = Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                self.bsr_address.parent = self
                                self._children_name_map["bsr_address"] = "bsr-address"
                                self._children_yang_names.add("bsr-address")

                                self.candidate_bsr_address = Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                self.candidate_bsr_address.parent = self
                                self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                self._children_yang_names.add("candidate-bsr-address")
                                self._segment_path = lambda: "bsr-election" + "[pim-scope='" + self.pim_scope.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection, ['pim_scope', 'bootstrap_timeout', 'bsr_election_state', 'bsr_mask_length', 'bsr_priority', 'bsr_scope', 'bsr_up_time', 'candidate_bsr_flag', 'candidate_bsr_mask_length', 'candidate_bsr_priority', 'candidate_bsr_state'], name, value)


                            class BsrAddress(Entity):
                                """
                                BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                    self.yang_name = "bsr-address"
                                    self.yang_parent_name = "bsr-election"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "bsr-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class CandidateBsrAddress(Entity):
                                """
                                C\-BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                    self.yang_name = "candidate-bsr-address"
                                    self.yang_parent_name = "bsr-election"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "candidate-bsr-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class CandidateRps(Entity):
                        """
                        PIM candidate\-RP
                        
                        .. attribute:: candidate_rp
                        
                        	PIM BSR candidate RP information
                        	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps, self).__init__()

                            self.yang_name = "candidate-rps"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"candidate-rp" : ("candidate_rp", Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp)}

                            self.candidate_rp = YList(self)
                            self._segment_path = lambda: "candidate-rps"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps, [], name, value)


                        class CandidateRp(Entity):
                            """
                            PIM BSR candidate RP information
                            
                            .. attribute:: rp_address  <key>
                            
                            	Candidate\-RP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp
                            
                            	Cand\-RP Address
                            	**type**\:   :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp>`
                            
                            .. attribute:: candidate_rp_advance_interval
                            
                            	Cand\-RP Adv Interval in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: candidate_rp_scope
                            
                            	Cand\-RP Scope
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: candidate_rp_uptime
                            
                            	Cand\-RP uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_access
                            
                            	Group Ranges Using this Cand\-RP
                            	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                            
                            .. attribute:: crp_holdtime
                            
                            	Cand\-RP Holdtime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_priority
                            
                            	Cand\-RP Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rps"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"candidate-rp" : ("candidate_rp", Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp)}
                                self._child_list_classes = {"crp-access" : ("crp_access", Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess)}

                                self.rp_address = YLeaf(YType.str, "rp-address")

                                self.acl_name = YLeaf(YType.str, "acl-name")

                                self.candidate_rp_advance_interval = YLeaf(YType.uint16, "candidate-rp-advance-interval")

                                self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                                self.candidate_rp_scope = YLeaf(YType.int32, "candidate-rp-scope")

                                self.candidate_rp_uptime = YLeaf(YType.uint16, "candidate-rp-uptime")

                                self.crp_holdtime = YLeaf(YType.uint16, "crp-holdtime")

                                self.crp_priority = YLeaf(YType.uint8, "crp-priority")

                                self.candidate_rp = Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp()
                                self.candidate_rp.parent = self
                                self._children_name_map["candidate_rp"] = "candidate-rp"
                                self._children_yang_names.add("candidate-rp")

                                self.crp_access = YList(self)
                                self._segment_path = lambda: "candidate-rp" + "[rp-address='" + self.rp_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, ['rp_address', 'acl_name', 'candidate_rp_advance_interval', 'candidate_rp_mode', 'candidate_rp_scope', 'candidate_rp_uptime', 'crp_holdtime', 'crp_priority'], name, value)


                            class CandidateRp(Entity):
                                """
                                Cand\-RP Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__init__()

                                    self.yang_name = "candidate-rp"
                                    self.yang_parent_name = "candidate-rp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "candidate-rp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class CrpAccess(Entity):
                                """
                                Group Ranges Using this Cand\-RP
                                
                                .. attribute:: acl_name
                                
                                	Group Access\-List Name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: candidate_rp_mode
                                
                                	Cand\-RP Mode
                                	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                    self.yang_name = "crp-access"
                                    self.yang_parent_name = "candidate-rp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.acl_name = YLeaf(YType.str, "acl-name")

                                    self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")
                                    self._segment_path = lambda: "crp-access"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, ['acl_name', 'candidate_rp_mode'], name, value)


                    class RpCaches(Entity):
                        """
                        PIM BSR RP cache table
                        
                        .. attribute:: rp_cache
                        
                        	PIM BSR RP cache
                        	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches, self).__init__()

                            self.yang_name = "rp-caches"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"rp-cache" : ("rp_cache", Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache)}

                            self.rp_cache = YList(self)
                            self._segment_path = lambda: "rp-caches"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches, [], name, value)


                        class RpCache(Entity):
                            """
                            PIM BSR RP cache
                            
                            .. attribute:: group_prefix  <key>
                            
                            	Group prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: candidate_rp_group_count
                            
                            	C\-RP count for this Prefix
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: candidate_rp_list
                            
                            	C\-RP list for this prefix
                            	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList>`
                            
                            .. attribute:: group_prefix_length
                            
                            	Group Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_prefix_xr
                            
                            	Group Prefix
                            	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__init__()

                                self.yang_name = "rp-cache"
                                self.yang_parent_name = "rp-caches"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"candidate-rp-list" : ("candidate_rp_list", Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList), "group-prefix-xr" : ("group_prefix_xr", Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr)}
                                self._child_list_classes = {}

                                self.group_prefix = YLeaf(YType.str, "group-prefix")

                                self.candidate_rp_group_count = YLeaf(YType.uint32, "candidate-rp-group-count")

                                self.group_prefix_length = YLeaf(YType.uint32, "group-prefix-length")

                                self.candidate_rp_list = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                self.candidate_rp_list.parent = self
                                self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                self._children_yang_names.add("candidate-rp-list")

                                self.group_prefix_xr = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                self.group_prefix_xr.parent = self
                                self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                                self._children_yang_names.add("group-prefix-xr")
                                self._segment_path = lambda: "rp-cache" + "[group-prefix='" + self.group_prefix.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache, ['group_prefix', 'candidate_rp_group_count', 'group_prefix_length'], name, value)


                            class CandidateRpList(Entity):
                                """
                                C\-RP list for this prefix
                                
                                .. attribute:: pim_bsr_crp_bag
                                
                                	pim bsr crp bag
                                	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                    self.yang_name = "candidate-rp-list"
                                    self.yang_parent_name = "rp-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"pim-bsr-crp-bag" : ("pim_bsr_crp_bag", Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag)}

                                    self.pim_bsr_crp_bag = YList(self)
                                    self._segment_path = lambda: "candidate-rp-list"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, [], name, value)


                                class PimBsrCrpBag(Entity):
                                    """
                                    pim bsr crp bag
                                    
                                    .. attribute:: candidate_rp_address
                                    
                                    	C\-RP address
                                    	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                    
                                    .. attribute:: candidate_rp_expires
                                    
                                    	C\-RP Expires
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_holdtime
                                    
                                    	C\-RP Holdtime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_priority
                                    
                                    	C\-RP Priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: candidate_rp_up_time
                                    
                                    	C\-RP Uptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protocol
                                    
                                    	PIM Protocol
                                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                        self.yang_name = "pim-bsr-crp-bag"
                                        self.yang_parent_name = "candidate-rp-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"candidate-rp-address" : ("candidate_rp_address", Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress)}
                                        self._child_list_classes = {}

                                        self.candidate_rp_expires = YLeaf(YType.uint16, "candidate-rp-expires")

                                        self.candidate_rp_holdtime = YLeaf(YType.uint16, "candidate-rp-holdtime")

                                        self.candidate_rp_priority = YLeaf(YType.uint8, "candidate-rp-priority")

                                        self.candidate_rp_up_time = YLeaf(YType.uint16, "candidate-rp-up-time")

                                        self.protocol = YLeaf(YType.enumeration, "protocol")

                                        self.candidate_rp_address = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                        self.candidate_rp_address.parent = self
                                        self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                        self._children_yang_names.add("candidate-rp-address")
                                        self._segment_path = lambda: "pim-bsr-crp-bag"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, ['candidate_rp_expires', 'candidate_rp_holdtime', 'candidate_rp_priority', 'candidate_rp_up_time', 'protocol'], name, value)


                                    class CandidateRpAddress(Entity):
                                        """
                                        C\-RP address
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                            self.yang_name = "candidate-rp-address"
                                            self.yang_parent_name = "pim-bsr-crp-bag"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                            self._segment_path = lambda: "candidate-rp-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class GroupPrefixXr(Entity):
                                """
                                Group Prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                    self.yang_name = "group-prefix-xr"
                                    self.yang_parent_name = "rp-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-prefix-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Context(Entity):
                    """
                    PIM context information
                    
                    .. attribute:: active_table_count
                    
                    	Number of active Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: allow_rp_configured
                    
                    	Allow RP Configured
                    	**type**\:  bool
                    
                    .. attribute:: allow_rp_group_list
                    
                    	Allow RP Group\-List ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: allow_rp_rp_list
                    
                    	Allow RP RP\-list ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: anycast_rp_configured
                    
                    	Anycast\-RP config
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_policy_name
                    
                    	Anycast\-RP Policy Name
                    	**type**\:  str
                    
                    .. attribute:: anycast_rp_range
                    
                    	Anycast\-RP Ranges
                    	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange>`
                    
                    .. attribute:: bgp_auto_discovery_configured
                    
                    	BGP Auto\-Discovery configured
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery_type
                    
                    	BGP Auto Discovery Type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_i_pmsi_added
                    
                    	BGP I\-PMSI Added
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_address
                    
                    	BGP remote interface address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_remote_interface
                    
                    	BGP remote interface handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: bgp_remote_interface_name
                    
                    	BGP remote interface name
                    	**type**\:  str
                    
                    .. attribute:: bgp_remote_on
                    
                    	BGP remote interface status
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_state
                    
                    	BGP remote interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_source_active_announce
                    
                    	Send BGP Source\-Active Announcements
                    	**type**\:  bool
                    
                    .. attribute:: export_route_target
                    
                    	Export Route Targets
                    	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget>`
                    
                    .. attribute:: gin_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: gin_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: gin_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: import_route_target
                    
                    	Import Route Targets
                    	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget>`
                    
                    .. attribute:: in_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: in_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: in_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_signaling_local_enabled
                    
                    	Inband signaling Local enabled
                    	**type**\:  bool
                    
                    .. attribute:: in_band_signaling_remote_enabled
                    
                    	Inband signaling Remote enabled
                    	**type**\:  bool
                    
                    .. attribute:: inter_autonomous_system_enabled
                    
                    	Inter\-AS Enabled
                    	**type**\:  bool
                    
                    .. attribute:: ir_maximum_mdt_aggregation
                    
                    	IR MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_announce_interval
                    
                    	IR Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_switchover_interval
                    
                    	IR Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_interface
                    
                    	IRMDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: ir_mdt_mtu
                    
                    	IRMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_name
                    
                    	IR MDT Name
                    	**type**\:  str
                    
                    .. attribute:: ir_mdt_rpf_identifier
                    
                    	IR RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_tail_label
                    
                    	IR Tail Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active
                    	**type**\:  bool
                    
                    .. attribute:: is_active_ital
                    
                    	Active ITAL
                    	**type**\:  bool
                    
                    .. attribute:: is_all_interface_disable_operation
                    
                    	PIM all interface disable operation
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_enabled
                    
                    	Auto RP Listen Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_sock_add
                    
                    	Auto RP listen sock add
                    	**type**\:  bool
                    
                    .. attribute:: is_create_gin_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_in_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_ir_mdt_interface
                    
                    	Create IR MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mdt_interface
                    
                    	Create MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mldp_mdt_interface
                    
                    	Create MLDP MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_rsvp_te_mdt_interface
                    
                    	Create RSVP\-TE MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_default_granges
                    
                    	Default granges
                    	**type**\:  bool
                    
                    .. attribute:: is_gin_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_in_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_ir_mdt_owner
                    
                    	IR MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_added
                    
                    	VRF LPTS filter added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_m_host_publish_pending
                    
                    	Publish pending for MHost Default interface
                    	**type**\:  bool
                    
                    .. attribute:: is_mdt_owner
                    
                    	MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mldp_mdt_owner
                    
                    	MLDP MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mrib_register
                    
                    	MRIB Register
                    	**type**\:  bool
                    
                    .. attribute:: is_multicast_rib_registration
                    
                    	Mcast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converge_received
                    
                    	PIM NSF RIB converge received
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converged
                    
                    	PIM NSF RIB converged
                    	**type**\:  bool
                    
                    .. attribute:: is_redistribution_reset
                    
                    	Pending redist reset
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_added
                    
                    	VRF LPTS filter added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_add_required
                    
                    	VRF required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_added
                    
                    	VRF added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_enabled
                    
                    	PIM RIB multiplath enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_interface_hash
                    
                    	PIM RIB multipath interface hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_hash
                    
                    	PIM RIB multipath source based hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_next_hop_hash
                    
                    	PIM RIB multipath source\-nexthop hash
                    	**type**\:  bool
                    
                    .. attribute:: is_routing_enabled
                    
                    	Routing Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rsvp_te_mdt_owner
                    
                    	RSVP\-TE MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_add_required
                    
                    	VRF required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_added
                    
                    	VRF added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_add_required
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_added
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind
                    
                    	VRF bound on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind_required
                    
                    	VRF bind required on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_unicast_rib_registration
                    
                    	Ucast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: maximum_mdt_aggregation
                    
                    	MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_announce_interval
                    
                    	Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_switchover_interval
                    
                    	Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_default_group
                    
                    	MDT Default group
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_gre_remote_rpf_identifier
                    
                    	GRE\-MDT Remote RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_gre_rpf_identifier
                    
                    	GRE\-MDT RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_immediate_switch
                    
                    	MDT Immediate Switch
                    	**type**\:  bool
                    
                    .. attribute:: mdt_interface
                    
                    	MDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mdt_mtu
                    
                    	MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_neighbor_filter_name
                    
                    	MDT Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: mdt_partitioned_ir_control_identifier
                    
                    	Partitioned IR MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_mdt_control_identifier
                    
                    	Partitioned MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_source
                    
                    	MDT source
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_source_interface
                    
                    	MDT Source Interface Name
                    	**type**\:  str
                    
                    .. attribute:: mhost_default_interface_config
                    
                    	Configured Mhost Defint
                    	**type**\:  str
                    
                    .. attribute:: mhost_interface
                    
                    	MHost handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mldp_auto_rp_announce_tree_added
                    
                    	MLDP Autorp Announce Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_auto_rp_discovery_tree_added
                    
                    	MLDP Autorp Discovery Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_bsr_control_tree_added
                    
                    	MLDP BSR Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_control_head_lsm_identifier
                    
                    	MLDP MVPN Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_local_label
                    
                    	Partitioned MDT Head local label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_lsm_identifier
                    
                    	MLDP Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_maximum_mdt_aggregation
                    
                    	MLDP MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_announce_interval
                    
                    	MLDP Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_switchover_interval
                    
                    	MLDP Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_interface
                    
                    	MLDP MDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mldp_mdt_mtu
                    
                    	MLDP MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_name
                    
                    	MLDP MDT Name
                    	**type**\:  str
                    
                    .. attribute:: mldp_mdt_remote_rpf_identifier
                    
                    	MLDP Remote RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_rpf_identifier
                    
                    	MLDP RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partioned_mp2m_ptree
                    
                    	MP2MP Partitioned MDT tree
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_head_lsm_identifier
                    
                    	Partitioned MDT Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_configured
                    
                    	MLDP Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_mdt_identifier
                    
                    	MLDP Partitioned MDT Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_head_lsm_identifier
                    
                    	MLDP Remote Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_partitioned_mdt_configured
                    
                    	MLDP Remote Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_root_address
                    
                    	MLDP Root addresses
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_root_count
                    
                    	MLDP Root count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: murib_id
                    
                    	MURIB ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: non_default_vrf_count_on_socket
                    
                    	Count of non\-default vrfs on raw socket
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: organization_unique_identifier
                    
                    	OUI for VPN\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mpte_li_drop
                    
                    	Route LI updates dropped for P2MP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: physical_interface_count
                    
                    	Enabled Physical Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: redistribution_reset_count
                    
                    	Redist reset count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_default_group
                    
                    	Remote Default Group
                    	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup>`
                    
                    .. attribute:: remote_table_id
                    
                    	Remote Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_distinguisher
                    
                    	RD value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: rpf_default_table
                    
                    	RPF Default Table
                    	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable>`
                    
                    .. attribute:: rpf_id
                    
                    	RPF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_policy_name
                    
                    	RPF topology selection route\-policy name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_maximum_mdt_aggregation
                    
                    	RSVP\-TE MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_announce_interval
                    
                    	RSVP\-TE Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_switchover_interval
                    
                    	RSVP\-TE Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_interface
                    
                    	RSVP\-TEMDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: rsvp_te_mdt_mtu
                    
                    	RSVP\-TEMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_name
                    
                    	RSVP\-TE MDT Name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_mdt_rpf_identifier
                    
                    	RSVP\-TE RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_static_p2mp_count
                    
                    	Number of Static P2MP\-TE MDT
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	PIM is using MuRIB
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_time
                    
                    	S,G Expiry Time Configured, in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sg_expiry_timer_configured
                    
                    	S,G Expiry Timer Configured
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_timer_sg_list
                    
                    	S,G expiry timer ACL name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: stale_rd_present
                    
                    	RD is stale
                    	**type**\:  bool
                    
                    .. attribute:: suppress_pim_data_mdt_tlv
                    
                    	Suppress PIM Data\-MDT TLV Announcements
                    	**type**\:  bool
                    
                    .. attribute:: suppress_shared_tree_join
                    
                    	Suppress Shared\-Tree Joins
                    	**type**\:  bool
                    
                    .. attribute:: table_count
                    
                    	Number of configured Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: umh
                    
                    	Join UMH Core\-Tree
                    	**type**\:  bool
                    
                    .. attribute:: valid_rd_present
                    
                    	RD is valid
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface_count
                    
                    	Enabled Virtual Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: virtual_mlc_interface_name
                    
                    	Virtual master line card Interface
                    	**type**\:  str
                    
                    .. attribute:: vpn_index
                    
                    	VPN Index
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Context, self).__init__()

                        self.yang_name = "context"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"remote-default-group" : ("remote_default_group", Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup), "rpf-default-table" : ("rpf_default_table", Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable)}
                        self._child_list_classes = {"anycast-rp-range" : ("anycast_rp_range", Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange), "export-route-target" : ("export_route_target", Ipv6Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget), "import-route-target" : ("import_route_target", Ipv6Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget)}

                        self.active_table_count = YLeaf(YType.uint32, "active-table-count")

                        self.allow_rp_configured = YLeaf(YType.boolean, "allow-rp-configured")

                        self.allow_rp_group_list = YLeaf(YType.str, "allow-rp-group-list")

                        self.allow_rp_rp_list = YLeaf(YType.str, "allow-rp-rp-list")

                        self.anycast_rp_configured = YLeaf(YType.boolean, "anycast-rp-configured")

                        self.anycast_rp_policy_name = YLeaf(YType.str, "anycast-rp-policy-name")

                        self.bgp_auto_discovery_configured = YLeaf(YType.boolean, "bgp-auto-discovery-configured")

                        self.bgp_auto_discovery_type = YLeaf(YType.uint32, "bgp-auto-discovery-type")

                        self.bgp_i_pmsi_added = YLeaf(YType.boolean, "bgp-i-pmsi-added")

                        self.bgp_remote_address = YLeaf(YType.str, "bgp-remote-address")

                        self.bgp_remote_interface = YLeaf(YType.str, "bgp-remote-interface")

                        self.bgp_remote_interface_name = YLeaf(YType.str, "bgp-remote-interface-name")

                        self.bgp_remote_on = YLeaf(YType.boolean, "bgp-remote-on")

                        self.bgp_remote_state = YLeaf(YType.uint32, "bgp-remote-state")

                        self.bgp_source_active_announce = YLeaf(YType.boolean, "bgp-source-active-announce")

                        self.gin_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-announce-interval")

                        self.gin_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-switchover-interval")

                        self.gin_b_and_mdt_interface = YLeaf(YType.str, "gin-b-and-mdt-interface")

                        self.gin_b_and_mdt_mtu = YLeaf(YType.uint32, "gin-b-and-mdt-mtu")

                        self.gin_b_and_mdt_name = YLeaf(YType.str, "gin-b-and-mdt-name")

                        self.gin_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "gin-b-and-mdt-rpf-identifier")

                        self.gin_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "gin-band-maximum-mdt-aggregation")

                        self.in_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-announce-interval")

                        self.in_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-switchover-interval")

                        self.in_b_and_mdt_interface = YLeaf(YType.str, "in-b-and-mdt-interface")

                        self.in_b_and_mdt_mtu = YLeaf(YType.uint32, "in-b-and-mdt-mtu")

                        self.in_b_and_mdt_name = YLeaf(YType.str, "in-b-and-mdt-name")

                        self.in_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "in-b-and-mdt-rpf-identifier")

                        self.in_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "in-band-maximum-mdt-aggregation")

                        self.in_band_signaling_local_enabled = YLeaf(YType.boolean, "in-band-signaling-local-enabled")

                        self.in_band_signaling_remote_enabled = YLeaf(YType.boolean, "in-band-signaling-remote-enabled")

                        self.inter_autonomous_system_enabled = YLeaf(YType.boolean, "inter-autonomous-system-enabled")

                        self.ir_maximum_mdt_aggregation = YLeaf(YType.uint32, "ir-maximum-mdt-aggregation")

                        self.ir_mdt_data_announce_interval = YLeaf(YType.uint32, "ir-mdt-data-announce-interval")

                        self.ir_mdt_data_switchover_interval = YLeaf(YType.uint32, "ir-mdt-data-switchover-interval")

                        self.ir_mdt_interface = YLeaf(YType.str, "ir-mdt-interface")

                        self.ir_mdt_mtu = YLeaf(YType.uint32, "ir-mdt-mtu")

                        self.ir_mdt_name = YLeaf(YType.str, "ir-mdt-name")

                        self.ir_mdt_rpf_identifier = YLeaf(YType.uint32, "ir-mdt-rpf-identifier")

                        self.ir_mdt_tail_label = YLeaf(YType.uint32, "ir-mdt-tail-label")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_active_ital = YLeaf(YType.boolean, "is-active-ital")

                        self.is_all_interface_disable_operation = YLeaf(YType.boolean, "is-all-interface-disable-operation")

                        self.is_auto_rp_listen_enabled = YLeaf(YType.boolean, "is-auto-rp-listen-enabled")

                        self.is_auto_rp_listen_sock_add = YLeaf(YType.boolean, "is-auto-rp-listen-sock-add")

                        self.is_create_gin_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-gin-b-and-mdt-interface")

                        self.is_create_in_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-in-b-and-mdt-interface")

                        self.is_create_ir_mdt_interface = YLeaf(YType.boolean, "is-create-ir-mdt-interface")

                        self.is_create_mdt_interface = YLeaf(YType.boolean, "is-create-mdt-interface")

                        self.is_create_mldp_mdt_interface = YLeaf(YType.boolean, "is-create-mldp-mdt-interface")

                        self.is_create_rsvp_te_mdt_interface = YLeaf(YType.boolean, "is-create-rsvp-te-mdt-interface")

                        self.is_default_granges = YLeaf(YType.boolean, "is-default-granges")

                        self.is_gin_b_and_mdt_owner = YLeaf(YType.boolean, "is-gin-b-and-mdt-owner")

                        self.is_in_b_and_mdt_owner = YLeaf(YType.boolean, "is-in-b-and-mdt-owner")

                        self.is_ir_mdt_owner = YLeaf(YType.boolean, "is-ir-mdt-owner")

                        self.is_lpts_socket_add_required = YLeaf(YType.boolean, "is-lpts-socket-add-required")

                        self.is_lpts_socket_added = YLeaf(YType.boolean, "is-lpts-socket-added")

                        self.is_m_host_publish_pending = YLeaf(YType.boolean, "is-m-host-publish-pending")

                        self.is_mdt_owner = YLeaf(YType.boolean, "is-mdt-owner")

                        self.is_mldp_mdt_owner = YLeaf(YType.boolean, "is-mldp-mdt-owner")

                        self.is_mrib_register = YLeaf(YType.boolean, "is-mrib-register")

                        self.is_multicast_rib_registration = YLeaf(YType.boolean, "is-multicast-rib-registration")

                        self.is_pim_nsf_rib_converge_received = YLeaf(YType.boolean, "is-pim-nsf-rib-converge-received")

                        self.is_pim_nsf_rib_converged = YLeaf(YType.boolean, "is-pim-nsf-rib-converged")

                        self.is_redistribution_reset = YLeaf(YType.boolean, "is-redistribution-reset")

                        self.is_register_injection_lpts_socket_add_required = YLeaf(YType.boolean, "is-register-injection-lpts-socket-add-required")

                        self.is_register_injection_lpts_socket_added = YLeaf(YType.boolean, "is-register-injection-lpts-socket-added")

                        self.is_register_injection_socket_add_required = YLeaf(YType.boolean, "is-register-injection-socket-add-required")

                        self.is_register_injection_socket_added = YLeaf(YType.boolean, "is-register-injection-socket-added")

                        self.is_rib_multipath_enabled = YLeaf(YType.boolean, "is-rib-multipath-enabled")

                        self.is_rib_multipath_interface_hash = YLeaf(YType.boolean, "is-rib-multipath-interface-hash")

                        self.is_rib_multipath_source_hash = YLeaf(YType.boolean, "is-rib-multipath-source-hash")

                        self.is_rib_multipath_source_next_hop_hash = YLeaf(YType.boolean, "is-rib-multipath-source-next-hop-hash")

                        self.is_routing_enabled = YLeaf(YType.boolean, "is-routing-enabled")

                        self.is_rsvp_te_mdt_owner = YLeaf(YType.boolean, "is-rsvp-te-mdt-owner")

                        self.is_socket_add_required = YLeaf(YType.boolean, "is-socket-add-required")

                        self.is_socket_added = YLeaf(YType.boolean, "is-socket-added")

                        self.is_udp_socket_add_required = YLeaf(YType.boolean, "is-udp-socket-add-required")

                        self.is_udp_socket_added = YLeaf(YType.boolean, "is-udp-socket-added")

                        self.is_udp_socket_bind = YLeaf(YType.boolean, "is-udp-socket-bind")

                        self.is_udp_socket_bind_required = YLeaf(YType.boolean, "is-udp-socket-bind-required")

                        self.is_unicast_rib_registration = YLeaf(YType.boolean, "is-unicast-rib-registration")

                        self.maximum_mdt_aggregation = YLeaf(YType.uint32, "maximum-mdt-aggregation")

                        self.mdt_data_announce_interval = YLeaf(YType.uint32, "mdt-data-announce-interval")

                        self.mdt_data_switchover_interval = YLeaf(YType.uint32, "mdt-data-switchover-interval")

                        self.mdt_default_group = YLeaf(YType.str, "mdt-default-group")

                        self.mdt_gre_remote_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-remote-rpf-identifier")

                        self.mdt_gre_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-rpf-identifier")

                        self.mdt_immediate_switch = YLeaf(YType.boolean, "mdt-immediate-switch")

                        self.mdt_interface = YLeaf(YType.str, "mdt-interface")

                        self.mdt_mtu = YLeaf(YType.uint32, "mdt-mtu")

                        self.mdt_neighbor_filter_name = YLeaf(YType.str, "mdt-neighbor-filter-name")

                        self.mdt_partitioned_ir_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-ir-control-identifier")

                        self.mdt_partitioned_mdt_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-mdt-control-identifier")

                        self.mdt_source = YLeaf(YType.str, "mdt-source")

                        self.mdt_source_interface = YLeaf(YType.str, "mdt-source-interface")

                        self.mhost_default_interface_config = YLeaf(YType.str, "mhost-default-interface-config")

                        self.mhost_interface = YLeaf(YType.str, "mhost-interface")

                        self.mldp_auto_rp_announce_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-announce-tree-added")

                        self.mldp_auto_rp_discovery_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-discovery-tree-added")

                        self.mldp_bsr_control_tree_added = YLeaf(YType.boolean, "mldp-bsr-control-tree-added")

                        self.mldp_control_head_lsm_identifier = YLeaf(YType.uint32, "mldp-control-head-lsm-identifier")

                        self.mldp_head_local_label = YLeaf(YType.uint32, "mldp-head-local-label")

                        self.mldp_head_lsm_identifier = YLeaf(YType.uint32, "mldp-head-lsm-identifier")

                        self.mldp_maximum_mdt_aggregation = YLeaf(YType.uint32, "mldp-maximum-mdt-aggregation")

                        self.mldp_mdt_data_announce_interval = YLeaf(YType.uint32, "mldp-mdt-data-announce-interval")

                        self.mldp_mdt_data_switchover_interval = YLeaf(YType.uint32, "mldp-mdt-data-switchover-interval")

                        self.mldp_mdt_interface = YLeaf(YType.str, "mldp-mdt-interface")

                        self.mldp_mdt_mtu = YLeaf(YType.uint32, "mldp-mdt-mtu")

                        self.mldp_mdt_name = YLeaf(YType.str, "mldp-mdt-name")

                        self.mldp_mdt_remote_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-remote-rpf-identifier")

                        self.mldp_mdt_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-rpf-identifier")

                        self.mldp_partioned_mp2m_ptree = YLeaf(YType.boolean, "mldp-partioned-mp2m-ptree")

                        self.mldp_partitioned_head_lsm_identifier = YLeaf(YType.uint32, "mldp-partitioned-head-lsm-identifier")

                        self.mldp_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-partitioned-mdt-configured")

                        self.mldp_partitioned_mdt_identifier = YLeaf(YType.uint32, "mldp-partitioned-mdt-identifier")

                        self.mldp_remote_head_lsm_identifier = YLeaf(YType.uint32, "mldp-remote-head-lsm-identifier")

                        self.mldp_remote_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-remote-partitioned-mdt-configured")

                        self.mldp_root_address = YLeafList(YType.uint32, "mldp-root-address")

                        self.mldp_root_count = YLeaf(YType.uint32, "mldp-root-count")

                        self.murib_id = YLeaf(YType.uint32, "murib-id")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.non_default_vrf_count_on_socket = YLeaf(YType.uint32, "non-default-vrf-count-on-socket")

                        self.organization_unique_identifier = YLeaf(YType.uint32, "organization-unique-identifier")

                        self.p2mpte_li_drop = YLeaf(YType.uint32, "p2mpte-li-drop")

                        self.physical_interface_count = YLeaf(YType.uint64, "physical-interface-count")

                        self.redistribution_reset_count = YLeaf(YType.uint32, "redistribution-reset-count")

                        self.remote_table_id = YLeaf(YType.uint32, "remote-table-id")

                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                        self.rpf_id = YLeaf(YType.uint32, "rpf-id")

                        self.rpf_policy_name = YLeaf(YType.str, "rpf-policy-name")

                        self.rsvp_te_maximum_mdt_aggregation = YLeaf(YType.uint32, "rsvp-te-maximum-mdt-aggregation")

                        self.rsvp_te_mdt_data_announce_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-announce-interval")

                        self.rsvp_te_mdt_data_switchover_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-switchover-interval")

                        self.rsvp_te_mdt_interface = YLeaf(YType.str, "rsvp-te-mdt-interface")

                        self.rsvp_te_mdt_mtu = YLeaf(YType.uint32, "rsvp-te-mdt-mtu")

                        self.rsvp_te_mdt_name = YLeaf(YType.str, "rsvp-te-mdt-name")

                        self.rsvp_te_mdt_rpf_identifier = YLeaf(YType.uint32, "rsvp-te-mdt-rpf-identifier")

                        self.rsvp_te_mdt_static_p2mp_count = YLeaf(YType.uint32, "rsvp-te-mdt-static-p2mp-count")

                        self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                        self.sg_expiry_time = YLeaf(YType.uint16, "sg-expiry-time")

                        self.sg_expiry_timer_configured = YLeaf(YType.boolean, "sg-expiry-timer-configured")

                        self.sg_expiry_timer_sg_list = YLeaf(YType.str, "sg-expiry-timer-sg-list")

                        self.stale_rd_present = YLeaf(YType.boolean, "stale-rd-present")

                        self.suppress_pim_data_mdt_tlv = YLeaf(YType.boolean, "suppress-pim-data-mdt-tlv")

                        self.suppress_shared_tree_join = YLeaf(YType.boolean, "suppress-shared-tree-join")

                        self.table_count = YLeaf(YType.uint32, "table-count")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.umh = YLeaf(YType.boolean, "umh")

                        self.valid_rd_present = YLeaf(YType.boolean, "valid-rd-present")

                        self.virtual_interface_count = YLeaf(YType.uint64, "virtual-interface-count")

                        self.virtual_mlc_interface_name = YLeaf(YType.str, "virtual-mlc-interface-name")

                        self.vpn_index = YLeaf(YType.uint32, "vpn-index")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.remote_default_group = Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup()
                        self.remote_default_group.parent = self
                        self._children_name_map["remote_default_group"] = "remote-default-group"
                        self._children_yang_names.add("remote-default-group")

                        self.rpf_default_table = Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable()
                        self.rpf_default_table.parent = self
                        self._children_name_map["rpf_default_table"] = "rpf-default-table"
                        self._children_yang_names.add("rpf-default-table")

                        self.anycast_rp_range = YList(self)
                        self.export_route_target = YList(self)
                        self.import_route_target = YList(self)
                        self._segment_path = lambda: "context"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Context, ['active_table_count', 'allow_rp_configured', 'allow_rp_group_list', 'allow_rp_rp_list', 'anycast_rp_configured', 'anycast_rp_policy_name', 'bgp_auto_discovery_configured', 'bgp_auto_discovery_type', 'bgp_i_pmsi_added', 'bgp_remote_address', 'bgp_remote_interface', 'bgp_remote_interface_name', 'bgp_remote_on', 'bgp_remote_state', 'bgp_source_active_announce', 'gin_b_and_mdt_data_announce_interval', 'gin_b_and_mdt_data_switchover_interval', 'gin_b_and_mdt_interface', 'gin_b_and_mdt_mtu', 'gin_b_and_mdt_name', 'gin_b_and_mdt_rpf_identifier', 'gin_band_maximum_mdt_aggregation', 'in_b_and_mdt_data_announce_interval', 'in_b_and_mdt_data_switchover_interval', 'in_b_and_mdt_interface', 'in_b_and_mdt_mtu', 'in_b_and_mdt_name', 'in_b_and_mdt_rpf_identifier', 'in_band_maximum_mdt_aggregation', 'in_band_signaling_local_enabled', 'in_band_signaling_remote_enabled', 'inter_autonomous_system_enabled', 'ir_maximum_mdt_aggregation', 'ir_mdt_data_announce_interval', 'ir_mdt_data_switchover_interval', 'ir_mdt_interface', 'ir_mdt_mtu', 'ir_mdt_name', 'ir_mdt_rpf_identifier', 'ir_mdt_tail_label', 'is_active', 'is_active_ital', 'is_all_interface_disable_operation', 'is_auto_rp_listen_enabled', 'is_auto_rp_listen_sock_add', 'is_create_gin_b_and_mdt_interface', 'is_create_in_b_and_mdt_interface', 'is_create_ir_mdt_interface', 'is_create_mdt_interface', 'is_create_mldp_mdt_interface', 'is_create_rsvp_te_mdt_interface', 'is_default_granges', 'is_gin_b_and_mdt_owner', 'is_in_b_and_mdt_owner', 'is_ir_mdt_owner', 'is_lpts_socket_add_required', 'is_lpts_socket_added', 'is_m_host_publish_pending', 'is_mdt_owner', 'is_mldp_mdt_owner', 'is_mrib_register', 'is_multicast_rib_registration', 'is_pim_nsf_rib_converge_received', 'is_pim_nsf_rib_converged', 'is_redistribution_reset', 'is_register_injection_lpts_socket_add_required', 'is_register_injection_lpts_socket_added', 'is_register_injection_socket_add_required', 'is_register_injection_socket_added', 'is_rib_multipath_enabled', 'is_rib_multipath_interface_hash', 'is_rib_multipath_source_hash', 'is_rib_multipath_source_next_hop_hash', 'is_routing_enabled', 'is_rsvp_te_mdt_owner', 'is_socket_add_required', 'is_socket_added', 'is_udp_socket_add_required', 'is_udp_socket_added', 'is_udp_socket_bind', 'is_udp_socket_bind_required', 'is_unicast_rib_registration', 'maximum_mdt_aggregation', 'mdt_data_announce_interval', 'mdt_data_switchover_interval', 'mdt_default_group', 'mdt_gre_remote_rpf_identifier', 'mdt_gre_rpf_identifier', 'mdt_immediate_switch', 'mdt_interface', 'mdt_mtu', 'mdt_neighbor_filter_name', 'mdt_partitioned_ir_control_identifier', 'mdt_partitioned_mdt_control_identifier', 'mdt_source', 'mdt_source_interface', 'mhost_default_interface_config', 'mhost_interface', 'mldp_auto_rp_announce_tree_added', 'mldp_auto_rp_discovery_tree_added', 'mldp_bsr_control_tree_added', 'mldp_control_head_lsm_identifier', 'mldp_head_local_label', 'mldp_head_lsm_identifier', 'mldp_maximum_mdt_aggregation', 'mldp_mdt_data_announce_interval', 'mldp_mdt_data_switchover_interval', 'mldp_mdt_interface', 'mldp_mdt_mtu', 'mldp_mdt_name', 'mldp_mdt_remote_rpf_identifier', 'mldp_mdt_rpf_identifier', 'mldp_partioned_mp2m_ptree', 'mldp_partitioned_head_lsm_identifier', 'mldp_partitioned_mdt_configured', 'mldp_partitioned_mdt_identifier', 'mldp_remote_head_lsm_identifier', 'mldp_remote_partitioned_mdt_configured', 'mldp_root_address', 'mldp_root_count', 'murib_id', 'neighbor_filter_name', 'non_default_vrf_count_on_socket', 'organization_unique_identifier', 'p2mpte_li_drop', 'physical_interface_count', 'redistribution_reset_count', 'remote_table_id', 'route_distinguisher', 'rpf_id', 'rpf_policy_name', 'rsvp_te_maximum_mdt_aggregation', 'rsvp_te_mdt_data_announce_interval', 'rsvp_te_mdt_data_switchover_interval', 'rsvp_te_mdt_interface', 'rsvp_te_mdt_mtu', 'rsvp_te_mdt_name', 'rsvp_te_mdt_rpf_identifier', 'rsvp_te_mdt_static_p2mp_count', 'rump_enabled', 'sg_expiry_time', 'sg_expiry_timer_configured', 'sg_expiry_timer_sg_list', 'stale_rd_present', 'suppress_pim_data_mdt_tlv', 'suppress_shared_tree_join', 'table_count', 'table_id', 'umh', 'valid_rd_present', 'virtual_interface_count', 'virtual_mlc_interface_name', 'vpn_index', 'vrf_id'], name, value)


                    class AnycastRpRange(Entity):
                        """
                        Anycast\-RP Ranges
                        
                        .. attribute:: ancast_rp_marked
                        
                        	Anycast\-RP Range marked
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Anycast\-RP Range Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Anycast\-RP Range Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange, self).__init__()

                            self.yang_name = "anycast-rp-range"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"prefix" : ("prefix", Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix)}
                            self._child_list_classes = {}

                            self.ancast_rp_marked = YLeaf(YType.boolean, "ancast-rp-marked")

                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                            self.prefix = Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")
                            self._segment_path = lambda: "anycast-rp-range"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange, ['ancast_rp_marked', 'prefix_length'], name, value)


                        class Prefix(Entity):
                            """
                            Anycast\-RP Range Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "anycast-rp-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class ExportRouteTarget(Entity):
                        """
                        Export Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget, self).__init__()

                            self.yang_name = "export-route-target"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                            self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                            self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                            self.configured = YLeaf(YType.boolean, "configured")

                            self.route_target = YLeaf(YType.str, "route-target")

                            self.segment_border = YLeaf(YType.boolean, "segment-border")

                            self.update_pending = YLeaf(YType.boolean, "update-pending")
                            self._segment_path = lambda: "export-route-target"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget, ['anycast_rp', 'anycast_rp_marked', 'bgp_auto_discovery', 'configured', 'route_target', 'segment_border', 'update_pending'], name, value)


                    class ImportRouteTarget(Entity):
                        """
                        Import Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget, self).__init__()

                            self.yang_name = "import-route-target"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                            self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                            self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                            self.configured = YLeaf(YType.boolean, "configured")

                            self.route_target = YLeaf(YType.str, "route-target")

                            self.segment_border = YLeaf(YType.boolean, "segment-border")

                            self.update_pending = YLeaf(YType.boolean, "update-pending")
                            self._segment_path = lambda: "import-route-target"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget, ['anycast_rp', 'anycast_rp_marked', 'bgp_auto_discovery', 'configured', 'route_target', 'segment_border', 'update_pending'], name, value)


                    class RemoteDefaultGroup(Entity):
                        """
                        Remote Default Group
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__init__()

                            self.yang_name = "remote-default-group"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "remote-default-group"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfDefaultTable(Entity):
                        """
                        RPF Default Table
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable, self).__init__()

                            self.yang_name = "rpf-default-table"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                            self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                            self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                            self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                            self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.table_id = YLeaf(YType.uint32, "table-id")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")
                            self._segment_path = lambda: "rpf-default-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable, ['afi', 'is_active', 'is_ital_registration_done', 'is_rib_convergence', 'is_rib_convergence_received', 'is_rib_registration_done', 'rpf_registrations', 'safi', 'table_id', 'table_name', 'vrf_id'], name, value)


                class Gre(Entity):
                    """
                    GRE information
                    
                    .. attribute:: gre_hashes
                    
                    	GRE hash
                    	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes>`
                    
                    .. attribute:: gre_next_hops
                    
                    	GRE destination neighbor table
                    	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Gre, self).__init__()

                        self.yang_name = "gre"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"gre-hashes" : ("gre_hashes", Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes), "gre-next-hops" : ("gre_next_hops", Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops)}
                        self._child_list_classes = {}

                        self.gre_hashes = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes()
                        self.gre_hashes.parent = self
                        self._children_name_map["gre_hashes"] = "gre-hashes"
                        self._children_yang_names.add("gre-hashes")

                        self.gre_next_hops = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops()
                        self.gre_next_hops.parent = self
                        self._children_name_map["gre_next_hops"] = "gre-next-hops"
                        self._children_yang_names.add("gre-next-hops")
                        self._segment_path = lambda: "gre"


                    class GreHashes(Entity):
                        """
                        GRE hash
                        
                        .. attribute:: gre_hash
                        
                        	PIM GRE Hashed Underlying Interface
                        	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes, self).__init__()

                            self.yang_name = "gre-hashes"
                            self.yang_parent_name = "gre"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"gre-hash" : ("gre_hash", Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash)}

                            self.gre_hash = YList(self)
                            self._segment_path = lambda: "gre-hashes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes, [], name, value)


                        class GreHash(Entity):
                            """
                            PIM GRE Hashed Underlying Interface
                            
                            .. attribute:: source_address  <key>
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: destination_address  <key>
                            
                            	Destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: ifname  <key>
                            
                            	GRE Tunnel Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__init__()

                                self.yang_name = "gre-hash"
                                self.yang_parent_name = "gre-hashes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.ifname = YLeaf(YType.str, "ifname")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")
                                self._segment_path = lambda: "gre-hash" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[ifname='" + self.ifname.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash, ['source_address', 'destination_address', 'ifname', 'next_hop_interface'], name, value)


                    class GreNextHops(Entity):
                        """
                        GRE destination neighbor table
                        
                        .. attribute:: gre_next_hop
                        
                        	PIM GRE address next\-hop information
                        	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops, self).__init__()

                            self.yang_name = "gre-next-hops"
                            self.yang_parent_name = "gre"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"gre-next-hop" : ("gre_next_hop", Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop)}

                            self.gre_next_hop = YList(self)
                            self._segment_path = lambda: "gre-next-hops"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops, [], name, value)


                        class GreNextHop(Entity):
                            """
                            PIM GRE address next\-hop information
                            
                            .. attribute:: destination_address  <key>
                            
                            	GRE destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: gre_path
                            
                            	GRE Paths list
                            	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath>`
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__init__()

                                self.yang_name = "gre-next-hop"
                                self.yang_parent_name = "gre-next-hops"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"registered-address" : ("registered_address", Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress)}
                                self._child_list_classes = {"gre-path" : ("gre_path", Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath)}

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.is_connected = YLeaf(YType.uint8, "is-connected")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                self.registered_address = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                self.registered_address.parent = self
                                self._children_name_map["registered_address"] = "registered-address"
                                self._children_yang_names.add("registered-address")

                                self.gre_path = YList(self)
                                self._segment_path = lambda: "gre-next-hop" + "[destination-address='" + self.destination_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, ['destination_address', 'is_connected', 'metric', 'metric_preference'], name, value)


                            class GrePath(Entity):
                                """
                                GRE Paths list
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: gre_interface_name
                                
                                	GRE Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: gre_neighbor
                                
                                	GRE neighbor
                                	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                                
                                .. attribute:: gre_next_hop
                                
                                	GRE nexthop
                                	**type**\:   :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop>`
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_gre_interface_disabled
                                
                                	Is the gre interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                    self.yang_name = "gre-path"
                                    self.yang_parent_name = "gre-next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"gre-neighbor" : ("gre_neighbor", Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor), "gre-next-hop" : ("gre_next_hop", Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop)}
                                    self._child_list_classes = {}

                                    self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                    self.gre_interface_name = YLeaf(YType.str, "gre-interface-name")

                                    self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                    self.is_gre_interface_disabled = YLeaf(YType.boolean, "is-gre-interface-disabled")

                                    self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                    self.gre_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                    self.gre_neighbor.parent = self
                                    self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                    self._children_yang_names.add("gre-neighbor")

                                    self.gre_next_hop = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                    self.gre_next_hop.parent = self
                                    self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                    self._children_yang_names.add("gre-next-hop")
                                    self._segment_path = lambda: "gre-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, ['extranet_vrf_name', 'gre_interface_name', 'is_connector_attribute_present', 'is_gre_interface_disabled', 'is_via_lsm'], name, value)


                                class GreNeighbor(Entity):
                                    """
                                    GRE neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                        self.yang_name = "gre-neighbor"
                                        self.yang_parent_name = "gre-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "gre-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class GreNextHop(Entity):
                                    """
                                    GRE nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__init__()

                                        self.yang_name = "gre-next-hop"
                                        self.yang_parent_name = "gre-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "gre-next-hop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class RegisteredAddress(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                    self.yang_name = "registered-address"
                                    self.yang_parent_name = "gre-next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "registered-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class GroupMapRpfs(Entity):
                    """
                    PIM group mapping information
                    
                    .. attribute:: group_map_rpf
                    
                    	PIM group mapping entry
                    	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs, self).__init__()

                        self.yang_name = "group-map-rpfs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"group-map-rpf" : ("group_map_rpf", Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf)}

                        self.group_map_rpf = YList(self)
                        self._segment_path = lambda: "group-map-rpfs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs, [], name, value)


                    class GroupMapRpf(Entity):
                        """
                        PIM group mapping entry
                        
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_priority
                        
                        	RP priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__init__()

                            self.yang_name = "group-map-rpf"
                            self.yang_parent_name = "group-map-rpfs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-map-information" : ("group_map_information", Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation), "rpf-neighbor" : ("rpf_neighbor", Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor)}
                            self._child_list_classes = {}

                            self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                            self.client = YLeaf(YType.enumeration, "client")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_priority = YLeaf(YType.int32, "rp-priority")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.group_map_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")
                            self._segment_path = lambda: "group-map-rpf"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, ['are_we_rp', 'client', 'prefix', 'prefix_length', 'protocol', 'rp_address', 'rp_priority', 'rpf_interface_name', 'rpf_vrf_name'], name, value)


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-rpf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"prefix" : ("prefix", Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix), "rp-address" : ("rp_address", Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress)}
                                self._child_list_classes = {}

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")
                                self._segment_path = lambda: "group-map-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, ['client', 'group_count', 'is_override', 'is_used', 'mrib_active', 'prefix_length', 'priority', 'protocol'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "prefix"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "rp-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "group-map-rpf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class GroupMapSources(Entity):
                    """
                    PIM group\-mapping with source information
                    
                    .. attribute:: group_map_source
                    
                    	PIM Group Mapping Entry with source information
                    	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources, self).__init__()

                        self.yang_name = "group-map-sources"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"group-map-source" : ("group_map_source", Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource)}

                        self.group_map_source = YList(self)
                        self._segment_path = lambda: "group-map-sources"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources, [], name, value)


                    class GroupMapSource(Entity):
                        """
                        PIM Group Mapping Entry with source information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	RP Priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__init__()

                            self.yang_name = "group-map-source"
                            self.yang_parent_name = "group-map-sources"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-map-information" : ("group_map_information", Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation), "source-of-information" : ("source_of_information", Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation)}
                            self._child_list_classes = {}

                            self.client = YLeaf(YType.enumeration, "client")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.holdtime = YLeaf(YType.int32, "holdtime")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.int32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_map_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.source_of_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")
                            self._segment_path = lambda: "group-map-source"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource, ['client', 'expires', 'holdtime', 'prefix', 'prefix_length', 'priority', 'protocol', 'rp_address', 'uptime'], name, value)


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"prefix" : ("prefix", Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix), "rp-address" : ("rp_address", Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress)}
                                self._child_list_classes = {}

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")
                                self._segment_path = lambda: "group-map-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, ['client', 'group_count', 'is_override', 'is_used', 'mrib_active', 'prefix_length', 'priority', 'protocol'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "prefix"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "rp-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-map-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-of-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class IfrsInterfaces(Entity):
                    """
                    PIM interfaces in forward reference store table
                    
                    .. attribute:: ifrs_interface
                    
                    	PIM IFRS interface information
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ifrs-interface" : ("ifrs_interface", Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface)}

                        self.ifrs_interface = YList(self)
                        self._segment_path = lambda: "ifrs-interfaces"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces, [], name, value)


                    class IfrsInterface(Entity):
                        """
                        PIM IFRS interface information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"dr-address" : ("dr_address", Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress)}
                            self._child_list_classes = {"interface-address" : ("interface_address", Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "dr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "interface-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class IfrsSummary(Entity):
                    """
                    PIM interfaces in forward reference store
                    summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration counts
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Number of interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary, self).__init__()

                        self.yang_name = "ifrs-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                        self.interface_count = YLeaf(YType.uint32, "interface-count")
                        self._segment_path = lambda: "ifrs-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary, ['configuration_count', 'interface_count'], name, value)


                class InterfaceOldFormats(Entity):
                    """
                    PIM interfaces in old format
                    
                    .. attribute:: interface_old_format
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats, self).__init__()

                        self.yang_name = "interface-old-formats"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-old-format" : ("interface_old_format", Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat)}

                        self.interface_old_format = YList(self)
                        self._segment_path = lambda: "interface-old-formats"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats, [], name, value)


                    class InterfaceOldFormat(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                            self.yang_name = "interface-old-format"
                            self.yang_parent_name = "interface-old-formats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"dr-address" : ("dr_address", Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress)}
                            self._child_list_classes = {"interface-address" : ("interface_address", Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "interface-old-format" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "dr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "interface-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceStatistics(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_statistic
                    
                    	PIM interface statistics
                    	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics, self).__init__()

                        self.yang_name = "interface-statistics"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-statistic" : ("interface_statistic", Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic)}

                        self.interface_statistic = YList(self)
                        self._segment_path = lambda: "interface-statistics"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics, [], name, value)


                    class InterfaceStatistic(Entity):
                        """
                        PIM interface statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: input_assert
                        
                        	Assert packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_bsr_message
                        
                        	Input BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_candidate_rp_advertisement
                        
                        	Input Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_df_election
                        
                        	DF Election packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_ack_message
                        
                        	Input Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_message
                        
                        	Input Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_hello
                        
                        	Hello packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_jp
                        
                        	Join Prune packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_miscellaneous
                        
                        	Miscellaneous packet in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register
                        
                        	Register packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register_stop
                        
                        	Register Stop packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_assert
                        
                        	Assert packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_bsr_message
                        
                        	Output BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_candidate_rp_advertisement
                        
                        	Output Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_df_election
                        
                        	DF Election packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_ack_message
                        
                        	Output Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_message
                        
                        	Output Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_hello
                        
                        	Hello packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_jp
                        
                        	Join Prune packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register
                        
                        	Register packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register_stop
                        
                        	Register Stop packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__init__()

                            self.yang_name = "interface-statistic"
                            self.yang_parent_name = "interface-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.input_assert = YLeaf(YType.uint32, "input-assert")

                            self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                            self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                            self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                            self.input_graft_ack_message = YLeaf(YType.uint32, "input-graft-ack-message")

                            self.input_graft_message = YLeaf(YType.uint32, "input-graft-message")

                            self.input_hello = YLeaf(YType.uint32, "input-hello")

                            self.input_jp = YLeaf(YType.uint32, "input-jp")

                            self.input_miscellaneous = YLeaf(YType.uint32, "input-miscellaneous")

                            self.input_register = YLeaf(YType.uint32, "input-register")

                            self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                            self.output_assert = YLeaf(YType.uint32, "output-assert")

                            self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                            self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                            self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                            self.output_graft_ack_message = YLeaf(YType.uint32, "output-graft-ack-message")

                            self.output_graft_message = YLeaf(YType.uint32, "output-graft-message")

                            self.output_hello = YLeaf(YType.uint32, "output-hello")

                            self.output_jp = YLeaf(YType.uint32, "output-jp")

                            self.output_register = YLeaf(YType.uint32, "output-register")

                            self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")
                            self._segment_path = lambda: "interface-statistic" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, ['interface_name', 'input_assert', 'input_bsr_message', 'input_candidate_rp_advertisement', 'input_df_election', 'input_graft_ack_message', 'input_graft_message', 'input_hello', 'input_jp', 'input_miscellaneous', 'input_register', 'input_register_stop', 'output_assert', 'output_bsr_message', 'output_candidate_rp_advertisement', 'output_df_election', 'output_graft_ack_message', 'output_graft_message', 'output_hello', 'output_jp', 'output_register', 'output_register_stop'], name, value)


                class Interfaces(Entity):
                    """
                    PIM interfaces
                    
                    .. attribute:: interface
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces, self).__init__()

                        self.yang_name = "interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface" : ("interface", Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface)}

                        self.interface = YList(self)
                        self._segment_path = lambda: "interfaces"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Interfaces, [], name, value)


                    class Interface(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"dr-address" : ("dr_address", Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress)}
                            self._child_list_classes = {"interface-address" : ("interface_address", Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "dr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "interface-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class JpStatistics(Entity):
                    """
                    PIM join prune statistics table
                    
                    .. attribute:: jp_statistic
                    
                    	PIM Join Prune Statistics
                    	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.JpStatistics, self).__init__()

                        self.yang_name = "jp-statistics"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"jp-statistic" : ("jp_statistic", Ipv6Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic)}

                        self.jp_statistic = YList(self)
                        self._segment_path = lambda: "jp-statistics"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.JpStatistics, [], name, value)


                    class JpStatistic(Entity):
                        """
                        PIM Join Prune Statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received
                        
                        	Received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received100
                        
                        	Received 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_10k
                        
                        	Received 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_1k
                        
                        	Received 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_50k
                        
                        	Deprecated by Received100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted
                        
                        	Transmitted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted100
                        
                        	Transmitted 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_10k
                        
                        	Transmitted 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_1k
                        
                        	Transmitted 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_50k
                        
                        	Deprecated by Transmitted100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic, self).__init__()

                            self.yang_name = "jp-statistic"
                            self.yang_parent_name = "jp-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.received = YLeaf(YType.uint32, "received")

                            self.received100 = YLeaf(YType.uint16, "received100")

                            self.received_10k = YLeaf(YType.uint16, "received-10k")

                            self.received_1k = YLeaf(YType.uint16, "received-1k")

                            self.received_50k = YLeaf(YType.uint16, "received-50k")

                            self.transmitted = YLeaf(YType.uint32, "transmitted")

                            self.transmitted100 = YLeaf(YType.uint16, "transmitted100")

                            self.transmitted_10k = YLeaf(YType.uint16, "transmitted-10k")

                            self.transmitted_1k = YLeaf(YType.uint16, "transmitted-1k")

                            self.transmitted_50k = YLeaf(YType.uint16, "transmitted-50k")
                            self._segment_path = lambda: "jp-statistic" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic, ['interface_name', 'interface_name_xr', 'mtu', 'received', 'received100', 'received_10k', 'received_1k', 'received_50k', 'transmitted', 'transmitted100', 'transmitted_10k', 'transmitted_1k', 'transmitted_50k'], name, value)


                class MibDatabases(Entity):
                    """
                    PIM group database for mroute mibs table
                    
                    .. attribute:: mib_database
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases, self).__init__()

                        self.yang_name = "mib-databases"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"mib-database" : ("mib_database", Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase)}

                        self.mib_database = YList(self)
                        self._segment_path = lambda: "mib-databases"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases, [], name, value)


                    class MibDatabase(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: assert_metric
                        
                        	Assert Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_metric_preference
                        
                        	Assert Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_rpt_bit
                        
                        	Assert RPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: bidirectional_route
                        
                        	Is this Bidir ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Multicast satic route group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr>`
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface name 
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: rpf_mask
                        
                        	Mask of the multicast root
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_neighbor
                        
                        	The RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: source_address
                        
                        	Multicast static route source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr>`
                        
                        .. attribute:: source_netmask
                        
                        	Source mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: spt_bit
                        
                        	Is SPT bit set ?
                        	**type**\:  bool
                        
                        .. attribute:: upstream_assert_timer
                        
                        	Upstream Assert Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime of route
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase, self).__init__()

                            self.yang_name = "mib-database"
                            self.yang_parent_name = "mib-databases"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr), "rpf-neighbor" : ("rpf_neighbor", Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor), "rpf-root" : ("rpf_root", Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot), "source-address-xr" : ("source_address_xr", Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr)}
                            self._child_list_classes = {}

                            self.assert_metric = YLeaf(YType.uint32, "assert-metric")

                            self.assert_metric_preference = YLeaf(YType.uint32, "assert-metric-preference")

                            self.assert_rpt_bit = YLeaf(YType.boolean, "assert-rpt-bit")

                            self.bidirectional_route = YLeaf(YType.boolean, "bidirectional-route")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                            self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_mask = YLeaf(YType.uint32, "rpf-mask")

                            self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                            self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_netmask = YLeaf(YType.int32, "source-netmask")

                            self.spt_bit = YLeaf(YType.boolean, "spt-bit")

                            self.upstream_assert_timer = YLeaf(YType.int32, "upstream-assert-timer")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                            self.rpf_root = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._children_yang_names.add("rpf-root")

                            self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")
                            self._segment_path = lambda: "mib-database"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase, ['assert_metric', 'assert_metric_preference', 'assert_rpt_bit', 'bidirectional_route', 'group_address', 'protocol', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_mask', 'rpf_safi', 'rpf_table_name', 'rpf_vrf_name', 'source_address', 'source_netmask', 'spt_bit', 'upstream_assert_timer', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            The RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-root"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class MulticastStaticRoutes(Entity):
                    """
                    PIM multicast static route table
                    
                    .. attribute:: multicast_static_route
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes, self).__init__()

                        self.yang_name = "multicast-static-routes"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"multicast-static-route" : ("multicast_static_route", Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute)}

                        self.multicast_static_route = YList(self)
                        self._segment_path = lambda: "multicast-static-routes"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes, [], name, value)


                    class MulticastStaticRoute(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: address
                        
                        	Network address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: distance
                        
                        	Distance
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_via_lsm
                        
                        	LSM flag
                        	**type**\:  bool
                        
                        .. attribute:: nexthop
                        
                        	Next Hop
                        	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: prefix_length_xr
                        
                        	Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                            self.yang_name = "multicast-static-route"
                            self.yang_parent_name = "multicast-static-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"nexthop" : ("nexthop", Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop), "prefix" : ("prefix", Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix)}
                            self._child_list_classes = {}

                            self.address = YLeaf(YType.str, "address")

                            self.distance = YLeaf(YType.uint32, "distance")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                            self.nexthop = Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                            self.nexthop.parent = self
                            self._children_name_map["nexthop"] = "nexthop"
                            self._children_yang_names.add("nexthop")

                            self.prefix = Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")
                            self._segment_path = lambda: "multicast-static-route"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, ['address', 'distance', 'interface_name', 'is_via_lsm', 'prefix_length', 'prefix_length_xr'], name, value)


                        class Nexthop(Entity):
                            """
                            Next Hop
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                                self.yang_name = "nexthop"
                                self.yang_parent_name = "multicast-static-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "nexthop"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Prefix(Entity):
                            """
                            Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "multicast-static-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class NeighborOldFormats(Entity):
                    """
                    PIM neighbor table old format
                    
                    .. attribute:: neighbor_old_format
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats, self).__init__()

                        self.yang_name = "neighbor-old-formats"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-old-format" : ("neighbor_old_format", Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat)}

                        self.neighbor_old_format = YList(self)
                        self._segment_path = lambda: "neighbor-old-formats"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats, [], name, value)


                    class NeighborOldFormat(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__init__()

                            self.yang_name = "neighbor-old-format"
                            self.yang_parent_name = "neighbor-old-formats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr)}

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                            self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                            self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.neighbor_address_xr = YList(self)
                            self._segment_path = lambda: "neighbor-old-format"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, ['dr_priority', 'expires', 'expiry_timer', 'interface_name', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bfd_state', 'is_bidirectional_capable', 'is_dr_priority_capable', 'is_ecmp_redirect_capable', 'is_proxy_capable', 'is_this_neighbor_dr', 'is_this_neighbor_us', 'neighbor_address', 'override_interval', 'propagation_delay', 'uptime'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "neighbor-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class NeighborSummaries(Entity):
                    """
                    PIM neighbor summary table
                    
                    .. attribute:: neighbor_summary
                    
                    	PIM neighbor summary information
                    	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries, self).__init__()

                        self.yang_name = "neighbor-summaries"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-summary" : ("neighbor_summary", Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary)}

                        self.neighbor_summary = YList(self)
                        self._segment_path = lambda: "neighbor-summaries"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries, [], name, value)


                    class NeighborSummary(Entity):
                        """
                        PIM neighbor summary information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: number_of_external_neighbors
                        
                        	Number of external neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__init__()

                            self.yang_name = "neighbor-summary"
                            self.yang_parent_name = "neighbor-summaries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.number_of_external_neighbors = YLeaf(YType.int32, "number-of-external-neighbors")

                            self.number_of_neighbors = YLeaf(YType.int32, "number-of-neighbors")
                            self._segment_path = lambda: "neighbor-summary" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary, ['interface_name', 'number_of_external_neighbors', 'number_of_neighbors'], name, value)


                class Neighbors(Entity):
                    """
                    PIM neighbor table
                    
                    .. attribute:: neighbor
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Neighbors, self).__init__()

                        self.yang_name = "neighbors"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor" : ("neighbor", Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor)}

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "neighbors"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Neighbors, [], name, value)


                    class Neighbor(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbors"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr)}

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                            self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                            self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.neighbor_address_xr = YList(self)
                            self._segment_path = lambda: "neighbor"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor, ['dr_priority', 'expires', 'expiry_timer', 'interface_name', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bfd_state', 'is_bidirectional_capable', 'is_dr_priority_capable', 'is_ecmp_redirect_capable', 'is_proxy_capable', 'is_this_neighbor_dr', 'is_this_neighbor_us', 'neighbor_address', 'override_interval', 'propagation_delay', 'uptime'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "neighbor-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class NetIoTunnels(Entity):
                    """
                    Tunnel information that NETIO has 
                    
                    .. attribute:: net_io_tunnel
                    
                    	PIM netio tunnel information
                    	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels, self).__init__()

                        self.yang_name = "net-io-tunnels"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"net-io-tunnel" : ("net_io_tunnel", Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel)}

                        self.net_io_tunnel = YList(self)
                        self._segment_path = lambda: "net-io-tunnels"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels, [], name, value)


                    class NetIoTunnel(Entity):
                        """
                        PIM netio tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__init__()

                            self.yang_name = "net-io-tunnel"
                            self.yang_parent_name = "net-io-tunnels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-netio" : ("group_address_netio", Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio), "rp-address" : ("rp_address", Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress), "source-address" : ("source_address", Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress), "source-address-netio" : ("source_address_netio", Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio)}
                            self._child_list_classes = {}

                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_netio = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._children_yang_names.add("group-address-netio")

                            self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.source_address = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                            self.source_address_netio = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"
                            self._children_yang_names.add("source-address-netio")
                            self._segment_path = lambda: "net-io-tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, ['tunnel_name', 'vrf_name'], name, value)


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-netio"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-netio"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Ranges(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: range
                    
                    	PIM range list information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"range" : ("range", Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range)}

                        self.range = YList(self)
                        self._segment_path = lambda: "ranges"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Ranges, [], name, value)


                    class Range(Entity):
                        """
                        PIM range list information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: client_xr
                        
                        	Client mapping learnt via
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: group_range
                        
                        	List of group ranges
                        	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange>`
                        
                        .. attribute:: protocol
                        
                        	PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	Rendezvous point address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"rp-address-xr" : ("rp_address_xr", Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr), "source-of-information" : ("source_of_information", Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation)}
                            self._child_list_classes = {"group-range" : ("group_range", Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange)}

                            self.client = YLeaf(YType.enumeration, "client")

                            self.client_xr = YLeaf(YType.enumeration, "client-xr")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")

                            self.source_of_information = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                            self.group_range = YList(self)
                            self._segment_path = lambda: "range"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range, ['client', 'client_xr', 'expires', 'protocol', 'rp_address'], name, value)


                        class GroupRange(Entity):
                            """
                            List of group ranges
                            
                            .. attribute:: expires
                            
                            	When mapping expires
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: source_of_information
                            
                            	Source of information
                            	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange, self).__init__()

                                self.yang_name = "group-range"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"prefix" : ("prefix", Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix), "source-of-information" : ("source_of_information", Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation)}
                                self._child_list_classes = {}

                                self.expires = YLeaf(YType.uint64, "expires")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.prefix = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.source_of_information = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                                self._children_yang_names.add("source-of-information")
                                self._segment_path = lambda: "group-range"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange, ['expires', 'prefix_length', 'uptime'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "prefix"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceOfInformation(Entity):
                                """
                                Source of information
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                    self.yang_name = "source-of-information"
                                    self.yang_parent_name = "group-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-of-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddressXr(Entity):
                            """
                            Rendezvous point address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-of-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class RoutePolicy(Entity):
                    """
                    PIM route policy
                    
                    .. attribute:: route_policy_statistics
                    
                    	PIM route policy statistics
                    	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics>`
                    
                    .. attribute:: route_policy_tests
                    
                    	PIM route policy test run table
                    	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy, self).__init__()

                        self.yang_name = "route-policy"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"route-policy-statistics" : ("route_policy_statistics", Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics), "route-policy-tests" : ("route_policy_tests", Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests)}
                        self._child_list_classes = {}

                        self.route_policy_statistics = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                        self.route_policy_statistics.parent = self
                        self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                        self._children_yang_names.add("route-policy-statistics")

                        self.route_policy_tests = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                        self.route_policy_tests.parent = self
                        self._children_name_map["route_policy_tests"] = "route-policy-tests"
                        self._children_yang_names.add("route-policy-tests")
                        self._segment_path = lambda: "route-policy"


                    class RoutePolicyStatistics(Entity):
                        """
                        PIM route policy statistics
                        
                        .. attribute:: any_table
                        
                        	Number of RPF lookup in any Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Number of RPF lookup in default\-only Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop
                        
                        	Number of RPF drops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pass_
                        
                        	Number of RPF pass
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: requests
                        
                        	Number of RPF lookup requests
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__init__()

                            self.yang_name = "route-policy-statistics"
                            self.yang_parent_name = "route-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.any_table = YLeaf(YType.uint32, "any-table")

                            self.default_table = YLeaf(YType.uint32, "default-table")

                            self.drop = YLeaf(YType.uint32, "drop")

                            self.pass_ = YLeaf(YType.uint32, "pass")

                            self.policy_name = YLeaf(YType.str, "policy-name")

                            self.requests = YLeaf(YType.uint32, "requests")
                            self._segment_path = lambda: "route-policy-statistics"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, ['any_table', 'default_table', 'drop', 'pass_', 'policy_name', 'requests'], name, value)


                    class RoutePolicyTests(Entity):
                        """
                        PIM route policy test run table
                        
                        .. attribute:: route_policy_test
                        
                        	PIM route policy test run
                        	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__init__()

                            self.yang_name = "route-policy-tests"
                            self.yang_parent_name = "route-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"route-policy-test" : ("route_policy_test", Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest)}

                            self.route_policy_test = YList(self)
                            self._segment_path = lambda: "route-policy-tests"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, [], name, value)


                        class RoutePolicyTest(Entity):
                            """
                            PIM route policy test run
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_table
                            
                            	Default table selected
                            	**type**\:  bool
                            
                            .. attribute:: ext_comm
                            
                            	Extended Community
                            	**type**\:  str
                            
                            	**length:** 1..8
                            
                            .. attribute:: extended_community_rt
                            
                            	Route Target
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: group_address
                            
                            	Group IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                            
                            .. attribute:: pass_
                            
                            	Pass
                            	**type**\:  bool
                            
                            .. attribute:: policy_name
                            
                            	RPF policy name
                            	**type**\:  str
                            
                            .. attribute:: safi
                            
                            	SAFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_address
                            
                            	Source IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                            
                            .. attribute:: table_active
                            
                            	Table active
                            	**type**\:  bool
                            
                            .. attribute:: table_exists
                            
                            	Table exists
                            	**type**\:  bool
                            
                            .. attribute:: table_name
                            
                            	Table name
                            	**type**\:  str
                            
                            .. attribute:: vrf_name
                            
                            	VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                                self.yang_name = "route-policy-test"
                                self.yang_parent_name = "route-policy-tests"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr), "source-address-xr" : ("source_address_xr", Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr)}
                                self._child_list_classes = {}

                                self.afi = YLeaf(YType.uint32, "afi")

                                self.default_table = YLeaf(YType.boolean, "default-table")

                                self.ext_comm = YLeaf(YType.str, "ext-comm")

                                self.extended_community_rt = YLeaf(YType.str, "extended-community-rt")

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.pass_ = YLeaf(YType.boolean, "pass")

                                self.policy_name = YLeaf(YType.str, "policy-name")

                                self.safi = YLeaf(YType.uint32, "safi")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.table_active = YLeaf(YType.boolean, "table-active")

                                self.table_exists = YLeaf(YType.boolean, "table-exists")

                                self.table_name = YLeaf(YType.str, "table-name")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                                self._children_yang_names.add("source-address-xr")
                                self._segment_path = lambda: "route-policy-test"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, ['afi', 'default_table', 'ext_comm', 'extended_community_rt', 'group_address', 'pass_', 'policy_name', 'safi', 'source_address', 'table_active', 'table_exists', 'table_name', 'vrf_name'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "route-policy-test"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "route-policy-test"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class RpfRedirect(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle
                    
                    .. attribute:: bundle_interfaces
                    
                    	PIM ECMP RPF\-redirect bundle information
                    	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces>`
                    
                    .. attribute:: redirect_route_databases
                    
                    	PIM ECMP RPF\-redirect route database
                    	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect, self).__init__()

                        self.yang_name = "rpf-redirect"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"bundle-interfaces" : ("bundle_interfaces", Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces), "redirect-route-databases" : ("redirect_route_databases", Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases)}
                        self._child_list_classes = {}

                        self.bundle_interfaces = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                        self.bundle_interfaces.parent = self
                        self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                        self._children_yang_names.add("bundle-interfaces")

                        self.redirect_route_databases = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                        self.redirect_route_databases.parent = self
                        self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                        self._children_yang_names.add("redirect-route-databases")
                        self._segment_path = lambda: "rpf-redirect"


                    class BundleInterfaces(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle information
                        
                        .. attribute:: bundle_interface
                        
                        	PIM ECMP RPF\-redirect bundle interface information
                        	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__init__()

                            self.yang_name = "bundle-interfaces"
                            self.yang_parent_name = "rpf-redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"bundle-interface" : ("bundle_interface", Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface)}

                            self.bundle_interface = YList(self)
                            self._segment_path = lambda: "bundle-interfaces"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces, [], name, value)


                        class BundleInterface(Entity):
                            """
                            PIM ECMP RPF\-redirect bundle interface
                            information
                            
                            .. attribute:: allocated_bandwidth
                            
                            	Bandwidth allocated in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_threshold_bandwidth
                            
                            	Configured threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_bandwidth
                            
                            	Bandwidth available in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_threshold_bandwidth
                            
                            	Available threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\:  str
                            
                            	**length:** 1..32
                            
                            .. attribute:: interface_name
                            
                            	Bundle interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: rpf_redirect_bundle_name
                            
                            	RPF redirect bundle name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: rpf_redirect_interface_name
                            
                            	RPF redirect interface name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: snooping_bandwidth_used
                            
                            	Bandwidth used by snooped entries in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: topology_bandwidth_used
                            
                            	Bandwidth used by topology in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: total_bandwidth
                            
                            	Total bandwidth used in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                                self.yang_name = "bundle-interface"
                                self.yang_parent_name = "bundle-interfaces"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.allocated_bandwidth = YLeaf(YType.int32, "allocated-bandwidth")

                                self.allocated_threshold_bandwidth = YLeaf(YType.int32, "allocated-threshold-bandwidth")

                                self.available_bandwidth = YLeaf(YType.int32, "available-bandwidth")

                                self.available_threshold_bandwidth = YLeaf(YType.int32, "available-threshold-bandwidth")

                                self.bundle_name = YLeaf(YType.str, "bundle-name")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.rpf_redirect_bundle_name = YLeaf(YType.str, "rpf-redirect-bundle-name")

                                self.rpf_redirect_interface_name = YLeaf(YType.str, "rpf-redirect-interface-name")

                                self.snooping_bandwidth_used = YLeaf(YType.int32, "snooping-bandwidth-used")

                                self.topology_bandwidth_used = YLeaf(YType.int32, "topology-bandwidth-used")

                                self.total_bandwidth = YLeaf(YType.int32, "total-bandwidth")
                                self._segment_path = lambda: "bundle-interface"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, ['allocated_bandwidth', 'allocated_threshold_bandwidth', 'available_bandwidth', 'available_threshold_bandwidth', 'bundle_name', 'interface_name', 'rpf_redirect_bundle_name', 'rpf_redirect_interface_name', 'snooping_bandwidth_used', 'topology_bandwidth_used', 'total_bandwidth'], name, value)


                    class RedirectRouteDatabases(Entity):
                        """
                        PIM ECMP RPF\-redirect route database
                        
                        .. attribute:: redirect_route_database
                        
                        	PIM ECMP RPF\-redirect route information
                        	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__init__()

                            self.yang_name = "redirect-route-databases"
                            self.yang_parent_name = "rpf-redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"redirect-route-database" : ("redirect_route_database", Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase)}

                            self.redirect_route_database = YList(self)
                            self._segment_path = lambda: "redirect-route-databases"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, [], name, value)


                        class RedirectRouteDatabase(Entity):
                            """
                            PIM ECMP RPF\-redirect route information
                            
                            .. attribute:: bandwidth
                            
                            	Bandwidth in Kbps
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Group ddress
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                            
                            .. attribute:: interface
                            
                            	Outgoing interface list
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                                self.yang_name = "redirect-route-database"
                                self.yang_parent_name = "redirect-route-databases"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr), "source-address-xr" : ("source_address_xr", Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr)}
                                self._child_list_classes = {"interface" : ("interface", Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface)}

                                self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                                self._children_yang_names.add("source-address-xr")

                                self.interface = YList(self)
                                self._segment_path = lambda: "redirect-route-database"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, ['bandwidth', 'group_address', 'source_address', 'uptime'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group ddress
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class Interface(Entity):
                                """
                                Outgoing interface list
                                
                                .. attribute:: expiry
                                
                                	Expiry in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: is_outgoing_interface
                                
                                	Is outgoing Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface
                                
                                	Is RPF Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_snoop_interface
                                
                                	Is snooping Interface
                                	**type**\:  bool
                                
                                .. attribute:: rpf_address
                                
                                	RPF Address
                                	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                                
                                .. attribute:: uptime
                                
                                	Uptime in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"rpf-address" : ("rpf_address", Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress)}
                                    self._child_list_classes = {}

                                    self.expiry = YLeaf(YType.uint64, "expiry")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.is_outgoing_interface = YLeaf(YType.boolean, "is-outgoing-interface")

                                    self.is_rpf_interface = YLeaf(YType.boolean, "is-rpf-interface")

                                    self.is_snoop_interface = YLeaf(YType.boolean, "is-snoop-interface")

                                    self.uptime = YLeaf(YType.uint64, "uptime")

                                    self.rpf_address = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                    self.rpf_address.parent = self
                                    self._children_name_map["rpf_address"] = "rpf-address"
                                    self._children_yang_names.add("rpf-address")
                                    self._segment_path = lambda: "interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, ['expiry', 'interface_name', 'is_outgoing_interface', 'is_rpf_interface', 'is_snoop_interface', 'uptime'], name, value)


                                class RpfAddress(Entity):
                                    """
                                    RPF Address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                        self.yang_name = "rpf-address"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "rpf-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class RpfSummary(Entity):
                    """
                    PIM RPF registration summary
                    
                    .. attribute:: default_safi
                    
                    	Default RPF Table SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table_name
                    
                    	Default RPF Table Name
                    	**type**\:  str
                    
                    .. attribute:: is_isis_mtr_configured
                    
                    	Is ISIS MTR configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_isis_te_configured
                    
                    	Is ISIS TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_mbgp_configured
                    
                    	Is MBGP configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_enabled
                    
                    	Is Multipath Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_interface_hash_enabled
                    
                    	Is Multipath Interface Hash Extension Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_hash_enabled
                    
                    	Is Multipath Source based Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_next_hop_hash_enabled
                    
                    	Is Multipath Source\-Nexthop Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ospf_te_configured
                    
                    	Is OSPF TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: mo_frr_configured
                    
                    	Is MoFRR configured?
                    	**type**\:  bool
                    
                    .. attribute:: rib_convergence_time_left
                    
                    	RIB convergence time left in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_convergence_timeout
                    
                    	RIB convergence timeout in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_mo_frr_configured
                    
                    	Is MoFRR RIB configured?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	Is RUMP MuRIB enabled?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.RpfSummary, self).__init__()

                        self.yang_name = "rpf-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.default_safi = YLeaf(YType.uint32, "default-safi")

                        self.default_table_name = YLeaf(YType.str, "default-table-name")

                        self.is_isis_mtr_configured = YLeaf(YType.boolean, "is-isis-mtr-configured")

                        self.is_isis_te_configured = YLeaf(YType.boolean, "is-isis-te-configured")

                        self.is_mbgp_configured = YLeaf(YType.boolean, "is-mbgp-configured")

                        self.is_multipath_enabled = YLeaf(YType.boolean, "is-multipath-enabled")

                        self.is_multipath_interface_hash_enabled = YLeaf(YType.boolean, "is-multipath-interface-hash-enabled")

                        self.is_multipath_source_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-hash-enabled")

                        self.is_multipath_source_next_hop_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-next-hop-hash-enabled")

                        self.is_ospf_te_configured = YLeaf(YType.boolean, "is-ospf-te-configured")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.mo_frr_configured = YLeaf(YType.boolean, "mo-frr-configured")

                        self.rib_convergence_time_left = YLeaf(YType.uint32, "rib-convergence-time-left")

                        self.rib_convergence_timeout = YLeaf(YType.uint32, "rib-convergence-timeout")

                        self.rib_mo_frr_configured = YLeaf(YType.boolean, "rib-mo-frr-configured")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")
                        self._segment_path = lambda: "rpf-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfSummary, ['default_safi', 'default_table_name', 'is_isis_mtr_configured', 'is_isis_te_configured', 'is_mbgp_configured', 'is_multipath_enabled', 'is_multipath_interface_hash_enabled', 'is_multipath_source_hash_enabled', 'is_multipath_source_next_hop_hash_enabled', 'is_ospf_te_configured', 'is_rib_convergence', 'mo_frr_configured', 'rib_convergence_time_left', 'rib_convergence_timeout', 'rib_mo_frr_configured', 'rpf_registrations', 'rump_enabled'], name, value)


                class Safs(Entity):
                    """
                    SAFI table and type
                    
                    .. attribute:: saf
                    
                    	SAF name 
                    	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs, self).__init__()

                        self.yang_name = "safs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"saf" : ("saf", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf)}

                        self.saf = YList(self)
                        self._segment_path = lambda: "safs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs, [], name, value)


                    class Saf(Entity):
                        """
                        SAF name 
                        
                        .. attribute:: rpf_hash_source_groups
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups>`
                        
                        .. attribute:: rpf_hash_sources
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources>`
                        
                        .. attribute:: rpfs
                        
                        	PIM RPF information table
                        	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs>`
                        
                        .. attribute:: saf_name
                        
                        	SAF name 
                        	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name 
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf, self).__init__()

                            self.yang_name = "saf"
                            self.yang_parent_name = "safs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"rpf-hash-source-groups" : ("rpf_hash_source_groups", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups), "rpf-hash-sources" : ("rpf_hash_sources", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources), "rpfs" : ("rpfs", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs)}
                            self._child_list_classes = {}

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                            self.topology_name = YLeaf(YType.str, "topology-name")

                            self.rpf_hash_source_groups = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                            self.rpf_hash_source_groups.parent = self
                            self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                            self._children_yang_names.add("rpf-hash-source-groups")

                            self.rpf_hash_sources = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                            self.rpf_hash_sources.parent = self
                            self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                            self._children_yang_names.add("rpf-hash-sources")

                            self.rpfs = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs()
                            self.rpfs.parent = self
                            self._children_name_map["rpfs"] = "rpfs"
                            self._children_yang_names.add("rpfs")
                            self._segment_path = lambda: "saf"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf, ['saf_name', 'topology_name'], name, value)


                        class RpfHashSourceGroups(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source_group
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__init__()

                                self.yang_name = "rpf-hash-source-groups"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"rpf-hash-source-group" : ("rpf_hash_source_group", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup)}

                                self.rpf_hash_source_group = YList(self)
                                self._segment_path = lambda: "rpf-hash-source-groups"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, [], name, value)


                            class RpfHashSourceGroup(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: group_address
                                
                                	Group address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: mask_length
                                
                                	Hash mask length
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                    self.yang_name = "rpf-hash-source-group"
                                    self.yang_parent_name = "rpf-hash-source-groups"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress), "secondary-next-hop-address" : ("secondary_next_hop_address", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress)}
                                    self._child_list_classes = {}

                                    self.group_address = YLeaf(YType.str, "group-address")

                                    self.mask_length = YLeaf(YType.int32, "mask-length")

                                    self.mofrr = YLeaf(YType.int32, "mofrr")

                                    self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                    self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                    self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                    self._children_yang_names.add("next-hop-address")

                                    self.secondary_next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._children_yang_names.add("secondary-next-hop-address")
                                    self._segment_path = lambda: "rpf-hash-source-group"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, ['group_address', 'mask_length', 'mofrr', 'next_hop_interface', 'next_hop_multipath_enabled', 'secondary_next_hop_interface', 'source_address'], name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "next-hop-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "secondary-next-hop-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfHashSources(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__init__()

                                self.yang_name = "rpf-hash-sources"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"rpf-hash-source" : ("rpf_hash_source", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource)}

                                self.rpf_hash_source = YList(self)
                                self._segment_path = lambda: "rpf-hash-sources"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources, [], name, value)


                            class RpfHashSource(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                    self.yang_name = "rpf-hash-source"
                                    self.yang_parent_name = "rpf-hash-sources"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress), "secondary-next-hop-address" : ("secondary_next_hop_address", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress)}
                                    self._child_list_classes = {}

                                    self.mofrr = YLeaf(YType.int32, "mofrr")

                                    self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                    self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                    self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                    self._children_yang_names.add("next-hop-address")

                                    self.secondary_next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._children_yang_names.add("secondary-next-hop-address")
                                    self._segment_path = lambda: "rpf-hash-source"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, ['mofrr', 'next_hop_interface', 'next_hop_multipath_enabled', 'secondary_next_hop_interface', 'source_address'], name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "next-hop-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "secondary-next-hop-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Rpfs(Entity):
                            """
                            PIM RPF information table
                            
                            .. attribute:: rpf
                            
                            	PIM RPF information
                            	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs, self).__init__()

                                self.yang_name = "rpfs"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"rpf" : ("rpf", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf)}

                                self.rpf = YList(self)
                                self._segment_path = lambda: "rpfs"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs, [], name, value)


                            class Rpf(Entity):
                                """
                                PIM RPF information
                                
                                .. attribute:: registered_address  <key>
                                
                                	Address for which RPF lookup
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: is_connected
                                
                                	Are we connected ?
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_rpf_bgp_route
                                
                                	Is RPF through BGP route
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_preference
                                
                                	Metric preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: registered_address_xr
                                
                                	Address registered
                                	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                                
                                .. attribute:: rpf_path
                                
                                	RPF Paths list
                                	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__init__()

                                    self.yang_name = "rpf"
                                    self.yang_parent_name = "rpfs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"registered-address-xr" : ("registered_address_xr", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr)}
                                    self._child_list_classes = {"rpf-path" : ("rpf_path", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath)}

                                    self.registered_address = YLeaf(YType.str, "registered-address")

                                    self.is_connected = YLeaf(YType.uint8, "is-connected")

                                    self.is_rpf_bgp_route = YLeaf(YType.boolean, "is-rpf-bgp-route")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                    self.registered_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                    self.registered_address_xr.parent = self
                                    self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                    self._children_yang_names.add("registered-address-xr")

                                    self.rpf_path = YList(self)
                                    self._segment_path = lambda: "rpf" + "[registered-address='" + self.registered_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, ['registered_address', 'is_connected', 'is_rpf_bgp_route', 'metric', 'metric_preference'], name, value)


                                class RegisteredAddressXr(Entity):
                                    """
                                    Address registered
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                        self.yang_name = "registered-address-xr"
                                        self.yang_parent_name = "rpf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "registered-address-xr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class RpfPath(Entity):
                                    """
                                    RPF Paths list
                                    
                                    .. attribute:: connector
                                    
                                    	Connector Attribute
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: extranet_vrf_name
                                    
                                    	Extranet VRF name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    .. attribute:: is_connector_attribute_present
                                    
                                    	Connector attribute present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rpf_interface_disabled
                                    
                                    	Is the rpf interface disabled ?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_lsm
                                    
                                    	Via LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_mlsm
                                    
                                    	Via Mstatic LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpf_interface_name
                                    
                                    	RPF Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: rpf_neighbor
                                    
                                    	RPF neighbor
                                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                    
                                    .. attribute:: rpf_nexthop
                                    
                                    	RPF nexthop
                                    	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                        self.yang_name = "rpf-path"
                                        self.yang_parent_name = "rpf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rpf-neighbor" : ("rpf_neighbor", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor), "rpf-nexthop" : ("rpf_nexthop", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop)}
                                        self._child_list_classes = {}

                                        self.connector = YLeaf(YType.str, "connector")

                                        self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                        self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                        self.is_rpf_interface_disabled = YLeaf(YType.boolean, "is-rpf-interface-disabled")

                                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                        self.is_via_mlsm = YLeaf(YType.boolean, "is-via-mlsm")

                                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                                        self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                        self.rpf_neighbor.parent = self
                                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                        self._children_yang_names.add("rpf-neighbor")

                                        self.rpf_nexthop = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                        self.rpf_nexthop.parent = self
                                        self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                        self._children_yang_names.add("rpf-nexthop")
                                        self._segment_path = lambda: "rpf-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, ['connector', 'extranet_vrf_name', 'is_connector_attribute_present', 'is_rpf_interface_disabled', 'is_via_lsm', 'is_via_mlsm', 'rpf_interface_name'], name, value)


                                    class RpfNeighbor(Entity):
                                        """
                                        RPF neighbor
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                            self.yang_name = "rpf-neighbor"
                                            self.yang_parent_name = "rpf-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                            self._segment_path = lambda: "rpf-neighbor"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                    class RpfNexthop(Entity):
                                        """
                                        RPF nexthop
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                            self.yang_name = "rpf-nexthop"
                                            self.yang_parent_name = "rpf-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                            self._segment_path = lambda: "rpf-nexthop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Summary(Entity):
                    """
                    PIM summary
                    
                    .. attribute:: bsr_candidate_rp_set_count
                    
                    	Current crp\-set count from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_limit
                    
                    	Maximum crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_threshold
                    
                    	Threshold crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_range_threshold
                    
                    	Threshold group range from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_count
                    
                    	Current group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_limit
                    
                    	Maximum group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_auto_rp_ranges_limit
                    
                    	Global Auto\-RP maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_count
                    
                    	Global BSR current crp\-set count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_limit
                    
                    	Global BSR maximum crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_threshold
                    
                    	Global BSR Threshold crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_count
                    
                    	Global BSR current group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_limit
                    
                    	Global BSR maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_threshold
                    
                    	Global BSR Threshold group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_register_limit
                    
                    	Maximum global registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bsr_ranges_threshold_reached
                    
                    	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_auto_rp_ranges_limit_reached
                    
                    	Is global AutoRP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_bsr_ranges_limit_reached
                    
                    	Is global BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_register_limit_reached
                    
                    	Is global PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_route_limit_reached
                    
                    	Is global route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_rxi_limit_reached
                    
                    	Is global interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_maximum_enforcement_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: is_ranges_limit_reached
                    
                    	Is Auto\-RP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_route_limit_reached
                    
                    	Is route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: ranges_count
                    
                    	Current group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_limit
                    
                    	Maximum group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_threshold
                    
                    	OOR theshold of grange ranges from AutoRP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_count
                    
                    	Current registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit
                    
                    	Maximum registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit_reached
                    
                    	Is PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: register_threshold
                    
                    	Threshold registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_count
                    
                    	Current routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_limit
                    
                    	Maximum routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_low_water_mark
                    
                    	The number of routes below which the throttle on route creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_threshold
                    
                    	Threshold routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_limit_reached
                    
                    	Is interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: rxi_low_water_mark
                    
                    	The rxi below which the throttle on interface creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_count
                    
                    	Current Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_limit
                    
                    	Maximum Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_threshold
                    
                    	Topology Interface State threshold
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                        self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                        self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                        self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                        self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                        self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                        self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                        self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                        self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                        self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                        self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                        self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                        self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                        self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                        self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                        self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                        self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                        self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                        self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                        self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                        self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                        self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                        self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                        self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                        self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                        self.register_count = YLeaf(YType.uint32, "register-count")

                        self.register_limit = YLeaf(YType.uint32, "register-limit")

                        self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                        self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                        self.route_count = YLeaf(YType.uint32, "route-count")

                        self.route_limit = YLeaf(YType.uint32, "route-limit")

                        self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                        self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                        self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                        self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                        self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                        self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                        self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")
                        self._segment_path = lambda: "summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Summary, ['bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_threshold', 'bsr_range_threshold', 'bsr_ranges_count', 'bsr_ranges_limit', 'global_auto_rp_ranges_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_threshold', 'global_bsr_ranges_count', 'global_bsr_ranges_limit', 'global_bsr_ranges_threshold', 'global_register_limit', 'is_bsr_ranges_threshold_reached', 'is_global_auto_rp_ranges_limit_reached', 'is_global_bsr_ranges_limit_reached', 'is_global_register_limit_reached', 'is_global_route_limit_reached', 'is_global_rxi_limit_reached', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'is_ranges_limit_reached', 'is_route_limit_reached', 'ranges_count', 'ranges_limit', 'ranges_threshold', 'register_count', 'register_limit', 'register_limit_reached', 'register_threshold', 'route_count', 'route_limit', 'route_low_water_mark', 'route_threshold', 'rxi_limit_reached', 'rxi_low_water_mark', 'topology_interface_state_count', 'topology_interface_state_limit', 'topology_interface_state_threshold'], name, value)


                class TableContexts(Entity):
                    """
                    PIM table context list
                    
                    .. attribute:: table_context
                    
                    	PIM table context information
                    	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TableContexts.TableContext>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.TableContexts, self).__init__()

                        self.yang_name = "table-contexts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"table-context" : ("table_context", Ipv6Pim.Active.Vrfs.Vrf.TableContexts.TableContext)}

                        self.table_context = YList(self)
                        self._segment_path = lambda: "table-contexts"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TableContexts, [], name, value)


                    class TableContext(Entity):
                        """
                        PIM table context information
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: saf_name
                        
                        	SAF name
                        	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: topology_name
                        
                        	Topology name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.TableContexts.TableContext, self).__init__()

                            self.yang_name = "table-context"
                            self.yang_parent_name = "table-contexts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                            self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                            self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                            self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                            self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.table_id = YLeaf(YType.uint32, "table-id")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.topology_name = YLeaf(YType.str, "topology-name")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")
                            self._segment_path = lambda: "table-context"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TableContexts.TableContext, ['afi', 'is_active', 'is_ital_registration_done', 'is_rib_convergence', 'is_rib_convergence_received', 'is_rib_registration_done', 'rpf_registrations', 'saf_name', 'safi', 'table_id', 'table_name', 'topology_name', 'vrf_id'], name, value)


                class Topologies(Entity):
                    """
                    PIM topology table
                    
                    .. attribute:: topology
                    
                    	PIM topology information
                    	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Topologies, self).__init__()

                        self.yang_name = "topologies"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"topology" : ("topology", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology)}

                        self.topology = YList(self)
                        self._segment_path = lambda: "topologies"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies, [], name, value)


                    class Topology(Entity):
                        """
                        PIM topology information
                        
                        .. attribute:: alive
                        
                        	Alive time in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: anycast_rp_match
                        
                        	Group matches Anycast\-RP policy
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_route_target
                        
                        	Anycast\-RP RT
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: assume_alive
                        
                        	The Assume Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: bgp_join
                        
                        	BGP C JOIN
                        	**type**\:  bool
                        
                        .. attribute:: bgp_jp_time
                        
                        	BGP C JP Time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: connected
                        
                        	Is Connected ?
                        	**type**\:  bool
                        
                        .. attribute:: crossed_threshold
                        
                        	Incoming traffic crossed threshold. MT flag set
                        	**type**\:  bool
                        
                        .. attribute:: customer_routing_type
                        
                        	Type of Customer Routing in the MVPN
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: data_mdt_addr_assigned
                        
                        	PIM has assigned a Data MDT Address
                        	**type**\:  bool
                        
                        .. attribute:: dont_check_connected
                        
                        	Do we need to make the connected check on this route ?
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	When this entry expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: extranet_route
                        
                        	Is a Extranet route ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr>`
                        
                        .. attribute:: inherit_alive
                        
                        	The Inherit Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: inherit_spt
                        
                        	The Inherit SPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: is_via_lsm
                        
                        	Via LSM
                        	**type**\:  bool
                        
                        .. attribute:: jp_status
                        
                        	Join\-Prune Status
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: kat_state
                        
                        	Keep Alive Timer State
                        	**type**\:  bool
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: limit_reached
                        
                        	Have we throttled the creation of routes or interfaces ?
                        	**type**\:  bool
                        
                        .. attribute:: low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_active
                        
                        	Is MoFRR Active?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_backup
                        
                        	Is this Mofrr Backup?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_primary
                        
                        	Is this Mofrr Primary?
                        	**type**\:  bool
                        
                        .. attribute:: orig_src_address
                        
                        	Orig Src Address
                        	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress>`
                        
                        .. attribute:: outgoing_interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface>`
                        
                        .. attribute:: probe_alive
                        
                        	The Probe Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: proxy
                        
                        	Is the RPF target a proxy?
                        	**type**\:  bool
                        
                        .. attribute:: proxy_address
                        
                        	RPF Proxy address
                        	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress>`
                        
                        .. attribute:: really_alive
                        
                        	The Really Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: register_received
                        
                        	Have registers been received for this source ?
                        	**type**\:  bool
                        
                        .. attribute:: register_received_timer
                        
                        	Register Received Timer in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: remote_source
                        
                        	MSDP told us
                        	**type**\:  bool
                        
                        .. attribute:: rib_mo_frr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rp_address
                        
                        	RP Address (If rpt)
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor>`
                        
                        .. attribute:: rpf_proxy_enabled
                        
                        	Is rpf if proxy enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpt
                        
                        	RPT bit
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpt_xr
                        
                        	Is this on the RPT ?
                        	**type**\:  bool
                        
                        .. attribute:: sa_joined
                        
                        	BGP SA join
                        	**type**\:  bool
                        
                        .. attribute:: sa_received
                        
                        	BGP SA received
                        	**type**\:  bool
                        
                        .. attribute:: sa_sent
                        
                        	BGP SA sent
                        	**type**\:  bool
                        
                        .. attribute:: secondary_rpf_interface_name
                        
                        	Secondary Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: secondary_rpf_neighbor
                        
                        	Secondary RPF Neighbor
                        	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor>`
                        
                        .. attribute:: sending_null_registers
                        
                        	Are we sending null registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: sending_registers
                        
                        	Are we sending registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: signal_sources
                        
                        	Signal Sources on route?
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr>`
                        
                        .. attribute:: spt
                        
                        	Is this on the SPT ?
                        	**type**\:  bool
                        
                        .. attribute:: suppress_registers
                        
                        	When the Null register probe expires
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vxlan
                        
                        	Is this VXLAN?
                        	**type**\:  bool
                        
                        .. attribute:: wildcard
                        
                        	WC \-Wildcard
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology, self).__init__()

                            self.yang_name = "topology"
                            self.yang_parent_name = "topologies"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr), "orig-src-address" : ("orig_src_address", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress), "proxy-address" : ("proxy_address", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress), "rp-address" : ("rp_address", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress), "rpf-neighbor" : ("rpf_neighbor", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor), "rpf-root" : ("rpf_root", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot), "secondary-rpf-neighbor" : ("secondary_rpf_neighbor", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor), "source-address-xr" : ("source_address_xr", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr)}
                            self._child_list_classes = {"outgoing-interface" : ("outgoing_interface", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface)}

                            self.alive = YLeaf(YType.int32, "alive")

                            self.anycast_rp_match = YLeaf(YType.boolean, "anycast-rp-match")

                            self.anycast_rp_route_target = YLeaf(YType.str, "anycast-rp-route-target")

                            self.assume_alive = YLeaf(YType.boolean, "assume-alive")

                            self.bgp_join = YLeaf(YType.boolean, "bgp-join")

                            self.bgp_jp_time = YLeaf(YType.uint64, "bgp-jp-time")

                            self.connected = YLeaf(YType.boolean, "connected")

                            self.crossed_threshold = YLeaf(YType.boolean, "crossed-threshold")

                            self.customer_routing_type = YLeaf(YType.int32, "customer-routing-type")

                            self.data_mdt_addr_assigned = YLeaf(YType.boolean, "data-mdt-addr-assigned")

                            self.dont_check_connected = YLeaf(YType.boolean, "dont-check-connected")

                            self.expiry = YLeaf(YType.uint64, "expiry")

                            self.extranet_route = YLeaf(YType.boolean, "extranet-route")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.inherit_alive = YLeaf(YType.boolean, "inherit-alive")

                            self.inherit_spt = YLeaf(YType.boolean, "inherit-spt")

                            self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                            self.jp_status = YLeaf(YType.int32, "jp-status")

                            self.jp_timer = YLeaf(YType.int32, "jp-timer")

                            self.kat_state = YLeaf(YType.boolean, "kat-state")

                            self.last_hop = YLeaf(YType.boolean, "last-hop")

                            self.limit_reached = YLeaf(YType.boolean, "limit-reached")

                            self.low_memory = YLeaf(YType.boolean, "low-memory")

                            self.mofrr_active = YLeaf(YType.boolean, "mofrr-active")

                            self.mofrr_backup = YLeaf(YType.boolean, "mofrr-backup")

                            self.mofrr_enabled = YLeaf(YType.boolean, "mofrr-enabled")

                            self.mofrr_primary = YLeaf(YType.boolean, "mofrr-primary")

                            self.probe_alive = YLeaf(YType.boolean, "probe-alive")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.proxy = YLeaf(YType.boolean, "proxy")

                            self.really_alive = YLeaf(YType.boolean, "really-alive")

                            self.register_received = YLeaf(YType.boolean, "register-received")

                            self.register_received_timer = YLeaf(YType.int32, "register-received-timer")

                            self.remote_source = YLeaf(YType.boolean, "remote-source")

                            self.rib_mo_frr_enabled = YLeaf(YType.boolean, "rib-mo-frr-enabled")

                            self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                            self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_proxy_enabled = YLeaf(YType.boolean, "rpf-proxy-enabled")

                            self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                            self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.rpt = YLeaf(YType.int32, "rpt")

                            self.rpt_xr = YLeaf(YType.boolean, "rpt-xr")

                            self.sa_joined = YLeaf(YType.boolean, "sa-joined")

                            self.sa_received = YLeaf(YType.boolean, "sa-received")

                            self.sa_sent = YLeaf(YType.boolean, "sa-sent")

                            self.secondary_rpf_interface_name = YLeaf(YType.str, "secondary-rpf-interface-name")

                            self.sending_null_registers = YLeaf(YType.boolean, "sending-null-registers")

                            self.sending_registers = YLeaf(YType.boolean, "sending-registers")

                            self.signal_sources = YLeaf(YType.boolean, "signal-sources")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.spt = YLeaf(YType.boolean, "spt")

                            self.suppress_registers = YLeaf(YType.int32, "suppress-registers")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.vxlan = YLeaf(YType.boolean, "vxlan")

                            self.wildcard = YLeaf(YType.boolean, "wildcard")

                            self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.orig_src_address = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                            self.orig_src_address.parent = self
                            self._children_name_map["orig_src_address"] = "orig-src-address"
                            self._children_yang_names.add("orig-src-address")

                            self.proxy_address = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                            self.proxy_address.parent = self
                            self._children_name_map["proxy_address"] = "proxy-address"
                            self._children_yang_names.add("proxy-address")

                            self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                            self.rpf_root = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._children_yang_names.add("rpf-root")

                            self.secondary_rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                            self.secondary_rpf_neighbor.parent = self
                            self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                            self._children_yang_names.add("secondary-rpf-neighbor")

                            self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                            self.outgoing_interface = YList(self)
                            self._segment_path = lambda: "topology"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology, ['alive', 'anycast_rp_match', 'anycast_rp_route_target', 'assume_alive', 'bgp_join', 'bgp_jp_time', 'connected', 'crossed_threshold', 'customer_routing_type', 'data_mdt_addr_assigned', 'dont_check_connected', 'expiry', 'extranet_route', 'group_address', 'inherit_alive', 'inherit_spt', 'is_via_lsm', 'jp_status', 'jp_timer', 'kat_state', 'last_hop', 'limit_reached', 'low_memory', 'mofrr_active', 'mofrr_backup', 'mofrr_enabled', 'mofrr_primary', 'probe_alive', 'protocol', 'proxy', 'really_alive', 'register_received', 'register_received_timer', 'remote_source', 'rib_mo_frr_enabled', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_proxy_enabled', 'rpf_safi', 'rpf_table_name', 'rpf_vrf_name', 'rpt', 'rpt_xr', 'sa_joined', 'sa_received', 'sa_sent', 'secondary_rpf_interface_name', 'sending_null_registers', 'sending_registers', 'signal_sources', 'source_address', 'spt', 'suppress_registers', 'uptime', 'vxlan', 'wildcard'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class OrigSrcAddress(Entity):
                            """
                            Orig Src Address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__init__()

                                self.yang_name = "orig-src-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "orig-src-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class OutgoingInterface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: admin_boundary
                            
                            	Is this an administrative boundary ?
                            	**type**\:  bool
                            
                            .. attribute:: assert_state
                            
                            	Assert State
                            	**type**\:  bool
                            
                            .. attribute:: assert_timer
                            
                            	Assert Timer in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: assert_winner
                            
                            	Assert Winner
                            	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner>`
                            
                            .. attribute:: bgp_c_mcast_join
                            
                            	BGP C\-Mcast join
                            	**type**\:  bool
                            
                            .. attribute:: bgp_c_mcast_prune_delay_timer
                            
                            	BGP C\-MCAST Prune Suppression in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: data_mdt_join
                            
                            	Data MDT join
                            	**type**\:  bool
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: extranet_interface
                            
                            	Is this an Extranet Interface ?
                            	**type**\:  bool
                            
                            .. attribute:: forwarding_state
                            
                            	Forward or Prune
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: igmp_membership
                            
                            	IGMP membership
                            	**type**\:  bool
                            
                            .. attribute:: immediate_state
                            
                            	Immediate fwding state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: interface_name
                            
                            	Interface Identifier
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: internal_interest_info
                            
                            	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: internal_interest_information
                            
                            	Internal Interest. Replaces internal\-interest\-info
                            	**type**\:   :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                            
                            .. attribute:: jp_state
                            
                            	Join\-Prune State
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: jp_timer
                            
                            	Join\-Prune Timer (secs)
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: last_hop
                            
                            	Are we last hop ?
                            	**type**\:  bool
                            
                            .. attribute:: local_mdt_join
                            
                            	Default MDT Join
                            	**type**\:  bool
                            
                            .. attribute:: local_members
                            
                            	Local Information. Deprecated \- use 'local\-members\-information' instead
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: local_members_information
                            
                            	Local Information. Replaces local\-members
                            	**type**\:   :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                            
                            .. attribute:: mdt_safi_join
                            
                            	MDT Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mldp_inband_mdt
                            
                            	MLDP Inband MDT interface
                            	**type**\:  bool
                            
                            .. attribute:: mldp_stale
                            
                            	OLE is stale
                            	**type**\:  bool
                            
                            .. attribute:: mvpn_safi_join
                            
                            	MVPN Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mvpnv6_safi_join
                            
                            	MVPN IPv6 Safi join
                            	**type**\:  bool
                            
                            .. attribute:: sa_prune
                            
                            	BGP SA Prune state
                            	**type**\:  bool
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: vrf_name
                            
                            	VRF which physically owns
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__init__()

                                self.yang_name = "outgoing-interface"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"assert-winner" : ("assert_winner", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner)}
                                self._child_list_classes = {}

                                self.admin_boundary = YLeaf(YType.boolean, "admin-boundary")

                                self.assert_state = YLeaf(YType.boolean, "assert-state")

                                self.assert_timer = YLeaf(YType.int32, "assert-timer")

                                self.bgp_c_mcast_join = YLeaf(YType.boolean, "bgp-c-mcast-join")

                                self.bgp_c_mcast_prune_delay_timer = YLeaf(YType.uint64, "bgp-c-mcast-prune-delay-timer")

                                self.data_mdt_join = YLeaf(YType.boolean, "data-mdt-join")

                                self.expiry = YLeaf(YType.uint64, "expiry")

                                self.extranet_interface = YLeaf(YType.boolean, "extranet-interface")

                                self.forwarding_state = YLeaf(YType.int32, "forwarding-state")

                                self.igmp_membership = YLeaf(YType.boolean, "igmp-membership")

                                self.immediate_state = YLeaf(YType.int32, "immediate-state")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.internal_interest_info = YLeaf(YType.int32, "internal-interest-info")

                                self.internal_interest_information = YLeaf(YType.enumeration, "internal-interest-information")

                                self.jp_state = YLeaf(YType.int32, "jp-state")

                                self.jp_timer = YLeaf(YType.int32, "jp-timer")

                                self.last_hop = YLeaf(YType.boolean, "last-hop")

                                self.local_mdt_join = YLeaf(YType.boolean, "local-mdt-join")

                                self.local_members = YLeaf(YType.int32, "local-members")

                                self.local_members_information = YLeaf(YType.enumeration, "local-members-information")

                                self.mdt_safi_join = YLeaf(YType.boolean, "mdt-safi-join")

                                self.mldp_inband_mdt = YLeaf(YType.boolean, "mldp-inband-mdt")

                                self.mldp_stale = YLeaf(YType.boolean, "mldp-stale")

                                self.mvpn_safi_join = YLeaf(YType.boolean, "mvpn-safi-join")

                                self.mvpnv6_safi_join = YLeaf(YType.boolean, "mvpnv6-safi-join")

                                self.sa_prune = YLeaf(YType.boolean, "sa-prune")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.assert_winner = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                self.assert_winner.parent = self
                                self._children_name_map["assert_winner"] = "assert-winner"
                                self._children_yang_names.add("assert-winner")
                                self._segment_path = lambda: "outgoing-interface"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, ['admin_boundary', 'assert_state', 'assert_timer', 'bgp_c_mcast_join', 'bgp_c_mcast_prune_delay_timer', 'data_mdt_join', 'expiry', 'extranet_interface', 'forwarding_state', 'igmp_membership', 'immediate_state', 'interface_name', 'internal_interest_info', 'internal_interest_information', 'jp_state', 'jp_timer', 'last_hop', 'local_mdt_join', 'local_members', 'local_members_information', 'mdt_safi_join', 'mldp_inband_mdt', 'mldp_stale', 'mvpn_safi_join', 'mvpnv6_safi_join', 'sa_prune', 'uptime', 'vrf_name'], name, value)


                            class AssertWinner(Entity):
                                """
                                Assert Winner
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                    self.yang_name = "assert-winner"
                                    self.yang_parent_name = "outgoing-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "assert-winner"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class ProxyAddress(Entity):
                            """
                            RPF Proxy address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__init__()

                                self.yang_name = "proxy-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "proxy-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP Address (If rpt)
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-root"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SecondaryRpfNeighbor(Entity):
                            """
                            Secondary RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                                self.yang_name = "secondary-rpf-neighbor"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "secondary-rpf-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class TopologyEntryFlagRouteCounts(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: topology_entry_flag_route_count
                    
                    	Route count for topology with entry flag set
                    	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-entry-flag-route-counts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"topology-entry-flag-route-count" : ("topology_entry_flag_route_count", Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount)}

                        self.topology_entry_flag_route_count = YList(self)
                        self._segment_path = lambda: "topology-entry-flag-route-counts"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts, [], name, value)


                    class TopologyEntryFlagRouteCount(Entity):
                        """
                        Route count for topology with entry flag set
                        
                        .. attribute:: entry_flag  <key>
                        
                        	entry flag
                        	**type**\:   :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                            self.yang_name = "topology-entry-flag-route-count"
                            self.yang_parent_name = "topology-entry-flag-route-counts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.entry_flag = YLeaf(YType.enumeration, "entry-flag")

                            self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                            self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                            self.groute_count = YLeaf(YType.uint32, "groute-count")

                            self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                            self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                            self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                            self._segment_path = lambda: "topology-entry-flag-route-count" + "[entry-flag='" + self.entry_flag.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, ['entry_flag', 'active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


                class TopologyInterfaceFlagRouteCounts(Entity):
                    """
                    Route count for topology with interface flag set
                    
                    .. attribute:: topology_interface_flag_route_count
                    
                    	Route count for topology with interface flag set
                    	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-interface-flag-route-counts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"topology-interface-flag-route-count" : ("topology_interface_flag_route_count", Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount)}

                        self.topology_interface_flag_route_count = YList(self)
                        self._segment_path = lambda: "topology-interface-flag-route-counts"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, [], name, value)


                    class TopologyInterfaceFlagRouteCount(Entity):
                        """
                        Route count for topology with interface flag
                        set
                        
                        .. attribute:: interface_flag  <key>
                        
                        	Interface flag
                        	**type**\:   :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                            self.yang_name = "topology-interface-flag-route-count"
                            self.yang_parent_name = "topology-interface-flag-route-counts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interface_flag = YLeaf(YType.enumeration, "interface-flag")

                            self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                            self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                            self.groute_count = YLeaf(YType.uint32, "groute-count")

                            self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                            self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                            self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                            self._segment_path = lambda: "topology-interface-flag-route-count" + "[interface-flag='" + self.interface_flag.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, ['interface_flag', 'active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


                class TopologyRouteCount(Entity):
                    """
                    Topology route count information from PIM
                    topology table
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount, self).__init__()

                        self.yang_name = "topology-route-count"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                        self._segment_path = lambda: "topology-route-count"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount, ['active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


                class TrafficCounters(Entity):
                    """
                    PIM message traffic counters
                    
                    .. attribute:: boundary_acl_rx_drop
                    
                    	Inc. JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_tx_drop
                    
                    	Out JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_error
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: format_error
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert_batched
                    
                    	Batched Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_data_register
                    
                    	Data Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_ecmp_redirect
                    
                    	Input Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb_error
                    
                    	No IDB for intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_pim_error
                    
                    	PIM Disabled on intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_error
                    
                    	No VRF for idb error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_null_register
                    
                    	Null Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim_version_error
                    
                    	Invalid PIM version error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inputs
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_destination_packets
                    
                    	Control Packets with Invalid Destination
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_join_prunes
                    
                    	PIM invalid Join/Prunes received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_registers
                    
                    	PIM invalid registers received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_local_source_address
                    
                    	Data MDT Join msgs dropped due to local source addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_idb
                    
                    	Data MDT Join msgs dropped due to idb missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_vrf
                    
                    	Data MDT Join msgs dropped due to vrf missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_null_local_address
                    
                    	Data MDT Join msgs dropped due to null local addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_bad_type
                    
                    	Data MDT TLV bad type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_received
                    
                    	Data MDT Join Msgs received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_sent
                    
                    	Data MDT Join Msgs sent
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_joins_drop_multiple_encapsulation
                    
                    	MDT Join msgs dropped due to multiple Encap limitation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_send_queue_full
                    
                    	Packets dropped since mdt send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_socket_error
                    
                    	MDT Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_invalid_lsm_identifier
                    
                    	 Invalid LSM ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_mdt_socket_connection
                    
                    	Packets dropped since no mdt socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_source_address
                    
                    	Packets dropped since no source address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: non_supported_packets
                    
                    	PIM non supported pckets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert_batched
                    
                    	Batched Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_data_register
                    
                    	Data Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_ecmp_redirect
                    
                    	Output Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello_bytes
                    
                    	Output Hello Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_join_group
                    
                    	Output Join Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_prune_bytes
                    
                    	Output JP Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_loop_error
                    
                    	Output on loopback error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_null_register
                    
                    	Null Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_prune_group
                    
                    	Output Prune Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: outputs
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_packman_error
                    
                    	Packets Dropped due to Pakman Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue
                    
                    	Packet queue state and statistics
                    	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue>`
                    
                    .. attribute:: packet_queue_last_clear
                    
                    	Time in seconds since the last clear of all packet queues stats
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: packet_read_socket_error
                    
                    	Packet Read Socket Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_standby
                    
                    	Packets Dropped due to Standby Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pakman_error
                    
                    	Pakman packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: send_queue_full
                    
                    	Packets dropped since send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_error
                    
                    	Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: standby_packets_error
                    
                    	Packets received in standby state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: truncated_pim_packets
                    
                    	Packets dropped due to truncated Joins or Prunes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"packet-queue" : ("packet_queue", Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue)}

                        self.boundary_acl_rx_drop = YLeaf(YType.uint32, "boundary-acl-rx-drop")

                        self.boundary_acl_tx_drop = YLeaf(YType.uint32, "boundary-acl-tx-drop")

                        self.checksum_error = YLeaf(YType.uint32, "checksum-error")

                        self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                        self.format_error = YLeaf(YType.uint32, "format-error")

                        self.input_assert = YLeaf(YType.uint32, "input-assert")

                        self.input_assert_batched = YLeaf(YType.uint32, "input-assert-batched")

                        self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                        self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                        self.input_data_register = YLeaf(YType.uint32, "input-data-register")

                        self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                        self.input_ecmp_redirect = YLeaf(YType.uint32, "input-ecmp-redirect")

                        self.input_hello = YLeaf(YType.uint32, "input-hello")

                        self.input_jp = YLeaf(YType.uint32, "input-jp")

                        self.input_no_idb_error = YLeaf(YType.uint32, "input-no-idb-error")

                        self.input_no_pim_error = YLeaf(YType.uint32, "input-no-pim-error")

                        self.input_no_vrf_error = YLeaf(YType.uint32, "input-no-vrf-error")

                        self.input_null_register = YLeaf(YType.uint32, "input-null-register")

                        self.input_pim_version_error = YLeaf(YType.uint32, "input-pim-version-error")

                        self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                        self.inputs = YLeaf(YType.uint32, "inputs")

                        self.invalid_destination_packets = YLeaf(YType.uint32, "invalid-destination-packets")

                        self.invalid_join_prunes = YLeaf(YType.uint32, "invalid-join-prunes")

                        self.invalid_registers = YLeaf(YType.uint32, "invalid-registers")

                        self.mdt_drop_local_source_address = YLeaf(YType.uint32, "mdt-drop-local-source-address")

                        self.mdt_drop_no_idb = YLeaf(YType.uint32, "mdt-drop-no-idb")

                        self.mdt_drop_no_vrf = YLeaf(YType.uint32, "mdt-drop-no-vrf")

                        self.mdt_drop_null_local_address = YLeaf(YType.uint32, "mdt-drop-null-local-address")

                        self.mdt_join_bad_type = YLeaf(YType.uint32, "mdt-join-bad-type")

                        self.mdt_join_tlv_received = YLeaf(YType.uint32, "mdt-join-tlv-received")

                        self.mdt_join_tlv_sent = YLeaf(YType.uint32, "mdt-join-tlv-sent")

                        self.mdt_joins_drop_multiple_encapsulation = YLeaf(YType.uint32, "mdt-joins-drop-multiple-encapsulation")

                        self.mdt_send_queue_full = YLeaf(YType.uint32, "mdt-send-queue-full")

                        self.mdt_socket_error = YLeaf(YType.uint32, "mdt-socket-error")

                        self.mldp_mdt_invalid_lsm_identifier = YLeaf(YType.uint32, "mldp-mdt-invalid-lsm-identifier")

                        self.no_mdt_socket_connection = YLeaf(YType.uint32, "no-mdt-socket-connection")

                        self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                        self.no_source_address = YLeaf(YType.uint32, "no-source-address")

                        self.non_supported_packets = YLeaf(YType.uint32, "non-supported-packets")

                        self.output_assert = YLeaf(YType.uint32, "output-assert")

                        self.output_assert_batched = YLeaf(YType.uint32, "output-assert-batched")

                        self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                        self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                        self.output_data_register = YLeaf(YType.uint32, "output-data-register")

                        self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                        self.output_ecmp_redirect = YLeaf(YType.uint32, "output-ecmp-redirect")

                        self.output_hello = YLeaf(YType.uint32, "output-hello")

                        self.output_hello_bytes = YLeaf(YType.uint32, "output-hello-bytes")

                        self.output_join_group = YLeaf(YType.uint32, "output-join-group")

                        self.output_join_prune_bytes = YLeaf(YType.uint32, "output-join-prune-bytes")

                        self.output_jp = YLeaf(YType.uint32, "output-jp")

                        self.output_loop_error = YLeaf(YType.uint32, "output-loop-error")

                        self.output_null_register = YLeaf(YType.uint32, "output-null-register")

                        self.output_prune_group = YLeaf(YType.uint32, "output-prune-group")

                        self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                        self.outputs = YLeaf(YType.uint32, "outputs")

                        self.packet_packman_error = YLeaf(YType.uint32, "packet-packman-error")

                        self.packet_queue_last_clear = YLeaf(YType.uint32, "packet-queue-last-clear")

                        self.packet_read_socket_error = YLeaf(YType.uint32, "packet-read-socket-error")

                        self.packets_standby = YLeaf(YType.uint32, "packets-standby")

                        self.pakman_error = YLeaf(YType.uint32, "pakman-error")

                        self.send_queue_full = YLeaf(YType.uint32, "send-queue-full")

                        self.socket_error = YLeaf(YType.uint32, "socket-error")

                        self.standby_packets_error = YLeaf(YType.uint32, "standby-packets-error")

                        self.truncated_pim_packets = YLeaf(YType.uint32, "truncated-pim-packets")

                        self.packet_queue = YList(self)
                        self._segment_path = lambda: "traffic-counters"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters, ['boundary_acl_rx_drop', 'boundary_acl_tx_drop', 'checksum_error', 'elapsed_time', 'format_error', 'input_assert', 'input_assert_batched', 'input_bsr_message', 'input_candidate_rp_advertisement', 'input_data_register', 'input_df_election', 'input_ecmp_redirect', 'input_hello', 'input_jp', 'input_no_idb_error', 'input_no_pim_error', 'input_no_vrf_error', 'input_null_register', 'input_pim_version_error', 'input_register_stop', 'inputs', 'invalid_destination_packets', 'invalid_join_prunes', 'invalid_registers', 'mdt_drop_local_source_address', 'mdt_drop_no_idb', 'mdt_drop_no_vrf', 'mdt_drop_null_local_address', 'mdt_join_bad_type', 'mdt_join_tlv_received', 'mdt_join_tlv_sent', 'mdt_joins_drop_multiple_encapsulation', 'mdt_send_queue_full', 'mdt_socket_error', 'mldp_mdt_invalid_lsm_identifier', 'no_mdt_socket_connection', 'no_socket_connection', 'no_source_address', 'non_supported_packets', 'output_assert', 'output_assert_batched', 'output_bsr_message', 'output_candidate_rp_advertisement', 'output_data_register', 'output_df_election', 'output_ecmp_redirect', 'output_hello', 'output_hello_bytes', 'output_join_group', 'output_join_prune_bytes', 'output_jp', 'output_loop_error', 'output_null_register', 'output_prune_group', 'output_register_stop', 'outputs', 'packet_packman_error', 'packet_queue_last_clear', 'packet_read_socket_error', 'packets_standby', 'pakman_error', 'send_queue_full', 'socket_error', 'standby_packets_error', 'truncated_pim_packets'], name, value)


                    class PacketQueue(Entity):
                        """
                        Packet queue state and statistics
                        
                        .. attribute:: packet_queue_priority
                        
                        	Priority of this packet queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: packet_queue_state
                        
                        	State of the queue
                        	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState>`
                        
                        .. attribute:: packet_queue_stats
                        
                        	Statistics about the queue
                        	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__init__()

                            self.yang_name = "packet-queue"
                            self.yang_parent_name = "traffic-counters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"packet-queue-state" : ("packet_queue_state", Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState), "packet-queue-stats" : ("packet_queue_stats", Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats)}
                            self._child_list_classes = {}

                            self.packet_queue_priority = YLeaf(YType.uint32, "packet-queue-priority")

                            self.packet_queue_state = Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                            self.packet_queue_state.parent = self
                            self._children_name_map["packet_queue_state"] = "packet-queue-state"
                            self._children_yang_names.add("packet-queue-state")

                            self.packet_queue_stats = Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                            self.packet_queue_stats.parent = self
                            self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                            self._children_yang_names.add("packet-queue-stats")
                            self._segment_path = lambda: "packet-queue"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue, ['packet_queue_priority'], name, value)


                        class PacketQueueState(Entity):
                            """
                            State of the queue
                            
                            .. attribute:: max_queue_size
                            
                            	Maximum size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_bytes
                            
                            	Size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_packets
                            
                            	Size of queue in number of packets
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                                self.yang_name = "packet-queue-state"
                                self.yang_parent_name = "packet-queue"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.max_queue_size = YLeaf(YType.uint32, "max-queue-size")

                                self.queue_size_bytes = YLeaf(YType.uint32, "queue-size-bytes")

                                self.queue_size_packets = YLeaf(YType.uint32, "queue-size-packets")
                                self._segment_path = lambda: "packet-queue-state"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, ['max_queue_size', 'queue_size_bytes', 'queue_size_packets'], name, value)


                        class PacketQueueStats(Entity):
                            """
                            Statistics about the queue
                            
                            .. attribute:: dequeued_packets
                            
                            	Total number of packets dequeued from this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: enqueued_packets
                            
                            	Total number of packets enqueued to this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_bytes
                            
                            	Highest number of bytes enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: high_water_mark_packets
                            
                            	Highest number of packets enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tail_drops
                            
                            	Number packets dropped from this queue due to max size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                                self.yang_name = "packet-queue-stats"
                                self.yang_parent_name = "packet-queue"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.dequeued_packets = YLeaf(YType.uint32, "dequeued-packets")

                                self.enqueued_packets = YLeaf(YType.uint32, "enqueued-packets")

                                self.high_water_mark_bytes = YLeaf(YType.uint32, "high-water-mark-bytes")

                                self.high_water_mark_packets = YLeaf(YType.uint32, "high-water-mark-packets")

                                self.tail_drops = YLeaf(YType.uint32, "tail-drops")
                                self._segment_path = lambda: "packet-queue-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, ['dequeued_packets', 'enqueued_packets', 'high_water_mark_bytes', 'high_water_mark_packets', 'tail_drops'], name, value)


                class Tunnels(Entity):
                    """
                    Tunnels information that PIM has
                    
                    .. attribute:: tunnel
                    
                    	PIM tunnel information
                    	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels, self).__init__()

                        self.yang_name = "tunnels"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"tunnel" : ("tunnel", Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel)}

                        self.tunnel = YList(self)
                        self._segment_path = lambda: "tunnels"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Tunnels, [], name, value)


                    class Tunnel(Entity):
                        """
                        PIM tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel, self).__init__()

                            self.yang_name = "tunnel"
                            self.yang_parent_name = "tunnels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-netio" : ("group_address_netio", Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio), "rp-address" : ("rp_address", Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress), "source-address" : ("source_address", Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress), "source-address-netio" : ("source_address_netio", Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio)}
                            self._child_list_classes = {}

                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_netio = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._children_yang_names.add("group-address-netio")

                            self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.source_address = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                            self.source_address_netio = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"
                            self._children_yang_names.add("source-address-netio")
                            self._segment_path = lambda: "tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel, ['tunnel_name', 'vrf_name'], name, value)


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-netio"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-netio"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


    class Standby(Entity):
        """
        Standby Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2017-06-26'

        def __init__(self):
            super(Ipv6Pim.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "ipv6-pim"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"default-context" : ("default_context", Ipv6Pim.Standby.DefaultContext), "process" : ("process", Ipv6Pim.Standby.Process), "vrfs" : ("vrfs", Ipv6Pim.Standby.Vrfs)}
            self._child_list_classes = {}

            self.default_context = Ipv6Pim.Standby.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"
            self._children_yang_names.add("default-context")

            self.process = Ipv6Pim.Standby.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"
            self._children_yang_names.add("process")

            self.vrfs = Ipv6Pim.Standby.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._children_yang_names.add("vrfs")
            self._segment_path = lambda: "standby"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/%s" % self._segment_path()


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: auto_rp
            
            	PIM Auto\-RP information
            	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.AutoRp>`
            
            .. attribute:: bgp_afs
            
            	PIM BGP SAFI table
            	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs>`
            
            .. attribute:: bidir_df_states
            
            	Bidirectional PIM DF election state table
            	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfStates>`
            
            .. attribute:: bidir_df_winners
            
            	Bidirectional PIM DF election winner table
            	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfWinners>`
            
            .. attribute:: bsr
            
            	PIM BSR information
            	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr>`
            
            .. attribute:: context
            
            	PIM context information
            	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context>`
            
            .. attribute:: global_interfaces
            
            	PIM global interface table
            	**type**\:   :py:class:`GlobalInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GlobalInterfaces>`
            
            .. attribute:: gre
            
            	GRE information
            	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre>`
            
            .. attribute:: group_map_rpfs
            
            	PIM group mapping information
            	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs>`
            
            .. attribute:: group_map_sources
            
            	PIM group\-mapping with source information
            	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources>`
            
            .. attribute:: ifrs_interfaces
            
            	PIM interfaces in forward reference store table
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: ifrs_summary
            
            	PIM interfaces in forward reference store summary
            	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsSummary>`
            
            .. attribute:: interface_old_formats
            
            	PIM interfaces in old format
            	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats>`
            
            .. attribute:: interface_statistics
            
            	PIM interface statistics
            	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceStatistics>`
            
            .. attribute:: interfaces
            
            	PIM interfaces
            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Interfaces>`
            
            .. attribute:: jp_statistics
            
            	PIM join prune statistics table
            	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.JpStatistics>`
            
            .. attribute:: mib_databases
            
            	PIM group database for mroute mibs table
            	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases>`
            
            .. attribute:: multicast_static_routes
            
            	PIM multicast static route table
            	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes>`
            
            .. attribute:: neighbor_old_formats
            
            	PIM neighbor table old format
            	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborOldFormats>`
            
            .. attribute:: neighbor_summaries
            
            	PIM neighbor summary table
            	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborSummaries>`
            
            .. attribute:: neighbors
            
            	PIM neighbor table
            	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Neighbors>`
            
            .. attribute:: net_io_tunnels
            
            	Tunnel information that NETIO has 
            	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels>`
            
            .. attribute:: ranges
            
            	PIM range list information
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges>`
            
            .. attribute:: route_policy
            
            	PIM route policy
            	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy>`
            
            .. attribute:: rpf_redirect
            
            	PIM ECMP RPF\-redirect bundle
            	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect>`
            
            .. attribute:: rpf_summary
            
            	PIM RPF registration summary
            	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfSummary>`
            
            .. attribute:: safs
            
            	SAFI table and type
            	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs>`
            
            .. attribute:: summary
            
            	PIM summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Summary>`
            
            .. attribute:: table_contexts
            
            	PIM table context list
            	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TableContexts>`
            
            .. attribute:: topologies
            
            	PIM topology table
            	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies>`
            
            .. attribute:: topology_entry_flag_route_counts
            
            	Route count for topology with entry flag set
            	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts>`
            
            .. attribute:: topology_interface_flag_route_counts
            
            	Route count for topology with interface flag set
            	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts>`
            
            .. attribute:: topology_route_count
            
            	Topology route count information from PIM topology table
            	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyRouteCount>`
            
            .. attribute:: traffic_counters
            
            	PIM message traffic counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TrafficCounters>`
            
            .. attribute:: tunnels
            
            	Tunnels information that PIM has
            	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Ipv6Pim.Standby.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"auto-rp" : ("auto_rp", Ipv6Pim.Standby.DefaultContext.AutoRp), "bgp-afs" : ("bgp_afs", Ipv6Pim.Standby.DefaultContext.BgpAfs), "bidir-df-states" : ("bidir_df_states", Ipv6Pim.Standby.DefaultContext.BidirDfStates), "bidir-df-winners" : ("bidir_df_winners", Ipv6Pim.Standby.DefaultContext.BidirDfWinners), "bsr" : ("bsr", Ipv6Pim.Standby.DefaultContext.Bsr), "context" : ("context", Ipv6Pim.Standby.DefaultContext.Context), "global-interfaces" : ("global_interfaces", Ipv6Pim.Standby.DefaultContext.GlobalInterfaces), "gre" : ("gre", Ipv6Pim.Standby.DefaultContext.Gre), "group-map-rpfs" : ("group_map_rpfs", Ipv6Pim.Standby.DefaultContext.GroupMapRpfs), "group-map-sources" : ("group_map_sources", Ipv6Pim.Standby.DefaultContext.GroupMapSources), "ifrs-interfaces" : ("ifrs_interfaces", Ipv6Pim.Standby.DefaultContext.IfrsInterfaces), "ifrs-summary" : ("ifrs_summary", Ipv6Pim.Standby.DefaultContext.IfrsSummary), "interface-old-formats" : ("interface_old_formats", Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats), "interface-statistics" : ("interface_statistics", Ipv6Pim.Standby.DefaultContext.InterfaceStatistics), "interfaces" : ("interfaces", Ipv6Pim.Standby.DefaultContext.Interfaces), "jp-statistics" : ("jp_statistics", Ipv6Pim.Standby.DefaultContext.JpStatistics), "mib-databases" : ("mib_databases", Ipv6Pim.Standby.DefaultContext.MibDatabases), "multicast-static-routes" : ("multicast_static_routes", Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes), "neighbor-old-formats" : ("neighbor_old_formats", Ipv6Pim.Standby.DefaultContext.NeighborOldFormats), "neighbor-summaries" : ("neighbor_summaries", Ipv6Pim.Standby.DefaultContext.NeighborSummaries), "neighbors" : ("neighbors", Ipv6Pim.Standby.DefaultContext.Neighbors), "net-io-tunnels" : ("net_io_tunnels", Ipv6Pim.Standby.DefaultContext.NetIoTunnels), "ranges" : ("ranges", Ipv6Pim.Standby.DefaultContext.Ranges), "route-policy" : ("route_policy", Ipv6Pim.Standby.DefaultContext.RoutePolicy), "rpf-redirect" : ("rpf_redirect", Ipv6Pim.Standby.DefaultContext.RpfRedirect), "rpf-summary" : ("rpf_summary", Ipv6Pim.Standby.DefaultContext.RpfSummary), "safs" : ("safs", Ipv6Pim.Standby.DefaultContext.Safs), "summary" : ("summary", Ipv6Pim.Standby.DefaultContext.Summary), "table-contexts" : ("table_contexts", Ipv6Pim.Standby.DefaultContext.TableContexts), "topologies" : ("topologies", Ipv6Pim.Standby.DefaultContext.Topologies), "topology-entry-flag-route-counts" : ("topology_entry_flag_route_counts", Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts), "topology-interface-flag-route-counts" : ("topology_interface_flag_route_counts", Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts), "topology-route-count" : ("topology_route_count", Ipv6Pim.Standby.DefaultContext.TopologyRouteCount), "traffic-counters" : ("traffic_counters", Ipv6Pim.Standby.DefaultContext.TrafficCounters), "tunnels" : ("tunnels", Ipv6Pim.Standby.DefaultContext.Tunnels)}
                self._child_list_classes = {}

                self.auto_rp = Ipv6Pim.Standby.DefaultContext.AutoRp()
                self.auto_rp.parent = self
                self._children_name_map["auto_rp"] = "auto-rp"
                self._children_yang_names.add("auto-rp")

                self.bgp_afs = Ipv6Pim.Standby.DefaultContext.BgpAfs()
                self.bgp_afs.parent = self
                self._children_name_map["bgp_afs"] = "bgp-afs"
                self._children_yang_names.add("bgp-afs")

                self.bidir_df_states = Ipv6Pim.Standby.DefaultContext.BidirDfStates()
                self.bidir_df_states.parent = self
                self._children_name_map["bidir_df_states"] = "bidir-df-states"
                self._children_yang_names.add("bidir-df-states")

                self.bidir_df_winners = Ipv6Pim.Standby.DefaultContext.BidirDfWinners()
                self.bidir_df_winners.parent = self
                self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                self._children_yang_names.add("bidir-df-winners")

                self.bsr = Ipv6Pim.Standby.DefaultContext.Bsr()
                self.bsr.parent = self
                self._children_name_map["bsr"] = "bsr"
                self._children_yang_names.add("bsr")

                self.context = Ipv6Pim.Standby.DefaultContext.Context()
                self.context.parent = self
                self._children_name_map["context"] = "context"
                self._children_yang_names.add("context")

                self.global_interfaces = Ipv6Pim.Standby.DefaultContext.GlobalInterfaces()
                self.global_interfaces.parent = self
                self._children_name_map["global_interfaces"] = "global-interfaces"
                self._children_yang_names.add("global-interfaces")

                self.gre = Ipv6Pim.Standby.DefaultContext.Gre()
                self.gre.parent = self
                self._children_name_map["gre"] = "gre"
                self._children_yang_names.add("gre")

                self.group_map_rpfs = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs()
                self.group_map_rpfs.parent = self
                self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                self._children_yang_names.add("group-map-rpfs")

                self.group_map_sources = Ipv6Pim.Standby.DefaultContext.GroupMapSources()
                self.group_map_sources.parent = self
                self._children_name_map["group_map_sources"] = "group-map-sources"
                self._children_yang_names.add("group-map-sources")

                self.ifrs_interfaces = Ipv6Pim.Standby.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                self._children_yang_names.add("ifrs-interfaces")

                self.ifrs_summary = Ipv6Pim.Standby.DefaultContext.IfrsSummary()
                self.ifrs_summary.parent = self
                self._children_name_map["ifrs_summary"] = "ifrs-summary"
                self._children_yang_names.add("ifrs-summary")

                self.interface_old_formats = Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats()
                self.interface_old_formats.parent = self
                self._children_name_map["interface_old_formats"] = "interface-old-formats"
                self._children_yang_names.add("interface-old-formats")

                self.interface_statistics = Ipv6Pim.Standby.DefaultContext.InterfaceStatistics()
                self.interface_statistics.parent = self
                self._children_name_map["interface_statistics"] = "interface-statistics"
                self._children_yang_names.add("interface-statistics")

                self.interfaces = Ipv6Pim.Standby.DefaultContext.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"
                self._children_yang_names.add("interfaces")

                self.jp_statistics = Ipv6Pim.Standby.DefaultContext.JpStatistics()
                self.jp_statistics.parent = self
                self._children_name_map["jp_statistics"] = "jp-statistics"
                self._children_yang_names.add("jp-statistics")

                self.mib_databases = Ipv6Pim.Standby.DefaultContext.MibDatabases()
                self.mib_databases.parent = self
                self._children_name_map["mib_databases"] = "mib-databases"
                self._children_yang_names.add("mib-databases")

                self.multicast_static_routes = Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes()
                self.multicast_static_routes.parent = self
                self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                self._children_yang_names.add("multicast-static-routes")

                self.neighbor_old_formats = Ipv6Pim.Standby.DefaultContext.NeighborOldFormats()
                self.neighbor_old_formats.parent = self
                self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                self._children_yang_names.add("neighbor-old-formats")

                self.neighbor_summaries = Ipv6Pim.Standby.DefaultContext.NeighborSummaries()
                self.neighbor_summaries.parent = self
                self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                self._children_yang_names.add("neighbor-summaries")

                self.neighbors = Ipv6Pim.Standby.DefaultContext.Neighbors()
                self.neighbors.parent = self
                self._children_name_map["neighbors"] = "neighbors"
                self._children_yang_names.add("neighbors")

                self.net_io_tunnels = Ipv6Pim.Standby.DefaultContext.NetIoTunnels()
                self.net_io_tunnels.parent = self
                self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                self._children_yang_names.add("net-io-tunnels")

                self.ranges = Ipv6Pim.Standby.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"
                self._children_yang_names.add("ranges")

                self.route_policy = Ipv6Pim.Standby.DefaultContext.RoutePolicy()
                self.route_policy.parent = self
                self._children_name_map["route_policy"] = "route-policy"
                self._children_yang_names.add("route-policy")

                self.rpf_redirect = Ipv6Pim.Standby.DefaultContext.RpfRedirect()
                self.rpf_redirect.parent = self
                self._children_name_map["rpf_redirect"] = "rpf-redirect"
                self._children_yang_names.add("rpf-redirect")

                self.rpf_summary = Ipv6Pim.Standby.DefaultContext.RpfSummary()
                self.rpf_summary.parent = self
                self._children_name_map["rpf_summary"] = "rpf-summary"
                self._children_yang_names.add("rpf-summary")

                self.safs = Ipv6Pim.Standby.DefaultContext.Safs()
                self.safs.parent = self
                self._children_name_map["safs"] = "safs"
                self._children_yang_names.add("safs")

                self.summary = Ipv6Pim.Standby.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.table_contexts = Ipv6Pim.Standby.DefaultContext.TableContexts()
                self.table_contexts.parent = self
                self._children_name_map["table_contexts"] = "table-contexts"
                self._children_yang_names.add("table-contexts")

                self.topologies = Ipv6Pim.Standby.DefaultContext.Topologies()
                self.topologies.parent = self
                self._children_name_map["topologies"] = "topologies"
                self._children_yang_names.add("topologies")

                self.topology_entry_flag_route_counts = Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts()
                self.topology_entry_flag_route_counts.parent = self
                self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                self._children_yang_names.add("topology-entry-flag-route-counts")

                self.topology_interface_flag_route_counts = Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts()
                self.topology_interface_flag_route_counts.parent = self
                self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                self._children_yang_names.add("topology-interface-flag-route-counts")

                self.topology_route_count = Ipv6Pim.Standby.DefaultContext.TopologyRouteCount()
                self.topology_route_count.parent = self
                self._children_name_map["topology_route_count"] = "topology-route-count"
                self._children_yang_names.add("topology-route-count")

                self.traffic_counters = Ipv6Pim.Standby.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"
                self._children_yang_names.add("traffic-counters")

                self.tunnels = Ipv6Pim.Standby.DefaultContext.Tunnels()
                self.tunnels.parent = self
                self._children_name_map["tunnels"] = "tunnels"
                self._children_yang_names.add("tunnels")
                self._segment_path = lambda: "default-context"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/%s" % self._segment_path()


            class AutoRp(Entity):
                """
                PIM Auto\-RP information
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.AutoRp, self).__init__()

                    self.yang_name = "auto-rp"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self._segment_path = lambda: "auto-rp"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()


            class BgpAfs(Entity):
                """
                PIM BGP SAFI table
                
                .. attribute:: bgp_af
                
                	PIM BGP SAFI information
                	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.BgpAfs, self).__init__()

                    self.yang_name = "bgp-afs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"bgp-af" : ("bgp_af", Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf)}

                    self.bgp_af = YList(self)
                    self._segment_path = lambda: "bgp-afs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BgpAfs, [], name, value)


                class BgpAf(Entity):
                    """
                    PIM BGP SAFI information
                    
                    .. attribute:: extranet_path_count
                    
                    	Count of dependent extranet paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group
                    
                    	Group address
                    	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group>`
                    
                    .. attribute:: group_address
                    
                    	Group IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: is_bgp_added
                    
                    	SAFI learnt from BGP
                    	**type**\:  bool
                    
                    .. attribute:: next_hop
                    
                    	Next hop address
                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop>`
                    
                    .. attribute:: route_distinguisher
                    
                    	Router ID
                    	**type**\:  str
                    
                    	**length:** 0..256
                    
                    .. attribute:: source
                    
                    	Source address
                    	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf, self).__init__()

                        self.yang_name = "bgp-af"
                        self.yang_parent_name = "bgp-afs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group" : ("group", Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group), "next-hop" : ("next_hop", Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop), "source" : ("source", Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source)}
                        self._child_list_classes = {}

                        self.extranet_path_count = YLeaf(YType.uint32, "extranet-path-count")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.is_bgp_added = YLeaf(YType.boolean, "is-bgp-added")

                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group = Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group()
                        self.group.parent = self
                        self._children_name_map["group"] = "group"
                        self._children_yang_names.add("group")

                        self.next_hop = Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._children_yang_names.add("next-hop")

                        self.source = Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"
                        self._children_yang_names.add("source")
                        self._segment_path = lambda: "bgp-af"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bgp-afs/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf, ['extranet_path_count', 'group_address', 'is_bgp_added', 'route_distinguisher', 'source_address'], name, value)


                    class Group(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bgp-afs/bgp-af/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class NextHop(Entity):
                        """
                        Next hop address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "next-hop"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bgp-afs/bgp-af/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Source(Entity):
                        """
                        Source address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bgp-afs/bgp-af/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class BidirDfStates(Entity):
                """
                Bidirectional PIM DF election state table
                
                .. attribute:: bidir_df_state
                
                	Bidirectional PIM DF Election Table Entry
                	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.BidirDfStates, self).__init__()

                    self.yang_name = "bidir-df-states"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"bidir-df-state" : ("bidir_df_state", Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState)}

                    self.bidir_df_state = YList(self)
                    self._segment_path = lambda: "bidir-df-states"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BidirDfStates, [], name, value)


                class BidirDfState(Entity):
                    """
                    Bidirectional PIM DF Election Table Entry
                    
                    .. attribute:: election_state
                    
                    	DF Election State
                    	**type**\:  str
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: our_metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: our_metric_preference
                    
                    	MetricPreference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr>`
                    
                    .. attribute:: time_nano_seconds
                    
                    	Timer expires (nseconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: time_seconds
                    
                    	Timer expires (seconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState, self).__init__()

                        self.yang_name = "bidir-df-state"
                        self.yang_parent_name = "bidir-df-states"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rp-address-xr" : ("rp_address_xr", Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr)}
                        self._child_list_classes = {}

                        self.election_state = YLeaf(YType.str, "election-state")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.our_metric = YLeaf(YType.uint32, "our-metric")

                        self.our_metric_preference = YLeaf(YType.uint32, "our-metric-preference")

                        self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.time_nano_seconds = YLeaf(YType.uint64, "time-nano-seconds")

                        self.time_seconds = YLeaf(YType.uint64, "time-seconds")

                        self.rp_address_xr = Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")
                        self._segment_path = lambda: "bidir-df-state"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bidir-df-states/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState, ['election_state', 'interface_name', 'our_metric', 'our_metric_preference', 'pim_interface_name', 'rp_address', 'time_nano_seconds', 'time_seconds'], name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-state"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bidir-df-states/bidir-df-state/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class BidirDfWinners(Entity):
                """
                Bidirectional PIM DF election winner table
                
                .. attribute:: bidir_df_winner
                
                	Bidirectional PIM DF election table entry
                	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners, self).__init__()

                    self.yang_name = "bidir-df-winners"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"bidir-df-winner" : ("bidir_df_winner", Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner)}

                    self.bidir_df_winner = YList(self)
                    self._segment_path = lambda: "bidir-df-winners"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BidirDfWinners, [], name, value)


                class BidirDfWinner(Entity):
                    """
                    Bidirectional PIM DF election table entry
                    
                    .. attribute:: are_we_df
                    
                    	Are we DF
                    	**type**\:  bool
                    
                    .. attribute:: df_winner
                    
                    	DF Winner
                    	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner>`
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_preference
                    
                    	Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                    
                    .. attribute:: rp_lan
                    
                    	Is this the RP LAN
                    	**type**\:  bool
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner, self).__init__()

                        self.yang_name = "bidir-df-winner"
                        self.yang_parent_name = "bidir-df-winners"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"df-winner" : ("df_winner", Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner), "rp-address-xr" : ("rp_address_xr", Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr)}
                        self._child_list_classes = {}

                        self.are_we_df = YLeaf(YType.boolean, "are-we-df")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.metric = YLeaf(YType.uint32, "metric")

                        self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                        self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_lan = YLeaf(YType.boolean, "rp-lan")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.df_winner = Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                        self.df_winner.parent = self
                        self._children_name_map["df_winner"] = "df-winner"
                        self._children_yang_names.add("df-winner")

                        self.rp_address_xr = Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")
                        self._segment_path = lambda: "bidir-df-winner"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bidir-df-winners/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner, ['are_we_df', 'interface_name', 'metric', 'metric_preference', 'pim_interface_name', 'rp_address', 'rp_lan', 'uptime'], name, value)


                    class DfWinner(Entity):
                        """
                        DF Winner
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                            self.yang_name = "df-winner"
                            self.yang_parent_name = "bidir-df-winner"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "df-winner"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bidir-df-winners/bidir-df-winner/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-winner"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bidir-df-winners/bidir-df-winner/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Bsr(Entity):
                """
                PIM BSR information
                
                .. attribute:: bsr_elections
                
                	PIM BSR election state
                	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections>`
                
                .. attribute:: candidate_rps
                
                	PIM candidate\-RP
                	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps>`
                
                .. attribute:: rp_caches
                
                	PIM BSR RP cache table
                	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Bsr, self).__init__()

                    self.yang_name = "bsr"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"bsr-elections" : ("bsr_elections", Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections), "candidate-rps" : ("candidate_rps", Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps), "rp-caches" : ("rp_caches", Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches)}
                    self._child_list_classes = {}

                    self.bsr_elections = Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections()
                    self.bsr_elections.parent = self
                    self._children_name_map["bsr_elections"] = "bsr-elections"
                    self._children_yang_names.add("bsr-elections")

                    self.candidate_rps = Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps()
                    self.candidate_rps.parent = self
                    self._children_name_map["candidate_rps"] = "candidate-rps"
                    self._children_yang_names.add("candidate-rps")

                    self.rp_caches = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches()
                    self.rp_caches.parent = self
                    self._children_name_map["rp_caches"] = "rp-caches"
                    self._children_yang_names.add("rp-caches")
                    self._segment_path = lambda: "bsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()


                class BsrElections(Entity):
                    """
                    PIM BSR election state
                    
                    .. attribute:: bsr_election
                    
                    	PIM BSR information
                    	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections, self).__init__()

                        self.yang_name = "bsr-elections"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"bsr-election" : ("bsr_election", Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection)}

                        self.bsr_election = YList(self)
                        self._segment_path = lambda: "bsr-elections"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bsr/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections, [], name, value)


                    class BsrElection(Entity):
                        """
                        PIM BSR information
                        
                        .. attribute:: pim_scope  <key>
                        
                        	BSR information
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: bootstrap_timeout
                        
                        	Bootstrap Timeout
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_address
                        
                        	BSR address
                        	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress>`
                        
                        .. attribute:: bsr_election_state
                        
                        	BSR Election State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_mask_length
                        
                        	Hash Function Mask Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_priority
                        
                        	BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_scope
                        
                        	BSR Scope
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_up_time
                        
                        	BSR Uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_address
                        
                        	C\-BSR address
                        	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                        
                        .. attribute:: candidate_bsr_flag
                        
                        	BSR Candidate Config Flag
                        	**type**\:  bool
                        
                        .. attribute:: candidate_bsr_mask_length
                        
                        	C\-BSR Hash Func. Mask Len
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_priority
                        
                        	C\-BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_state
                        
                        	BSR Candidate State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection, self).__init__()

                            self.yang_name = "bsr-election"
                            self.yang_parent_name = "bsr-elections"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"bsr-address" : ("bsr_address", Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress), "candidate-bsr-address" : ("candidate_bsr_address", Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress)}
                            self._child_list_classes = {}

                            self.pim_scope = YLeaf(YType.int32, "pim-scope")

                            self.bootstrap_timeout = YLeaf(YType.uint16, "bootstrap-timeout")

                            self.bsr_election_state = YLeaf(YType.uint32, "bsr-election-state")

                            self.bsr_mask_length = YLeaf(YType.uint8, "bsr-mask-length")

                            self.bsr_priority = YLeaf(YType.uint8, "bsr-priority")

                            self.bsr_scope = YLeaf(YType.uint16, "bsr-scope")

                            self.bsr_up_time = YLeaf(YType.uint16, "bsr-up-time")

                            self.candidate_bsr_flag = YLeaf(YType.boolean, "candidate-bsr-flag")

                            self.candidate_bsr_mask_length = YLeaf(YType.uint8, "candidate-bsr-mask-length")

                            self.candidate_bsr_priority = YLeaf(YType.uint8, "candidate-bsr-priority")

                            self.candidate_bsr_state = YLeaf(YType.uint32, "candidate-bsr-state")

                            self.bsr_address = Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                            self.bsr_address.parent = self
                            self._children_name_map["bsr_address"] = "bsr-address"
                            self._children_yang_names.add("bsr-address")

                            self.candidate_bsr_address = Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                            self.candidate_bsr_address.parent = self
                            self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                            self._children_yang_names.add("candidate-bsr-address")
                            self._segment_path = lambda: "bsr-election" + "[pim-scope='" + self.pim_scope.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bsr/bsr-elections/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection, ['pim_scope', 'bootstrap_timeout', 'bsr_election_state', 'bsr_mask_length', 'bsr_priority', 'bsr_scope', 'bsr_up_time', 'candidate_bsr_flag', 'candidate_bsr_mask_length', 'candidate_bsr_priority', 'candidate_bsr_state'], name, value)


                        class BsrAddress(Entity):
                            """
                            BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                self.yang_name = "bsr-address"
                                self.yang_parent_name = "bsr-election"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "bsr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class CandidateBsrAddress(Entity):
                            """
                            C\-BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                self.yang_name = "candidate-bsr-address"
                                self.yang_parent_name = "bsr-election"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "candidate-bsr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class CandidateRps(Entity):
                    """
                    PIM candidate\-RP
                    
                    .. attribute:: candidate_rp
                    
                    	PIM BSR candidate RP information
                    	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps, self).__init__()

                        self.yang_name = "candidate-rps"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"candidate-rp" : ("candidate_rp", Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp)}

                        self.candidate_rp = YList(self)
                        self._segment_path = lambda: "candidate-rps"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bsr/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps, [], name, value)


                    class CandidateRp(Entity):
                        """
                        PIM BSR candidate RP information
                        
                        .. attribute:: rp_address  <key>
                        
                        	Candidate\-RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: acl_name
                        
                        	Group Access\-List Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: candidate_rp
                        
                        	Cand\-RP Address
                        	**type**\:   :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp>`
                        
                        .. attribute:: candidate_rp_advance_interval
                        
                        	Cand\-RP Adv Interval in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: candidate_rp_mode
                        
                        	Cand\-RP Mode
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: candidate_rp_scope
                        
                        	Cand\-RP Scope
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: candidate_rp_uptime
                        
                        	Cand\-RP uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_access
                        
                        	Group Ranges Using this Cand\-RP
                        	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                        
                        .. attribute:: crp_holdtime
                        
                        	Cand\-RP Holdtime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_priority
                        
                        	Cand\-RP Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__init__()

                            self.yang_name = "candidate-rp"
                            self.yang_parent_name = "candidate-rps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"candidate-rp" : ("candidate_rp", Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp)}
                            self._child_list_classes = {"crp-access" : ("crp_access", Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess)}

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.acl_name = YLeaf(YType.str, "acl-name")

                            self.candidate_rp_advance_interval = YLeaf(YType.uint16, "candidate-rp-advance-interval")

                            self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                            self.candidate_rp_scope = YLeaf(YType.int32, "candidate-rp-scope")

                            self.candidate_rp_uptime = YLeaf(YType.uint16, "candidate-rp-uptime")

                            self.crp_holdtime = YLeaf(YType.uint16, "crp-holdtime")

                            self.crp_priority = YLeaf(YType.uint8, "crp-priority")

                            self.candidate_rp = Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp()
                            self.candidate_rp.parent = self
                            self._children_name_map["candidate_rp"] = "candidate-rp"
                            self._children_yang_names.add("candidate-rp")

                            self.crp_access = YList(self)
                            self._segment_path = lambda: "candidate-rp" + "[rp-address='" + self.rp_address.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bsr/candidate-rps/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp, ['rp_address', 'acl_name', 'candidate_rp_advance_interval', 'candidate_rp_mode', 'candidate_rp_scope', 'candidate_rp_uptime', 'crp_holdtime', 'crp_priority'], name, value)


                        class CandidateRp(Entity):
                            """
                            Cand\-RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "candidate-rp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class CrpAccess(Entity):
                            """
                            Group Ranges Using this Cand\-RP
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                self.yang_name = "crp-access"
                                self.yang_parent_name = "candidate-rp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.acl_name = YLeaf(YType.str, "acl-name")

                                self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")
                                self._segment_path = lambda: "crp-access"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, ['acl_name', 'candidate_rp_mode'], name, value)


                class RpCaches(Entity):
                    """
                    PIM BSR RP cache table
                    
                    .. attribute:: rp_cache
                    
                    	PIM BSR RP cache
                    	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches, self).__init__()

                        self.yang_name = "rp-caches"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"rp-cache" : ("rp_cache", Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache)}

                        self.rp_cache = YList(self)
                        self._segment_path = lambda: "rp-caches"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bsr/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches, [], name, value)


                    class RpCache(Entity):
                        """
                        PIM BSR RP cache
                        
                        .. attribute:: group_prefix  <key>
                        
                        	Group prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: candidate_rp_group_count
                        
                        	C\-RP count for this Prefix
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: candidate_rp_list
                        
                        	C\-RP list for this prefix
                        	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList>`
                        
                        .. attribute:: group_prefix_length
                        
                        	Group Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_prefix_xr
                        
                        	Group Prefix
                        	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache, self).__init__()

                            self.yang_name = "rp-cache"
                            self.yang_parent_name = "rp-caches"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"candidate-rp-list" : ("candidate_rp_list", Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList), "group-prefix-xr" : ("group_prefix_xr", Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr)}
                            self._child_list_classes = {}

                            self.group_prefix = YLeaf(YType.str, "group-prefix")

                            self.candidate_rp_group_count = YLeaf(YType.uint32, "candidate-rp-group-count")

                            self.group_prefix_length = YLeaf(YType.uint32, "group-prefix-length")

                            self.candidate_rp_list = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                            self.candidate_rp_list.parent = self
                            self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                            self._children_yang_names.add("candidate-rp-list")

                            self.group_prefix_xr = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                            self.group_prefix_xr.parent = self
                            self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                            self._children_yang_names.add("group-prefix-xr")
                            self._segment_path = lambda: "rp-cache" + "[group-prefix='" + self.group_prefix.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bsr/rp-caches/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache, ['group_prefix', 'candidate_rp_group_count', 'group_prefix_length'], name, value)


                        class CandidateRpList(Entity):
                            """
                            C\-RP list for this prefix
                            
                            .. attribute:: pim_bsr_crp_bag
                            
                            	pim bsr crp bag
                            	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                self.yang_name = "candidate-rp-list"
                                self.yang_parent_name = "rp-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"pim-bsr-crp-bag" : ("pim_bsr_crp_bag", Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag)}

                                self.pim_bsr_crp_bag = YList(self)
                                self._segment_path = lambda: "candidate-rp-list"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, [], name, value)


                            class PimBsrCrpBag(Entity):
                                """
                                pim bsr crp bag
                                
                                .. attribute:: candidate_rp_address
                                
                                	C\-RP address
                                	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                
                                .. attribute:: candidate_rp_expires
                                
                                	C\-RP Expires
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_holdtime
                                
                                	C\-RP Holdtime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_priority
                                
                                	C\-RP Priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: candidate_rp_up_time
                                
                                	C\-RP Uptime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: protocol
                                
                                	PIM Protocol
                                	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                    self.yang_name = "pim-bsr-crp-bag"
                                    self.yang_parent_name = "candidate-rp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"candidate-rp-address" : ("candidate_rp_address", Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress)}
                                    self._child_list_classes = {}

                                    self.candidate_rp_expires = YLeaf(YType.uint16, "candidate-rp-expires")

                                    self.candidate_rp_holdtime = YLeaf(YType.uint16, "candidate-rp-holdtime")

                                    self.candidate_rp_priority = YLeaf(YType.uint8, "candidate-rp-priority")

                                    self.candidate_rp_up_time = YLeaf(YType.uint16, "candidate-rp-up-time")

                                    self.protocol = YLeaf(YType.enumeration, "protocol")

                                    self.candidate_rp_address = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                    self.candidate_rp_address.parent = self
                                    self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                    self._children_yang_names.add("candidate-rp-address")
                                    self._segment_path = lambda: "pim-bsr-crp-bag"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, ['candidate_rp_expires', 'candidate_rp_holdtime', 'candidate_rp_priority', 'candidate_rp_up_time', 'protocol'], name, value)


                                class CandidateRpAddress(Entity):
                                    """
                                    C\-RP address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                        self.yang_name = "candidate-rp-address"
                                        self.yang_parent_name = "pim-bsr-crp-bag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "candidate-rp-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class GroupPrefixXr(Entity):
                            """
                            Group Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                self.yang_name = "group-prefix-xr"
                                self.yang_parent_name = "rp-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-prefix-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Context(Entity):
                """
                PIM context information
                
                .. attribute:: active_table_count
                
                	Number of active Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: allow_rp_configured
                
                	Allow RP Configured
                	**type**\:  bool
                
                .. attribute:: allow_rp_group_list
                
                	Allow RP Group\-List ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: allow_rp_rp_list
                
                	Allow RP RP\-list ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: anycast_rp_configured
                
                	Anycast\-RP config
                	**type**\:  bool
                
                .. attribute:: anycast_rp_policy_name
                
                	Anycast\-RP Policy Name
                	**type**\:  str
                
                .. attribute:: anycast_rp_range
                
                	Anycast\-RP Ranges
                	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange>`
                
                .. attribute:: bgp_auto_discovery_configured
                
                	BGP Auto\-Discovery configured
                	**type**\:  bool
                
                .. attribute:: bgp_auto_discovery_type
                
                	BGP Auto Discovery Type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_i_pmsi_added
                
                	BGP I\-PMSI Added
                	**type**\:  bool
                
                .. attribute:: bgp_remote_address
                
                	BGP remote interface address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: bgp_remote_interface
                
                	BGP remote interface handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: bgp_remote_interface_name
                
                	BGP remote interface name
                	**type**\:  str
                
                .. attribute:: bgp_remote_on
                
                	BGP remote interface status
                	**type**\:  bool
                
                .. attribute:: bgp_remote_state
                
                	BGP remote interface state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_source_active_announce
                
                	Send BGP Source\-Active Announcements
                	**type**\:  bool
                
                .. attribute:: export_route_target
                
                	Export Route Targets
                	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.ExportRouteTarget>`
                
                .. attribute:: gin_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: gin_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: gin_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: import_route_target
                
                	Import Route Targets
                	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.ImportRouteTarget>`
                
                .. attribute:: in_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: in_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: in_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_signaling_local_enabled
                
                	Inband signaling Local enabled
                	**type**\:  bool
                
                .. attribute:: in_band_signaling_remote_enabled
                
                	Inband signaling Remote enabled
                	**type**\:  bool
                
                .. attribute:: inter_autonomous_system_enabled
                
                	Inter\-AS Enabled
                	**type**\:  bool
                
                .. attribute:: ir_maximum_mdt_aggregation
                
                	IR MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_announce_interval
                
                	IR Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_switchover_interval
                
                	IR Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_interface
                
                	IRMDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: ir_mdt_mtu
                
                	IRMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_name
                
                	IR MDT Name
                	**type**\:  str
                
                .. attribute:: ir_mdt_rpf_identifier
                
                	IR RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_tail_label
                
                	IR Tail Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_active
                
                	Active
                	**type**\:  bool
                
                .. attribute:: is_active_ital
                
                	Active ITAL
                	**type**\:  bool
                
                .. attribute:: is_all_interface_disable_operation
                
                	PIM all interface disable operation
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_enabled
                
                	Auto RP Listen Enabled
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_sock_add
                
                	Auto RP listen sock add
                	**type**\:  bool
                
                .. attribute:: is_create_gin_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_in_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_ir_mdt_interface
                
                	Create IR MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mdt_interface
                
                	Create MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mldp_mdt_interface
                
                	Create MLDP MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_rsvp_te_mdt_interface
                
                	Create RSVP\-TE MDT interface
                	**type**\:  bool
                
                .. attribute:: is_default_granges
                
                	Default granges
                	**type**\:  bool
                
                .. attribute:: is_gin_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_in_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_ir_mdt_owner
                
                	IR MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_add_required
                
                	VRF LPTS filter required on Socket
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_added
                
                	VRF LPTS filter added on Socket
                	**type**\:  bool
                
                .. attribute:: is_m_host_publish_pending
                
                	Publish pending for MHost Default interface
                	**type**\:  bool
                
                .. attribute:: is_mdt_owner
                
                	MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mldp_mdt_owner
                
                	MLDP MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mrib_register
                
                	MRIB Register
                	**type**\:  bool
                
                .. attribute:: is_multicast_rib_registration
                
                	Mcast RIB Registration
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converge_received
                
                	PIM NSF RIB converge received
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converged
                
                	PIM NSF RIB converged
                	**type**\:  bool
                
                .. attribute:: is_redistribution_reset
                
                	Pending redist reset
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_add_required
                
                	VRF LPTS filter required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_added
                
                	VRF LPTS filter added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_add_required
                
                	VRF required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_added
                
                	VRF added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_enabled
                
                	PIM RIB multiplath enabled
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_interface_hash
                
                	PIM RIB multipath interface hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_hash
                
                	PIM RIB multipath source based hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_next_hop_hash
                
                	PIM RIB multipath source\-nexthop hash
                	**type**\:  bool
                
                .. attribute:: is_routing_enabled
                
                	Routing Enabled
                	**type**\:  bool
                
                .. attribute:: is_rsvp_te_mdt_owner
                
                	RSVP\-TE MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_socket_add_required
                
                	VRF required on Socket
                	**type**\:  bool
                
                .. attribute:: is_socket_added
                
                	VRF added on Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_add_required
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_added
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind
                
                	VRF bound on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind_required
                
                	VRF bind required on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_unicast_rib_registration
                
                	Ucast RIB Registration
                	**type**\:  bool
                
                .. attribute:: maximum_mdt_aggregation
                
                	MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_announce_interval
                
                	Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_switchover_interval
                
                	Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_default_group
                
                	MDT Default group
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_gre_remote_rpf_identifier
                
                	GRE\-MDT Remote RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_gre_rpf_identifier
                
                	GRE\-MDT RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_immediate_switch
                
                	MDT Immediate Switch
                	**type**\:  bool
                
                .. attribute:: mdt_interface
                
                	MDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: mdt_mtu
                
                	MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_neighbor_filter_name
                
                	MDT Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: mdt_partitioned_ir_control_identifier
                
                	Partitioned IR MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_mdt_control_identifier
                
                	Partitioned MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_source
                
                	MDT source
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_source_interface
                
                	MDT Source Interface Name
                	**type**\:  str
                
                .. attribute:: mhost_default_interface_config
                
                	Configured Mhost Defint
                	**type**\:  str
                
                .. attribute:: mhost_interface
                
                	MHost handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: mldp_auto_rp_announce_tree_added
                
                	MLDP Autorp Announce Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_auto_rp_discovery_tree_added
                
                	MLDP Autorp Discovery Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_bsr_control_tree_added
                
                	MLDP BSR Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_control_head_lsm_identifier
                
                	MLDP MVPN Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_local_label
                
                	Partitioned MDT Head local label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_lsm_identifier
                
                	MLDP Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_maximum_mdt_aggregation
                
                	MLDP MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_announce_interval
                
                	MLDP Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_switchover_interval
                
                	MLDP Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_interface
                
                	MLDP MDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: mldp_mdt_mtu
                
                	MLDP MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_name
                
                	MLDP MDT Name
                	**type**\:  str
                
                .. attribute:: mldp_mdt_remote_rpf_identifier
                
                	MLDP Remote RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_rpf_identifier
                
                	MLDP RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partioned_mp2m_ptree
                
                	MP2MP Partitioned MDT tree
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_head_lsm_identifier
                
                	Partitioned MDT Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_configured
                
                	MLDP Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_mdt_identifier
                
                	MLDP Partitioned MDT Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_head_lsm_identifier
                
                	MLDP Remote Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_partitioned_mdt_configured
                
                	MLDP Remote Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_root_address
                
                	MLDP Root addresses
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_root_count
                
                	MLDP Root count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: murib_id
                
                	MURIB ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_filter_name
                
                	Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: non_default_vrf_count_on_socket
                
                	Count of non\-default vrfs on raw socket
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: organization_unique_identifier
                
                	OUI for VPN\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mpte_li_drop
                
                	Route LI updates dropped for P2MP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: physical_interface_count
                
                	Enabled Physical Interface Count
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: redistribution_reset_count
                
                	Redist reset count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_default_group
                
                	Remote Default Group
                	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup>`
                
                .. attribute:: remote_table_id
                
                	Remote Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_distinguisher
                
                	RD value
                	**type**\:  str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: rpf_default_table
                
                	RPF Default Table
                	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable>`
                
                .. attribute:: rpf_id
                
                	RPF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_policy_name
                
                	RPF topology selection route\-policy name
                	**type**\:  str
                
                .. attribute:: rsvp_te_maximum_mdt_aggregation
                
                	RSVP\-TE MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_announce_interval
                
                	RSVP\-TE Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_switchover_interval
                
                	RSVP\-TE Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_interface
                
                	RSVP\-TEMDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: rsvp_te_mdt_mtu
                
                	RSVP\-TEMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_name
                
                	RSVP\-TE MDT Name
                	**type**\:  str
                
                .. attribute:: rsvp_te_mdt_rpf_identifier
                
                	RSVP\-TE RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_static_p2mp_count
                
                	Number of Static P2MP\-TE MDT
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	PIM is using MuRIB
                	**type**\:  bool
                
                .. attribute:: sg_expiry_time
                
                	S,G Expiry Time Configured, in seconds
                	**type**\:  int
                
                	**range:** 0..65535
                
                	**units**\: second
                
                .. attribute:: sg_expiry_timer_configured
                
                	S,G Expiry Timer Configured
                	**type**\:  bool
                
                .. attribute:: sg_expiry_timer_sg_list
                
                	S,G expiry timer ACL name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: stale_rd_present
                
                	RD is stale
                	**type**\:  bool
                
                .. attribute:: suppress_pim_data_mdt_tlv
                
                	Suppress PIM Data\-MDT TLV Announcements
                	**type**\:  bool
                
                .. attribute:: suppress_shared_tree_join
                
                	Suppress Shared\-Tree Joins
                	**type**\:  bool
                
                .. attribute:: table_count
                
                	Number of configured Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_id
                
                	Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: umh
                
                	Join UMH Core\-Tree
                	**type**\:  bool
                
                .. attribute:: valid_rd_present
                
                	RD is valid
                	**type**\:  bool
                
                .. attribute:: virtual_interface_count
                
                	Enabled Virtual Interface Count
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: virtual_mlc_interface_name
                
                	Virtual master line card Interface
                	**type**\:  str
                
                .. attribute:: vpn_index
                
                	VPN Index
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf_id
                
                	VRF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Context, self).__init__()

                    self.yang_name = "context"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"remote-default-group" : ("remote_default_group", Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup), "rpf-default-table" : ("rpf_default_table", Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable)}
                    self._child_list_classes = {"anycast-rp-range" : ("anycast_rp_range", Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange), "export-route-target" : ("export_route_target", Ipv6Pim.Standby.DefaultContext.Context.ExportRouteTarget), "import-route-target" : ("import_route_target", Ipv6Pim.Standby.DefaultContext.Context.ImportRouteTarget)}

                    self.active_table_count = YLeaf(YType.uint32, "active-table-count")

                    self.allow_rp_configured = YLeaf(YType.boolean, "allow-rp-configured")

                    self.allow_rp_group_list = YLeaf(YType.str, "allow-rp-group-list")

                    self.allow_rp_rp_list = YLeaf(YType.str, "allow-rp-rp-list")

                    self.anycast_rp_configured = YLeaf(YType.boolean, "anycast-rp-configured")

                    self.anycast_rp_policy_name = YLeaf(YType.str, "anycast-rp-policy-name")

                    self.bgp_auto_discovery_configured = YLeaf(YType.boolean, "bgp-auto-discovery-configured")

                    self.bgp_auto_discovery_type = YLeaf(YType.uint32, "bgp-auto-discovery-type")

                    self.bgp_i_pmsi_added = YLeaf(YType.boolean, "bgp-i-pmsi-added")

                    self.bgp_remote_address = YLeaf(YType.str, "bgp-remote-address")

                    self.bgp_remote_interface = YLeaf(YType.str, "bgp-remote-interface")

                    self.bgp_remote_interface_name = YLeaf(YType.str, "bgp-remote-interface-name")

                    self.bgp_remote_on = YLeaf(YType.boolean, "bgp-remote-on")

                    self.bgp_remote_state = YLeaf(YType.uint32, "bgp-remote-state")

                    self.bgp_source_active_announce = YLeaf(YType.boolean, "bgp-source-active-announce")

                    self.gin_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-announce-interval")

                    self.gin_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-switchover-interval")

                    self.gin_b_and_mdt_interface = YLeaf(YType.str, "gin-b-and-mdt-interface")

                    self.gin_b_and_mdt_mtu = YLeaf(YType.uint32, "gin-b-and-mdt-mtu")

                    self.gin_b_and_mdt_name = YLeaf(YType.str, "gin-b-and-mdt-name")

                    self.gin_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "gin-b-and-mdt-rpf-identifier")

                    self.gin_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "gin-band-maximum-mdt-aggregation")

                    self.in_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-announce-interval")

                    self.in_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-switchover-interval")

                    self.in_b_and_mdt_interface = YLeaf(YType.str, "in-b-and-mdt-interface")

                    self.in_b_and_mdt_mtu = YLeaf(YType.uint32, "in-b-and-mdt-mtu")

                    self.in_b_and_mdt_name = YLeaf(YType.str, "in-b-and-mdt-name")

                    self.in_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "in-b-and-mdt-rpf-identifier")

                    self.in_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "in-band-maximum-mdt-aggregation")

                    self.in_band_signaling_local_enabled = YLeaf(YType.boolean, "in-band-signaling-local-enabled")

                    self.in_band_signaling_remote_enabled = YLeaf(YType.boolean, "in-band-signaling-remote-enabled")

                    self.inter_autonomous_system_enabled = YLeaf(YType.boolean, "inter-autonomous-system-enabled")

                    self.ir_maximum_mdt_aggregation = YLeaf(YType.uint32, "ir-maximum-mdt-aggregation")

                    self.ir_mdt_data_announce_interval = YLeaf(YType.uint32, "ir-mdt-data-announce-interval")

                    self.ir_mdt_data_switchover_interval = YLeaf(YType.uint32, "ir-mdt-data-switchover-interval")

                    self.ir_mdt_interface = YLeaf(YType.str, "ir-mdt-interface")

                    self.ir_mdt_mtu = YLeaf(YType.uint32, "ir-mdt-mtu")

                    self.ir_mdt_name = YLeaf(YType.str, "ir-mdt-name")

                    self.ir_mdt_rpf_identifier = YLeaf(YType.uint32, "ir-mdt-rpf-identifier")

                    self.ir_mdt_tail_label = YLeaf(YType.uint32, "ir-mdt-tail-label")

                    self.is_active = YLeaf(YType.boolean, "is-active")

                    self.is_active_ital = YLeaf(YType.boolean, "is-active-ital")

                    self.is_all_interface_disable_operation = YLeaf(YType.boolean, "is-all-interface-disable-operation")

                    self.is_auto_rp_listen_enabled = YLeaf(YType.boolean, "is-auto-rp-listen-enabled")

                    self.is_auto_rp_listen_sock_add = YLeaf(YType.boolean, "is-auto-rp-listen-sock-add")

                    self.is_create_gin_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-gin-b-and-mdt-interface")

                    self.is_create_in_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-in-b-and-mdt-interface")

                    self.is_create_ir_mdt_interface = YLeaf(YType.boolean, "is-create-ir-mdt-interface")

                    self.is_create_mdt_interface = YLeaf(YType.boolean, "is-create-mdt-interface")

                    self.is_create_mldp_mdt_interface = YLeaf(YType.boolean, "is-create-mldp-mdt-interface")

                    self.is_create_rsvp_te_mdt_interface = YLeaf(YType.boolean, "is-create-rsvp-te-mdt-interface")

                    self.is_default_granges = YLeaf(YType.boolean, "is-default-granges")

                    self.is_gin_b_and_mdt_owner = YLeaf(YType.boolean, "is-gin-b-and-mdt-owner")

                    self.is_in_b_and_mdt_owner = YLeaf(YType.boolean, "is-in-b-and-mdt-owner")

                    self.is_ir_mdt_owner = YLeaf(YType.boolean, "is-ir-mdt-owner")

                    self.is_lpts_socket_add_required = YLeaf(YType.boolean, "is-lpts-socket-add-required")

                    self.is_lpts_socket_added = YLeaf(YType.boolean, "is-lpts-socket-added")

                    self.is_m_host_publish_pending = YLeaf(YType.boolean, "is-m-host-publish-pending")

                    self.is_mdt_owner = YLeaf(YType.boolean, "is-mdt-owner")

                    self.is_mldp_mdt_owner = YLeaf(YType.boolean, "is-mldp-mdt-owner")

                    self.is_mrib_register = YLeaf(YType.boolean, "is-mrib-register")

                    self.is_multicast_rib_registration = YLeaf(YType.boolean, "is-multicast-rib-registration")

                    self.is_pim_nsf_rib_converge_received = YLeaf(YType.boolean, "is-pim-nsf-rib-converge-received")

                    self.is_pim_nsf_rib_converged = YLeaf(YType.boolean, "is-pim-nsf-rib-converged")

                    self.is_redistribution_reset = YLeaf(YType.boolean, "is-redistribution-reset")

                    self.is_register_injection_lpts_socket_add_required = YLeaf(YType.boolean, "is-register-injection-lpts-socket-add-required")

                    self.is_register_injection_lpts_socket_added = YLeaf(YType.boolean, "is-register-injection-lpts-socket-added")

                    self.is_register_injection_socket_add_required = YLeaf(YType.boolean, "is-register-injection-socket-add-required")

                    self.is_register_injection_socket_added = YLeaf(YType.boolean, "is-register-injection-socket-added")

                    self.is_rib_multipath_enabled = YLeaf(YType.boolean, "is-rib-multipath-enabled")

                    self.is_rib_multipath_interface_hash = YLeaf(YType.boolean, "is-rib-multipath-interface-hash")

                    self.is_rib_multipath_source_hash = YLeaf(YType.boolean, "is-rib-multipath-source-hash")

                    self.is_rib_multipath_source_next_hop_hash = YLeaf(YType.boolean, "is-rib-multipath-source-next-hop-hash")

                    self.is_routing_enabled = YLeaf(YType.boolean, "is-routing-enabled")

                    self.is_rsvp_te_mdt_owner = YLeaf(YType.boolean, "is-rsvp-te-mdt-owner")

                    self.is_socket_add_required = YLeaf(YType.boolean, "is-socket-add-required")

                    self.is_socket_added = YLeaf(YType.boolean, "is-socket-added")

                    self.is_udp_socket_add_required = YLeaf(YType.boolean, "is-udp-socket-add-required")

                    self.is_udp_socket_added = YLeaf(YType.boolean, "is-udp-socket-added")

                    self.is_udp_socket_bind = YLeaf(YType.boolean, "is-udp-socket-bind")

                    self.is_udp_socket_bind_required = YLeaf(YType.boolean, "is-udp-socket-bind-required")

                    self.is_unicast_rib_registration = YLeaf(YType.boolean, "is-unicast-rib-registration")

                    self.maximum_mdt_aggregation = YLeaf(YType.uint32, "maximum-mdt-aggregation")

                    self.mdt_data_announce_interval = YLeaf(YType.uint32, "mdt-data-announce-interval")

                    self.mdt_data_switchover_interval = YLeaf(YType.uint32, "mdt-data-switchover-interval")

                    self.mdt_default_group = YLeaf(YType.str, "mdt-default-group")

                    self.mdt_gre_remote_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-remote-rpf-identifier")

                    self.mdt_gre_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-rpf-identifier")

                    self.mdt_immediate_switch = YLeaf(YType.boolean, "mdt-immediate-switch")

                    self.mdt_interface = YLeaf(YType.str, "mdt-interface")

                    self.mdt_mtu = YLeaf(YType.uint32, "mdt-mtu")

                    self.mdt_neighbor_filter_name = YLeaf(YType.str, "mdt-neighbor-filter-name")

                    self.mdt_partitioned_ir_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-ir-control-identifier")

                    self.mdt_partitioned_mdt_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-mdt-control-identifier")

                    self.mdt_source = YLeaf(YType.str, "mdt-source")

                    self.mdt_source_interface = YLeaf(YType.str, "mdt-source-interface")

                    self.mhost_default_interface_config = YLeaf(YType.str, "mhost-default-interface-config")

                    self.mhost_interface = YLeaf(YType.str, "mhost-interface")

                    self.mldp_auto_rp_announce_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-announce-tree-added")

                    self.mldp_auto_rp_discovery_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-discovery-tree-added")

                    self.mldp_bsr_control_tree_added = YLeaf(YType.boolean, "mldp-bsr-control-tree-added")

                    self.mldp_control_head_lsm_identifier = YLeaf(YType.uint32, "mldp-control-head-lsm-identifier")

                    self.mldp_head_local_label = YLeaf(YType.uint32, "mldp-head-local-label")

                    self.mldp_head_lsm_identifier = YLeaf(YType.uint32, "mldp-head-lsm-identifier")

                    self.mldp_maximum_mdt_aggregation = YLeaf(YType.uint32, "mldp-maximum-mdt-aggregation")

                    self.mldp_mdt_data_announce_interval = YLeaf(YType.uint32, "mldp-mdt-data-announce-interval")

                    self.mldp_mdt_data_switchover_interval = YLeaf(YType.uint32, "mldp-mdt-data-switchover-interval")

                    self.mldp_mdt_interface = YLeaf(YType.str, "mldp-mdt-interface")

                    self.mldp_mdt_mtu = YLeaf(YType.uint32, "mldp-mdt-mtu")

                    self.mldp_mdt_name = YLeaf(YType.str, "mldp-mdt-name")

                    self.mldp_mdt_remote_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-remote-rpf-identifier")

                    self.mldp_mdt_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-rpf-identifier")

                    self.mldp_partioned_mp2m_ptree = YLeaf(YType.boolean, "mldp-partioned-mp2m-ptree")

                    self.mldp_partitioned_head_lsm_identifier = YLeaf(YType.uint32, "mldp-partitioned-head-lsm-identifier")

                    self.mldp_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-partitioned-mdt-configured")

                    self.mldp_partitioned_mdt_identifier = YLeaf(YType.uint32, "mldp-partitioned-mdt-identifier")

                    self.mldp_remote_head_lsm_identifier = YLeaf(YType.uint32, "mldp-remote-head-lsm-identifier")

                    self.mldp_remote_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-remote-partitioned-mdt-configured")

                    self.mldp_root_address = YLeafList(YType.uint32, "mldp-root-address")

                    self.mldp_root_count = YLeaf(YType.uint32, "mldp-root-count")

                    self.murib_id = YLeaf(YType.uint32, "murib-id")

                    self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                    self.non_default_vrf_count_on_socket = YLeaf(YType.uint32, "non-default-vrf-count-on-socket")

                    self.organization_unique_identifier = YLeaf(YType.uint32, "organization-unique-identifier")

                    self.p2mpte_li_drop = YLeaf(YType.uint32, "p2mpte-li-drop")

                    self.physical_interface_count = YLeaf(YType.uint64, "physical-interface-count")

                    self.redistribution_reset_count = YLeaf(YType.uint32, "redistribution-reset-count")

                    self.remote_table_id = YLeaf(YType.uint32, "remote-table-id")

                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                    self.rpf_id = YLeaf(YType.uint32, "rpf-id")

                    self.rpf_policy_name = YLeaf(YType.str, "rpf-policy-name")

                    self.rsvp_te_maximum_mdt_aggregation = YLeaf(YType.uint32, "rsvp-te-maximum-mdt-aggregation")

                    self.rsvp_te_mdt_data_announce_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-announce-interval")

                    self.rsvp_te_mdt_data_switchover_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-switchover-interval")

                    self.rsvp_te_mdt_interface = YLeaf(YType.str, "rsvp-te-mdt-interface")

                    self.rsvp_te_mdt_mtu = YLeaf(YType.uint32, "rsvp-te-mdt-mtu")

                    self.rsvp_te_mdt_name = YLeaf(YType.str, "rsvp-te-mdt-name")

                    self.rsvp_te_mdt_rpf_identifier = YLeaf(YType.uint32, "rsvp-te-mdt-rpf-identifier")

                    self.rsvp_te_mdt_static_p2mp_count = YLeaf(YType.uint32, "rsvp-te-mdt-static-p2mp-count")

                    self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                    self.sg_expiry_time = YLeaf(YType.uint16, "sg-expiry-time")

                    self.sg_expiry_timer_configured = YLeaf(YType.boolean, "sg-expiry-timer-configured")

                    self.sg_expiry_timer_sg_list = YLeaf(YType.str, "sg-expiry-timer-sg-list")

                    self.stale_rd_present = YLeaf(YType.boolean, "stale-rd-present")

                    self.suppress_pim_data_mdt_tlv = YLeaf(YType.boolean, "suppress-pim-data-mdt-tlv")

                    self.suppress_shared_tree_join = YLeaf(YType.boolean, "suppress-shared-tree-join")

                    self.table_count = YLeaf(YType.uint32, "table-count")

                    self.table_id = YLeaf(YType.uint32, "table-id")

                    self.umh = YLeaf(YType.boolean, "umh")

                    self.valid_rd_present = YLeaf(YType.boolean, "valid-rd-present")

                    self.virtual_interface_count = YLeaf(YType.uint64, "virtual-interface-count")

                    self.virtual_mlc_interface_name = YLeaf(YType.str, "virtual-mlc-interface-name")

                    self.vpn_index = YLeaf(YType.uint32, "vpn-index")

                    self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                    self.remote_default_group = Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup()
                    self.remote_default_group.parent = self
                    self._children_name_map["remote_default_group"] = "remote-default-group"
                    self._children_yang_names.add("remote-default-group")

                    self.rpf_default_table = Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable()
                    self.rpf_default_table.parent = self
                    self._children_name_map["rpf_default_table"] = "rpf-default-table"
                    self._children_yang_names.add("rpf-default-table")

                    self.anycast_rp_range = YList(self)
                    self.export_route_target = YList(self)
                    self.import_route_target = YList(self)
                    self._segment_path = lambda: "context"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Context, ['active_table_count', 'allow_rp_configured', 'allow_rp_group_list', 'allow_rp_rp_list', 'anycast_rp_configured', 'anycast_rp_policy_name', 'bgp_auto_discovery_configured', 'bgp_auto_discovery_type', 'bgp_i_pmsi_added', 'bgp_remote_address', 'bgp_remote_interface', 'bgp_remote_interface_name', 'bgp_remote_on', 'bgp_remote_state', 'bgp_source_active_announce', 'gin_b_and_mdt_data_announce_interval', 'gin_b_and_mdt_data_switchover_interval', 'gin_b_and_mdt_interface', 'gin_b_and_mdt_mtu', 'gin_b_and_mdt_name', 'gin_b_and_mdt_rpf_identifier', 'gin_band_maximum_mdt_aggregation', 'in_b_and_mdt_data_announce_interval', 'in_b_and_mdt_data_switchover_interval', 'in_b_and_mdt_interface', 'in_b_and_mdt_mtu', 'in_b_and_mdt_name', 'in_b_and_mdt_rpf_identifier', 'in_band_maximum_mdt_aggregation', 'in_band_signaling_local_enabled', 'in_band_signaling_remote_enabled', 'inter_autonomous_system_enabled', 'ir_maximum_mdt_aggregation', 'ir_mdt_data_announce_interval', 'ir_mdt_data_switchover_interval', 'ir_mdt_interface', 'ir_mdt_mtu', 'ir_mdt_name', 'ir_mdt_rpf_identifier', 'ir_mdt_tail_label', 'is_active', 'is_active_ital', 'is_all_interface_disable_operation', 'is_auto_rp_listen_enabled', 'is_auto_rp_listen_sock_add', 'is_create_gin_b_and_mdt_interface', 'is_create_in_b_and_mdt_interface', 'is_create_ir_mdt_interface', 'is_create_mdt_interface', 'is_create_mldp_mdt_interface', 'is_create_rsvp_te_mdt_interface', 'is_default_granges', 'is_gin_b_and_mdt_owner', 'is_in_b_and_mdt_owner', 'is_ir_mdt_owner', 'is_lpts_socket_add_required', 'is_lpts_socket_added', 'is_m_host_publish_pending', 'is_mdt_owner', 'is_mldp_mdt_owner', 'is_mrib_register', 'is_multicast_rib_registration', 'is_pim_nsf_rib_converge_received', 'is_pim_nsf_rib_converged', 'is_redistribution_reset', 'is_register_injection_lpts_socket_add_required', 'is_register_injection_lpts_socket_added', 'is_register_injection_socket_add_required', 'is_register_injection_socket_added', 'is_rib_multipath_enabled', 'is_rib_multipath_interface_hash', 'is_rib_multipath_source_hash', 'is_rib_multipath_source_next_hop_hash', 'is_routing_enabled', 'is_rsvp_te_mdt_owner', 'is_socket_add_required', 'is_socket_added', 'is_udp_socket_add_required', 'is_udp_socket_added', 'is_udp_socket_bind', 'is_udp_socket_bind_required', 'is_unicast_rib_registration', 'maximum_mdt_aggregation', 'mdt_data_announce_interval', 'mdt_data_switchover_interval', 'mdt_default_group', 'mdt_gre_remote_rpf_identifier', 'mdt_gre_rpf_identifier', 'mdt_immediate_switch', 'mdt_interface', 'mdt_mtu', 'mdt_neighbor_filter_name', 'mdt_partitioned_ir_control_identifier', 'mdt_partitioned_mdt_control_identifier', 'mdt_source', 'mdt_source_interface', 'mhost_default_interface_config', 'mhost_interface', 'mldp_auto_rp_announce_tree_added', 'mldp_auto_rp_discovery_tree_added', 'mldp_bsr_control_tree_added', 'mldp_control_head_lsm_identifier', 'mldp_head_local_label', 'mldp_head_lsm_identifier', 'mldp_maximum_mdt_aggregation', 'mldp_mdt_data_announce_interval', 'mldp_mdt_data_switchover_interval', 'mldp_mdt_interface', 'mldp_mdt_mtu', 'mldp_mdt_name', 'mldp_mdt_remote_rpf_identifier', 'mldp_mdt_rpf_identifier', 'mldp_partioned_mp2m_ptree', 'mldp_partitioned_head_lsm_identifier', 'mldp_partitioned_mdt_configured', 'mldp_partitioned_mdt_identifier', 'mldp_remote_head_lsm_identifier', 'mldp_remote_partitioned_mdt_configured', 'mldp_root_address', 'mldp_root_count', 'murib_id', 'neighbor_filter_name', 'non_default_vrf_count_on_socket', 'organization_unique_identifier', 'p2mpte_li_drop', 'physical_interface_count', 'redistribution_reset_count', 'remote_table_id', 'route_distinguisher', 'rpf_id', 'rpf_policy_name', 'rsvp_te_maximum_mdt_aggregation', 'rsvp_te_mdt_data_announce_interval', 'rsvp_te_mdt_data_switchover_interval', 'rsvp_te_mdt_interface', 'rsvp_te_mdt_mtu', 'rsvp_te_mdt_name', 'rsvp_te_mdt_rpf_identifier', 'rsvp_te_mdt_static_p2mp_count', 'rump_enabled', 'sg_expiry_time', 'sg_expiry_timer_configured', 'sg_expiry_timer_sg_list', 'stale_rd_present', 'suppress_pim_data_mdt_tlv', 'suppress_shared_tree_join', 'table_count', 'table_id', 'umh', 'valid_rd_present', 'virtual_interface_count', 'virtual_mlc_interface_name', 'vpn_index', 'vrf_id'], name, value)


                class AnycastRpRange(Entity):
                    """
                    Anycast\-RP Ranges
                    
                    .. attribute:: ancast_rp_marked
                    
                    	Anycast\-RP Range marked
                    	**type**\:  bool
                    
                    .. attribute:: prefix
                    
                    	Anycast\-RP Range Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Anycast\-RP Range Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange, self).__init__()

                        self.yang_name = "anycast-rp-range"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"prefix" : ("prefix", Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix)}
                        self._child_list_classes = {}

                        self.ancast_rp_marked = YLeaf(YType.boolean, "ancast-rp-marked")

                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                        self.prefix = Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._children_yang_names.add("prefix")
                        self._segment_path = lambda: "anycast-rp-range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange, ['ancast_rp_marked', 'prefix_length'], name, value)


                    class Prefix(Entity):
                        """
                        Anycast\-RP Range Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "anycast-rp-range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "prefix"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/context/anycast-rp-range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class ExportRouteTarget(Entity):
                    """
                    Export Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Context.ExportRouteTarget, self).__init__()

                        self.yang_name = "export-route-target"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                        self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                        self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                        self.configured = YLeaf(YType.boolean, "configured")

                        self.route_target = YLeaf(YType.str, "route-target")

                        self.segment_border = YLeaf(YType.boolean, "segment-border")

                        self.update_pending = YLeaf(YType.boolean, "update-pending")
                        self._segment_path = lambda: "export-route-target"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Context.ExportRouteTarget, ['anycast_rp', 'anycast_rp_marked', 'bgp_auto_discovery', 'configured', 'route_target', 'segment_border', 'update_pending'], name, value)


                class ImportRouteTarget(Entity):
                    """
                    Import Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Context.ImportRouteTarget, self).__init__()

                        self.yang_name = "import-route-target"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                        self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                        self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                        self.configured = YLeaf(YType.boolean, "configured")

                        self.route_target = YLeaf(YType.str, "route-target")

                        self.segment_border = YLeaf(YType.boolean, "segment-border")

                        self.update_pending = YLeaf(YType.boolean, "update-pending")
                        self._segment_path = lambda: "import-route-target"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Context.ImportRouteTarget, ['anycast_rp', 'anycast_rp_marked', 'bgp_auto_discovery', 'configured', 'route_target', 'segment_border', 'update_pending'], name, value)


                class RemoteDefaultGroup(Entity):
                    """
                    Remote Default Group
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup, self).__init__()

                        self.yang_name = "remote-default-group"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.af_name = YLeaf(YType.enumeration, "af-name")

                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                        self._segment_path = lambda: "remote-default-group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class RpfDefaultTable(Entity):
                    """
                    RPF Default Table
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable, self).__init__()

                        self.yang_name = "rpf-default-table"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.uint32, "afi")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                        self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.safi = YLeaf(YType.uint32, "safi")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.table_name = YLeaf(YType.str, "table-name")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")
                        self._segment_path = lambda: "rpf-default-table"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable, ['afi', 'is_active', 'is_ital_registration_done', 'is_rib_convergence', 'is_rib_convergence_received', 'is_rib_registration_done', 'rpf_registrations', 'safi', 'table_id', 'table_name', 'vrf_id'], name, value)


            class GlobalInterfaces(Entity):
                """
                PIM global interface table
                
                .. attribute:: global_interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`GlobalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces, self).__init__()

                    self.yang_name = "global-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"global-interface" : ("global_interface", Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface)}

                    self.global_interface = YList(self)
                    self._segment_path = lambda: "global-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces, [], name, value)


                class GlobalInterface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface, self).__init__()

                        self.yang_name = "global-interface"
                        self.yang_parent_name = "global-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"dr-address" : ("dr_address", Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress)}
                        self._child_list_classes = {"interface-address" : ("interface_address", Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "global-interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/global-interfaces/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "global-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "dr-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "global-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "interface-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Gre(Entity):
                """
                GRE information
                
                .. attribute:: gre_hashes
                
                	GRE hash
                	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreHashes>`
                
                .. attribute:: gre_next_hops
                
                	GRE destination neighbor table
                	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Gre, self).__init__()

                    self.yang_name = "gre"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"gre-hashes" : ("gre_hashes", Ipv6Pim.Standby.DefaultContext.Gre.GreHashes), "gre-next-hops" : ("gre_next_hops", Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops)}
                    self._child_list_classes = {}

                    self.gre_hashes = Ipv6Pim.Standby.DefaultContext.Gre.GreHashes()
                    self.gre_hashes.parent = self
                    self._children_name_map["gre_hashes"] = "gre-hashes"
                    self._children_yang_names.add("gre-hashes")

                    self.gre_next_hops = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops()
                    self.gre_next_hops.parent = self
                    self._children_name_map["gre_next_hops"] = "gre-next-hops"
                    self._children_yang_names.add("gre-next-hops")
                    self._segment_path = lambda: "gre"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()


                class GreHashes(Entity):
                    """
                    GRE hash
                    
                    .. attribute:: gre_hash
                    
                    	PIM GRE Hashed Underlying Interface
                    	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreHashes.GreHash>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Gre.GreHashes, self).__init__()

                        self.yang_name = "gre-hashes"
                        self.yang_parent_name = "gre"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"gre-hash" : ("gre_hash", Ipv6Pim.Standby.DefaultContext.Gre.GreHashes.GreHash)}

                        self.gre_hash = YList(self)
                        self._segment_path = lambda: "gre-hashes"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/gre/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Gre.GreHashes, [], name, value)


                    class GreHash(Entity):
                        """
                        PIM GRE Hashed Underlying Interface
                        
                        .. attribute:: source_address  <key>
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: destination_address  <key>
                        
                        	Destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: ifname  <key>
                        
                        	GRE Tunnel Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: next_hop_interface
                        
                        	Next hop neighbor interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Gre.GreHashes.GreHash, self).__init__()

                            self.yang_name = "gre-hash"
                            self.yang_parent_name = "gre-hashes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.ifname = YLeaf(YType.str, "ifname")

                            self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")
                            self._segment_path = lambda: "gre-hash" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[ifname='" + self.ifname.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/gre/gre-hashes/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Gre.GreHashes.GreHash, ['source_address', 'destination_address', 'ifname', 'next_hop_interface'], name, value)


                class GreNextHops(Entity):
                    """
                    GRE destination neighbor table
                    
                    .. attribute:: gre_next_hop
                    
                    	PIM GRE address next\-hop information
                    	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops, self).__init__()

                        self.yang_name = "gre-next-hops"
                        self.yang_parent_name = "gre"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"gre-next-hop" : ("gre_next_hop", Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop)}

                        self.gre_next_hop = YList(self)
                        self._segment_path = lambda: "gre-next-hops"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/gre/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops, [], name, value)


                    class GreNextHop(Entity):
                        """
                        PIM GRE address next\-hop information
                        
                        .. attribute:: destination_address  <key>
                        
                        	GRE destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: gre_path
                        
                        	GRE Paths list
                        	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath>`
                        
                        .. attribute:: is_connected
                        
                        	Are we connected ?
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: registered_address
                        
                        	Address registered
                        	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop, self).__init__()

                            self.yang_name = "gre-next-hop"
                            self.yang_parent_name = "gre-next-hops"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"registered-address" : ("registered_address", Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress)}
                            self._child_list_classes = {"gre-path" : ("gre_path", Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath)}

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.is_connected = YLeaf(YType.uint8, "is-connected")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                            self.registered_address = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                            self.registered_address.parent = self
                            self._children_name_map["registered_address"] = "registered-address"
                            self._children_yang_names.add("registered-address")

                            self.gre_path = YList(self)
                            self._segment_path = lambda: "gre-next-hop" + "[destination-address='" + self.destination_address.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/gre/gre-next-hops/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop, ['destination_address', 'is_connected', 'metric', 'metric_preference'], name, value)


                        class GrePath(Entity):
                            """
                            GRE Paths list
                            
                            .. attribute:: extranet_vrf_name
                            
                            	Extranet VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: gre_interface_name
                            
                            	GRE Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: gre_neighbor
                            
                            	GRE neighbor
                            	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                            
                            .. attribute:: gre_next_hop
                            
                            	GRE nexthop
                            	**type**\:   :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop>`
                            
                            .. attribute:: is_connector_attribute_present
                            
                            	Connector attribute present
                            	**type**\:  bool
                            
                            .. attribute:: is_gre_interface_disabled
                            
                            	Is the gre interface disabled ?
                            	**type**\:  bool
                            
                            .. attribute:: is_via_lsm
                            
                            	Via LSM
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                self.yang_name = "gre-path"
                                self.yang_parent_name = "gre-next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"gre-neighbor" : ("gre_neighbor", Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor), "gre-next-hop" : ("gre_next_hop", Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop)}
                                self._child_list_classes = {}

                                self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                self.gre_interface_name = YLeaf(YType.str, "gre-interface-name")

                                self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                self.is_gre_interface_disabled = YLeaf(YType.boolean, "is-gre-interface-disabled")

                                self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                self.gre_neighbor = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                self.gre_neighbor.parent = self
                                self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                self._children_yang_names.add("gre-neighbor")

                                self.gre_next_hop = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                self.gre_next_hop.parent = self
                                self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                self._children_yang_names.add("gre-next-hop")
                                self._segment_path = lambda: "gre-path"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, ['extranet_vrf_name', 'gre_interface_name', 'is_connector_attribute_present', 'is_gre_interface_disabled', 'is_via_lsm'], name, value)


                            class GreNeighbor(Entity):
                                """
                                GRE neighbor
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                    self.yang_name = "gre-neighbor"
                                    self.yang_parent_name = "gre-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "gre-neighbor"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class GreNextHop(Entity):
                                """
                                GRE nexthop
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__init__()

                                    self.yang_name = "gre-next-hop"
                                    self.yang_parent_name = "gre-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "gre-next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RegisteredAddress(Entity):
                            """
                            Address registered
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                self.yang_name = "registered-address"
                                self.yang_parent_name = "gre-next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "registered-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class GroupMapRpfs(Entity):
                """
                PIM group mapping information
                
                .. attribute:: group_map_rpf
                
                	PIM group mapping entry
                	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs, self).__init__()

                    self.yang_name = "group-map-rpfs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"group-map-rpf" : ("group_map_rpf", Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf)}

                    self.group_map_rpf = YList(self)
                    self._segment_path = lambda: "group-map-rpfs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs, [], name, value)


                class GroupMapRpf(Entity):
                    """
                    PIM group mapping entry
                    
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_priority
                    
                    	RP priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__init__()

                        self.yang_name = "group-map-rpf"
                        self.yang_parent_name = "group-map-rpfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-map-information" : ("group_map_information", Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation), "rpf-neighbor" : ("rpf_neighbor", Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor)}
                        self._child_list_classes = {}

                        self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                        self.client = YLeaf(YType.enumeration, "client")

                        self.prefix = YLeaf(YType.str, "prefix")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_priority = YLeaf(YType.int32, "rp-priority")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.group_map_information = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")
                        self._segment_path = lambda: "group-map-rpf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-rpfs/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf, ['are_we_rp', 'client', 'prefix', 'prefix_length', 'protocol', 'rp_address', 'rp_priority', 'rpf_interface_name', 'rpf_vrf_name'], name, value)


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-rpf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"prefix" : ("prefix", Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix), "rp-address" : ("rp_address", Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress)}
                            self._child_list_classes = {}

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")
                            self._segment_path = lambda: "group-map-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-rpfs/group-map-rpf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, ['client', 'group_count', 'is_override', 'is_used', 'mrib_active', 'prefix_length', 'priority', 'protocol'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "group-map-rpf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-rpfs/group-map-rpf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class GroupMapSources(Entity):
                """
                PIM group\-mapping with source information
                
                .. attribute:: group_map_source
                
                	PIM Group Mapping Entry with source information
                	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.GroupMapSources, self).__init__()

                    self.yang_name = "group-map-sources"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"group-map-source" : ("group_map_source", Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource)}

                    self.group_map_source = YList(self)
                    self._segment_path = lambda: "group-map-sources"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapSources, [], name, value)


                class GroupMapSource(Entity):
                    """
                    PIM Group Mapping Entry with source information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: priority
                    
                    	RP Priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource, self).__init__()

                        self.yang_name = "group-map-source"
                        self.yang_parent_name = "group-map-sources"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-map-information" : ("group_map_information", Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation), "source-of-information" : ("source_of_information", Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation)}
                        self._child_list_classes = {}

                        self.client = YLeaf(YType.enumeration, "client")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.holdtime = YLeaf(YType.int32, "holdtime")

                        self.prefix = YLeaf(YType.str, "prefix")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.priority = YLeaf(YType.int32, "priority")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_map_information = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.source_of_information = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")
                        self._segment_path = lambda: "group-map-source"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-sources/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource, ['client', 'expires', 'holdtime', 'prefix', 'prefix_length', 'priority', 'protocol', 'rp_address', 'uptime'], name, value)


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"prefix" : ("prefix", Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix), "rp-address" : ("rp_address", Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress)}
                            self._child_list_classes = {}

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")
                            self._segment_path = lambda: "group-map-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-sources/group-map-source/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, ['client', 'group_count', 'is_override', 'is_used', 'mrib_active', 'prefix_length', 'priority', 'protocol'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-sources/group-map-source/group-map-information/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-sources/group-map-source/group-map-information/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceOfInformation(Entity):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "group-map-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-of-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-sources/group-map-source/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class IfrsInterfaces(Entity):
                """
                PIM interfaces in forward reference store table
                
                .. attribute:: ifrs_interface
                
                	PIM IFRS interface information
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"ifrs-interface" : ("ifrs_interface", Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface)}

                    self.ifrs_interface = YList(self)
                    self._segment_path = lambda: "ifrs-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces, [], name, value)


                class IfrsInterface(Entity):
                    """
                    PIM IFRS interface information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"dr-address" : ("dr_address", Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress)}
                        self._child_list_classes = {"interface-address" : ("interface_address", Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ifrs-interfaces/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "dr-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "interface-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class IfrsSummary(Entity):
                """
                PIM interfaces in forward reference store
                summary
                
                .. attribute:: configuration_count
                
                	Configuration counts
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Number of interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.IfrsSummary, self).__init__()

                    self.yang_name = "ifrs-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                    self.interface_count = YLeaf(YType.uint32, "interface-count")
                    self._segment_path = lambda: "ifrs-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.IfrsSummary, ['configuration_count', 'interface_count'], name, value)


            class InterfaceOldFormats(Entity):
                """
                PIM interfaces in old format
                
                .. attribute:: interface_old_format
                
                	PIM interface name
                	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats, self).__init__()

                    self.yang_name = "interface-old-formats"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-old-format" : ("interface_old_format", Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat)}

                    self.interface_old_format = YList(self)
                    self._segment_path = lambda: "interface-old-formats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats, [], name, value)


                class InterfaceOldFormat(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                        self.yang_name = "interface-old-format"
                        self.yang_parent_name = "interface-old-formats"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"dr-address" : ("dr_address", Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress)}
                        self._child_list_classes = {"interface-address" : ("interface_address", Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "interface-old-format" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/interface-old-formats/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "dr-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "interface-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceStatistics(Entity):
                """
                PIM interface statistics
                
                .. attribute:: interface_statistic
                
                	PIM interface statistics
                	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.InterfaceStatistics, self).__init__()

                    self.yang_name = "interface-statistics"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-statistic" : ("interface_statistic", Ipv6Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic)}

                    self.interface_statistic = YList(self)
                    self._segment_path = lambda: "interface-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.InterfaceStatistics, [], name, value)


                class InterfaceStatistic(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_ack_message
                    
                    	Input Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_message
                    
                    	Input Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_miscellaneous
                    
                    	Miscellaneous packet in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register
                    
                    	Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_ack_message
                    
                    	Output Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_message
                    
                    	Output Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register
                    
                    	Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__init__()

                        self.yang_name = "interface-statistic"
                        self.yang_parent_name = "interface-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.input_assert = YLeaf(YType.uint32, "input-assert")

                        self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                        self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                        self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                        self.input_graft_ack_message = YLeaf(YType.uint32, "input-graft-ack-message")

                        self.input_graft_message = YLeaf(YType.uint32, "input-graft-message")

                        self.input_hello = YLeaf(YType.uint32, "input-hello")

                        self.input_jp = YLeaf(YType.uint32, "input-jp")

                        self.input_miscellaneous = YLeaf(YType.uint32, "input-miscellaneous")

                        self.input_register = YLeaf(YType.uint32, "input-register")

                        self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                        self.output_assert = YLeaf(YType.uint32, "output-assert")

                        self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                        self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                        self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                        self.output_graft_ack_message = YLeaf(YType.uint32, "output-graft-ack-message")

                        self.output_graft_message = YLeaf(YType.uint32, "output-graft-message")

                        self.output_hello = YLeaf(YType.uint32, "output-hello")

                        self.output_jp = YLeaf(YType.uint32, "output-jp")

                        self.output_register = YLeaf(YType.uint32, "output-register")

                        self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")
                        self._segment_path = lambda: "interface-statistic" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/interface-statistics/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic, ['interface_name', 'input_assert', 'input_bsr_message', 'input_candidate_rp_advertisement', 'input_df_election', 'input_graft_ack_message', 'input_graft_message', 'input_hello', 'input_jp', 'input_miscellaneous', 'input_register', 'input_register_stop', 'output_assert', 'output_bsr_message', 'output_candidate_rp_advertisement', 'output_df_election', 'output_graft_ack_message', 'output_graft_message', 'output_hello', 'output_jp', 'output_register', 'output_register_stop'], name, value)


            class Interfaces(Entity):
                """
                PIM interfaces
                
                .. attribute:: interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Interfaces.Interface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface" : ("interface", Ipv6Pim.Standby.DefaultContext.Interfaces.Interface)}

                    self.interface = YList(self)
                    self._segment_path = lambda: "interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Interfaces, [], name, value)


                class Interface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"dr-address" : ("dr_address", Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress)}
                        self._child_list_classes = {"interface-address" : ("interface_address", Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/interfaces/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "dr-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "interface-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class JpStatistics(Entity):
                """
                PIM join prune statistics table
                
                .. attribute:: jp_statistic
                
                	PIM Join Prune Statistics
                	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.JpStatistics.JpStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.JpStatistics, self).__init__()

                    self.yang_name = "jp-statistics"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"jp-statistic" : ("jp_statistic", Ipv6Pim.Standby.DefaultContext.JpStatistics.JpStatistic)}

                    self.jp_statistic = YList(self)
                    self._segment_path = lambda: "jp-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.JpStatistics, [], name, value)


                class JpStatistic(Entity):
                    """
                    PIM Join Prune Statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mtu
                    
                    	Interface MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received
                    
                    	Received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received100
                    
                    	Received 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_10k
                    
                    	Received 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_1k
                    
                    	Received 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_50k
                    
                    	Deprecated by Received100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted
                    
                    	Transmitted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted100
                    
                    	Transmitted 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_10k
                    
                    	Transmitted 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_1k
                    
                    	Transmitted 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_50k
                    
                    	Deprecated by Transmitted100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.JpStatistics.JpStatistic, self).__init__()

                        self.yang_name = "jp-statistic"
                        self.yang_parent_name = "jp-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.received = YLeaf(YType.uint32, "received")

                        self.received100 = YLeaf(YType.uint16, "received100")

                        self.received_10k = YLeaf(YType.uint16, "received-10k")

                        self.received_1k = YLeaf(YType.uint16, "received-1k")

                        self.received_50k = YLeaf(YType.uint16, "received-50k")

                        self.transmitted = YLeaf(YType.uint32, "transmitted")

                        self.transmitted100 = YLeaf(YType.uint16, "transmitted100")

                        self.transmitted_10k = YLeaf(YType.uint16, "transmitted-10k")

                        self.transmitted_1k = YLeaf(YType.uint16, "transmitted-1k")

                        self.transmitted_50k = YLeaf(YType.uint16, "transmitted-50k")
                        self._segment_path = lambda: "jp-statistic" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/jp-statistics/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.JpStatistics.JpStatistic, ['interface_name', 'interface_name_xr', 'mtu', 'received', 'received100', 'received_10k', 'received_1k', 'received_50k', 'transmitted', 'transmitted100', 'transmitted_10k', 'transmitted_1k', 'transmitted_50k'], name, value)


            class MibDatabases(Entity):
                """
                PIM group database for mroute mibs table
                
                .. attribute:: mib_database
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.MibDatabases, self).__init__()

                    self.yang_name = "mib-databases"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"mib-database" : ("mib_database", Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase)}

                    self.mib_database = YList(self)
                    self._segment_path = lambda: "mib-databases"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MibDatabases, [], name, value)


                class MibDatabase(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: assert_metric
                    
                    	Assert Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_metric_preference
                    
                    	Assert Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_rpt_bit
                    
                    	Assert RPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: bidirectional_route
                    
                    	Is this Bidir ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Multicast satic route group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr>`
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface name 
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: rpf_mask
                    
                    	Mask of the multicast root
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_neighbor
                    
                    	The RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: source_address
                    
                    	Multicast static route source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr>`
                    
                    .. attribute:: source_netmask
                    
                    	Source mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: spt_bit
                    
                    	Is SPT bit set ?
                    	**type**\:  bool
                    
                    .. attribute:: upstream_assert_timer
                    
                    	Upstream Assert Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime of route
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase, self).__init__()

                        self.yang_name = "mib-database"
                        self.yang_parent_name = "mib-databases"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr), "rpf-neighbor" : ("rpf_neighbor", Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor), "rpf-root" : ("rpf_root", Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot), "source-address-xr" : ("source_address_xr", Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr)}
                        self._child_list_classes = {}

                        self.assert_metric = YLeaf(YType.uint32, "assert-metric")

                        self.assert_metric_preference = YLeaf(YType.uint32, "assert-metric-preference")

                        self.assert_rpt_bit = YLeaf(YType.boolean, "assert-rpt-bit")

                        self.bidirectional_route = YLeaf(YType.boolean, "bidirectional-route")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                        self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_mask = YLeaf(YType.uint32, "rpf-mask")

                        self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                        self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.source_netmask = YLeaf(YType.int32, "source-netmask")

                        self.spt_bit = YLeaf(YType.boolean, "spt-bit")

                        self.upstream_assert_timer = YLeaf(YType.int32, "upstream-assert-timer")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_address_xr = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                        self.rpf_root = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._children_yang_names.add("rpf-root")

                        self.source_address_xr = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"
                        self._children_yang_names.add("source-address-xr")
                        self._segment_path = lambda: "mib-database"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/mib-databases/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase, ['assert_metric', 'assert_metric_preference', 'assert_rpt_bit', 'bidirectional_route', 'group_address', 'protocol', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_mask', 'rpf_safi', 'rpf_table_name', 'rpf_vrf_name', 'source_address', 'source_netmask', 'spt_bit', 'upstream_assert_timer', 'uptime'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/mib-databases/mib-database/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        The RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/mib-databases/mib-database/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-root"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/mib-databases/mib-database/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/mib-databases/mib-database/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class MulticastStaticRoutes(Entity):
                """
                PIM multicast static route table
                
                .. attribute:: multicast_static_route
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes, self).__init__()

                    self.yang_name = "multicast-static-routes"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"multicast-static-route" : ("multicast_static_route", Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute)}

                    self.multicast_static_route = YList(self)
                    self._segment_path = lambda: "multicast-static-routes"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes, [], name, value)


                class MulticastStaticRoute(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: address
                    
                    	Network address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: distance
                    
                    	Distance
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_via_lsm
                    
                    	LSM flag
                    	**type**\:  bool
                    
                    .. attribute:: nexthop
                    
                    	Next Hop
                    	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: prefix_length_xr
                    
                    	Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                        self.yang_name = "multicast-static-route"
                        self.yang_parent_name = "multicast-static-routes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"nexthop" : ("nexthop", Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop), "prefix" : ("prefix", Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix)}
                        self._child_list_classes = {}

                        self.address = YLeaf(YType.str, "address")

                        self.distance = YLeaf(YType.uint32, "distance")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                        self.nexthop = Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                        self.nexthop.parent = self
                        self._children_name_map["nexthop"] = "nexthop"
                        self._children_yang_names.add("nexthop")

                        self.prefix = Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._children_yang_names.add("prefix")
                        self._segment_path = lambda: "multicast-static-route"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/multicast-static-routes/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, ['address', 'distance', 'interface_name', 'is_via_lsm', 'prefix_length', 'prefix_length_xr'], name, value)


                    class Nexthop(Entity):
                        """
                        Next Hop
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                            self.yang_name = "nexthop"
                            self.yang_parent_name = "multicast-static-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "nexthop"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/multicast-static-routes/multicast-static-route/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Prefix(Entity):
                        """
                        Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "multicast-static-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "prefix"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/multicast-static-routes/multicast-static-route/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class NeighborOldFormats(Entity):
                """
                PIM neighbor table old format
                
                .. attribute:: neighbor_old_format
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats, self).__init__()

                    self.yang_name = "neighbor-old-formats"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"neighbor-old-format" : ("neighbor_old_format", Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat)}

                    self.neighbor_old_format = YList(self)
                    self._segment_path = lambda: "neighbor-old-formats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats, [], name, value)


                class NeighborOldFormat(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__init__()

                        self.yang_name = "neighbor-old-format"
                        self.yang_parent_name = "neighbor-old-formats"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr)}

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                        self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                        self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.neighbor_address_xr = YList(self)
                        self._segment_path = lambda: "neighbor-old-format"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/neighbor-old-formats/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat, ['dr_priority', 'expires', 'expiry_timer', 'interface_name', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bfd_state', 'is_bidirectional_capable', 'is_dr_priority_capable', 'is_ecmp_redirect_capable', 'is_proxy_capable', 'is_this_neighbor_dr', 'is_this_neighbor_us', 'neighbor_address', 'override_interval', 'propagation_delay', 'uptime'], name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "neighbor-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/neighbor-old-formats/neighbor-old-format/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class NeighborSummaries(Entity):
                """
                PIM neighbor summary table
                
                .. attribute:: neighbor_summary
                
                	PIM neighbor summary information
                	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.NeighborSummaries, self).__init__()

                    self.yang_name = "neighbor-summaries"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"neighbor-summary" : ("neighbor_summary", Ipv6Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary)}

                    self.neighbor_summary = YList(self)
                    self._segment_path = lambda: "neighbor-summaries"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NeighborSummaries, [], name, value)


                class NeighborSummary(Entity):
                    """
                    PIM neighbor summary information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: number_of_external_neighbors
                    
                    	Number of external neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary, self).__init__()

                        self.yang_name = "neighbor-summary"
                        self.yang_parent_name = "neighbor-summaries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.number_of_external_neighbors = YLeaf(YType.int32, "number-of-external-neighbors")

                        self.number_of_neighbors = YLeaf(YType.int32, "number-of-neighbors")
                        self._segment_path = lambda: "neighbor-summary" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/neighbor-summaries/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary, ['interface_name', 'number_of_external_neighbors', 'number_of_neighbors'], name, value)


            class Neighbors(Entity):
                """
                PIM neighbor table
                
                .. attribute:: neighbor
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Neighbors, self).__init__()

                    self.yang_name = "neighbors"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"neighbor" : ("neighbor", Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor)}

                    self.neighbor = YList(self)
                    self._segment_path = lambda: "neighbors"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Neighbors, [], name, value)


                class Neighbor(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "neighbors"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr)}

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                        self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                        self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.neighbor_address_xr = YList(self)
                        self._segment_path = lambda: "neighbor"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/neighbors/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor, ['dr_priority', 'expires', 'expiry_timer', 'interface_name', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bfd_state', 'is_bidirectional_capable', 'is_dr_priority_capable', 'is_ecmp_redirect_capable', 'is_proxy_capable', 'is_this_neighbor_dr', 'is_this_neighbor_us', 'neighbor_address', 'override_interval', 'propagation_delay', 'uptime'], name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "neighbor-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/neighbors/neighbor/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class NetIoTunnels(Entity):
                """
                Tunnel information that NETIO has 
                
                .. attribute:: net_io_tunnel
                
                	PIM netio tunnel information
                	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels, self).__init__()

                    self.yang_name = "net-io-tunnels"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"net-io-tunnel" : ("net_io_tunnel", Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel)}

                    self.net_io_tunnel = YList(self)
                    self._segment_path = lambda: "net-io-tunnels"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NetIoTunnels, [], name, value)


                class NetIoTunnel(Entity):
                    """
                    PIM netio tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel, self).__init__()

                        self.yang_name = "net-io-tunnel"
                        self.yang_parent_name = "net-io-tunnels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-netio" : ("group_address_netio", Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio), "rp-address" : ("rp_address", Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress), "source-address" : ("source_address", Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress), "source-address-netio" : ("source_address_netio", Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio)}
                        self._child_list_classes = {}

                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.group_address_netio = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._children_yang_names.add("group-address-netio")

                        self.rp_address = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                        self.source_address_netio = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"
                        self._children_yang_names.add("source-address-netio")
                        self._segment_path = lambda: "net-io-tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/net-io-tunnels/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel, ['tunnel_name', 'vrf_name'], name, value)


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-netio"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address-netio"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Ranges(Entity):
                """
                PIM range list information
                
                .. attribute:: range
                
                	PIM range list information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"range" : ("range", Ipv6Pim.Standby.DefaultContext.Ranges.Range)}

                    self.range = YList(self)
                    self._segment_path = lambda: "ranges"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Ranges, [], name, value)


                class Range(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: client_xr
                    
                    	Client mapping learnt via
                    	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                    
                    .. attribute:: expires
                    
                    	When mapping expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: group_range
                    
                    	List of group ranges
                    	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange>`
                    
                    .. attribute:: protocol
                    
                    	PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	Rendezvous point address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr>`
                    
                    .. attribute:: source_of_information
                    
                    	Source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rp-address-xr" : ("rp_address_xr", Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr), "source-of-information" : ("source_of_information", Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation)}
                        self._child_list_classes = {"group-range" : ("group_range", Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange)}

                        self.client = YLeaf(YType.enumeration, "client")

                        self.client_xr = YLeaf(YType.enumeration, "client-xr")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_address_xr = Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")

                        self.source_of_information = Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")

                        self.group_range = YList(self)
                        self._segment_path = lambda: "range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ranges/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Ranges.Range, ['client', 'client_xr', 'expires', 'protocol', 'rp_address'], name, value)


                    class GroupRange(Entity):
                        """
                        List of group ranges
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange, self).__init__()

                            self.yang_name = "group-range"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"prefix" : ("prefix", Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix), "source-of-information" : ("source_of_information", Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation)}
                            self._child_list_classes = {}

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.prefix = Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.source_of_information = Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")
                            self._segment_path = lambda: "group-range"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ranges/range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange, ['expires', 'prefix_length', 'uptime'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ranges/range/group-range/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-of-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ranges/range/group-range/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddressXr(Entity):
                        """
                        Rendezvous point address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ranges/range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceOfInformation(Entity):
                        """
                        Source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-of-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ranges/range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class RoutePolicy(Entity):
                """
                PIM route policy
                
                .. attribute:: route_policy_statistics
                
                	PIM route policy statistics
                	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics>`
                
                .. attribute:: route_policy_tests
                
                	PIM route policy test run table
                	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.RoutePolicy, self).__init__()

                    self.yang_name = "route-policy"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"route-policy-statistics" : ("route_policy_statistics", Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics), "route-policy-tests" : ("route_policy_tests", Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests)}
                    self._child_list_classes = {}

                    self.route_policy_statistics = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                    self.route_policy_statistics.parent = self
                    self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                    self._children_yang_names.add("route-policy-statistics")

                    self.route_policy_tests = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests()
                    self.route_policy_tests.parent = self
                    self._children_name_map["route_policy_tests"] = "route-policy-tests"
                    self._children_yang_names.add("route-policy-tests")
                    self._segment_path = lambda: "route-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()


                class RoutePolicyStatistics(Entity):
                    """
                    PIM route policy statistics
                    
                    .. attribute:: any_table
                    
                    	Number of RPF lookup in any Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table
                    
                    	Number of RPF lookup in default\-only Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop
                    
                    	Number of RPF drops
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pass_
                    
                    	Number of RPF pass
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: policy_name
                    
                    	RPF policy name
                    	**type**\:  str
                    
                    .. attribute:: requests
                    
                    	Number of RPF lookup requests
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__init__()

                        self.yang_name = "route-policy-statistics"
                        self.yang_parent_name = "route-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.any_table = YLeaf(YType.uint32, "any-table")

                        self.default_table = YLeaf(YType.uint32, "default-table")

                        self.drop = YLeaf(YType.uint32, "drop")

                        self.pass_ = YLeaf(YType.uint32, "pass")

                        self.policy_name = YLeaf(YType.str, "policy-name")

                        self.requests = YLeaf(YType.uint32, "requests")
                        self._segment_path = lambda: "route-policy-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/route-policy/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics, ['any_table', 'default_table', 'drop', 'pass_', 'policy_name', 'requests'], name, value)


                class RoutePolicyTests(Entity):
                    """
                    PIM route policy test run table
                    
                    .. attribute:: route_policy_test
                    
                    	PIM route policy test run
                    	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests, self).__init__()

                        self.yang_name = "route-policy-tests"
                        self.yang_parent_name = "route-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"route-policy-test" : ("route_policy_test", Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest)}

                        self.route_policy_test = YList(self)
                        self._segment_path = lambda: "route-policy-tests"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/route-policy/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests, [], name, value)


                    class RoutePolicyTest(Entity):
                        """
                        PIM route policy test run
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Default table selected
                        	**type**\:  bool
                        
                        .. attribute:: ext_comm
                        
                        	Extended Community
                        	**type**\:  str
                        
                        	**length:** 1..8
                        
                        .. attribute:: extended_community_rt
                        
                        	Route Target
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                        
                        .. attribute:: pass_
                        
                        	Pass
                        	**type**\:  bool
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                        
                        .. attribute:: table_active
                        
                        	Table active
                        	**type**\:  bool
                        
                        .. attribute:: table_exists
                        
                        	Table exists
                        	**type**\:  bool
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_name
                        
                        	VRF name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                            self.yang_name = "route-policy-test"
                            self.yang_parent_name = "route-policy-tests"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr), "source-address-xr" : ("source_address_xr", Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr)}
                            self._child_list_classes = {}

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.default_table = YLeaf(YType.boolean, "default-table")

                            self.ext_comm = YLeaf(YType.str, "ext-comm")

                            self.extended_community_rt = YLeaf(YType.str, "extended-community-rt")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.pass_ = YLeaf(YType.boolean, "pass")

                            self.policy_name = YLeaf(YType.str, "policy-name")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.table_active = YLeaf(YType.boolean, "table-active")

                            self.table_exists = YLeaf(YType.boolean, "table-exists")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_xr = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.source_address_xr = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")
                            self._segment_path = lambda: "route-policy-test"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/route-policy/route-policy-tests/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, ['afi', 'default_table', 'ext_comm', 'extended_community_rt', 'group_address', 'pass_', 'policy_name', 'safi', 'source_address', 'table_active', 'table_exists', 'table_name', 'vrf_name'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "route-policy-test"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "route-policy-test"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class RpfRedirect(Entity):
                """
                PIM ECMP RPF\-redirect bundle
                
                .. attribute:: bundle_interfaces
                
                	PIM ECMP RPF\-redirect bundle information
                	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces>`
                
                .. attribute:: redirect_route_databases
                
                	PIM ECMP RPF\-redirect route database
                	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.RpfRedirect, self).__init__()

                    self.yang_name = "rpf-redirect"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"bundle-interfaces" : ("bundle_interfaces", Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces), "redirect-route-databases" : ("redirect_route_databases", Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases)}
                    self._child_list_classes = {}

                    self.bundle_interfaces = Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces()
                    self.bundle_interfaces.parent = self
                    self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                    self._children_yang_names.add("bundle-interfaces")

                    self.redirect_route_databases = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                    self.redirect_route_databases.parent = self
                    self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                    self._children_yang_names.add("redirect-route-databases")
                    self._segment_path = lambda: "rpf-redirect"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()


                class BundleInterfaces(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle information
                    
                    .. attribute:: bundle_interface
                    
                    	PIM ECMP RPF\-redirect bundle interface information
                    	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces, self).__init__()

                        self.yang_name = "bundle-interfaces"
                        self.yang_parent_name = "rpf-redirect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"bundle-interface" : ("bundle_interface", Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface)}

                        self.bundle_interface = YList(self)
                        self._segment_path = lambda: "bundle-interfaces"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces, [], name, value)


                    class BundleInterface(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle interface
                        information
                        
                        .. attribute:: allocated_bandwidth
                        
                        	Bandwidth allocated in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_threshold_bandwidth
                        
                        	Configured threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_threshold_bandwidth
                        
                        	Available threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: bundle_name
                        
                        	Bundle name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: interface_name
                        
                        	Bundle interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: rpf_redirect_bundle_name
                        
                        	RPF redirect bundle name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_redirect_interface_name
                        
                        	RPF redirect interface name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: snooping_bandwidth_used
                        
                        	Bandwidth used by snooped entries in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: topology_bandwidth_used
                        
                        	Bandwidth used by topology in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: total_bandwidth
                        
                        	Total bandwidth used in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                            self.yang_name = "bundle-interface"
                            self.yang_parent_name = "bundle-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.allocated_bandwidth = YLeaf(YType.int32, "allocated-bandwidth")

                            self.allocated_threshold_bandwidth = YLeaf(YType.int32, "allocated-threshold-bandwidth")

                            self.available_bandwidth = YLeaf(YType.int32, "available-bandwidth")

                            self.available_threshold_bandwidth = YLeaf(YType.int32, "available-threshold-bandwidth")

                            self.bundle_name = YLeaf(YType.str, "bundle-name")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.rpf_redirect_bundle_name = YLeaf(YType.str, "rpf-redirect-bundle-name")

                            self.rpf_redirect_interface_name = YLeaf(YType.str, "rpf-redirect-interface-name")

                            self.snooping_bandwidth_used = YLeaf(YType.int32, "snooping-bandwidth-used")

                            self.topology_bandwidth_used = YLeaf(YType.int32, "topology-bandwidth-used")

                            self.total_bandwidth = YLeaf(YType.int32, "total-bandwidth")
                            self._segment_path = lambda: "bundle-interface"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/bundle-interfaces/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, ['allocated_bandwidth', 'allocated_threshold_bandwidth', 'available_bandwidth', 'available_threshold_bandwidth', 'bundle_name', 'interface_name', 'rpf_redirect_bundle_name', 'rpf_redirect_interface_name', 'snooping_bandwidth_used', 'topology_bandwidth_used', 'total_bandwidth'], name, value)


                class RedirectRouteDatabases(Entity):
                    """
                    PIM ECMP RPF\-redirect route database
                    
                    .. attribute:: redirect_route_database
                    
                    	PIM ECMP RPF\-redirect route information
                    	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__init__()

                        self.yang_name = "redirect-route-databases"
                        self.yang_parent_name = "rpf-redirect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"redirect-route-database" : ("redirect_route_database", Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase)}

                        self.redirect_route_database = YList(self)
                        self._segment_path = lambda: "redirect-route-databases"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases, [], name, value)


                    class RedirectRouteDatabase(Entity):
                        """
                        PIM ECMP RPF\-redirect route information
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group ddress
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                        
                        .. attribute:: interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                            self.yang_name = "redirect-route-database"
                            self.yang_parent_name = "redirect-route-databases"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr), "source-address-xr" : ("source_address_xr", Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr)}
                            self._child_list_classes = {"interface" : ("interface", Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface)}

                            self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.source_address_xr = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                            self.interface = YList(self)
                            self._segment_path = lambda: "redirect-route-database"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/redirect-route-databases/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, ['bandwidth', 'group_address', 'source_address', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group ddress
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Interface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_outgoing_interface
                            
                            	Is outgoing Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_rpf_interface
                            
                            	Is RPF Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_snoop_interface
                            
                            	Is snooping Interface
                            	**type**\:  bool
                            
                            .. attribute:: rpf_address
                            
                            	RPF Address
                            	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"rpf-address" : ("rpf_address", Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress)}
                                self._child_list_classes = {}

                                self.expiry = YLeaf(YType.uint64, "expiry")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.is_outgoing_interface = YLeaf(YType.boolean, "is-outgoing-interface")

                                self.is_rpf_interface = YLeaf(YType.boolean, "is-rpf-interface")

                                self.is_snoop_interface = YLeaf(YType.boolean, "is-snoop-interface")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.rpf_address = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                self.rpf_address.parent = self
                                self._children_name_map["rpf_address"] = "rpf-address"
                                self._children_yang_names.add("rpf-address")
                                self._segment_path = lambda: "interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, ['expiry', 'interface_name', 'is_outgoing_interface', 'is_rpf_interface', 'is_snoop_interface', 'uptime'], name, value)


                            class RpfAddress(Entity):
                                """
                                RPF Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                    self.yang_name = "rpf-address"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "rpf-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class RpfSummary(Entity):
                """
                PIM RPF registration summary
                
                .. attribute:: default_safi
                
                	Default RPF Table SAFI
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: default_table_name
                
                	Default RPF Table Name
                	**type**\:  str
                
                .. attribute:: is_isis_mtr_configured
                
                	Is ISIS MTR configured?
                	**type**\:  bool
                
                .. attribute:: is_isis_te_configured
                
                	Is ISIS TE configured?
                	**type**\:  bool
                
                .. attribute:: is_mbgp_configured
                
                	Is MBGP configured?
                	**type**\:  bool
                
                .. attribute:: is_multipath_enabled
                
                	Is Multipath Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_interface_hash_enabled
                
                	Is Multipath Interface Hash Extension Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_hash_enabled
                
                	Is Multipath Source based Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_next_hop_hash_enabled
                
                	Is Multipath Source\-Nexthop Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_ospf_te_configured
                
                	Is OSPF TE configured?
                	**type**\:  bool
                
                .. attribute:: is_rib_convergence
                
                	RIB Convergence status
                	**type**\:  bool
                
                .. attribute:: mo_frr_configured
                
                	Is MoFRR configured?
                	**type**\:  bool
                
                .. attribute:: rib_convergence_time_left
                
                	RIB convergence time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_convergence_timeout
                
                	RIB convergence timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_mo_frr_configured
                
                	Is MoFRR RIB configured?
                	**type**\:  bool
                
                .. attribute:: rpf_registrations
                
                	RPF Registration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	Is RUMP MuRIB enabled?
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.RpfSummary, self).__init__()

                    self.yang_name = "rpf-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.default_safi = YLeaf(YType.uint32, "default-safi")

                    self.default_table_name = YLeaf(YType.str, "default-table-name")

                    self.is_isis_mtr_configured = YLeaf(YType.boolean, "is-isis-mtr-configured")

                    self.is_isis_te_configured = YLeaf(YType.boolean, "is-isis-te-configured")

                    self.is_mbgp_configured = YLeaf(YType.boolean, "is-mbgp-configured")

                    self.is_multipath_enabled = YLeaf(YType.boolean, "is-multipath-enabled")

                    self.is_multipath_interface_hash_enabled = YLeaf(YType.boolean, "is-multipath-interface-hash-enabled")

                    self.is_multipath_source_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-hash-enabled")

                    self.is_multipath_source_next_hop_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-next-hop-hash-enabled")

                    self.is_ospf_te_configured = YLeaf(YType.boolean, "is-ospf-te-configured")

                    self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                    self.mo_frr_configured = YLeaf(YType.boolean, "mo-frr-configured")

                    self.rib_convergence_time_left = YLeaf(YType.uint32, "rib-convergence-time-left")

                    self.rib_convergence_timeout = YLeaf(YType.uint32, "rib-convergence-timeout")

                    self.rib_mo_frr_configured = YLeaf(YType.boolean, "rib-mo-frr-configured")

                    self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                    self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")
                    self._segment_path = lambda: "rpf-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfSummary, ['default_safi', 'default_table_name', 'is_isis_mtr_configured', 'is_isis_te_configured', 'is_mbgp_configured', 'is_multipath_enabled', 'is_multipath_interface_hash_enabled', 'is_multipath_source_hash_enabled', 'is_multipath_source_next_hop_hash_enabled', 'is_ospf_te_configured', 'is_rib_convergence', 'mo_frr_configured', 'rib_convergence_time_left', 'rib_convergence_timeout', 'rib_mo_frr_configured', 'rpf_registrations', 'rump_enabled'], name, value)


            class Safs(Entity):
                """
                SAFI table and type
                
                .. attribute:: saf
                
                	SAF name 
                	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Safs, self).__init__()

                    self.yang_name = "safs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"saf" : ("saf", Ipv6Pim.Standby.DefaultContext.Safs.Saf)}

                    self.saf = YList(self)
                    self._segment_path = lambda: "safs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs, [], name, value)


                class Saf(Entity):
                    """
                    SAF name 
                    
                    .. attribute:: rpf_hash_source_groups
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups>`
                    
                    .. attribute:: rpf_hash_sources
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources>`
                    
                    .. attribute:: rpfs
                    
                    	PIM RPF information table
                    	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs>`
                    
                    .. attribute:: saf_name
                    
                    	SAF name 
                    	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name 
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Safs.Saf, self).__init__()

                        self.yang_name = "saf"
                        self.yang_parent_name = "safs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rpf-hash-source-groups" : ("rpf_hash_source_groups", Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups), "rpf-hash-sources" : ("rpf_hash_sources", Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources), "rpfs" : ("rpfs", Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs)}
                        self._child_list_classes = {}

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                        self.topology_name = YLeaf(YType.str, "topology-name")

                        self.rpf_hash_source_groups = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                        self.rpf_hash_source_groups.parent = self
                        self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                        self._children_yang_names.add("rpf-hash-source-groups")

                        self.rpf_hash_sources = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources()
                        self.rpf_hash_sources.parent = self
                        self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                        self._children_yang_names.add("rpf-hash-sources")

                        self.rpfs = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs()
                        self.rpfs.parent = self
                        self._children_name_map["rpfs"] = "rpfs"
                        self._children_yang_names.add("rpfs")
                        self._segment_path = lambda: "saf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf, ['saf_name', 'topology_name'], name, value)


                    class RpfHashSourceGroups(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source_group
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__init__()

                            self.yang_name = "rpf-hash-source-groups"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"rpf-hash-source-group" : ("rpf_hash_source_group", Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup)}

                            self.rpf_hash_source_group = YList(self)
                            self._segment_path = lambda: "rpf-hash-source-groups"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups, [], name, value)


                        class RpfHashSourceGroup(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: mask_length
                            
                            	Hash mask length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                self.yang_name = "rpf-hash-source-group"
                                self.yang_parent_name = "rpf-hash-source-groups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"next-hop-address" : ("next_hop_address", Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress), "secondary-next-hop-address" : ("secondary_next_hop_address", Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress)}
                                self._child_list_classes = {}

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.mask_length = YLeaf(YType.int32, "mask-length")

                                self.mofrr = YLeaf(YType.int32, "mofrr")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                self._children_yang_names.add("next-hop-address")

                                self.secondary_next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._children_yang_names.add("secondary-next-hop-address")
                                self._segment_path = lambda: "rpf-hash-source-group"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpf-hash-source-groups/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, ['group_address', 'mask_length', 'mofrr', 'next_hop_interface', 'next_hop_multipath_enabled', 'secondary_next_hop_interface', 'source_address'], name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "secondary-next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfHashSources(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources, self).__init__()

                            self.yang_name = "rpf-hash-sources"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"rpf-hash-source" : ("rpf_hash_source", Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource)}

                            self.rpf_hash_source = YList(self)
                            self._segment_path = lambda: "rpf-hash-sources"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources, [], name, value)


                        class RpfHashSource(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                self.yang_name = "rpf-hash-source"
                                self.yang_parent_name = "rpf-hash-sources"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"next-hop-address" : ("next_hop_address", Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress), "secondary-next-hop-address" : ("secondary_next_hop_address", Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress)}
                                self._child_list_classes = {}

                                self.mofrr = YLeaf(YType.int32, "mofrr")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                self._children_yang_names.add("next-hop-address")

                                self.secondary_next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._children_yang_names.add("secondary-next-hop-address")
                                self._segment_path = lambda: "rpf-hash-source"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpf-hash-sources/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, ['mofrr', 'next_hop_interface', 'next_hop_multipath_enabled', 'secondary_next_hop_interface', 'source_address'], name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "secondary-next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Rpfs(Entity):
                        """
                        PIM RPF information table
                        
                        .. attribute:: rpf
                        
                        	PIM RPF information
                        	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs, self).__init__()

                            self.yang_name = "rpfs"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"rpf" : ("rpf", Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf)}

                            self.rpf = YList(self)
                            self._segment_path = lambda: "rpfs"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs, [], name, value)


                        class Rpf(Entity):
                            """
                            PIM RPF information
                            
                            .. attribute:: registered_address  <key>
                            
                            	Address for which RPF lookup
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_rpf_bgp_route
                            
                            	Is RPF through BGP route
                            	**type**\:  bool
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address_xr
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                            
                            .. attribute:: rpf_path
                            
                            	RPF Paths list
                            	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__init__()

                                self.yang_name = "rpf"
                                self.yang_parent_name = "rpfs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"registered-address-xr" : ("registered_address_xr", Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr)}
                                self._child_list_classes = {"rpf-path" : ("rpf_path", Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath)}

                                self.registered_address = YLeaf(YType.str, "registered-address")

                                self.is_connected = YLeaf(YType.uint8, "is-connected")

                                self.is_rpf_bgp_route = YLeaf(YType.boolean, "is-rpf-bgp-route")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                self.registered_address_xr = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                self.registered_address_xr.parent = self
                                self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                self._children_yang_names.add("registered-address-xr")

                                self.rpf_path = YList(self)
                                self._segment_path = lambda: "rpf" + "[registered-address='" + self.registered_address.get() + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpfs/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf, ['registered_address', 'is_connected', 'is_rpf_bgp_route', 'metric', 'metric_preference'], name, value)


                            class RegisteredAddressXr(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                    self.yang_name = "registered-address-xr"
                                    self.yang_parent_name = "rpf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "registered-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class RpfPath(Entity):
                                """
                                RPF Paths list
                                
                                .. attribute:: connector
                                
                                	Connector Attribute
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface_disabled
                                
                                	Is the rpf interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                .. attribute:: is_via_mlsm
                                
                                	Via Mstatic LSM
                                	**type**\:  bool
                                
                                .. attribute:: rpf_interface_name
                                
                                	RPF Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: rpf_neighbor
                                
                                	RPF neighbor
                                	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                
                                .. attribute:: rpf_nexthop
                                
                                	RPF nexthop
                                	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                    self.yang_name = "rpf-path"
                                    self.yang_parent_name = "rpf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"rpf-neighbor" : ("rpf_neighbor", Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor), "rpf-nexthop" : ("rpf_nexthop", Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop)}
                                    self._child_list_classes = {}

                                    self.connector = YLeaf(YType.str, "connector")

                                    self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                    self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                    self.is_rpf_interface_disabled = YLeaf(YType.boolean, "is-rpf-interface-disabled")

                                    self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                    self.is_via_mlsm = YLeaf(YType.boolean, "is-via-mlsm")

                                    self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                                    self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                    self._children_yang_names.add("rpf-neighbor")

                                    self.rpf_nexthop = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                    self.rpf_nexthop.parent = self
                                    self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                    self._children_yang_names.add("rpf-nexthop")
                                    self._segment_path = lambda: "rpf-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, ['connector', 'extranet_vrf_name', 'is_connector_attribute_present', 'is_rpf_interface_disabled', 'is_via_lsm', 'is_via_mlsm', 'rpf_interface_name'], name, value)


                                class RpfNeighbor(Entity):
                                    """
                                    RPF neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                        self.yang_name = "rpf-neighbor"
                                        self.yang_parent_name = "rpf-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "rpf-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class RpfNexthop(Entity):
                                    """
                                    RPF nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                        self.yang_name = "rpf-nexthop"
                                        self.yang_parent_name = "rpf-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "rpf-nexthop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Summary(Entity):
                """
                PIM summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                    self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                    self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                    self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                    self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                    self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                    self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                    self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                    self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                    self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                    self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                    self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                    self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                    self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                    self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                    self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                    self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                    self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                    self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                    self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                    self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                    self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                    self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                    self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                    self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                    self.register_count = YLeaf(YType.uint32, "register-count")

                    self.register_limit = YLeaf(YType.uint32, "register-limit")

                    self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                    self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                    self.route_count = YLeaf(YType.uint32, "route-count")

                    self.route_limit = YLeaf(YType.uint32, "route-limit")

                    self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                    self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                    self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                    self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                    self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                    self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                    self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Summary, ['bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_threshold', 'bsr_range_threshold', 'bsr_ranges_count', 'bsr_ranges_limit', 'global_auto_rp_ranges_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_threshold', 'global_bsr_ranges_count', 'global_bsr_ranges_limit', 'global_bsr_ranges_threshold', 'global_register_limit', 'is_bsr_ranges_threshold_reached', 'is_global_auto_rp_ranges_limit_reached', 'is_global_bsr_ranges_limit_reached', 'is_global_register_limit_reached', 'is_global_route_limit_reached', 'is_global_rxi_limit_reached', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'is_ranges_limit_reached', 'is_route_limit_reached', 'ranges_count', 'ranges_limit', 'ranges_threshold', 'register_count', 'register_limit', 'register_limit_reached', 'register_threshold', 'route_count', 'route_limit', 'route_low_water_mark', 'route_threshold', 'rxi_limit_reached', 'rxi_low_water_mark', 'topology_interface_state_count', 'topology_interface_state_limit', 'topology_interface_state_threshold'], name, value)


            class TableContexts(Entity):
                """
                PIM table context list
                
                .. attribute:: table_context
                
                	PIM table context information
                	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TableContexts.TableContext>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.TableContexts, self).__init__()

                    self.yang_name = "table-contexts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"table-context" : ("table_context", Ipv6Pim.Standby.DefaultContext.TableContexts.TableContext)}

                    self.table_context = YList(self)
                    self._segment_path = lambda: "table-contexts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TableContexts, [], name, value)


                class TableContext(Entity):
                    """
                    PIM table context information
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saf_name
                    
                    	SAF name
                    	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: topology_name
                    
                    	Topology name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.TableContexts.TableContext, self).__init__()

                        self.yang_name = "table-context"
                        self.yang_parent_name = "table-contexts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.uint32, "afi")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                        self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                        self.safi = YLeaf(YType.uint32, "safi")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.table_name = YLeaf(YType.str, "table-name")

                        self.topology_name = YLeaf(YType.str, "topology-name")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")
                        self._segment_path = lambda: "table-context"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/table-contexts/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TableContexts.TableContext, ['afi', 'is_active', 'is_ital_registration_done', 'is_rib_convergence', 'is_rib_convergence_received', 'is_rib_registration_done', 'rpf_registrations', 'saf_name', 'safi', 'table_id', 'table_name', 'topology_name', 'vrf_id'], name, value)


            class Topologies(Entity):
                """
                PIM topology table
                
                .. attribute:: topology
                
                	PIM topology information
                	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Topologies, self).__init__()

                    self.yang_name = "topologies"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"topology" : ("topology", Ipv6Pim.Standby.DefaultContext.Topologies.Topology)}

                    self.topology = YList(self)
                    self._segment_path = lambda: "topologies"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies, [], name, value)


                class Topology(Entity):
                    """
                    PIM topology information
                    
                    .. attribute:: alive
                    
                    	Alive time in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: anycast_rp_match
                    
                    	Group matches Anycast\-RP policy
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_route_target
                    
                    	Anycast\-RP RT
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: assume_alive
                    
                    	The Assume Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: bgp_join
                    
                    	BGP C JOIN
                    	**type**\:  bool
                    
                    .. attribute:: bgp_jp_time
                    
                    	BGP C JP Time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: connected
                    
                    	Is Connected ?
                    	**type**\:  bool
                    
                    .. attribute:: crossed_threshold
                    
                    	Incoming traffic crossed threshold. MT flag set
                    	**type**\:  bool
                    
                    .. attribute:: customer_routing_type
                    
                    	Type of Customer Routing in the MVPN
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: data_mdt_addr_assigned
                    
                    	PIM has assigned a Data MDT Address
                    	**type**\:  bool
                    
                    .. attribute:: dont_check_connected
                    
                    	Do we need to make the connected check on this route ?
                    	**type**\:  bool
                    
                    .. attribute:: expiry
                    
                    	When this entry expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: extranet_route
                    
                    	Is a Extranet route ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr>`
                    
                    .. attribute:: inherit_alive
                    
                    	The Inherit Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: inherit_spt
                    
                    	The Inherit SPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: is_via_lsm
                    
                    	Via LSM
                    	**type**\:  bool
                    
                    .. attribute:: jp_status
                    
                    	Join\-Prune Status
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: jp_timer
                    
                    	Join\-Prune Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: kat_state
                    
                    	Keep Alive Timer State
                    	**type**\:  bool
                    
                    .. attribute:: last_hop
                    
                    	Are we last hop ?
                    	**type**\:  bool
                    
                    .. attribute:: limit_reached
                    
                    	Have we throttled the creation of routes or interfaces ?
                    	**type**\:  bool
                    
                    .. attribute:: low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_active
                    
                    	Is MoFRR Active?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_backup
                    
                    	Is this Mofrr Backup?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_primary
                    
                    	Is this Mofrr Primary?
                    	**type**\:  bool
                    
                    .. attribute:: orig_src_address
                    
                    	Orig Src Address
                    	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress>`
                    
                    .. attribute:: outgoing_interface
                    
                    	Outgoing interface list
                    	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface>`
                    
                    .. attribute:: probe_alive
                    
                    	The Probe Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: proxy
                    
                    	Is the RPF target a proxy?
                    	**type**\:  bool
                    
                    .. attribute:: proxy_address
                    
                    	RPF Proxy address
                    	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress>`
                    
                    .. attribute:: really_alive
                    
                    	The Really Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: register_received
                    
                    	Have registers been received for this source ?
                    	**type**\:  bool
                    
                    .. attribute:: register_received_timer
                    
                    	Register Received Timer in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: remote_source
                    
                    	MSDP told us
                    	**type**\:  bool
                    
                    .. attribute:: rib_mo_frr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rp_address
                    
                    	RP Address (If rpt)
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor>`
                    
                    .. attribute:: rpf_proxy_enabled
                    
                    	Is rpf if proxy enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: rpt
                    
                    	RPT bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpt_xr
                    
                    	Is this on the RPT ?
                    	**type**\:  bool
                    
                    .. attribute:: sa_joined
                    
                    	BGP SA join
                    	**type**\:  bool
                    
                    .. attribute:: sa_received
                    
                    	BGP SA received
                    	**type**\:  bool
                    
                    .. attribute:: sa_sent
                    
                    	BGP SA sent
                    	**type**\:  bool
                    
                    .. attribute:: secondary_rpf_interface_name
                    
                    	Secondary Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: secondary_rpf_neighbor
                    
                    	Secondary RPF Neighbor
                    	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor>`
                    
                    .. attribute:: sending_null_registers
                    
                    	Are we sending null registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: sending_registers
                    
                    	Are we sending registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: signal_sources
                    
                    	Signal Sources on route?
                    	**type**\:  bool
                    
                    .. attribute:: source_address
                    
                    	Source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr>`
                    
                    .. attribute:: spt
                    
                    	Is this on the SPT ?
                    	**type**\:  bool
                    
                    .. attribute:: suppress_registers
                    
                    	When the Null register probe expires
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: vxlan
                    
                    	Is this VXLAN?
                    	**type**\:  bool
                    
                    .. attribute:: wildcard
                    
                    	WC \-Wildcard
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology, self).__init__()

                        self.yang_name = "topology"
                        self.yang_parent_name = "topologies"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr), "orig-src-address" : ("orig_src_address", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress), "proxy-address" : ("proxy_address", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress), "rp-address" : ("rp_address", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress), "rpf-neighbor" : ("rpf_neighbor", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor), "rpf-root" : ("rpf_root", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot), "secondary-rpf-neighbor" : ("secondary_rpf_neighbor", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor), "source-address-xr" : ("source_address_xr", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr)}
                        self._child_list_classes = {"outgoing-interface" : ("outgoing_interface", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface)}

                        self.alive = YLeaf(YType.int32, "alive")

                        self.anycast_rp_match = YLeaf(YType.boolean, "anycast-rp-match")

                        self.anycast_rp_route_target = YLeaf(YType.str, "anycast-rp-route-target")

                        self.assume_alive = YLeaf(YType.boolean, "assume-alive")

                        self.bgp_join = YLeaf(YType.boolean, "bgp-join")

                        self.bgp_jp_time = YLeaf(YType.uint64, "bgp-jp-time")

                        self.connected = YLeaf(YType.boolean, "connected")

                        self.crossed_threshold = YLeaf(YType.boolean, "crossed-threshold")

                        self.customer_routing_type = YLeaf(YType.int32, "customer-routing-type")

                        self.data_mdt_addr_assigned = YLeaf(YType.boolean, "data-mdt-addr-assigned")

                        self.dont_check_connected = YLeaf(YType.boolean, "dont-check-connected")

                        self.expiry = YLeaf(YType.uint64, "expiry")

                        self.extranet_route = YLeaf(YType.boolean, "extranet-route")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.inherit_alive = YLeaf(YType.boolean, "inherit-alive")

                        self.inherit_spt = YLeaf(YType.boolean, "inherit-spt")

                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                        self.jp_status = YLeaf(YType.int32, "jp-status")

                        self.jp_timer = YLeaf(YType.int32, "jp-timer")

                        self.kat_state = YLeaf(YType.boolean, "kat-state")

                        self.last_hop = YLeaf(YType.boolean, "last-hop")

                        self.limit_reached = YLeaf(YType.boolean, "limit-reached")

                        self.low_memory = YLeaf(YType.boolean, "low-memory")

                        self.mofrr_active = YLeaf(YType.boolean, "mofrr-active")

                        self.mofrr_backup = YLeaf(YType.boolean, "mofrr-backup")

                        self.mofrr_enabled = YLeaf(YType.boolean, "mofrr-enabled")

                        self.mofrr_primary = YLeaf(YType.boolean, "mofrr-primary")

                        self.probe_alive = YLeaf(YType.boolean, "probe-alive")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.proxy = YLeaf(YType.boolean, "proxy")

                        self.really_alive = YLeaf(YType.boolean, "really-alive")

                        self.register_received = YLeaf(YType.boolean, "register-received")

                        self.register_received_timer = YLeaf(YType.int32, "register-received-timer")

                        self.remote_source = YLeaf(YType.boolean, "remote-source")

                        self.rib_mo_frr_enabled = YLeaf(YType.boolean, "rib-mo-frr-enabled")

                        self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                        self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_proxy_enabled = YLeaf(YType.boolean, "rpf-proxy-enabled")

                        self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                        self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.rpt = YLeaf(YType.int32, "rpt")

                        self.rpt_xr = YLeaf(YType.boolean, "rpt-xr")

                        self.sa_joined = YLeaf(YType.boolean, "sa-joined")

                        self.sa_received = YLeaf(YType.boolean, "sa-received")

                        self.sa_sent = YLeaf(YType.boolean, "sa-sent")

                        self.secondary_rpf_interface_name = YLeaf(YType.str, "secondary-rpf-interface-name")

                        self.sending_null_registers = YLeaf(YType.boolean, "sending-null-registers")

                        self.sending_registers = YLeaf(YType.boolean, "sending-registers")

                        self.signal_sources = YLeaf(YType.boolean, "signal-sources")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.spt = YLeaf(YType.boolean, "spt")

                        self.suppress_registers = YLeaf(YType.int32, "suppress-registers")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.vxlan = YLeaf(YType.boolean, "vxlan")

                        self.wildcard = YLeaf(YType.boolean, "wildcard")

                        self.group_address_xr = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.orig_src_address = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress()
                        self.orig_src_address.parent = self
                        self._children_name_map["orig_src_address"] = "orig-src-address"
                        self._children_yang_names.add("orig-src-address")

                        self.proxy_address = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress()
                        self.proxy_address.parent = self
                        self._children_name_map["proxy_address"] = "proxy-address"
                        self._children_yang_names.add("proxy-address")

                        self.rp_address = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                        self.rpf_root = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._children_yang_names.add("rpf-root")

                        self.secondary_rpf_neighbor = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                        self.secondary_rpf_neighbor.parent = self
                        self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                        self._children_yang_names.add("secondary-rpf-neighbor")

                        self.source_address_xr = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"
                        self._children_yang_names.add("source-address-xr")

                        self.outgoing_interface = YList(self)
                        self._segment_path = lambda: "topology"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology, ['alive', 'anycast_rp_match', 'anycast_rp_route_target', 'assume_alive', 'bgp_join', 'bgp_jp_time', 'connected', 'crossed_threshold', 'customer_routing_type', 'data_mdt_addr_assigned', 'dont_check_connected', 'expiry', 'extranet_route', 'group_address', 'inherit_alive', 'inherit_spt', 'is_via_lsm', 'jp_status', 'jp_timer', 'kat_state', 'last_hop', 'limit_reached', 'low_memory', 'mofrr_active', 'mofrr_backup', 'mofrr_enabled', 'mofrr_primary', 'probe_alive', 'protocol', 'proxy', 'really_alive', 'register_received', 'register_received_timer', 'remote_source', 'rib_mo_frr_enabled', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_proxy_enabled', 'rpf_safi', 'rpf_table_name', 'rpf_vrf_name', 'rpt', 'rpt_xr', 'sa_joined', 'sa_received', 'sa_sent', 'secondary_rpf_interface_name', 'sending_null_registers', 'sending_registers', 'signal_sources', 'source_address', 'spt', 'suppress_registers', 'uptime', 'vxlan', 'wildcard'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class OrigSrcAddress(Entity):
                        """
                        Orig Src Address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__init__()

                            self.yang_name = "orig-src-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "orig-src-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class OutgoingInterface(Entity):
                        """
                        Outgoing interface list
                        
                        .. attribute:: admin_boundary
                        
                        	Is this an administrative boundary ?
                        	**type**\:  bool
                        
                        .. attribute:: assert_state
                        
                        	Assert State
                        	**type**\:  bool
                        
                        .. attribute:: assert_timer
                        
                        	Assert Timer in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: assert_winner
                        
                        	Assert Winner
                        	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner>`
                        
                        .. attribute:: bgp_c_mcast_join
                        
                        	BGP C\-Mcast join
                        	**type**\:  bool
                        
                        .. attribute:: bgp_c_mcast_prune_delay_timer
                        
                        	BGP C\-MCAST Prune Suppression in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: data_mdt_join
                        
                        	Data MDT join
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	Expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: extranet_interface
                        
                        	Is this an Extranet Interface ?
                        	**type**\:  bool
                        
                        .. attribute:: forwarding_state
                        
                        	Forward or Prune
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: igmp_membership
                        
                        	IGMP membership
                        	**type**\:  bool
                        
                        .. attribute:: immediate_state
                        
                        	Immediate fwding state
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: internal_interest_info
                        
                        	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: internal_interest_information
                        
                        	Internal Interest. Replaces internal\-interest\-info
                        	**type**\:   :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                        
                        .. attribute:: jp_state
                        
                        	Join\-Prune State
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer (secs)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: local_mdt_join
                        
                        	Default MDT Join
                        	**type**\:  bool
                        
                        .. attribute:: local_members
                        
                        	Local Information. Deprecated \- use 'local\-members\-information' instead
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: local_members_information
                        
                        	Local Information. Replaces local\-members
                        	**type**\:   :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                        
                        .. attribute:: mdt_safi_join
                        
                        	MDT Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mldp_inband_mdt
                        
                        	MLDP Inband MDT interface
                        	**type**\:  bool
                        
                        .. attribute:: mldp_stale
                        
                        	OLE is stale
                        	**type**\:  bool
                        
                        .. attribute:: mvpn_safi_join
                        
                        	MVPN Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mvpnv6_safi_join
                        
                        	MVPN IPv6 Safi join
                        	**type**\:  bool
                        
                        .. attribute:: sa_prune
                        
                        	BGP SA Prune state
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vrf_name
                        
                        	VRF which physically owns
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface, self).__init__()

                            self.yang_name = "outgoing-interface"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"assert-winner" : ("assert_winner", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner)}
                            self._child_list_classes = {}

                            self.admin_boundary = YLeaf(YType.boolean, "admin-boundary")

                            self.assert_state = YLeaf(YType.boolean, "assert-state")

                            self.assert_timer = YLeaf(YType.int32, "assert-timer")

                            self.bgp_c_mcast_join = YLeaf(YType.boolean, "bgp-c-mcast-join")

                            self.bgp_c_mcast_prune_delay_timer = YLeaf(YType.uint64, "bgp-c-mcast-prune-delay-timer")

                            self.data_mdt_join = YLeaf(YType.boolean, "data-mdt-join")

                            self.expiry = YLeaf(YType.uint64, "expiry")

                            self.extranet_interface = YLeaf(YType.boolean, "extranet-interface")

                            self.forwarding_state = YLeaf(YType.int32, "forwarding-state")

                            self.igmp_membership = YLeaf(YType.boolean, "igmp-membership")

                            self.immediate_state = YLeaf(YType.int32, "immediate-state")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.internal_interest_info = YLeaf(YType.int32, "internal-interest-info")

                            self.internal_interest_information = YLeaf(YType.enumeration, "internal-interest-information")

                            self.jp_state = YLeaf(YType.int32, "jp-state")

                            self.jp_timer = YLeaf(YType.int32, "jp-timer")

                            self.last_hop = YLeaf(YType.boolean, "last-hop")

                            self.local_mdt_join = YLeaf(YType.boolean, "local-mdt-join")

                            self.local_members = YLeaf(YType.int32, "local-members")

                            self.local_members_information = YLeaf(YType.enumeration, "local-members-information")

                            self.mdt_safi_join = YLeaf(YType.boolean, "mdt-safi-join")

                            self.mldp_inband_mdt = YLeaf(YType.boolean, "mldp-inband-mdt")

                            self.mldp_stale = YLeaf(YType.boolean, "mldp-stale")

                            self.mvpn_safi_join = YLeaf(YType.boolean, "mvpn-safi-join")

                            self.mvpnv6_safi_join = YLeaf(YType.boolean, "mvpnv6-safi-join")

                            self.sa_prune = YLeaf(YType.boolean, "sa-prune")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.assert_winner = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                            self.assert_winner.parent = self
                            self._children_name_map["assert_winner"] = "assert-winner"
                            self._children_yang_names.add("assert-winner")
                            self._segment_path = lambda: "outgoing-interface"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface, ['admin_boundary', 'assert_state', 'assert_timer', 'bgp_c_mcast_join', 'bgp_c_mcast_prune_delay_timer', 'data_mdt_join', 'expiry', 'extranet_interface', 'forwarding_state', 'igmp_membership', 'immediate_state', 'interface_name', 'internal_interest_info', 'internal_interest_information', 'jp_state', 'jp_timer', 'last_hop', 'local_mdt_join', 'local_members', 'local_members_information', 'mdt_safi_join', 'mldp_inband_mdt', 'mldp_stale', 'mvpn_safi_join', 'mvpnv6_safi_join', 'sa_prune', 'uptime', 'vrf_name'], name, value)


                        class AssertWinner(Entity):
                            """
                            Assert Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                self.yang_name = "assert-winner"
                                self.yang_parent_name = "outgoing-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "assert-winner"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/outgoing-interface/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class ProxyAddress(Entity):
                        """
                        RPF Proxy address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress, self).__init__()

                            self.yang_name = "proxy-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "proxy-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address (If rpt)
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-root"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SecondaryRpfNeighbor(Entity):
                        """
                        Secondary RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                            self.yang_name = "secondary-rpf-neighbor"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "secondary-rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class TopologyEntryFlagRouteCounts(Entity):
                """
                Route count for topology with entry flag set
                
                .. attribute:: topology_entry_flag_route_count
                
                	Route count for topology with entry flag set
                	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-entry-flag-route-counts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"topology-entry-flag-route-count" : ("topology_entry_flag_route_count", Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount)}

                    self.topology_entry_flag_route_count = YList(self)
                    self._segment_path = lambda: "topology-entry-flag-route-counts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts, [], name, value)


                class TopologyEntryFlagRouteCount(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: entry_flag  <key>
                    
                    	entry flag
                    	**type**\:   :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                        self.yang_name = "topology-entry-flag-route-count"
                        self.yang_parent_name = "topology-entry-flag-route-counts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.entry_flag = YLeaf(YType.enumeration, "entry-flag")

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                        self._segment_path = lambda: "topology-entry-flag-route-count" + "[entry-flag='" + self.entry_flag.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topology-entry-flag-route-counts/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, ['entry_flag', 'active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


            class TopologyInterfaceFlagRouteCounts(Entity):
                """
                Route count for topology with interface flag set
                
                .. attribute:: topology_interface_flag_route_count
                
                	Route count for topology with interface flag set
                	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-interface-flag-route-counts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"topology-interface-flag-route-count" : ("topology_interface_flag_route_count", Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount)}

                    self.topology_interface_flag_route_count = YList(self)
                    self._segment_path = lambda: "topology-interface-flag-route-counts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts, [], name, value)


                class TopologyInterfaceFlagRouteCount(Entity):
                    """
                    Route count for topology with interface flag
                    set
                    
                    .. attribute:: interface_flag  <key>
                    
                    	Interface flag
                    	**type**\:   :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                        self.yang_name = "topology-interface-flag-route-count"
                        self.yang_parent_name = "topology-interface-flag-route-counts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.interface_flag = YLeaf(YType.enumeration, "interface-flag")

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                        self._segment_path = lambda: "topology-interface-flag-route-count" + "[interface-flag='" + self.interface_flag.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topology-interface-flag-route-counts/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, ['interface_flag', 'active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


            class TopologyRouteCount(Entity):
                """
                Topology route count information from PIM
                topology table
                
                .. attribute:: active_group_ranges
                
                	No. of (\*,G/M) routes active in mrib
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_ranges
                
                	No. of (\*,G/M) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groute_count
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: sg_route_count
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sgr_route_count
                
                	No. of (S,G)RPT routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.TopologyRouteCount, self).__init__()

                    self.yang_name = "topology-route-count"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                    self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                    self.groute_count = YLeaf(YType.uint32, "groute-count")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                    self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                    self._segment_path = lambda: "topology-route-count"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TopologyRouteCount, ['active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


            class TrafficCounters(Entity):
                """
                PIM message traffic counters
                
                .. attribute:: boundary_acl_rx_drop
                
                	Inc. JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_tx_drop
                
                	Out JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_error
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: format_error
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert
                
                	Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert_batched
                
                	Batched Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_bsr_message
                
                	Input BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_candidate_rp_advertisement
                
                	Input Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_data_register
                
                	Data Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_df_election
                
                	DF Election packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_ecmp_redirect
                
                	Input Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_hello
                
                	Hello packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_jp
                
                	Join Prune packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb_error
                
                	No IDB for intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_pim_error
                
                	PIM Disabled on intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_error
                
                	No VRF for idb error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_null_register
                
                	Null Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim_version_error
                
                	Invalid PIM version error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_register_stop
                
                	Register Stop packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: inputs
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_destination_packets
                
                	Control Packets with Invalid Destination
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_join_prunes
                
                	PIM invalid Join/Prunes received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_registers
                
                	PIM invalid registers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_local_source_address
                
                	Data MDT Join msgs dropped due to local source addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_idb
                
                	Data MDT Join msgs dropped due to idb missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_vrf
                
                	Data MDT Join msgs dropped due to vrf missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_null_local_address
                
                	Data MDT Join msgs dropped due to null local addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_bad_type
                
                	Data MDT TLV bad type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_received
                
                	Data MDT Join Msgs received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_sent
                
                	Data MDT Join Msgs sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_joins_drop_multiple_encapsulation
                
                	MDT Join msgs dropped due to multiple Encap limitation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_send_queue_full
                
                	Packets dropped since mdt send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_socket_error
                
                	MDT Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_invalid_lsm_identifier
                
                	 Invalid LSM ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_mdt_socket_connection
                
                	Packets dropped since no mdt socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_source_address
                
                	Packets dropped since no source address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: non_supported_packets
                
                	PIM non supported pckets
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert
                
                	Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert_batched
                
                	Batched Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_bsr_message
                
                	Output BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_candidate_rp_advertisement
                
                	Output Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_data_register
                
                	Data Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_df_election
                
                	DF Election packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_ecmp_redirect
                
                	Output Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello
                
                	Hello packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello_bytes
                
                	Output Hello Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_join_group
                
                	Output Join Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_prune_bytes
                
                	Output JP Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_jp
                
                	Join Prune packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_loop_error
                
                	Output on loopback error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_null_register
                
                	Null Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_prune_group
                
                	Output Prune Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_register_stop
                
                	Register Stop packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outputs
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_packman_error
                
                	Packets Dropped due to Pakman Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue
                
                	Packet queue state and statistics
                	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue>`
                
                .. attribute:: packet_queue_last_clear
                
                	Time in seconds since the last clear of all packet queues stats
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: packet_read_socket_error
                
                	Packet Read Socket Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_standby
                
                	Packets Dropped due to Standby Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pakman_error
                
                	Pakman packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_queue_full
                
                	Packets dropped since send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_error
                
                	Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_packets_error
                
                	Packets received in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: truncated_pim_packets
                
                	Packets dropped due to truncated Joins or Prunes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"packet-queue" : ("packet_queue", Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue)}

                    self.boundary_acl_rx_drop = YLeaf(YType.uint32, "boundary-acl-rx-drop")

                    self.boundary_acl_tx_drop = YLeaf(YType.uint32, "boundary-acl-tx-drop")

                    self.checksum_error = YLeaf(YType.uint32, "checksum-error")

                    self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                    self.format_error = YLeaf(YType.uint32, "format-error")

                    self.input_assert = YLeaf(YType.uint32, "input-assert")

                    self.input_assert_batched = YLeaf(YType.uint32, "input-assert-batched")

                    self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                    self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                    self.input_data_register = YLeaf(YType.uint32, "input-data-register")

                    self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                    self.input_ecmp_redirect = YLeaf(YType.uint32, "input-ecmp-redirect")

                    self.input_hello = YLeaf(YType.uint32, "input-hello")

                    self.input_jp = YLeaf(YType.uint32, "input-jp")

                    self.input_no_idb_error = YLeaf(YType.uint32, "input-no-idb-error")

                    self.input_no_pim_error = YLeaf(YType.uint32, "input-no-pim-error")

                    self.input_no_vrf_error = YLeaf(YType.uint32, "input-no-vrf-error")

                    self.input_null_register = YLeaf(YType.uint32, "input-null-register")

                    self.input_pim_version_error = YLeaf(YType.uint32, "input-pim-version-error")

                    self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                    self.inputs = YLeaf(YType.uint32, "inputs")

                    self.invalid_destination_packets = YLeaf(YType.uint32, "invalid-destination-packets")

                    self.invalid_join_prunes = YLeaf(YType.uint32, "invalid-join-prunes")

                    self.invalid_registers = YLeaf(YType.uint32, "invalid-registers")

                    self.mdt_drop_local_source_address = YLeaf(YType.uint32, "mdt-drop-local-source-address")

                    self.mdt_drop_no_idb = YLeaf(YType.uint32, "mdt-drop-no-idb")

                    self.mdt_drop_no_vrf = YLeaf(YType.uint32, "mdt-drop-no-vrf")

                    self.mdt_drop_null_local_address = YLeaf(YType.uint32, "mdt-drop-null-local-address")

                    self.mdt_join_bad_type = YLeaf(YType.uint32, "mdt-join-bad-type")

                    self.mdt_join_tlv_received = YLeaf(YType.uint32, "mdt-join-tlv-received")

                    self.mdt_join_tlv_sent = YLeaf(YType.uint32, "mdt-join-tlv-sent")

                    self.mdt_joins_drop_multiple_encapsulation = YLeaf(YType.uint32, "mdt-joins-drop-multiple-encapsulation")

                    self.mdt_send_queue_full = YLeaf(YType.uint32, "mdt-send-queue-full")

                    self.mdt_socket_error = YLeaf(YType.uint32, "mdt-socket-error")

                    self.mldp_mdt_invalid_lsm_identifier = YLeaf(YType.uint32, "mldp-mdt-invalid-lsm-identifier")

                    self.no_mdt_socket_connection = YLeaf(YType.uint32, "no-mdt-socket-connection")

                    self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                    self.no_source_address = YLeaf(YType.uint32, "no-source-address")

                    self.non_supported_packets = YLeaf(YType.uint32, "non-supported-packets")

                    self.output_assert = YLeaf(YType.uint32, "output-assert")

                    self.output_assert_batched = YLeaf(YType.uint32, "output-assert-batched")

                    self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                    self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                    self.output_data_register = YLeaf(YType.uint32, "output-data-register")

                    self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                    self.output_ecmp_redirect = YLeaf(YType.uint32, "output-ecmp-redirect")

                    self.output_hello = YLeaf(YType.uint32, "output-hello")

                    self.output_hello_bytes = YLeaf(YType.uint32, "output-hello-bytes")

                    self.output_join_group = YLeaf(YType.uint32, "output-join-group")

                    self.output_join_prune_bytes = YLeaf(YType.uint32, "output-join-prune-bytes")

                    self.output_jp = YLeaf(YType.uint32, "output-jp")

                    self.output_loop_error = YLeaf(YType.uint32, "output-loop-error")

                    self.output_null_register = YLeaf(YType.uint32, "output-null-register")

                    self.output_prune_group = YLeaf(YType.uint32, "output-prune-group")

                    self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                    self.outputs = YLeaf(YType.uint32, "outputs")

                    self.packet_packman_error = YLeaf(YType.uint32, "packet-packman-error")

                    self.packet_queue_last_clear = YLeaf(YType.uint32, "packet-queue-last-clear")

                    self.packet_read_socket_error = YLeaf(YType.uint32, "packet-read-socket-error")

                    self.packets_standby = YLeaf(YType.uint32, "packets-standby")

                    self.pakman_error = YLeaf(YType.uint32, "pakman-error")

                    self.send_queue_full = YLeaf(YType.uint32, "send-queue-full")

                    self.socket_error = YLeaf(YType.uint32, "socket-error")

                    self.standby_packets_error = YLeaf(YType.uint32, "standby-packets-error")

                    self.truncated_pim_packets = YLeaf(YType.uint32, "truncated-pim-packets")

                    self.packet_queue = YList(self)
                    self._segment_path = lambda: "traffic-counters"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TrafficCounters, ['boundary_acl_rx_drop', 'boundary_acl_tx_drop', 'checksum_error', 'elapsed_time', 'format_error', 'input_assert', 'input_assert_batched', 'input_bsr_message', 'input_candidate_rp_advertisement', 'input_data_register', 'input_df_election', 'input_ecmp_redirect', 'input_hello', 'input_jp', 'input_no_idb_error', 'input_no_pim_error', 'input_no_vrf_error', 'input_null_register', 'input_pim_version_error', 'input_register_stop', 'inputs', 'invalid_destination_packets', 'invalid_join_prunes', 'invalid_registers', 'mdt_drop_local_source_address', 'mdt_drop_no_idb', 'mdt_drop_no_vrf', 'mdt_drop_null_local_address', 'mdt_join_bad_type', 'mdt_join_tlv_received', 'mdt_join_tlv_sent', 'mdt_joins_drop_multiple_encapsulation', 'mdt_send_queue_full', 'mdt_socket_error', 'mldp_mdt_invalid_lsm_identifier', 'no_mdt_socket_connection', 'no_socket_connection', 'no_source_address', 'non_supported_packets', 'output_assert', 'output_assert_batched', 'output_bsr_message', 'output_candidate_rp_advertisement', 'output_data_register', 'output_df_election', 'output_ecmp_redirect', 'output_hello', 'output_hello_bytes', 'output_join_group', 'output_join_prune_bytes', 'output_jp', 'output_loop_error', 'output_null_register', 'output_prune_group', 'output_register_stop', 'outputs', 'packet_packman_error', 'packet_queue_last_clear', 'packet_read_socket_error', 'packets_standby', 'pakman_error', 'send_queue_full', 'socket_error', 'standby_packets_error', 'truncated_pim_packets'], name, value)


                class PacketQueue(Entity):
                    """
                    Packet queue state and statistics
                    
                    .. attribute:: packet_queue_priority
                    
                    	Priority of this packet queue
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_state
                    
                    	State of the queue
                    	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState>`
                    
                    .. attribute:: packet_queue_stats
                    
                    	Statistics about the queue
                    	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue, self).__init__()

                        self.yang_name = "packet-queue"
                        self.yang_parent_name = "traffic-counters"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"packet-queue-state" : ("packet_queue_state", Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState), "packet-queue-stats" : ("packet_queue_stats", Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats)}
                        self._child_list_classes = {}

                        self.packet_queue_priority = YLeaf(YType.uint32, "packet-queue-priority")

                        self.packet_queue_state = Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                        self.packet_queue_state.parent = self
                        self._children_name_map["packet_queue_state"] = "packet-queue-state"
                        self._children_yang_names.add("packet-queue-state")

                        self.packet_queue_stats = Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                        self.packet_queue_stats.parent = self
                        self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                        self._children_yang_names.add("packet-queue-stats")
                        self._segment_path = lambda: "packet-queue"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/traffic-counters/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue, ['packet_queue_priority'], name, value)


                    class PacketQueueState(Entity):
                        """
                        State of the queue
                        
                        .. attribute:: max_queue_size
                        
                        	Maximum size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_bytes
                        
                        	Size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_packets
                        
                        	Size of queue in number of packets
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                            self.yang_name = "packet-queue-state"
                            self.yang_parent_name = "packet-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.max_queue_size = YLeaf(YType.uint32, "max-queue-size")

                            self.queue_size_bytes = YLeaf(YType.uint32, "queue-size-bytes")

                            self.queue_size_packets = YLeaf(YType.uint32, "queue-size-packets")
                            self._segment_path = lambda: "packet-queue-state"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/traffic-counters/packet-queue/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, ['max_queue_size', 'queue_size_bytes', 'queue_size_packets'], name, value)


                    class PacketQueueStats(Entity):
                        """
                        Statistics about the queue
                        
                        .. attribute:: dequeued_packets
                        
                        	Total number of packets dequeued from this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: enqueued_packets
                        
                        	Total number of packets enqueued to this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_bytes
                        
                        	Highest number of bytes enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: high_water_mark_packets
                        
                        	Highest number of packets enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tail_drops
                        
                        	Number packets dropped from this queue due to max size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                            self.yang_name = "packet-queue-stats"
                            self.yang_parent_name = "packet-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.dequeued_packets = YLeaf(YType.uint32, "dequeued-packets")

                            self.enqueued_packets = YLeaf(YType.uint32, "enqueued-packets")

                            self.high_water_mark_bytes = YLeaf(YType.uint32, "high-water-mark-bytes")

                            self.high_water_mark_packets = YLeaf(YType.uint32, "high-water-mark-packets")

                            self.tail_drops = YLeaf(YType.uint32, "tail-drops")
                            self._segment_path = lambda: "packet-queue-stats"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/traffic-counters/packet-queue/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, ['dequeued_packets', 'enqueued_packets', 'high_water_mark_bytes', 'high_water_mark_packets', 'tail_drops'], name, value)


            class Tunnels(Entity):
                """
                Tunnels information that PIM has
                
                .. attribute:: tunnel
                
                	PIM tunnel information
                	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Tunnels, self).__init__()

                    self.yang_name = "tunnels"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"tunnel" : ("tunnel", Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel)}

                    self.tunnel = YList(self)
                    self._segment_path = lambda: "tunnels"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Tunnels, [], name, value)


                class Tunnel(Entity):
                    """
                    PIM tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel, self).__init__()

                        self.yang_name = "tunnel"
                        self.yang_parent_name = "tunnels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-netio" : ("group_address_netio", Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio), "rp-address" : ("rp_address", Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress), "source-address" : ("source_address", Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress), "source-address-netio" : ("source_address_netio", Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio)}
                        self._child_list_classes = {}

                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.group_address_netio = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._children_yang_names.add("group-address-netio")

                        self.rp_address = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                        self.source_address_netio = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"
                        self._children_yang_names.add("source-address-netio")
                        self._segment_path = lambda: "tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/tunnels/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel, ['tunnel_name', 'vrf_name'], name, value)


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-netio"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address-netio"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


        class Process(Entity):
            """
            Process
            
            .. attribute:: issu
            
            	ISSU Information
            	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.Issu>`
            
            .. attribute:: nsf
            
            	PIM NSF information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.Nsr>`
            
            .. attribute:: summary
            
            	PIM Global Summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.Summary>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Ipv6Pim.Standby.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"issu" : ("issu", Ipv6Pim.Standby.Process.Issu), "nsf" : ("nsf", Ipv6Pim.Standby.Process.Nsf), "nsr" : ("nsr", Ipv6Pim.Standby.Process.Nsr), "summary" : ("summary", Ipv6Pim.Standby.Process.Summary)}
                self._child_list_classes = {}

                self.issu = Ipv6Pim.Standby.Process.Issu()
                self.issu.parent = self
                self._children_name_map["issu"] = "issu"
                self._children_yang_names.add("issu")

                self.nsf = Ipv6Pim.Standby.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"
                self._children_yang_names.add("nsf")

                self.nsr = Ipv6Pim.Standby.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
                self._children_yang_names.add("nsr")

                self.summary = Ipv6Pim.Standby.Process.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")
                self._segment_path = lambda: "process"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/%s" % self._segment_path()


            class Issu(Entity):
                """
                ISSU Information
                
                .. attribute:: checkpoint_idt_timestamp
                
                	Time when Checkpoint IDT done
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: eoc_received_timestamp
                
                	Time when EOC was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: ihms_received_timestamp
                
                	Time when IHMS done was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: informationvalid
                
                	Is Information valid ?
                	**type**\:  bool
                
                .. attribute:: is_checkpoint_idt_done
                
                	Was Checkpoint IDT done ?
                	**type**\:  bool
                
                .. attribute:: is_eoc_received
                
                	Was EOC received ?
                	**type**\:  bool
                
                .. attribute:: is_ihms_done_received
                
                	Was IHMS done received ?
                	**type**\:  bool
                
                .. attribute:: is_nbr_sync_received
                
                	Was NBR Sync achieved ?
                	**type**\:  bool
                
                .. attribute:: is_rib_sync_received
                
                	Was RIB Sync received ?
                	**type**\:  bool
                
                .. attribute:: last_ha_role_notification_received
                
                	Time when last HA role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_phase_notification_received
                
                	Time when last ISSU Phase nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_role_notification_received
                
                	Time when last ISSU role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: nbr_sync_received_timestamp
                
                	Time when NBR Sync was achieved
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: phase_issu
                
                	ISSU Phase
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: rib_sync_received_timestamp
                
                	Time when RIB Sync was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: role_ha
                
                	HA role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: role_issu
                
                	ISSU role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.Process.Issu, self).__init__()

                    self.yang_name = "issu"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.checkpoint_idt_timestamp = YLeaf(YType.uint64, "checkpoint-idt-timestamp")

                    self.eoc_received_timestamp = YLeaf(YType.uint64, "eoc-received-timestamp")

                    self.ihms_received_timestamp = YLeaf(YType.uint64, "ihms-received-timestamp")

                    self.informationvalid = YLeaf(YType.boolean, "informationvalid")

                    self.is_checkpoint_idt_done = YLeaf(YType.boolean, "is-checkpoint-idt-done")

                    self.is_eoc_received = YLeaf(YType.boolean, "is-eoc-received")

                    self.is_ihms_done_received = YLeaf(YType.boolean, "is-ihms-done-received")

                    self.is_nbr_sync_received = YLeaf(YType.boolean, "is-nbr-sync-received")

                    self.is_rib_sync_received = YLeaf(YType.boolean, "is-rib-sync-received")

                    self.last_ha_role_notification_received = YLeaf(YType.uint64, "last-ha-role-notification-received")

                    self.last_issu_phase_notification_received = YLeaf(YType.uint64, "last-issu-phase-notification-received")

                    self.last_issu_role_notification_received = YLeaf(YType.uint64, "last-issu-role-notification-received")

                    self.nbr_sync_received_timestamp = YLeaf(YType.uint64, "nbr-sync-received-timestamp")

                    self.phase_issu = YLeaf(YType.int32, "phase-issu")

                    self.rib_sync_received_timestamp = YLeaf(YType.uint64, "rib-sync-received-timestamp")

                    self.role_ha = YLeaf(YType.int32, "role-ha")

                    self.role_issu = YLeaf(YType.int32, "role-issu")
                    self._segment_path = lambda: "issu"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.Process.Issu, ['checkpoint_idt_timestamp', 'eoc_received_timestamp', 'ihms_received_timestamp', 'informationvalid', 'is_checkpoint_idt_done', 'is_eoc_received', 'is_ihms_done_received', 'is_nbr_sync_received', 'is_rib_sync_received', 'last_ha_role_notification_received', 'last_issu_phase_notification_received', 'last_issu_role_notification_received', 'nbr_sync_received_timestamp', 'phase_issu', 'rib_sync_received_timestamp', 'role_ha', 'role_issu'], name, value)


            class Nsf(Entity):
                """
                PIM NSF information
                
                .. attribute:: configured_state
                
                	Is Multicast NSF Configured
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_sec
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_sec
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_sec
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: nsf_state
                
                	Are we currently in NSF
                	**type**\:  bool
                
                .. attribute:: nsf_time_left
                
                	Multicast NSF time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: nsf_timeout
                
                	Multicast NSF timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: waiting_membership
                
                	Waiting for IGMP/MLD
                	**type**\:  bool
                
                .. attribute:: waiting_timer
                
                	Waiting for NSF timer expiry
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.configured_state = YLeaf(YType.boolean, "configured-state")

                    self.last_icd_notif_recv = YLeaf(YType.int64, "last-icd-notif-recv")

                    self.last_icd_notif_recv_sec = YLeaf(YType.int32, "last-icd-notif-recv-sec")

                    self.last_nsf_off = YLeaf(YType.int64, "last-nsf-off")

                    self.last_nsf_off_sec = YLeaf(YType.int32, "last-nsf-off-sec")

                    self.last_nsf_on = YLeaf(YType.int64, "last-nsf-on")

                    self.last_nsf_on_sec = YLeaf(YType.int32, "last-nsf-on-sec")

                    self.nsf_state = YLeaf(YType.boolean, "nsf-state")

                    self.nsf_time_left = YLeaf(YType.uint32, "nsf-time-left")

                    self.nsf_timeout = YLeaf(YType.uint32, "nsf-timeout")

                    self.respawn_count = YLeaf(YType.uint32, "respawn-count")

                    self.waiting_membership = YLeaf(YType.boolean, "waiting-membership")

                    self.waiting_timer = YLeaf(YType.boolean, "waiting-timer")
                    self._segment_path = lambda: "nsf"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.Process.Nsf, ['configured_state', 'last_icd_notif_recv', 'last_icd_notif_recv_sec', 'last_nsf_off', 'last_nsf_off_sec', 'last_nsf_on', 'last_nsf_on_sec', 'nsf_state', 'nsf_time_left', 'nsf_timeout', 'respawn_count', 'waiting_membership', 'waiting_timer'], name, value)


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: count_connection_dn
                
                	No. of times connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_connection_up
                
                	No. of times connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_connection_dn
                
                	Time when connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_up
                
                	Time when connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: rmf_timer_expiry
                
                	Time for RMF timer to expire
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: rmf_timer_valid
                
                	Is RMF timer running ?
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.count_connection_dn = YLeaf(YType.uint32, "count-connection-dn")

                    self.count_connection_up = YLeaf(YType.uint32, "count-connection-up")

                    self.count_rmf_not_ready = YLeaf(YType.uint32, "count-rmf-not-ready")

                    self.count_rmf_ready = YLeaf(YType.uint32, "count-rmf-ready")

                    self.last_connection_dn = YLeaf(YType.uint64, "last-connection-dn")

                    self.last_connection_up = YLeaf(YType.uint64, "last-connection-up")

                    self.last_rmf_not_ready = YLeaf(YType.uint64, "last-rmf-not-ready")

                    self.last_rmf_ready = YLeaf(YType.uint64, "last-rmf-ready")

                    self.partner_connected = YLeaf(YType.boolean, "partner-connected")

                    self.rmf_notification_done = YLeaf(YType.boolean, "rmf-notification-done")

                    self.rmf_timer_expiry = YLeaf(YType.uint64, "rmf-timer-expiry")

                    self.rmf_timer_valid = YLeaf(YType.boolean, "rmf-timer-valid")

                    self.state = YLeaf(YType.uint8, "state")
                    self._segment_path = lambda: "nsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.Process.Nsr, ['count_connection_dn', 'count_connection_up', 'count_rmf_not_ready', 'count_rmf_ready', 'last_connection_dn', 'last_connection_up', 'last_rmf_not_ready', 'last_rmf_ready', 'partner_connected', 'rmf_notification_done', 'rmf_timer_expiry', 'rmf_timer_valid', 'state'], name, value)


            class Summary(Entity):
                """
                PIM Global Summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.Process.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                    self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                    self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                    self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                    self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                    self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                    self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                    self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                    self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                    self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                    self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                    self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                    self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                    self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                    self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                    self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                    self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                    self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                    self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                    self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                    self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                    self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                    self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                    self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                    self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                    self.register_count = YLeaf(YType.uint32, "register-count")

                    self.register_limit = YLeaf(YType.uint32, "register-limit")

                    self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                    self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                    self.route_count = YLeaf(YType.uint32, "route-count")

                    self.route_limit = YLeaf(YType.uint32, "route-limit")

                    self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                    self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                    self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                    self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                    self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                    self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                    self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.Process.Summary, ['bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_threshold', 'bsr_range_threshold', 'bsr_ranges_count', 'bsr_ranges_limit', 'global_auto_rp_ranges_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_threshold', 'global_bsr_ranges_count', 'global_bsr_ranges_limit', 'global_bsr_ranges_threshold', 'global_register_limit', 'is_bsr_ranges_threshold_reached', 'is_global_auto_rp_ranges_limit_reached', 'is_global_bsr_ranges_limit_reached', 'is_global_register_limit_reached', 'is_global_route_limit_reached', 'is_global_rxi_limit_reached', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'is_ranges_limit_reached', 'is_route_limit_reached', 'ranges_count', 'ranges_limit', 'ranges_threshold', 'register_count', 'register_limit', 'register_limit_reached', 'register_threshold', 'route_count', 'route_limit', 'route_low_water_mark', 'route_threshold', 'rxi_limit_reached', 'rxi_low_water_mark', 'topology_interface_state_count', 'topology_interface_state_limit', 'topology_interface_state_threshold'], name, value)


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF name
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Ipv6Pim.Standby.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"vrf" : ("vrf", Ipv6Pim.Standby.Vrfs.Vrf)}

                self.vrf = YList(self)
                self._segment_path = lambda: "vrfs"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Ipv6Pim.Standby.Vrfs, [], name, value)


            class Vrf(Entity):
                """
                VRF name
                
                .. attribute:: vrf_name  <key>
                
                	VRF name 
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: auto_rp
                
                	PIM Auto\-RP information
                	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.AutoRp>`
                
                .. attribute:: bgp_afs
                
                	PIM BGP SAFI table
                	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs>`
                
                .. attribute:: bidir_df_states
                
                	Bidirectional PIM DF election state table
                	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates>`
                
                .. attribute:: bidir_df_winners
                
                	Bidirectional PIM DF election winner table
                	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners>`
                
                .. attribute:: bsr
                
                	PIM BSR information
                	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr>`
                
                .. attribute:: context
                
                	PIM context information
                	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context>`
                
                .. attribute:: gre
                
                	GRE information
                	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre>`
                
                .. attribute:: group_map_rpfs
                
                	PIM group mapping information
                	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs>`
                
                .. attribute:: group_map_sources
                
                	PIM group\-mapping with source information
                	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources>`
                
                .. attribute:: ifrs_interfaces
                
                	PIM interfaces in forward reference store table
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: ifrs_summary
                
                	PIM interfaces in forward reference store summary
                	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary>`
                
                .. attribute:: interface_old_formats
                
                	PIM interfaces in old format
                	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats>`
                
                .. attribute:: interface_statistics
                
                	PIM interface statistics
                	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics>`
                
                .. attribute:: interfaces
                
                	PIM interfaces
                	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Interfaces>`
                
                .. attribute:: jp_statistics
                
                	PIM join prune statistics table
                	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics>`
                
                .. attribute:: mib_databases
                
                	PIM group database for mroute mibs table
                	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases>`
                
                .. attribute:: multicast_static_routes
                
                	PIM multicast static route table
                	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes>`
                
                .. attribute:: neighbor_old_formats
                
                	PIM neighbor table old format
                	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats>`
                
                .. attribute:: neighbor_summaries
                
                	PIM neighbor summary table
                	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries>`
                
                .. attribute:: neighbors
                
                	PIM neighbor table
                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Neighbors>`
                
                .. attribute:: net_io_tunnels
                
                	Tunnel information that NETIO has 
                	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels>`
                
                .. attribute:: ranges
                
                	PIM range list information
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges>`
                
                .. attribute:: route_policy
                
                	PIM route policy
                	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy>`
                
                .. attribute:: rpf_redirect
                
                	PIM ECMP RPF\-redirect bundle
                	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect>`
                
                .. attribute:: rpf_summary
                
                	PIM RPF registration summary
                	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary>`
                
                .. attribute:: safs
                
                	SAFI table and type
                	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs>`
                
                .. attribute:: summary
                
                	PIM summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Summary>`
                
                .. attribute:: table_contexts
                
                	PIM table context list
                	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TableContexts>`
                
                .. attribute:: topologies
                
                	PIM topology table
                	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies>`
                
                .. attribute:: topology_entry_flag_route_counts
                
                	Route count for topology with entry flag set
                	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts>`
                
                .. attribute:: topology_interface_flag_route_counts
                
                	Route count for topology with interface flag set
                	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts>`
                
                .. attribute:: topology_route_count
                
                	Topology route count information from PIM topology table
                	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount>`
                
                .. attribute:: traffic_counters
                
                	PIM message traffic counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters>`
                
                .. attribute:: tunnels
                
                	Tunnels information that PIM has
                	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Ipv6Pim.Standby.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"auto-rp" : ("auto_rp", Ipv6Pim.Standby.Vrfs.Vrf.AutoRp), "bgp-afs" : ("bgp_afs", Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs), "bidir-df-states" : ("bidir_df_states", Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates), "bidir-df-winners" : ("bidir_df_winners", Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners), "bsr" : ("bsr", Ipv6Pim.Standby.Vrfs.Vrf.Bsr), "context" : ("context", Ipv6Pim.Standby.Vrfs.Vrf.Context), "gre" : ("gre", Ipv6Pim.Standby.Vrfs.Vrf.Gre), "group-map-rpfs" : ("group_map_rpfs", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs), "group-map-sources" : ("group_map_sources", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources), "ifrs-interfaces" : ("ifrs_interfaces", Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces), "ifrs-summary" : ("ifrs_summary", Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary), "interface-old-formats" : ("interface_old_formats", Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats), "interface-statistics" : ("interface_statistics", Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics), "interfaces" : ("interfaces", Ipv6Pim.Standby.Vrfs.Vrf.Interfaces), "jp-statistics" : ("jp_statistics", Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics), "mib-databases" : ("mib_databases", Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases), "multicast-static-routes" : ("multicast_static_routes", Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes), "neighbor-old-formats" : ("neighbor_old_formats", Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats), "neighbor-summaries" : ("neighbor_summaries", Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries), "neighbors" : ("neighbors", Ipv6Pim.Standby.Vrfs.Vrf.Neighbors), "net-io-tunnels" : ("net_io_tunnels", Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels), "ranges" : ("ranges", Ipv6Pim.Standby.Vrfs.Vrf.Ranges), "route-policy" : ("route_policy", Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy), "rpf-redirect" : ("rpf_redirect", Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect), "rpf-summary" : ("rpf_summary", Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary), "safs" : ("safs", Ipv6Pim.Standby.Vrfs.Vrf.Safs), "summary" : ("summary", Ipv6Pim.Standby.Vrfs.Vrf.Summary), "table-contexts" : ("table_contexts", Ipv6Pim.Standby.Vrfs.Vrf.TableContexts), "topologies" : ("topologies", Ipv6Pim.Standby.Vrfs.Vrf.Topologies), "topology-entry-flag-route-counts" : ("topology_entry_flag_route_counts", Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts), "topology-interface-flag-route-counts" : ("topology_interface_flag_route_counts", Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts), "topology-route-count" : ("topology_route_count", Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount), "traffic-counters" : ("traffic_counters", Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters), "tunnels" : ("tunnels", Ipv6Pim.Standby.Vrfs.Vrf.Tunnels)}
                    self._child_list_classes = {}

                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                    self.auto_rp = Ipv6Pim.Standby.Vrfs.Vrf.AutoRp()
                    self.auto_rp.parent = self
                    self._children_name_map["auto_rp"] = "auto-rp"
                    self._children_yang_names.add("auto-rp")

                    self.bgp_afs = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs()
                    self.bgp_afs.parent = self
                    self._children_name_map["bgp_afs"] = "bgp-afs"
                    self._children_yang_names.add("bgp-afs")

                    self.bidir_df_states = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates()
                    self.bidir_df_states.parent = self
                    self._children_name_map["bidir_df_states"] = "bidir-df-states"
                    self._children_yang_names.add("bidir-df-states")

                    self.bidir_df_winners = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners()
                    self.bidir_df_winners.parent = self
                    self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                    self._children_yang_names.add("bidir-df-winners")

                    self.bsr = Ipv6Pim.Standby.Vrfs.Vrf.Bsr()
                    self.bsr.parent = self
                    self._children_name_map["bsr"] = "bsr"
                    self._children_yang_names.add("bsr")

                    self.context = Ipv6Pim.Standby.Vrfs.Vrf.Context()
                    self.context.parent = self
                    self._children_name_map["context"] = "context"
                    self._children_yang_names.add("context")

                    self.gre = Ipv6Pim.Standby.Vrfs.Vrf.Gre()
                    self.gre.parent = self
                    self._children_name_map["gre"] = "gre"
                    self._children_yang_names.add("gre")

                    self.group_map_rpfs = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs()
                    self.group_map_rpfs.parent = self
                    self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                    self._children_yang_names.add("group-map-rpfs")

                    self.group_map_sources = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources()
                    self.group_map_sources.parent = self
                    self._children_name_map["group_map_sources"] = "group-map-sources"
                    self._children_yang_names.add("group-map-sources")

                    self.ifrs_interfaces = Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    self._children_yang_names.add("ifrs-interfaces")

                    self.ifrs_summary = Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary()
                    self.ifrs_summary.parent = self
                    self._children_name_map["ifrs_summary"] = "ifrs-summary"
                    self._children_yang_names.add("ifrs-summary")

                    self.interface_old_formats = Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats()
                    self.interface_old_formats.parent = self
                    self._children_name_map["interface_old_formats"] = "interface-old-formats"
                    self._children_yang_names.add("interface-old-formats")

                    self.interface_statistics = Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics()
                    self.interface_statistics.parent = self
                    self._children_name_map["interface_statistics"] = "interface-statistics"
                    self._children_yang_names.add("interface-statistics")

                    self.interfaces = Ipv6Pim.Standby.Vrfs.Vrf.Interfaces()
                    self.interfaces.parent = self
                    self._children_name_map["interfaces"] = "interfaces"
                    self._children_yang_names.add("interfaces")

                    self.jp_statistics = Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics()
                    self.jp_statistics.parent = self
                    self._children_name_map["jp_statistics"] = "jp-statistics"
                    self._children_yang_names.add("jp-statistics")

                    self.mib_databases = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases()
                    self.mib_databases.parent = self
                    self._children_name_map["mib_databases"] = "mib-databases"
                    self._children_yang_names.add("mib-databases")

                    self.multicast_static_routes = Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes()
                    self.multicast_static_routes.parent = self
                    self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                    self._children_yang_names.add("multicast-static-routes")

                    self.neighbor_old_formats = Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats()
                    self.neighbor_old_formats.parent = self
                    self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                    self._children_yang_names.add("neighbor-old-formats")

                    self.neighbor_summaries = Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries()
                    self.neighbor_summaries.parent = self
                    self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                    self._children_yang_names.add("neighbor-summaries")

                    self.neighbors = Ipv6Pim.Standby.Vrfs.Vrf.Neighbors()
                    self.neighbors.parent = self
                    self._children_name_map["neighbors"] = "neighbors"
                    self._children_yang_names.add("neighbors")

                    self.net_io_tunnels = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels()
                    self.net_io_tunnels.parent = self
                    self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                    self._children_yang_names.add("net-io-tunnels")

                    self.ranges = Ipv6Pim.Standby.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"
                    self._children_yang_names.add("ranges")

                    self.route_policy = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy()
                    self.route_policy.parent = self
                    self._children_name_map["route_policy"] = "route-policy"
                    self._children_yang_names.add("route-policy")

                    self.rpf_redirect = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect()
                    self.rpf_redirect.parent = self
                    self._children_name_map["rpf_redirect"] = "rpf-redirect"
                    self._children_yang_names.add("rpf-redirect")

                    self.rpf_summary = Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary()
                    self.rpf_summary.parent = self
                    self._children_name_map["rpf_summary"] = "rpf-summary"
                    self._children_yang_names.add("rpf-summary")

                    self.safs = Ipv6Pim.Standby.Vrfs.Vrf.Safs()
                    self.safs.parent = self
                    self._children_name_map["safs"] = "safs"
                    self._children_yang_names.add("safs")

                    self.summary = Ipv6Pim.Standby.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.table_contexts = Ipv6Pim.Standby.Vrfs.Vrf.TableContexts()
                    self.table_contexts.parent = self
                    self._children_name_map["table_contexts"] = "table-contexts"
                    self._children_yang_names.add("table-contexts")

                    self.topologies = Ipv6Pim.Standby.Vrfs.Vrf.Topologies()
                    self.topologies.parent = self
                    self._children_name_map["topologies"] = "topologies"
                    self._children_yang_names.add("topologies")

                    self.topology_entry_flag_route_counts = Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                    self.topology_entry_flag_route_counts.parent = self
                    self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                    self._children_yang_names.add("topology-entry-flag-route-counts")

                    self.topology_interface_flag_route_counts = Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                    self.topology_interface_flag_route_counts.parent = self
                    self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                    self._children_yang_names.add("topology-interface-flag-route-counts")

                    self.topology_route_count = Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount()
                    self.topology_route_count.parent = self
                    self._children_name_map["topology_route_count"] = "topology-route-count"
                    self._children_yang_names.add("topology-route-count")

                    self.traffic_counters = Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"
                    self._children_yang_names.add("traffic-counters")

                    self.tunnels = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels()
                    self.tunnels.parent = self
                    self._children_name_map["tunnels"] = "tunnels"
                    self._children_yang_names.add("tunnels")
                    self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/vrfs/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf, ['vrf_name'], name, value)


                class AutoRp(Entity):
                    """
                    PIM Auto\-RP information
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.AutoRp, self).__init__()

                        self.yang_name = "auto-rp"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self._segment_path = lambda: "auto-rp"


                class BgpAfs(Entity):
                    """
                    PIM BGP SAFI table
                    
                    .. attribute:: bgp_af
                    
                    	PIM BGP SAFI information
                    	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs, self).__init__()

                        self.yang_name = "bgp-afs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"bgp-af" : ("bgp_af", Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf)}

                        self.bgp_af = YList(self)
                        self._segment_path = lambda: "bgp-afs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs, [], name, value)


                    class BgpAf(Entity):
                        """
                        PIM BGP SAFI information
                        
                        .. attribute:: extranet_path_count
                        
                        	Count of dependent extranet paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group
                        
                        	Group address
                        	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group>`
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: is_bgp_added
                        
                        	SAFI learnt from BGP
                        	**type**\:  bool
                        
                        .. attribute:: next_hop
                        
                        	Next hop address
                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop>`
                        
                        .. attribute:: route_distinguisher
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**length:** 0..256
                        
                        .. attribute:: source
                        
                        	Source address
                        	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf, self).__init__()

                            self.yang_name = "bgp-af"
                            self.yang_parent_name = "bgp-afs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group" : ("group", Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group), "next-hop" : ("next_hop", Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop), "source" : ("source", Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source)}
                            self._child_list_classes = {}

                            self.extranet_path_count = YLeaf(YType.uint32, "extranet-path-count")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.is_bgp_added = YLeaf(YType.boolean, "is-bgp-added")

                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                            self.group.parent = self
                            self._children_name_map["group"] = "group"
                            self._children_yang_names.add("group")

                            self.next_hop = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"
                            self._children_yang_names.add("next-hop")

                            self.source = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._children_yang_names.add("source")
                            self._segment_path = lambda: "bgp-af"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf, ['extranet_path_count', 'group_address', 'is_bgp_added', 'route_distinguisher', 'source_address'], name, value)


                        class Group(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__init__()

                                self.yang_name = "group"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class NextHop(Entity):
                            """
                            Next hop address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "next-hop"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Source(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class BidirDfStates(Entity):
                    """
                    Bidirectional PIM DF election state table
                    
                    .. attribute:: bidir_df_state
                    
                    	Bidirectional PIM DF Election Table Entry
                    	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates, self).__init__()

                        self.yang_name = "bidir-df-states"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"bidir-df-state" : ("bidir_df_state", Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState)}

                        self.bidir_df_state = YList(self)
                        self._segment_path = lambda: "bidir-df-states"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates, [], name, value)


                    class BidirDfState(Entity):
                        """
                        Bidirectional PIM DF Election Table Entry
                        
                        .. attribute:: election_state
                        
                        	DF Election State
                        	**type**\:  str
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: our_metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: our_metric_preference
                        
                        	MetricPreference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr>`
                        
                        .. attribute:: time_nano_seconds
                        
                        	Timer expires (nseconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: time_seconds
                        
                        	Timer expires (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__init__()

                            self.yang_name = "bidir-df-state"
                            self.yang_parent_name = "bidir-df-states"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"rp-address-xr" : ("rp_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr)}
                            self._child_list_classes = {}

                            self.election_state = YLeaf(YType.str, "election-state")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.our_metric = YLeaf(YType.uint32, "our-metric")

                            self.our_metric_preference = YLeaf(YType.uint32, "our-metric-preference")

                            self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.time_nano_seconds = YLeaf(YType.uint64, "time-nano-seconds")

                            self.time_seconds = YLeaf(YType.uint64, "time-seconds")

                            self.rp_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")
                            self._segment_path = lambda: "bidir-df-state"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState, ['election_state', 'interface_name', 'our_metric', 'our_metric_preference', 'pim_interface_name', 'rp_address', 'time_nano_seconds', 'time_seconds'], name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class BidirDfWinners(Entity):
                    """
                    Bidirectional PIM DF election winner table
                    
                    .. attribute:: bidir_df_winner
                    
                    	Bidirectional PIM DF election table entry
                    	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners, self).__init__()

                        self.yang_name = "bidir-df-winners"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"bidir-df-winner" : ("bidir_df_winner", Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner)}

                        self.bidir_df_winner = YList(self)
                        self._segment_path = lambda: "bidir-df-winners"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners, [], name, value)


                    class BidirDfWinner(Entity):
                        """
                        Bidirectional PIM DF election table entry
                        
                        .. attribute:: are_we_df
                        
                        	Are we DF
                        	**type**\:  bool
                        
                        .. attribute:: df_winner
                        
                        	DF Winner
                        	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner>`
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                        
                        .. attribute:: rp_lan
                        
                        	Is this the RP LAN
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__init__()

                            self.yang_name = "bidir-df-winner"
                            self.yang_parent_name = "bidir-df-winners"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"df-winner" : ("df_winner", Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner), "rp-address-xr" : ("rp_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr)}
                            self._child_list_classes = {}

                            self.are_we_df = YLeaf(YType.boolean, "are-we-df")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                            self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_lan = YLeaf(YType.boolean, "rp-lan")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.df_winner = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                            self.df_winner.parent = self
                            self._children_name_map["df_winner"] = "df-winner"
                            self._children_yang_names.add("df-winner")

                            self.rp_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")
                            self._segment_path = lambda: "bidir-df-winner"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, ['are_we_df', 'interface_name', 'metric', 'metric_preference', 'pim_interface_name', 'rp_address', 'rp_lan', 'uptime'], name, value)


                        class DfWinner(Entity):
                            """
                            DF Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                                self.yang_name = "df-winner"
                                self.yang_parent_name = "bidir-df-winner"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "df-winner"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-winner"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Bsr(Entity):
                    """
                    PIM BSR information
                    
                    .. attribute:: bsr_elections
                    
                    	PIM BSR election state
                    	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections>`
                    
                    .. attribute:: candidate_rps
                    
                    	PIM candidate\-RP
                    	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps>`
                    
                    .. attribute:: rp_caches
                    
                    	PIM BSR RP cache table
                    	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr, self).__init__()

                        self.yang_name = "bsr"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"bsr-elections" : ("bsr_elections", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections), "candidate-rps" : ("candidate_rps", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps), "rp-caches" : ("rp_caches", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches)}
                        self._child_list_classes = {}

                        self.bsr_elections = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections()
                        self.bsr_elections.parent = self
                        self._children_name_map["bsr_elections"] = "bsr-elections"
                        self._children_yang_names.add("bsr-elections")

                        self.candidate_rps = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps()
                        self.candidate_rps.parent = self
                        self._children_name_map["candidate_rps"] = "candidate-rps"
                        self._children_yang_names.add("candidate-rps")

                        self.rp_caches = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches()
                        self.rp_caches.parent = self
                        self._children_name_map["rp_caches"] = "rp-caches"
                        self._children_yang_names.add("rp-caches")
                        self._segment_path = lambda: "bsr"


                    class BsrElections(Entity):
                        """
                        PIM BSR election state
                        
                        .. attribute:: bsr_election
                        
                        	PIM BSR information
                        	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections, self).__init__()

                            self.yang_name = "bsr-elections"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"bsr-election" : ("bsr_election", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection)}

                            self.bsr_election = YList(self)
                            self._segment_path = lambda: "bsr-elections"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections, [], name, value)


                        class BsrElection(Entity):
                            """
                            PIM BSR information
                            
                            .. attribute:: pim_scope  <key>
                            
                            	BSR information
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: bootstrap_timeout
                            
                            	Bootstrap Timeout
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_address
                            
                            	BSR address
                            	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress>`
                            
                            .. attribute:: bsr_election_state
                            
                            	BSR Election State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_mask_length
                            
                            	Hash Function Mask Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_priority
                            
                            	BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_scope
                            
                            	BSR Scope
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_up_time
                            
                            	BSR Uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_address
                            
                            	C\-BSR address
                            	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                            
                            .. attribute:: candidate_bsr_flag
                            
                            	BSR Candidate Config Flag
                            	**type**\:  bool
                            
                            .. attribute:: candidate_bsr_mask_length
                            
                            	C\-BSR Hash Func. Mask Len
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_priority
                            
                            	C\-BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_state
                            
                            	BSR Candidate State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__init__()

                                self.yang_name = "bsr-election"
                                self.yang_parent_name = "bsr-elections"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"bsr-address" : ("bsr_address", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress), "candidate-bsr-address" : ("candidate_bsr_address", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress)}
                                self._child_list_classes = {}

                                self.pim_scope = YLeaf(YType.int32, "pim-scope")

                                self.bootstrap_timeout = YLeaf(YType.uint16, "bootstrap-timeout")

                                self.bsr_election_state = YLeaf(YType.uint32, "bsr-election-state")

                                self.bsr_mask_length = YLeaf(YType.uint8, "bsr-mask-length")

                                self.bsr_priority = YLeaf(YType.uint8, "bsr-priority")

                                self.bsr_scope = YLeaf(YType.uint16, "bsr-scope")

                                self.bsr_up_time = YLeaf(YType.uint16, "bsr-up-time")

                                self.candidate_bsr_flag = YLeaf(YType.boolean, "candidate-bsr-flag")

                                self.candidate_bsr_mask_length = YLeaf(YType.uint8, "candidate-bsr-mask-length")

                                self.candidate_bsr_priority = YLeaf(YType.uint8, "candidate-bsr-priority")

                                self.candidate_bsr_state = YLeaf(YType.uint32, "candidate-bsr-state")

                                self.bsr_address = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                self.bsr_address.parent = self
                                self._children_name_map["bsr_address"] = "bsr-address"
                                self._children_yang_names.add("bsr-address")

                                self.candidate_bsr_address = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                self.candidate_bsr_address.parent = self
                                self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                self._children_yang_names.add("candidate-bsr-address")
                                self._segment_path = lambda: "bsr-election" + "[pim-scope='" + self.pim_scope.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection, ['pim_scope', 'bootstrap_timeout', 'bsr_election_state', 'bsr_mask_length', 'bsr_priority', 'bsr_scope', 'bsr_up_time', 'candidate_bsr_flag', 'candidate_bsr_mask_length', 'candidate_bsr_priority', 'candidate_bsr_state'], name, value)


                            class BsrAddress(Entity):
                                """
                                BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                    self.yang_name = "bsr-address"
                                    self.yang_parent_name = "bsr-election"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "bsr-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class CandidateBsrAddress(Entity):
                                """
                                C\-BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                    self.yang_name = "candidate-bsr-address"
                                    self.yang_parent_name = "bsr-election"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "candidate-bsr-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class CandidateRps(Entity):
                        """
                        PIM candidate\-RP
                        
                        .. attribute:: candidate_rp
                        
                        	PIM BSR candidate RP information
                        	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps, self).__init__()

                            self.yang_name = "candidate-rps"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"candidate-rp" : ("candidate_rp", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp)}

                            self.candidate_rp = YList(self)
                            self._segment_path = lambda: "candidate-rps"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps, [], name, value)


                        class CandidateRp(Entity):
                            """
                            PIM BSR candidate RP information
                            
                            .. attribute:: rp_address  <key>
                            
                            	Candidate\-RP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp
                            
                            	Cand\-RP Address
                            	**type**\:   :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp>`
                            
                            .. attribute:: candidate_rp_advance_interval
                            
                            	Cand\-RP Adv Interval in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: candidate_rp_scope
                            
                            	Cand\-RP Scope
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: candidate_rp_uptime
                            
                            	Cand\-RP uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_access
                            
                            	Group Ranges Using this Cand\-RP
                            	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                            
                            .. attribute:: crp_holdtime
                            
                            	Cand\-RP Holdtime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_priority
                            
                            	Cand\-RP Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rps"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"candidate-rp" : ("candidate_rp", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp)}
                                self._child_list_classes = {"crp-access" : ("crp_access", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess)}

                                self.rp_address = YLeaf(YType.str, "rp-address")

                                self.acl_name = YLeaf(YType.str, "acl-name")

                                self.candidate_rp_advance_interval = YLeaf(YType.uint16, "candidate-rp-advance-interval")

                                self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                                self.candidate_rp_scope = YLeaf(YType.int32, "candidate-rp-scope")

                                self.candidate_rp_uptime = YLeaf(YType.uint16, "candidate-rp-uptime")

                                self.crp_holdtime = YLeaf(YType.uint16, "crp-holdtime")

                                self.crp_priority = YLeaf(YType.uint8, "crp-priority")

                                self.candidate_rp = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp()
                                self.candidate_rp.parent = self
                                self._children_name_map["candidate_rp"] = "candidate-rp"
                                self._children_yang_names.add("candidate-rp")

                                self.crp_access = YList(self)
                                self._segment_path = lambda: "candidate-rp" + "[rp-address='" + self.rp_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, ['rp_address', 'acl_name', 'candidate_rp_advance_interval', 'candidate_rp_mode', 'candidate_rp_scope', 'candidate_rp_uptime', 'crp_holdtime', 'crp_priority'], name, value)


                            class CandidateRp(Entity):
                                """
                                Cand\-RP Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__init__()

                                    self.yang_name = "candidate-rp"
                                    self.yang_parent_name = "candidate-rp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "candidate-rp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class CrpAccess(Entity):
                                """
                                Group Ranges Using this Cand\-RP
                                
                                .. attribute:: acl_name
                                
                                	Group Access\-List Name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: candidate_rp_mode
                                
                                	Cand\-RP Mode
                                	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                    self.yang_name = "crp-access"
                                    self.yang_parent_name = "candidate-rp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.acl_name = YLeaf(YType.str, "acl-name")

                                    self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")
                                    self._segment_path = lambda: "crp-access"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, ['acl_name', 'candidate_rp_mode'], name, value)


                    class RpCaches(Entity):
                        """
                        PIM BSR RP cache table
                        
                        .. attribute:: rp_cache
                        
                        	PIM BSR RP cache
                        	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches, self).__init__()

                            self.yang_name = "rp-caches"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"rp-cache" : ("rp_cache", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache)}

                            self.rp_cache = YList(self)
                            self._segment_path = lambda: "rp-caches"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches, [], name, value)


                        class RpCache(Entity):
                            """
                            PIM BSR RP cache
                            
                            .. attribute:: group_prefix  <key>
                            
                            	Group prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: candidate_rp_group_count
                            
                            	C\-RP count for this Prefix
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: candidate_rp_list
                            
                            	C\-RP list for this prefix
                            	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList>`
                            
                            .. attribute:: group_prefix_length
                            
                            	Group Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_prefix_xr
                            
                            	Group Prefix
                            	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__init__()

                                self.yang_name = "rp-cache"
                                self.yang_parent_name = "rp-caches"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"candidate-rp-list" : ("candidate_rp_list", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList), "group-prefix-xr" : ("group_prefix_xr", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr)}
                                self._child_list_classes = {}

                                self.group_prefix = YLeaf(YType.str, "group-prefix")

                                self.candidate_rp_group_count = YLeaf(YType.uint32, "candidate-rp-group-count")

                                self.group_prefix_length = YLeaf(YType.uint32, "group-prefix-length")

                                self.candidate_rp_list = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                self.candidate_rp_list.parent = self
                                self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                self._children_yang_names.add("candidate-rp-list")

                                self.group_prefix_xr = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                self.group_prefix_xr.parent = self
                                self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                                self._children_yang_names.add("group-prefix-xr")
                                self._segment_path = lambda: "rp-cache" + "[group-prefix='" + self.group_prefix.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache, ['group_prefix', 'candidate_rp_group_count', 'group_prefix_length'], name, value)


                            class CandidateRpList(Entity):
                                """
                                C\-RP list for this prefix
                                
                                .. attribute:: pim_bsr_crp_bag
                                
                                	pim bsr crp bag
                                	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                    self.yang_name = "candidate-rp-list"
                                    self.yang_parent_name = "rp-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"pim-bsr-crp-bag" : ("pim_bsr_crp_bag", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag)}

                                    self.pim_bsr_crp_bag = YList(self)
                                    self._segment_path = lambda: "candidate-rp-list"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, [], name, value)


                                class PimBsrCrpBag(Entity):
                                    """
                                    pim bsr crp bag
                                    
                                    .. attribute:: candidate_rp_address
                                    
                                    	C\-RP address
                                    	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                    
                                    .. attribute:: candidate_rp_expires
                                    
                                    	C\-RP Expires
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_holdtime
                                    
                                    	C\-RP Holdtime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_priority
                                    
                                    	C\-RP Priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: candidate_rp_up_time
                                    
                                    	C\-RP Uptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protocol
                                    
                                    	PIM Protocol
                                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                        self.yang_name = "pim-bsr-crp-bag"
                                        self.yang_parent_name = "candidate-rp-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"candidate-rp-address" : ("candidate_rp_address", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress)}
                                        self._child_list_classes = {}

                                        self.candidate_rp_expires = YLeaf(YType.uint16, "candidate-rp-expires")

                                        self.candidate_rp_holdtime = YLeaf(YType.uint16, "candidate-rp-holdtime")

                                        self.candidate_rp_priority = YLeaf(YType.uint8, "candidate-rp-priority")

                                        self.candidate_rp_up_time = YLeaf(YType.uint16, "candidate-rp-up-time")

                                        self.protocol = YLeaf(YType.enumeration, "protocol")

                                        self.candidate_rp_address = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                        self.candidate_rp_address.parent = self
                                        self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                        self._children_yang_names.add("candidate-rp-address")
                                        self._segment_path = lambda: "pim-bsr-crp-bag"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, ['candidate_rp_expires', 'candidate_rp_holdtime', 'candidate_rp_priority', 'candidate_rp_up_time', 'protocol'], name, value)


                                    class CandidateRpAddress(Entity):
                                        """
                                        C\-RP address
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                            self.yang_name = "candidate-rp-address"
                                            self.yang_parent_name = "pim-bsr-crp-bag"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                            self._segment_path = lambda: "candidate-rp-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class GroupPrefixXr(Entity):
                                """
                                Group Prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                    self.yang_name = "group-prefix-xr"
                                    self.yang_parent_name = "rp-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-prefix-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Context(Entity):
                    """
                    PIM context information
                    
                    .. attribute:: active_table_count
                    
                    	Number of active Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: allow_rp_configured
                    
                    	Allow RP Configured
                    	**type**\:  bool
                    
                    .. attribute:: allow_rp_group_list
                    
                    	Allow RP Group\-List ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: allow_rp_rp_list
                    
                    	Allow RP RP\-list ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: anycast_rp_configured
                    
                    	Anycast\-RP config
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_policy_name
                    
                    	Anycast\-RP Policy Name
                    	**type**\:  str
                    
                    .. attribute:: anycast_rp_range
                    
                    	Anycast\-RP Ranges
                    	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange>`
                    
                    .. attribute:: bgp_auto_discovery_configured
                    
                    	BGP Auto\-Discovery configured
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery_type
                    
                    	BGP Auto Discovery Type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_i_pmsi_added
                    
                    	BGP I\-PMSI Added
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_address
                    
                    	BGP remote interface address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_remote_interface
                    
                    	BGP remote interface handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: bgp_remote_interface_name
                    
                    	BGP remote interface name
                    	**type**\:  str
                    
                    .. attribute:: bgp_remote_on
                    
                    	BGP remote interface status
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_state
                    
                    	BGP remote interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_source_active_announce
                    
                    	Send BGP Source\-Active Announcements
                    	**type**\:  bool
                    
                    .. attribute:: export_route_target
                    
                    	Export Route Targets
                    	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget>`
                    
                    .. attribute:: gin_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: gin_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: gin_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: import_route_target
                    
                    	Import Route Targets
                    	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget>`
                    
                    .. attribute:: in_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: in_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: in_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_signaling_local_enabled
                    
                    	Inband signaling Local enabled
                    	**type**\:  bool
                    
                    .. attribute:: in_band_signaling_remote_enabled
                    
                    	Inband signaling Remote enabled
                    	**type**\:  bool
                    
                    .. attribute:: inter_autonomous_system_enabled
                    
                    	Inter\-AS Enabled
                    	**type**\:  bool
                    
                    .. attribute:: ir_maximum_mdt_aggregation
                    
                    	IR MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_announce_interval
                    
                    	IR Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_switchover_interval
                    
                    	IR Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_interface
                    
                    	IRMDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: ir_mdt_mtu
                    
                    	IRMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_name
                    
                    	IR MDT Name
                    	**type**\:  str
                    
                    .. attribute:: ir_mdt_rpf_identifier
                    
                    	IR RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_tail_label
                    
                    	IR Tail Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active
                    	**type**\:  bool
                    
                    .. attribute:: is_active_ital
                    
                    	Active ITAL
                    	**type**\:  bool
                    
                    .. attribute:: is_all_interface_disable_operation
                    
                    	PIM all interface disable operation
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_enabled
                    
                    	Auto RP Listen Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_sock_add
                    
                    	Auto RP listen sock add
                    	**type**\:  bool
                    
                    .. attribute:: is_create_gin_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_in_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_ir_mdt_interface
                    
                    	Create IR MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mdt_interface
                    
                    	Create MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mldp_mdt_interface
                    
                    	Create MLDP MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_rsvp_te_mdt_interface
                    
                    	Create RSVP\-TE MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_default_granges
                    
                    	Default granges
                    	**type**\:  bool
                    
                    .. attribute:: is_gin_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_in_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_ir_mdt_owner
                    
                    	IR MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_added
                    
                    	VRF LPTS filter added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_m_host_publish_pending
                    
                    	Publish pending for MHost Default interface
                    	**type**\:  bool
                    
                    .. attribute:: is_mdt_owner
                    
                    	MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mldp_mdt_owner
                    
                    	MLDP MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mrib_register
                    
                    	MRIB Register
                    	**type**\:  bool
                    
                    .. attribute:: is_multicast_rib_registration
                    
                    	Mcast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converge_received
                    
                    	PIM NSF RIB converge received
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converged
                    
                    	PIM NSF RIB converged
                    	**type**\:  bool
                    
                    .. attribute:: is_redistribution_reset
                    
                    	Pending redist reset
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_added
                    
                    	VRF LPTS filter added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_add_required
                    
                    	VRF required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_added
                    
                    	VRF added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_enabled
                    
                    	PIM RIB multiplath enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_interface_hash
                    
                    	PIM RIB multipath interface hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_hash
                    
                    	PIM RIB multipath source based hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_next_hop_hash
                    
                    	PIM RIB multipath source\-nexthop hash
                    	**type**\:  bool
                    
                    .. attribute:: is_routing_enabled
                    
                    	Routing Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rsvp_te_mdt_owner
                    
                    	RSVP\-TE MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_add_required
                    
                    	VRF required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_added
                    
                    	VRF added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_add_required
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_added
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind
                    
                    	VRF bound on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind_required
                    
                    	VRF bind required on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_unicast_rib_registration
                    
                    	Ucast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: maximum_mdt_aggregation
                    
                    	MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_announce_interval
                    
                    	Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_switchover_interval
                    
                    	Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_default_group
                    
                    	MDT Default group
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_gre_remote_rpf_identifier
                    
                    	GRE\-MDT Remote RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_gre_rpf_identifier
                    
                    	GRE\-MDT RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_immediate_switch
                    
                    	MDT Immediate Switch
                    	**type**\:  bool
                    
                    .. attribute:: mdt_interface
                    
                    	MDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mdt_mtu
                    
                    	MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_neighbor_filter_name
                    
                    	MDT Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: mdt_partitioned_ir_control_identifier
                    
                    	Partitioned IR MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_mdt_control_identifier
                    
                    	Partitioned MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_source
                    
                    	MDT source
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_source_interface
                    
                    	MDT Source Interface Name
                    	**type**\:  str
                    
                    .. attribute:: mhost_default_interface_config
                    
                    	Configured Mhost Defint
                    	**type**\:  str
                    
                    .. attribute:: mhost_interface
                    
                    	MHost handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mldp_auto_rp_announce_tree_added
                    
                    	MLDP Autorp Announce Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_auto_rp_discovery_tree_added
                    
                    	MLDP Autorp Discovery Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_bsr_control_tree_added
                    
                    	MLDP BSR Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_control_head_lsm_identifier
                    
                    	MLDP MVPN Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_local_label
                    
                    	Partitioned MDT Head local label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_lsm_identifier
                    
                    	MLDP Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_maximum_mdt_aggregation
                    
                    	MLDP MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_announce_interval
                    
                    	MLDP Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_switchover_interval
                    
                    	MLDP Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_interface
                    
                    	MLDP MDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mldp_mdt_mtu
                    
                    	MLDP MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_name
                    
                    	MLDP MDT Name
                    	**type**\:  str
                    
                    .. attribute:: mldp_mdt_remote_rpf_identifier
                    
                    	MLDP Remote RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_rpf_identifier
                    
                    	MLDP RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partioned_mp2m_ptree
                    
                    	MP2MP Partitioned MDT tree
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_head_lsm_identifier
                    
                    	Partitioned MDT Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_configured
                    
                    	MLDP Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_mdt_identifier
                    
                    	MLDP Partitioned MDT Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_head_lsm_identifier
                    
                    	MLDP Remote Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_partitioned_mdt_configured
                    
                    	MLDP Remote Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_root_address
                    
                    	MLDP Root addresses
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_root_count
                    
                    	MLDP Root count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: murib_id
                    
                    	MURIB ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: non_default_vrf_count_on_socket
                    
                    	Count of non\-default vrfs on raw socket
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: organization_unique_identifier
                    
                    	OUI for VPN\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mpte_li_drop
                    
                    	Route LI updates dropped for P2MP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: physical_interface_count
                    
                    	Enabled Physical Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: redistribution_reset_count
                    
                    	Redist reset count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_default_group
                    
                    	Remote Default Group
                    	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup>`
                    
                    .. attribute:: remote_table_id
                    
                    	Remote Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_distinguisher
                    
                    	RD value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: rpf_default_table
                    
                    	RPF Default Table
                    	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable>`
                    
                    .. attribute:: rpf_id
                    
                    	RPF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_policy_name
                    
                    	RPF topology selection route\-policy name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_maximum_mdt_aggregation
                    
                    	RSVP\-TE MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_announce_interval
                    
                    	RSVP\-TE Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_switchover_interval
                    
                    	RSVP\-TE Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_interface
                    
                    	RSVP\-TEMDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: rsvp_te_mdt_mtu
                    
                    	RSVP\-TEMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_name
                    
                    	RSVP\-TE MDT Name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_mdt_rpf_identifier
                    
                    	RSVP\-TE RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_static_p2mp_count
                    
                    	Number of Static P2MP\-TE MDT
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	PIM is using MuRIB
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_time
                    
                    	S,G Expiry Time Configured, in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sg_expiry_timer_configured
                    
                    	S,G Expiry Timer Configured
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_timer_sg_list
                    
                    	S,G expiry timer ACL name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: stale_rd_present
                    
                    	RD is stale
                    	**type**\:  bool
                    
                    .. attribute:: suppress_pim_data_mdt_tlv
                    
                    	Suppress PIM Data\-MDT TLV Announcements
                    	**type**\:  bool
                    
                    .. attribute:: suppress_shared_tree_join
                    
                    	Suppress Shared\-Tree Joins
                    	**type**\:  bool
                    
                    .. attribute:: table_count
                    
                    	Number of configured Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: umh
                    
                    	Join UMH Core\-Tree
                    	**type**\:  bool
                    
                    .. attribute:: valid_rd_present
                    
                    	RD is valid
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface_count
                    
                    	Enabled Virtual Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: virtual_mlc_interface_name
                    
                    	Virtual master line card Interface
                    	**type**\:  str
                    
                    .. attribute:: vpn_index
                    
                    	VPN Index
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Context, self).__init__()

                        self.yang_name = "context"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"remote-default-group" : ("remote_default_group", Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup), "rpf-default-table" : ("rpf_default_table", Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable)}
                        self._child_list_classes = {"anycast-rp-range" : ("anycast_rp_range", Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange), "export-route-target" : ("export_route_target", Ipv6Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget), "import-route-target" : ("import_route_target", Ipv6Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget)}

                        self.active_table_count = YLeaf(YType.uint32, "active-table-count")

                        self.allow_rp_configured = YLeaf(YType.boolean, "allow-rp-configured")

                        self.allow_rp_group_list = YLeaf(YType.str, "allow-rp-group-list")

                        self.allow_rp_rp_list = YLeaf(YType.str, "allow-rp-rp-list")

                        self.anycast_rp_configured = YLeaf(YType.boolean, "anycast-rp-configured")

                        self.anycast_rp_policy_name = YLeaf(YType.str, "anycast-rp-policy-name")

                        self.bgp_auto_discovery_configured = YLeaf(YType.boolean, "bgp-auto-discovery-configured")

                        self.bgp_auto_discovery_type = YLeaf(YType.uint32, "bgp-auto-discovery-type")

                        self.bgp_i_pmsi_added = YLeaf(YType.boolean, "bgp-i-pmsi-added")

                        self.bgp_remote_address = YLeaf(YType.str, "bgp-remote-address")

                        self.bgp_remote_interface = YLeaf(YType.str, "bgp-remote-interface")

                        self.bgp_remote_interface_name = YLeaf(YType.str, "bgp-remote-interface-name")

                        self.bgp_remote_on = YLeaf(YType.boolean, "bgp-remote-on")

                        self.bgp_remote_state = YLeaf(YType.uint32, "bgp-remote-state")

                        self.bgp_source_active_announce = YLeaf(YType.boolean, "bgp-source-active-announce")

                        self.gin_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-announce-interval")

                        self.gin_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-switchover-interval")

                        self.gin_b_and_mdt_interface = YLeaf(YType.str, "gin-b-and-mdt-interface")

                        self.gin_b_and_mdt_mtu = YLeaf(YType.uint32, "gin-b-and-mdt-mtu")

                        self.gin_b_and_mdt_name = YLeaf(YType.str, "gin-b-and-mdt-name")

                        self.gin_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "gin-b-and-mdt-rpf-identifier")

                        self.gin_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "gin-band-maximum-mdt-aggregation")

                        self.in_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-announce-interval")

                        self.in_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-switchover-interval")

                        self.in_b_and_mdt_interface = YLeaf(YType.str, "in-b-and-mdt-interface")

                        self.in_b_and_mdt_mtu = YLeaf(YType.uint32, "in-b-and-mdt-mtu")

                        self.in_b_and_mdt_name = YLeaf(YType.str, "in-b-and-mdt-name")

                        self.in_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "in-b-and-mdt-rpf-identifier")

                        self.in_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "in-band-maximum-mdt-aggregation")

                        self.in_band_signaling_local_enabled = YLeaf(YType.boolean, "in-band-signaling-local-enabled")

                        self.in_band_signaling_remote_enabled = YLeaf(YType.boolean, "in-band-signaling-remote-enabled")

                        self.inter_autonomous_system_enabled = YLeaf(YType.boolean, "inter-autonomous-system-enabled")

                        self.ir_maximum_mdt_aggregation = YLeaf(YType.uint32, "ir-maximum-mdt-aggregation")

                        self.ir_mdt_data_announce_interval = YLeaf(YType.uint32, "ir-mdt-data-announce-interval")

                        self.ir_mdt_data_switchover_interval = YLeaf(YType.uint32, "ir-mdt-data-switchover-interval")

                        self.ir_mdt_interface = YLeaf(YType.str, "ir-mdt-interface")

                        self.ir_mdt_mtu = YLeaf(YType.uint32, "ir-mdt-mtu")

                        self.ir_mdt_name = YLeaf(YType.str, "ir-mdt-name")

                        self.ir_mdt_rpf_identifier = YLeaf(YType.uint32, "ir-mdt-rpf-identifier")

                        self.ir_mdt_tail_label = YLeaf(YType.uint32, "ir-mdt-tail-label")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_active_ital = YLeaf(YType.boolean, "is-active-ital")

                        self.is_all_interface_disable_operation = YLeaf(YType.boolean, "is-all-interface-disable-operation")

                        self.is_auto_rp_listen_enabled = YLeaf(YType.boolean, "is-auto-rp-listen-enabled")

                        self.is_auto_rp_listen_sock_add = YLeaf(YType.boolean, "is-auto-rp-listen-sock-add")

                        self.is_create_gin_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-gin-b-and-mdt-interface")

                        self.is_create_in_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-in-b-and-mdt-interface")

                        self.is_create_ir_mdt_interface = YLeaf(YType.boolean, "is-create-ir-mdt-interface")

                        self.is_create_mdt_interface = YLeaf(YType.boolean, "is-create-mdt-interface")

                        self.is_create_mldp_mdt_interface = YLeaf(YType.boolean, "is-create-mldp-mdt-interface")

                        self.is_create_rsvp_te_mdt_interface = YLeaf(YType.boolean, "is-create-rsvp-te-mdt-interface")

                        self.is_default_granges = YLeaf(YType.boolean, "is-default-granges")

                        self.is_gin_b_and_mdt_owner = YLeaf(YType.boolean, "is-gin-b-and-mdt-owner")

                        self.is_in_b_and_mdt_owner = YLeaf(YType.boolean, "is-in-b-and-mdt-owner")

                        self.is_ir_mdt_owner = YLeaf(YType.boolean, "is-ir-mdt-owner")

                        self.is_lpts_socket_add_required = YLeaf(YType.boolean, "is-lpts-socket-add-required")

                        self.is_lpts_socket_added = YLeaf(YType.boolean, "is-lpts-socket-added")

                        self.is_m_host_publish_pending = YLeaf(YType.boolean, "is-m-host-publish-pending")

                        self.is_mdt_owner = YLeaf(YType.boolean, "is-mdt-owner")

                        self.is_mldp_mdt_owner = YLeaf(YType.boolean, "is-mldp-mdt-owner")

                        self.is_mrib_register = YLeaf(YType.boolean, "is-mrib-register")

                        self.is_multicast_rib_registration = YLeaf(YType.boolean, "is-multicast-rib-registration")

                        self.is_pim_nsf_rib_converge_received = YLeaf(YType.boolean, "is-pim-nsf-rib-converge-received")

                        self.is_pim_nsf_rib_converged = YLeaf(YType.boolean, "is-pim-nsf-rib-converged")

                        self.is_redistribution_reset = YLeaf(YType.boolean, "is-redistribution-reset")

                        self.is_register_injection_lpts_socket_add_required = YLeaf(YType.boolean, "is-register-injection-lpts-socket-add-required")

                        self.is_register_injection_lpts_socket_added = YLeaf(YType.boolean, "is-register-injection-lpts-socket-added")

                        self.is_register_injection_socket_add_required = YLeaf(YType.boolean, "is-register-injection-socket-add-required")

                        self.is_register_injection_socket_added = YLeaf(YType.boolean, "is-register-injection-socket-added")

                        self.is_rib_multipath_enabled = YLeaf(YType.boolean, "is-rib-multipath-enabled")

                        self.is_rib_multipath_interface_hash = YLeaf(YType.boolean, "is-rib-multipath-interface-hash")

                        self.is_rib_multipath_source_hash = YLeaf(YType.boolean, "is-rib-multipath-source-hash")

                        self.is_rib_multipath_source_next_hop_hash = YLeaf(YType.boolean, "is-rib-multipath-source-next-hop-hash")

                        self.is_routing_enabled = YLeaf(YType.boolean, "is-routing-enabled")

                        self.is_rsvp_te_mdt_owner = YLeaf(YType.boolean, "is-rsvp-te-mdt-owner")

                        self.is_socket_add_required = YLeaf(YType.boolean, "is-socket-add-required")

                        self.is_socket_added = YLeaf(YType.boolean, "is-socket-added")

                        self.is_udp_socket_add_required = YLeaf(YType.boolean, "is-udp-socket-add-required")

                        self.is_udp_socket_added = YLeaf(YType.boolean, "is-udp-socket-added")

                        self.is_udp_socket_bind = YLeaf(YType.boolean, "is-udp-socket-bind")

                        self.is_udp_socket_bind_required = YLeaf(YType.boolean, "is-udp-socket-bind-required")

                        self.is_unicast_rib_registration = YLeaf(YType.boolean, "is-unicast-rib-registration")

                        self.maximum_mdt_aggregation = YLeaf(YType.uint32, "maximum-mdt-aggregation")

                        self.mdt_data_announce_interval = YLeaf(YType.uint32, "mdt-data-announce-interval")

                        self.mdt_data_switchover_interval = YLeaf(YType.uint32, "mdt-data-switchover-interval")

                        self.mdt_default_group = YLeaf(YType.str, "mdt-default-group")

                        self.mdt_gre_remote_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-remote-rpf-identifier")

                        self.mdt_gre_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-rpf-identifier")

                        self.mdt_immediate_switch = YLeaf(YType.boolean, "mdt-immediate-switch")

                        self.mdt_interface = YLeaf(YType.str, "mdt-interface")

                        self.mdt_mtu = YLeaf(YType.uint32, "mdt-mtu")

                        self.mdt_neighbor_filter_name = YLeaf(YType.str, "mdt-neighbor-filter-name")

                        self.mdt_partitioned_ir_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-ir-control-identifier")

                        self.mdt_partitioned_mdt_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-mdt-control-identifier")

                        self.mdt_source = YLeaf(YType.str, "mdt-source")

                        self.mdt_source_interface = YLeaf(YType.str, "mdt-source-interface")

                        self.mhost_default_interface_config = YLeaf(YType.str, "mhost-default-interface-config")

                        self.mhost_interface = YLeaf(YType.str, "mhost-interface")

                        self.mldp_auto_rp_announce_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-announce-tree-added")

                        self.mldp_auto_rp_discovery_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-discovery-tree-added")

                        self.mldp_bsr_control_tree_added = YLeaf(YType.boolean, "mldp-bsr-control-tree-added")

                        self.mldp_control_head_lsm_identifier = YLeaf(YType.uint32, "mldp-control-head-lsm-identifier")

                        self.mldp_head_local_label = YLeaf(YType.uint32, "mldp-head-local-label")

                        self.mldp_head_lsm_identifier = YLeaf(YType.uint32, "mldp-head-lsm-identifier")

                        self.mldp_maximum_mdt_aggregation = YLeaf(YType.uint32, "mldp-maximum-mdt-aggregation")

                        self.mldp_mdt_data_announce_interval = YLeaf(YType.uint32, "mldp-mdt-data-announce-interval")

                        self.mldp_mdt_data_switchover_interval = YLeaf(YType.uint32, "mldp-mdt-data-switchover-interval")

                        self.mldp_mdt_interface = YLeaf(YType.str, "mldp-mdt-interface")

                        self.mldp_mdt_mtu = YLeaf(YType.uint32, "mldp-mdt-mtu")

                        self.mldp_mdt_name = YLeaf(YType.str, "mldp-mdt-name")

                        self.mldp_mdt_remote_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-remote-rpf-identifier")

                        self.mldp_mdt_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-rpf-identifier")

                        self.mldp_partioned_mp2m_ptree = YLeaf(YType.boolean, "mldp-partioned-mp2m-ptree")

                        self.mldp_partitioned_head_lsm_identifier = YLeaf(YType.uint32, "mldp-partitioned-head-lsm-identifier")

                        self.mldp_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-partitioned-mdt-configured")

                        self.mldp_partitioned_mdt_identifier = YLeaf(YType.uint32, "mldp-partitioned-mdt-identifier")

                        self.mldp_remote_head_lsm_identifier = YLeaf(YType.uint32, "mldp-remote-head-lsm-identifier")

                        self.mldp_remote_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-remote-partitioned-mdt-configured")

                        self.mldp_root_address = YLeafList(YType.uint32, "mldp-root-address")

                        self.mldp_root_count = YLeaf(YType.uint32, "mldp-root-count")

                        self.murib_id = YLeaf(YType.uint32, "murib-id")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.non_default_vrf_count_on_socket = YLeaf(YType.uint32, "non-default-vrf-count-on-socket")

                        self.organization_unique_identifier = YLeaf(YType.uint32, "organization-unique-identifier")

                        self.p2mpte_li_drop = YLeaf(YType.uint32, "p2mpte-li-drop")

                        self.physical_interface_count = YLeaf(YType.uint64, "physical-interface-count")

                        self.redistribution_reset_count = YLeaf(YType.uint32, "redistribution-reset-count")

                        self.remote_table_id = YLeaf(YType.uint32, "remote-table-id")

                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                        self.rpf_id = YLeaf(YType.uint32, "rpf-id")

                        self.rpf_policy_name = YLeaf(YType.str, "rpf-policy-name")

                        self.rsvp_te_maximum_mdt_aggregation = YLeaf(YType.uint32, "rsvp-te-maximum-mdt-aggregation")

                        self.rsvp_te_mdt_data_announce_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-announce-interval")

                        self.rsvp_te_mdt_data_switchover_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-switchover-interval")

                        self.rsvp_te_mdt_interface = YLeaf(YType.str, "rsvp-te-mdt-interface")

                        self.rsvp_te_mdt_mtu = YLeaf(YType.uint32, "rsvp-te-mdt-mtu")

                        self.rsvp_te_mdt_name = YLeaf(YType.str, "rsvp-te-mdt-name")

                        self.rsvp_te_mdt_rpf_identifier = YLeaf(YType.uint32, "rsvp-te-mdt-rpf-identifier")

                        self.rsvp_te_mdt_static_p2mp_count = YLeaf(YType.uint32, "rsvp-te-mdt-static-p2mp-count")

                        self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                        self.sg_expiry_time = YLeaf(YType.uint16, "sg-expiry-time")

                        self.sg_expiry_timer_configured = YLeaf(YType.boolean, "sg-expiry-timer-configured")

                        self.sg_expiry_timer_sg_list = YLeaf(YType.str, "sg-expiry-timer-sg-list")

                        self.stale_rd_present = YLeaf(YType.boolean, "stale-rd-present")

                        self.suppress_pim_data_mdt_tlv = YLeaf(YType.boolean, "suppress-pim-data-mdt-tlv")

                        self.suppress_shared_tree_join = YLeaf(YType.boolean, "suppress-shared-tree-join")

                        self.table_count = YLeaf(YType.uint32, "table-count")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.umh = YLeaf(YType.boolean, "umh")

                        self.valid_rd_present = YLeaf(YType.boolean, "valid-rd-present")

                        self.virtual_interface_count = YLeaf(YType.uint64, "virtual-interface-count")

                        self.virtual_mlc_interface_name = YLeaf(YType.str, "virtual-mlc-interface-name")

                        self.vpn_index = YLeaf(YType.uint32, "vpn-index")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.remote_default_group = Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup()
                        self.remote_default_group.parent = self
                        self._children_name_map["remote_default_group"] = "remote-default-group"
                        self._children_yang_names.add("remote-default-group")

                        self.rpf_default_table = Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable()
                        self.rpf_default_table.parent = self
                        self._children_name_map["rpf_default_table"] = "rpf-default-table"
                        self._children_yang_names.add("rpf-default-table")

                        self.anycast_rp_range = YList(self)
                        self.export_route_target = YList(self)
                        self.import_route_target = YList(self)
                        self._segment_path = lambda: "context"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Context, ['active_table_count', 'allow_rp_configured', 'allow_rp_group_list', 'allow_rp_rp_list', 'anycast_rp_configured', 'anycast_rp_policy_name', 'bgp_auto_discovery_configured', 'bgp_auto_discovery_type', 'bgp_i_pmsi_added', 'bgp_remote_address', 'bgp_remote_interface', 'bgp_remote_interface_name', 'bgp_remote_on', 'bgp_remote_state', 'bgp_source_active_announce', 'gin_b_and_mdt_data_announce_interval', 'gin_b_and_mdt_data_switchover_interval', 'gin_b_and_mdt_interface', 'gin_b_and_mdt_mtu', 'gin_b_and_mdt_name', 'gin_b_and_mdt_rpf_identifier', 'gin_band_maximum_mdt_aggregation', 'in_b_and_mdt_data_announce_interval', 'in_b_and_mdt_data_switchover_interval', 'in_b_and_mdt_interface', 'in_b_and_mdt_mtu', 'in_b_and_mdt_name', 'in_b_and_mdt_rpf_identifier', 'in_band_maximum_mdt_aggregation', 'in_band_signaling_local_enabled', 'in_band_signaling_remote_enabled', 'inter_autonomous_system_enabled', 'ir_maximum_mdt_aggregation', 'ir_mdt_data_announce_interval', 'ir_mdt_data_switchover_interval', 'ir_mdt_interface', 'ir_mdt_mtu', 'ir_mdt_name', 'ir_mdt_rpf_identifier', 'ir_mdt_tail_label', 'is_active', 'is_active_ital', 'is_all_interface_disable_operation', 'is_auto_rp_listen_enabled', 'is_auto_rp_listen_sock_add', 'is_create_gin_b_and_mdt_interface', 'is_create_in_b_and_mdt_interface', 'is_create_ir_mdt_interface', 'is_create_mdt_interface', 'is_create_mldp_mdt_interface', 'is_create_rsvp_te_mdt_interface', 'is_default_granges', 'is_gin_b_and_mdt_owner', 'is_in_b_and_mdt_owner', 'is_ir_mdt_owner', 'is_lpts_socket_add_required', 'is_lpts_socket_added', 'is_m_host_publish_pending', 'is_mdt_owner', 'is_mldp_mdt_owner', 'is_mrib_register', 'is_multicast_rib_registration', 'is_pim_nsf_rib_converge_received', 'is_pim_nsf_rib_converged', 'is_redistribution_reset', 'is_register_injection_lpts_socket_add_required', 'is_register_injection_lpts_socket_added', 'is_register_injection_socket_add_required', 'is_register_injection_socket_added', 'is_rib_multipath_enabled', 'is_rib_multipath_interface_hash', 'is_rib_multipath_source_hash', 'is_rib_multipath_source_next_hop_hash', 'is_routing_enabled', 'is_rsvp_te_mdt_owner', 'is_socket_add_required', 'is_socket_added', 'is_udp_socket_add_required', 'is_udp_socket_added', 'is_udp_socket_bind', 'is_udp_socket_bind_required', 'is_unicast_rib_registration', 'maximum_mdt_aggregation', 'mdt_data_announce_interval', 'mdt_data_switchover_interval', 'mdt_default_group', 'mdt_gre_remote_rpf_identifier', 'mdt_gre_rpf_identifier', 'mdt_immediate_switch', 'mdt_interface', 'mdt_mtu', 'mdt_neighbor_filter_name', 'mdt_partitioned_ir_control_identifier', 'mdt_partitioned_mdt_control_identifier', 'mdt_source', 'mdt_source_interface', 'mhost_default_interface_config', 'mhost_interface', 'mldp_auto_rp_announce_tree_added', 'mldp_auto_rp_discovery_tree_added', 'mldp_bsr_control_tree_added', 'mldp_control_head_lsm_identifier', 'mldp_head_local_label', 'mldp_head_lsm_identifier', 'mldp_maximum_mdt_aggregation', 'mldp_mdt_data_announce_interval', 'mldp_mdt_data_switchover_interval', 'mldp_mdt_interface', 'mldp_mdt_mtu', 'mldp_mdt_name', 'mldp_mdt_remote_rpf_identifier', 'mldp_mdt_rpf_identifier', 'mldp_partioned_mp2m_ptree', 'mldp_partitioned_head_lsm_identifier', 'mldp_partitioned_mdt_configured', 'mldp_partitioned_mdt_identifier', 'mldp_remote_head_lsm_identifier', 'mldp_remote_partitioned_mdt_configured', 'mldp_root_address', 'mldp_root_count', 'murib_id', 'neighbor_filter_name', 'non_default_vrf_count_on_socket', 'organization_unique_identifier', 'p2mpte_li_drop', 'physical_interface_count', 'redistribution_reset_count', 'remote_table_id', 'route_distinguisher', 'rpf_id', 'rpf_policy_name', 'rsvp_te_maximum_mdt_aggregation', 'rsvp_te_mdt_data_announce_interval', 'rsvp_te_mdt_data_switchover_interval', 'rsvp_te_mdt_interface', 'rsvp_te_mdt_mtu', 'rsvp_te_mdt_name', 'rsvp_te_mdt_rpf_identifier', 'rsvp_te_mdt_static_p2mp_count', 'rump_enabled', 'sg_expiry_time', 'sg_expiry_timer_configured', 'sg_expiry_timer_sg_list', 'stale_rd_present', 'suppress_pim_data_mdt_tlv', 'suppress_shared_tree_join', 'table_count', 'table_id', 'umh', 'valid_rd_present', 'virtual_interface_count', 'virtual_mlc_interface_name', 'vpn_index', 'vrf_id'], name, value)


                    class AnycastRpRange(Entity):
                        """
                        Anycast\-RP Ranges
                        
                        .. attribute:: ancast_rp_marked
                        
                        	Anycast\-RP Range marked
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Anycast\-RP Range Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Anycast\-RP Range Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange, self).__init__()

                            self.yang_name = "anycast-rp-range"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"prefix" : ("prefix", Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix)}
                            self._child_list_classes = {}

                            self.ancast_rp_marked = YLeaf(YType.boolean, "ancast-rp-marked")

                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                            self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")
                            self._segment_path = lambda: "anycast-rp-range"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange, ['ancast_rp_marked', 'prefix_length'], name, value)


                        class Prefix(Entity):
                            """
                            Anycast\-RP Range Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "anycast-rp-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class ExportRouteTarget(Entity):
                        """
                        Export Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget, self).__init__()

                            self.yang_name = "export-route-target"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                            self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                            self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                            self.configured = YLeaf(YType.boolean, "configured")

                            self.route_target = YLeaf(YType.str, "route-target")

                            self.segment_border = YLeaf(YType.boolean, "segment-border")

                            self.update_pending = YLeaf(YType.boolean, "update-pending")
                            self._segment_path = lambda: "export-route-target"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget, ['anycast_rp', 'anycast_rp_marked', 'bgp_auto_discovery', 'configured', 'route_target', 'segment_border', 'update_pending'], name, value)


                    class ImportRouteTarget(Entity):
                        """
                        Import Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget, self).__init__()

                            self.yang_name = "import-route-target"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                            self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                            self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                            self.configured = YLeaf(YType.boolean, "configured")

                            self.route_target = YLeaf(YType.str, "route-target")

                            self.segment_border = YLeaf(YType.boolean, "segment-border")

                            self.update_pending = YLeaf(YType.boolean, "update-pending")
                            self._segment_path = lambda: "import-route-target"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget, ['anycast_rp', 'anycast_rp_marked', 'bgp_auto_discovery', 'configured', 'route_target', 'segment_border', 'update_pending'], name, value)


                    class RemoteDefaultGroup(Entity):
                        """
                        Remote Default Group
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__init__()

                            self.yang_name = "remote-default-group"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "remote-default-group"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfDefaultTable(Entity):
                        """
                        RPF Default Table
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable, self).__init__()

                            self.yang_name = "rpf-default-table"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                            self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                            self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                            self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                            self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.table_id = YLeaf(YType.uint32, "table-id")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")
                            self._segment_path = lambda: "rpf-default-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable, ['afi', 'is_active', 'is_ital_registration_done', 'is_rib_convergence', 'is_rib_convergence_received', 'is_rib_registration_done', 'rpf_registrations', 'safi', 'table_id', 'table_name', 'vrf_id'], name, value)


                class Gre(Entity):
                    """
                    GRE information
                    
                    .. attribute:: gre_hashes
                    
                    	GRE hash
                    	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes>`
                    
                    .. attribute:: gre_next_hops
                    
                    	GRE destination neighbor table
                    	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Gre, self).__init__()

                        self.yang_name = "gre"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"gre-hashes" : ("gre_hashes", Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes), "gre-next-hops" : ("gre_next_hops", Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops)}
                        self._child_list_classes = {}

                        self.gre_hashes = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes()
                        self.gre_hashes.parent = self
                        self._children_name_map["gre_hashes"] = "gre-hashes"
                        self._children_yang_names.add("gre-hashes")

                        self.gre_next_hops = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops()
                        self.gre_next_hops.parent = self
                        self._children_name_map["gre_next_hops"] = "gre-next-hops"
                        self._children_yang_names.add("gre-next-hops")
                        self._segment_path = lambda: "gre"


                    class GreHashes(Entity):
                        """
                        GRE hash
                        
                        .. attribute:: gre_hash
                        
                        	PIM GRE Hashed Underlying Interface
                        	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes, self).__init__()

                            self.yang_name = "gre-hashes"
                            self.yang_parent_name = "gre"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"gre-hash" : ("gre_hash", Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash)}

                            self.gre_hash = YList(self)
                            self._segment_path = lambda: "gre-hashes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes, [], name, value)


                        class GreHash(Entity):
                            """
                            PIM GRE Hashed Underlying Interface
                            
                            .. attribute:: source_address  <key>
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: destination_address  <key>
                            
                            	Destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: ifname  <key>
                            
                            	GRE Tunnel Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__init__()

                                self.yang_name = "gre-hash"
                                self.yang_parent_name = "gre-hashes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.ifname = YLeaf(YType.str, "ifname")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")
                                self._segment_path = lambda: "gre-hash" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[ifname='" + self.ifname.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash, ['source_address', 'destination_address', 'ifname', 'next_hop_interface'], name, value)


                    class GreNextHops(Entity):
                        """
                        GRE destination neighbor table
                        
                        .. attribute:: gre_next_hop
                        
                        	PIM GRE address next\-hop information
                        	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops, self).__init__()

                            self.yang_name = "gre-next-hops"
                            self.yang_parent_name = "gre"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"gre-next-hop" : ("gre_next_hop", Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop)}

                            self.gre_next_hop = YList(self)
                            self._segment_path = lambda: "gre-next-hops"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops, [], name, value)


                        class GreNextHop(Entity):
                            """
                            PIM GRE address next\-hop information
                            
                            .. attribute:: destination_address  <key>
                            
                            	GRE destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: gre_path
                            
                            	GRE Paths list
                            	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath>`
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__init__()

                                self.yang_name = "gre-next-hop"
                                self.yang_parent_name = "gre-next-hops"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"registered-address" : ("registered_address", Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress)}
                                self._child_list_classes = {"gre-path" : ("gre_path", Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath)}

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.is_connected = YLeaf(YType.uint8, "is-connected")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                self.registered_address = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                self.registered_address.parent = self
                                self._children_name_map["registered_address"] = "registered-address"
                                self._children_yang_names.add("registered-address")

                                self.gre_path = YList(self)
                                self._segment_path = lambda: "gre-next-hop" + "[destination-address='" + self.destination_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, ['destination_address', 'is_connected', 'metric', 'metric_preference'], name, value)


                            class GrePath(Entity):
                                """
                                GRE Paths list
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: gre_interface_name
                                
                                	GRE Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: gre_neighbor
                                
                                	GRE neighbor
                                	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                                
                                .. attribute:: gre_next_hop
                                
                                	GRE nexthop
                                	**type**\:   :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop>`
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_gre_interface_disabled
                                
                                	Is the gre interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                    self.yang_name = "gre-path"
                                    self.yang_parent_name = "gre-next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"gre-neighbor" : ("gre_neighbor", Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor), "gre-next-hop" : ("gre_next_hop", Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop)}
                                    self._child_list_classes = {}

                                    self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                    self.gre_interface_name = YLeaf(YType.str, "gre-interface-name")

                                    self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                    self.is_gre_interface_disabled = YLeaf(YType.boolean, "is-gre-interface-disabled")

                                    self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                    self.gre_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                    self.gre_neighbor.parent = self
                                    self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                    self._children_yang_names.add("gre-neighbor")

                                    self.gre_next_hop = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                    self.gre_next_hop.parent = self
                                    self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                    self._children_yang_names.add("gre-next-hop")
                                    self._segment_path = lambda: "gre-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, ['extranet_vrf_name', 'gre_interface_name', 'is_connector_attribute_present', 'is_gre_interface_disabled', 'is_via_lsm'], name, value)


                                class GreNeighbor(Entity):
                                    """
                                    GRE neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                        self.yang_name = "gre-neighbor"
                                        self.yang_parent_name = "gre-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "gre-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class GreNextHop(Entity):
                                    """
                                    GRE nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__init__()

                                        self.yang_name = "gre-next-hop"
                                        self.yang_parent_name = "gre-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "gre-next-hop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class RegisteredAddress(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                    self.yang_name = "registered-address"
                                    self.yang_parent_name = "gre-next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "registered-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class GroupMapRpfs(Entity):
                    """
                    PIM group mapping information
                    
                    .. attribute:: group_map_rpf
                    
                    	PIM group mapping entry
                    	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs, self).__init__()

                        self.yang_name = "group-map-rpfs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"group-map-rpf" : ("group_map_rpf", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf)}

                        self.group_map_rpf = YList(self)
                        self._segment_path = lambda: "group-map-rpfs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs, [], name, value)


                    class GroupMapRpf(Entity):
                        """
                        PIM group mapping entry
                        
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_priority
                        
                        	RP priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__init__()

                            self.yang_name = "group-map-rpf"
                            self.yang_parent_name = "group-map-rpfs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-map-information" : ("group_map_information", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation), "rpf-neighbor" : ("rpf_neighbor", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor)}
                            self._child_list_classes = {}

                            self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                            self.client = YLeaf(YType.enumeration, "client")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_priority = YLeaf(YType.int32, "rp-priority")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.group_map_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")
                            self._segment_path = lambda: "group-map-rpf"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, ['are_we_rp', 'client', 'prefix', 'prefix_length', 'protocol', 'rp_address', 'rp_priority', 'rpf_interface_name', 'rpf_vrf_name'], name, value)


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-rpf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"prefix" : ("prefix", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix), "rp-address" : ("rp_address", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress)}
                                self._child_list_classes = {}

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")
                                self._segment_path = lambda: "group-map-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, ['client', 'group_count', 'is_override', 'is_used', 'mrib_active', 'prefix_length', 'priority', 'protocol'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "prefix"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "rp-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "group-map-rpf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class GroupMapSources(Entity):
                    """
                    PIM group\-mapping with source information
                    
                    .. attribute:: group_map_source
                    
                    	PIM Group Mapping Entry with source information
                    	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources, self).__init__()

                        self.yang_name = "group-map-sources"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"group-map-source" : ("group_map_source", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource)}

                        self.group_map_source = YList(self)
                        self._segment_path = lambda: "group-map-sources"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources, [], name, value)


                    class GroupMapSource(Entity):
                        """
                        PIM Group Mapping Entry with source information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	RP Priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__init__()

                            self.yang_name = "group-map-source"
                            self.yang_parent_name = "group-map-sources"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-map-information" : ("group_map_information", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation), "source-of-information" : ("source_of_information", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation)}
                            self._child_list_classes = {}

                            self.client = YLeaf(YType.enumeration, "client")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.holdtime = YLeaf(YType.int32, "holdtime")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.int32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_map_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.source_of_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")
                            self._segment_path = lambda: "group-map-source"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource, ['client', 'expires', 'holdtime', 'prefix', 'prefix_length', 'priority', 'protocol', 'rp_address', 'uptime'], name, value)


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"prefix" : ("prefix", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix), "rp-address" : ("rp_address", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress)}
                                self._child_list_classes = {}

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")
                                self._segment_path = lambda: "group-map-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, ['client', 'group_count', 'is_override', 'is_used', 'mrib_active', 'prefix_length', 'priority', 'protocol'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "prefix"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "rp-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-map-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-of-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class IfrsInterfaces(Entity):
                    """
                    PIM interfaces in forward reference store table
                    
                    .. attribute:: ifrs_interface
                    
                    	PIM IFRS interface information
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ifrs-interface" : ("ifrs_interface", Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface)}

                        self.ifrs_interface = YList(self)
                        self._segment_path = lambda: "ifrs-interfaces"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces, [], name, value)


                    class IfrsInterface(Entity):
                        """
                        PIM IFRS interface information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"dr-address" : ("dr_address", Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress)}
                            self._child_list_classes = {"interface-address" : ("interface_address", Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "dr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "interface-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class IfrsSummary(Entity):
                    """
                    PIM interfaces in forward reference store
                    summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration counts
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Number of interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary, self).__init__()

                        self.yang_name = "ifrs-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                        self.interface_count = YLeaf(YType.uint32, "interface-count")
                        self._segment_path = lambda: "ifrs-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary, ['configuration_count', 'interface_count'], name, value)


                class InterfaceOldFormats(Entity):
                    """
                    PIM interfaces in old format
                    
                    .. attribute:: interface_old_format
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats, self).__init__()

                        self.yang_name = "interface-old-formats"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-old-format" : ("interface_old_format", Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat)}

                        self.interface_old_format = YList(self)
                        self._segment_path = lambda: "interface-old-formats"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats, [], name, value)


                    class InterfaceOldFormat(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                            self.yang_name = "interface-old-format"
                            self.yang_parent_name = "interface-old-formats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"dr-address" : ("dr_address", Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress)}
                            self._child_list_classes = {"interface-address" : ("interface_address", Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "interface-old-format" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "dr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "interface-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceStatistics(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_statistic
                    
                    	PIM interface statistics
                    	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics, self).__init__()

                        self.yang_name = "interface-statistics"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-statistic" : ("interface_statistic", Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic)}

                        self.interface_statistic = YList(self)
                        self._segment_path = lambda: "interface-statistics"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics, [], name, value)


                    class InterfaceStatistic(Entity):
                        """
                        PIM interface statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: input_assert
                        
                        	Assert packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_bsr_message
                        
                        	Input BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_candidate_rp_advertisement
                        
                        	Input Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_df_election
                        
                        	DF Election packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_ack_message
                        
                        	Input Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_message
                        
                        	Input Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_hello
                        
                        	Hello packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_jp
                        
                        	Join Prune packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_miscellaneous
                        
                        	Miscellaneous packet in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register
                        
                        	Register packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register_stop
                        
                        	Register Stop packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_assert
                        
                        	Assert packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_bsr_message
                        
                        	Output BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_candidate_rp_advertisement
                        
                        	Output Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_df_election
                        
                        	DF Election packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_ack_message
                        
                        	Output Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_message
                        
                        	Output Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_hello
                        
                        	Hello packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_jp
                        
                        	Join Prune packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register
                        
                        	Register packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register_stop
                        
                        	Register Stop packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__init__()

                            self.yang_name = "interface-statistic"
                            self.yang_parent_name = "interface-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.input_assert = YLeaf(YType.uint32, "input-assert")

                            self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                            self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                            self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                            self.input_graft_ack_message = YLeaf(YType.uint32, "input-graft-ack-message")

                            self.input_graft_message = YLeaf(YType.uint32, "input-graft-message")

                            self.input_hello = YLeaf(YType.uint32, "input-hello")

                            self.input_jp = YLeaf(YType.uint32, "input-jp")

                            self.input_miscellaneous = YLeaf(YType.uint32, "input-miscellaneous")

                            self.input_register = YLeaf(YType.uint32, "input-register")

                            self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                            self.output_assert = YLeaf(YType.uint32, "output-assert")

                            self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                            self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                            self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                            self.output_graft_ack_message = YLeaf(YType.uint32, "output-graft-ack-message")

                            self.output_graft_message = YLeaf(YType.uint32, "output-graft-message")

                            self.output_hello = YLeaf(YType.uint32, "output-hello")

                            self.output_jp = YLeaf(YType.uint32, "output-jp")

                            self.output_register = YLeaf(YType.uint32, "output-register")

                            self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")
                            self._segment_path = lambda: "interface-statistic" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, ['interface_name', 'input_assert', 'input_bsr_message', 'input_candidate_rp_advertisement', 'input_df_election', 'input_graft_ack_message', 'input_graft_message', 'input_hello', 'input_jp', 'input_miscellaneous', 'input_register', 'input_register_stop', 'output_assert', 'output_bsr_message', 'output_candidate_rp_advertisement', 'output_df_election', 'output_graft_ack_message', 'output_graft_message', 'output_hello', 'output_jp', 'output_register', 'output_register_stop'], name, value)


                class Interfaces(Entity):
                    """
                    PIM interfaces
                    
                    .. attribute:: interface
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces, self).__init__()

                        self.yang_name = "interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface" : ("interface", Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface)}

                        self.interface = YList(self)
                        self._segment_path = lambda: "interfaces"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces, [], name, value)


                    class Interface(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"dr-address" : ("dr_address", Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress)}
                            self._child_list_classes = {"interface-address" : ("interface_address", Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "dr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "interface-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class JpStatistics(Entity):
                    """
                    PIM join prune statistics table
                    
                    .. attribute:: jp_statistic
                    
                    	PIM Join Prune Statistics
                    	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics, self).__init__()

                        self.yang_name = "jp-statistics"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"jp-statistic" : ("jp_statistic", Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic)}

                        self.jp_statistic = YList(self)
                        self._segment_path = lambda: "jp-statistics"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics, [], name, value)


                    class JpStatistic(Entity):
                        """
                        PIM Join Prune Statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received
                        
                        	Received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received100
                        
                        	Received 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_10k
                        
                        	Received 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_1k
                        
                        	Received 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_50k
                        
                        	Deprecated by Received100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted
                        
                        	Transmitted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted100
                        
                        	Transmitted 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_10k
                        
                        	Transmitted 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_1k
                        
                        	Transmitted 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_50k
                        
                        	Deprecated by Transmitted100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic, self).__init__()

                            self.yang_name = "jp-statistic"
                            self.yang_parent_name = "jp-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.received = YLeaf(YType.uint32, "received")

                            self.received100 = YLeaf(YType.uint16, "received100")

                            self.received_10k = YLeaf(YType.uint16, "received-10k")

                            self.received_1k = YLeaf(YType.uint16, "received-1k")

                            self.received_50k = YLeaf(YType.uint16, "received-50k")

                            self.transmitted = YLeaf(YType.uint32, "transmitted")

                            self.transmitted100 = YLeaf(YType.uint16, "transmitted100")

                            self.transmitted_10k = YLeaf(YType.uint16, "transmitted-10k")

                            self.transmitted_1k = YLeaf(YType.uint16, "transmitted-1k")

                            self.transmitted_50k = YLeaf(YType.uint16, "transmitted-50k")
                            self._segment_path = lambda: "jp-statistic" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic, ['interface_name', 'interface_name_xr', 'mtu', 'received', 'received100', 'received_10k', 'received_1k', 'received_50k', 'transmitted', 'transmitted100', 'transmitted_10k', 'transmitted_1k', 'transmitted_50k'], name, value)


                class MibDatabases(Entity):
                    """
                    PIM group database for mroute mibs table
                    
                    .. attribute:: mib_database
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases, self).__init__()

                        self.yang_name = "mib-databases"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"mib-database" : ("mib_database", Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase)}

                        self.mib_database = YList(self)
                        self._segment_path = lambda: "mib-databases"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases, [], name, value)


                    class MibDatabase(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: assert_metric
                        
                        	Assert Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_metric_preference
                        
                        	Assert Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_rpt_bit
                        
                        	Assert RPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: bidirectional_route
                        
                        	Is this Bidir ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Multicast satic route group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr>`
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface name 
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: rpf_mask
                        
                        	Mask of the multicast root
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_neighbor
                        
                        	The RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: source_address
                        
                        	Multicast static route source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr>`
                        
                        .. attribute:: source_netmask
                        
                        	Source mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: spt_bit
                        
                        	Is SPT bit set ?
                        	**type**\:  bool
                        
                        .. attribute:: upstream_assert_timer
                        
                        	Upstream Assert Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime of route
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase, self).__init__()

                            self.yang_name = "mib-database"
                            self.yang_parent_name = "mib-databases"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr), "rpf-neighbor" : ("rpf_neighbor", Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor), "rpf-root" : ("rpf_root", Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot), "source-address-xr" : ("source_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr)}
                            self._child_list_classes = {}

                            self.assert_metric = YLeaf(YType.uint32, "assert-metric")

                            self.assert_metric_preference = YLeaf(YType.uint32, "assert-metric-preference")

                            self.assert_rpt_bit = YLeaf(YType.boolean, "assert-rpt-bit")

                            self.bidirectional_route = YLeaf(YType.boolean, "bidirectional-route")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                            self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_mask = YLeaf(YType.uint32, "rpf-mask")

                            self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                            self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_netmask = YLeaf(YType.int32, "source-netmask")

                            self.spt_bit = YLeaf(YType.boolean, "spt-bit")

                            self.upstream_assert_timer = YLeaf(YType.int32, "upstream-assert-timer")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                            self.rpf_root = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._children_yang_names.add("rpf-root")

                            self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")
                            self._segment_path = lambda: "mib-database"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase, ['assert_metric', 'assert_metric_preference', 'assert_rpt_bit', 'bidirectional_route', 'group_address', 'protocol', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_mask', 'rpf_safi', 'rpf_table_name', 'rpf_vrf_name', 'source_address', 'source_netmask', 'spt_bit', 'upstream_assert_timer', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            The RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-root"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class MulticastStaticRoutes(Entity):
                    """
                    PIM multicast static route table
                    
                    .. attribute:: multicast_static_route
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes, self).__init__()

                        self.yang_name = "multicast-static-routes"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"multicast-static-route" : ("multicast_static_route", Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute)}

                        self.multicast_static_route = YList(self)
                        self._segment_path = lambda: "multicast-static-routes"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes, [], name, value)


                    class MulticastStaticRoute(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: address
                        
                        	Network address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: distance
                        
                        	Distance
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_via_lsm
                        
                        	LSM flag
                        	**type**\:  bool
                        
                        .. attribute:: nexthop
                        
                        	Next Hop
                        	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: prefix_length_xr
                        
                        	Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                            self.yang_name = "multicast-static-route"
                            self.yang_parent_name = "multicast-static-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"nexthop" : ("nexthop", Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop), "prefix" : ("prefix", Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix)}
                            self._child_list_classes = {}

                            self.address = YLeaf(YType.str, "address")

                            self.distance = YLeaf(YType.uint32, "distance")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                            self.nexthop = Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                            self.nexthop.parent = self
                            self._children_name_map["nexthop"] = "nexthop"
                            self._children_yang_names.add("nexthop")

                            self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")
                            self._segment_path = lambda: "multicast-static-route"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, ['address', 'distance', 'interface_name', 'is_via_lsm', 'prefix_length', 'prefix_length_xr'], name, value)


                        class Nexthop(Entity):
                            """
                            Next Hop
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                                self.yang_name = "nexthop"
                                self.yang_parent_name = "multicast-static-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "nexthop"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Prefix(Entity):
                            """
                            Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "multicast-static-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class NeighborOldFormats(Entity):
                    """
                    PIM neighbor table old format
                    
                    .. attribute:: neighbor_old_format
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats, self).__init__()

                        self.yang_name = "neighbor-old-formats"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-old-format" : ("neighbor_old_format", Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat)}

                        self.neighbor_old_format = YList(self)
                        self._segment_path = lambda: "neighbor-old-formats"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats, [], name, value)


                    class NeighborOldFormat(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__init__()

                            self.yang_name = "neighbor-old-format"
                            self.yang_parent_name = "neighbor-old-formats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr)}

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                            self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                            self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.neighbor_address_xr = YList(self)
                            self._segment_path = lambda: "neighbor-old-format"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, ['dr_priority', 'expires', 'expiry_timer', 'interface_name', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bfd_state', 'is_bidirectional_capable', 'is_dr_priority_capable', 'is_ecmp_redirect_capable', 'is_proxy_capable', 'is_this_neighbor_dr', 'is_this_neighbor_us', 'neighbor_address', 'override_interval', 'propagation_delay', 'uptime'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "neighbor-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class NeighborSummaries(Entity):
                    """
                    PIM neighbor summary table
                    
                    .. attribute:: neighbor_summary
                    
                    	PIM neighbor summary information
                    	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries, self).__init__()

                        self.yang_name = "neighbor-summaries"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-summary" : ("neighbor_summary", Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary)}

                        self.neighbor_summary = YList(self)
                        self._segment_path = lambda: "neighbor-summaries"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries, [], name, value)


                    class NeighborSummary(Entity):
                        """
                        PIM neighbor summary information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: number_of_external_neighbors
                        
                        	Number of external neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__init__()

                            self.yang_name = "neighbor-summary"
                            self.yang_parent_name = "neighbor-summaries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.number_of_external_neighbors = YLeaf(YType.int32, "number-of-external-neighbors")

                            self.number_of_neighbors = YLeaf(YType.int32, "number-of-neighbors")
                            self._segment_path = lambda: "neighbor-summary" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary, ['interface_name', 'number_of_external_neighbors', 'number_of_neighbors'], name, value)


                class Neighbors(Entity):
                    """
                    PIM neighbor table
                    
                    .. attribute:: neighbor
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors, self).__init__()

                        self.yang_name = "neighbors"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor" : ("neighbor", Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor)}

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "neighbors"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors, [], name, value)


                    class Neighbor(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbors"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr)}

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                            self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                            self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.neighbor_address_xr = YList(self)
                            self._segment_path = lambda: "neighbor"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor, ['dr_priority', 'expires', 'expiry_timer', 'interface_name', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bfd_state', 'is_bidirectional_capable', 'is_dr_priority_capable', 'is_ecmp_redirect_capable', 'is_proxy_capable', 'is_this_neighbor_dr', 'is_this_neighbor_us', 'neighbor_address', 'override_interval', 'propagation_delay', 'uptime'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "neighbor-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class NetIoTunnels(Entity):
                    """
                    Tunnel information that NETIO has 
                    
                    .. attribute:: net_io_tunnel
                    
                    	PIM netio tunnel information
                    	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels, self).__init__()

                        self.yang_name = "net-io-tunnels"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"net-io-tunnel" : ("net_io_tunnel", Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel)}

                        self.net_io_tunnel = YList(self)
                        self._segment_path = lambda: "net-io-tunnels"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels, [], name, value)


                    class NetIoTunnel(Entity):
                        """
                        PIM netio tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__init__()

                            self.yang_name = "net-io-tunnel"
                            self.yang_parent_name = "net-io-tunnels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-netio" : ("group_address_netio", Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio), "rp-address" : ("rp_address", Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress), "source-address" : ("source_address", Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress), "source-address-netio" : ("source_address_netio", Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio)}
                            self._child_list_classes = {}

                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._children_yang_names.add("group-address-netio")

                            self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.source_address = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                            self.source_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"
                            self._children_yang_names.add("source-address-netio")
                            self._segment_path = lambda: "net-io-tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, ['tunnel_name', 'vrf_name'], name, value)


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-netio"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-netio"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Ranges(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: range
                    
                    	PIM range list information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"range" : ("range", Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range)}

                        self.range = YList(self)
                        self._segment_path = lambda: "ranges"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Ranges, [], name, value)


                    class Range(Entity):
                        """
                        PIM range list information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: client_xr
                        
                        	Client mapping learnt via
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: group_range
                        
                        	List of group ranges
                        	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange>`
                        
                        .. attribute:: protocol
                        
                        	PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	Rendezvous point address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"rp-address-xr" : ("rp_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr), "source-of-information" : ("source_of_information", Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation)}
                            self._child_list_classes = {"group-range" : ("group_range", Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange)}

                            self.client = YLeaf(YType.enumeration, "client")

                            self.client_xr = YLeaf(YType.enumeration, "client-xr")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")

                            self.source_of_information = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                            self.group_range = YList(self)
                            self._segment_path = lambda: "range"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range, ['client', 'client_xr', 'expires', 'protocol', 'rp_address'], name, value)


                        class GroupRange(Entity):
                            """
                            List of group ranges
                            
                            .. attribute:: expires
                            
                            	When mapping expires
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: source_of_information
                            
                            	Source of information
                            	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange, self).__init__()

                                self.yang_name = "group-range"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"prefix" : ("prefix", Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix), "source-of-information" : ("source_of_information", Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation)}
                                self._child_list_classes = {}

                                self.expires = YLeaf(YType.uint64, "expires")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.source_of_information = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                                self._children_yang_names.add("source-of-information")
                                self._segment_path = lambda: "group-range"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange, ['expires', 'prefix_length', 'uptime'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "prefix"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceOfInformation(Entity):
                                """
                                Source of information
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                    self.yang_name = "source-of-information"
                                    self.yang_parent_name = "group-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-of-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddressXr(Entity):
                            """
                            Rendezvous point address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-of-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class RoutePolicy(Entity):
                    """
                    PIM route policy
                    
                    .. attribute:: route_policy_statistics
                    
                    	PIM route policy statistics
                    	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics>`
                    
                    .. attribute:: route_policy_tests
                    
                    	PIM route policy test run table
                    	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy, self).__init__()

                        self.yang_name = "route-policy"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"route-policy-statistics" : ("route_policy_statistics", Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics), "route-policy-tests" : ("route_policy_tests", Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests)}
                        self._child_list_classes = {}

                        self.route_policy_statistics = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                        self.route_policy_statistics.parent = self
                        self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                        self._children_yang_names.add("route-policy-statistics")

                        self.route_policy_tests = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                        self.route_policy_tests.parent = self
                        self._children_name_map["route_policy_tests"] = "route-policy-tests"
                        self._children_yang_names.add("route-policy-tests")
                        self._segment_path = lambda: "route-policy"


                    class RoutePolicyStatistics(Entity):
                        """
                        PIM route policy statistics
                        
                        .. attribute:: any_table
                        
                        	Number of RPF lookup in any Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Number of RPF lookup in default\-only Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop
                        
                        	Number of RPF drops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pass_
                        
                        	Number of RPF pass
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: requests
                        
                        	Number of RPF lookup requests
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__init__()

                            self.yang_name = "route-policy-statistics"
                            self.yang_parent_name = "route-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.any_table = YLeaf(YType.uint32, "any-table")

                            self.default_table = YLeaf(YType.uint32, "default-table")

                            self.drop = YLeaf(YType.uint32, "drop")

                            self.pass_ = YLeaf(YType.uint32, "pass")

                            self.policy_name = YLeaf(YType.str, "policy-name")

                            self.requests = YLeaf(YType.uint32, "requests")
                            self._segment_path = lambda: "route-policy-statistics"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, ['any_table', 'default_table', 'drop', 'pass_', 'policy_name', 'requests'], name, value)


                    class RoutePolicyTests(Entity):
                        """
                        PIM route policy test run table
                        
                        .. attribute:: route_policy_test
                        
                        	PIM route policy test run
                        	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__init__()

                            self.yang_name = "route-policy-tests"
                            self.yang_parent_name = "route-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"route-policy-test" : ("route_policy_test", Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest)}

                            self.route_policy_test = YList(self)
                            self._segment_path = lambda: "route-policy-tests"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, [], name, value)


                        class RoutePolicyTest(Entity):
                            """
                            PIM route policy test run
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_table
                            
                            	Default table selected
                            	**type**\:  bool
                            
                            .. attribute:: ext_comm
                            
                            	Extended Community
                            	**type**\:  str
                            
                            	**length:** 1..8
                            
                            .. attribute:: extended_community_rt
                            
                            	Route Target
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: group_address
                            
                            	Group IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                            
                            .. attribute:: pass_
                            
                            	Pass
                            	**type**\:  bool
                            
                            .. attribute:: policy_name
                            
                            	RPF policy name
                            	**type**\:  str
                            
                            .. attribute:: safi
                            
                            	SAFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_address
                            
                            	Source IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                            
                            .. attribute:: table_active
                            
                            	Table active
                            	**type**\:  bool
                            
                            .. attribute:: table_exists
                            
                            	Table exists
                            	**type**\:  bool
                            
                            .. attribute:: table_name
                            
                            	Table name
                            	**type**\:  str
                            
                            .. attribute:: vrf_name
                            
                            	VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                                self.yang_name = "route-policy-test"
                                self.yang_parent_name = "route-policy-tests"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr), "source-address-xr" : ("source_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr)}
                                self._child_list_classes = {}

                                self.afi = YLeaf(YType.uint32, "afi")

                                self.default_table = YLeaf(YType.boolean, "default-table")

                                self.ext_comm = YLeaf(YType.str, "ext-comm")

                                self.extended_community_rt = YLeaf(YType.str, "extended-community-rt")

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.pass_ = YLeaf(YType.boolean, "pass")

                                self.policy_name = YLeaf(YType.str, "policy-name")

                                self.safi = YLeaf(YType.uint32, "safi")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.table_active = YLeaf(YType.boolean, "table-active")

                                self.table_exists = YLeaf(YType.boolean, "table-exists")

                                self.table_name = YLeaf(YType.str, "table-name")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                                self._children_yang_names.add("source-address-xr")
                                self._segment_path = lambda: "route-policy-test"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, ['afi', 'default_table', 'ext_comm', 'extended_community_rt', 'group_address', 'pass_', 'policy_name', 'safi', 'source_address', 'table_active', 'table_exists', 'table_name', 'vrf_name'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "route-policy-test"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "route-policy-test"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class RpfRedirect(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle
                    
                    .. attribute:: bundle_interfaces
                    
                    	PIM ECMP RPF\-redirect bundle information
                    	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces>`
                    
                    .. attribute:: redirect_route_databases
                    
                    	PIM ECMP RPF\-redirect route database
                    	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect, self).__init__()

                        self.yang_name = "rpf-redirect"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"bundle-interfaces" : ("bundle_interfaces", Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces), "redirect-route-databases" : ("redirect_route_databases", Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases)}
                        self._child_list_classes = {}

                        self.bundle_interfaces = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                        self.bundle_interfaces.parent = self
                        self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                        self._children_yang_names.add("bundle-interfaces")

                        self.redirect_route_databases = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                        self.redirect_route_databases.parent = self
                        self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                        self._children_yang_names.add("redirect-route-databases")
                        self._segment_path = lambda: "rpf-redirect"


                    class BundleInterfaces(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle information
                        
                        .. attribute:: bundle_interface
                        
                        	PIM ECMP RPF\-redirect bundle interface information
                        	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__init__()

                            self.yang_name = "bundle-interfaces"
                            self.yang_parent_name = "rpf-redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"bundle-interface" : ("bundle_interface", Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface)}

                            self.bundle_interface = YList(self)
                            self._segment_path = lambda: "bundle-interfaces"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces, [], name, value)


                        class BundleInterface(Entity):
                            """
                            PIM ECMP RPF\-redirect bundle interface
                            information
                            
                            .. attribute:: allocated_bandwidth
                            
                            	Bandwidth allocated in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_threshold_bandwidth
                            
                            	Configured threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_bandwidth
                            
                            	Bandwidth available in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_threshold_bandwidth
                            
                            	Available threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\:  str
                            
                            	**length:** 1..32
                            
                            .. attribute:: interface_name
                            
                            	Bundle interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: rpf_redirect_bundle_name
                            
                            	RPF redirect bundle name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: rpf_redirect_interface_name
                            
                            	RPF redirect interface name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: snooping_bandwidth_used
                            
                            	Bandwidth used by snooped entries in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: topology_bandwidth_used
                            
                            	Bandwidth used by topology in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: total_bandwidth
                            
                            	Total bandwidth used in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                                self.yang_name = "bundle-interface"
                                self.yang_parent_name = "bundle-interfaces"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.allocated_bandwidth = YLeaf(YType.int32, "allocated-bandwidth")

                                self.allocated_threshold_bandwidth = YLeaf(YType.int32, "allocated-threshold-bandwidth")

                                self.available_bandwidth = YLeaf(YType.int32, "available-bandwidth")

                                self.available_threshold_bandwidth = YLeaf(YType.int32, "available-threshold-bandwidth")

                                self.bundle_name = YLeaf(YType.str, "bundle-name")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.rpf_redirect_bundle_name = YLeaf(YType.str, "rpf-redirect-bundle-name")

                                self.rpf_redirect_interface_name = YLeaf(YType.str, "rpf-redirect-interface-name")

                                self.snooping_bandwidth_used = YLeaf(YType.int32, "snooping-bandwidth-used")

                                self.topology_bandwidth_used = YLeaf(YType.int32, "topology-bandwidth-used")

                                self.total_bandwidth = YLeaf(YType.int32, "total-bandwidth")
                                self._segment_path = lambda: "bundle-interface"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, ['allocated_bandwidth', 'allocated_threshold_bandwidth', 'available_bandwidth', 'available_threshold_bandwidth', 'bundle_name', 'interface_name', 'rpf_redirect_bundle_name', 'rpf_redirect_interface_name', 'snooping_bandwidth_used', 'topology_bandwidth_used', 'total_bandwidth'], name, value)


                    class RedirectRouteDatabases(Entity):
                        """
                        PIM ECMP RPF\-redirect route database
                        
                        .. attribute:: redirect_route_database
                        
                        	PIM ECMP RPF\-redirect route information
                        	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__init__()

                            self.yang_name = "redirect-route-databases"
                            self.yang_parent_name = "rpf-redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"redirect-route-database" : ("redirect_route_database", Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase)}

                            self.redirect_route_database = YList(self)
                            self._segment_path = lambda: "redirect-route-databases"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, [], name, value)


                        class RedirectRouteDatabase(Entity):
                            """
                            PIM ECMP RPF\-redirect route information
                            
                            .. attribute:: bandwidth
                            
                            	Bandwidth in Kbps
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Group ddress
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                            
                            .. attribute:: interface
                            
                            	Outgoing interface list
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                                self.yang_name = "redirect-route-database"
                                self.yang_parent_name = "redirect-route-databases"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr), "source-address-xr" : ("source_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr)}
                                self._child_list_classes = {"interface" : ("interface", Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface)}

                                self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                                self._children_yang_names.add("source-address-xr")

                                self.interface = YList(self)
                                self._segment_path = lambda: "redirect-route-database"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, ['bandwidth', 'group_address', 'source_address', 'uptime'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group ddress
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class Interface(Entity):
                                """
                                Outgoing interface list
                                
                                .. attribute:: expiry
                                
                                	Expiry in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: is_outgoing_interface
                                
                                	Is outgoing Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface
                                
                                	Is RPF Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_snoop_interface
                                
                                	Is snooping Interface
                                	**type**\:  bool
                                
                                .. attribute:: rpf_address
                                
                                	RPF Address
                                	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                                
                                .. attribute:: uptime
                                
                                	Uptime in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"rpf-address" : ("rpf_address", Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress)}
                                    self._child_list_classes = {}

                                    self.expiry = YLeaf(YType.uint64, "expiry")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.is_outgoing_interface = YLeaf(YType.boolean, "is-outgoing-interface")

                                    self.is_rpf_interface = YLeaf(YType.boolean, "is-rpf-interface")

                                    self.is_snoop_interface = YLeaf(YType.boolean, "is-snoop-interface")

                                    self.uptime = YLeaf(YType.uint64, "uptime")

                                    self.rpf_address = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                    self.rpf_address.parent = self
                                    self._children_name_map["rpf_address"] = "rpf-address"
                                    self._children_yang_names.add("rpf-address")
                                    self._segment_path = lambda: "interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, ['expiry', 'interface_name', 'is_outgoing_interface', 'is_rpf_interface', 'is_snoop_interface', 'uptime'], name, value)


                                class RpfAddress(Entity):
                                    """
                                    RPF Address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                        self.yang_name = "rpf-address"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "rpf-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class RpfSummary(Entity):
                    """
                    PIM RPF registration summary
                    
                    .. attribute:: default_safi
                    
                    	Default RPF Table SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table_name
                    
                    	Default RPF Table Name
                    	**type**\:  str
                    
                    .. attribute:: is_isis_mtr_configured
                    
                    	Is ISIS MTR configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_isis_te_configured
                    
                    	Is ISIS TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_mbgp_configured
                    
                    	Is MBGP configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_enabled
                    
                    	Is Multipath Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_interface_hash_enabled
                    
                    	Is Multipath Interface Hash Extension Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_hash_enabled
                    
                    	Is Multipath Source based Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_next_hop_hash_enabled
                    
                    	Is Multipath Source\-Nexthop Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ospf_te_configured
                    
                    	Is OSPF TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: mo_frr_configured
                    
                    	Is MoFRR configured?
                    	**type**\:  bool
                    
                    .. attribute:: rib_convergence_time_left
                    
                    	RIB convergence time left in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_convergence_timeout
                    
                    	RIB convergence timeout in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_mo_frr_configured
                    
                    	Is MoFRR RIB configured?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	Is RUMP MuRIB enabled?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary, self).__init__()

                        self.yang_name = "rpf-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.default_safi = YLeaf(YType.uint32, "default-safi")

                        self.default_table_name = YLeaf(YType.str, "default-table-name")

                        self.is_isis_mtr_configured = YLeaf(YType.boolean, "is-isis-mtr-configured")

                        self.is_isis_te_configured = YLeaf(YType.boolean, "is-isis-te-configured")

                        self.is_mbgp_configured = YLeaf(YType.boolean, "is-mbgp-configured")

                        self.is_multipath_enabled = YLeaf(YType.boolean, "is-multipath-enabled")

                        self.is_multipath_interface_hash_enabled = YLeaf(YType.boolean, "is-multipath-interface-hash-enabled")

                        self.is_multipath_source_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-hash-enabled")

                        self.is_multipath_source_next_hop_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-next-hop-hash-enabled")

                        self.is_ospf_te_configured = YLeaf(YType.boolean, "is-ospf-te-configured")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.mo_frr_configured = YLeaf(YType.boolean, "mo-frr-configured")

                        self.rib_convergence_time_left = YLeaf(YType.uint32, "rib-convergence-time-left")

                        self.rib_convergence_timeout = YLeaf(YType.uint32, "rib-convergence-timeout")

                        self.rib_mo_frr_configured = YLeaf(YType.boolean, "rib-mo-frr-configured")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")
                        self._segment_path = lambda: "rpf-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary, ['default_safi', 'default_table_name', 'is_isis_mtr_configured', 'is_isis_te_configured', 'is_mbgp_configured', 'is_multipath_enabled', 'is_multipath_interface_hash_enabled', 'is_multipath_source_hash_enabled', 'is_multipath_source_next_hop_hash_enabled', 'is_ospf_te_configured', 'is_rib_convergence', 'mo_frr_configured', 'rib_convergence_time_left', 'rib_convergence_timeout', 'rib_mo_frr_configured', 'rpf_registrations', 'rump_enabled'], name, value)


                class Safs(Entity):
                    """
                    SAFI table and type
                    
                    .. attribute:: saf
                    
                    	SAF name 
                    	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs, self).__init__()

                        self.yang_name = "safs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"saf" : ("saf", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf)}

                        self.saf = YList(self)
                        self._segment_path = lambda: "safs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs, [], name, value)


                    class Saf(Entity):
                        """
                        SAF name 
                        
                        .. attribute:: rpf_hash_source_groups
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups>`
                        
                        .. attribute:: rpf_hash_sources
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources>`
                        
                        .. attribute:: rpfs
                        
                        	PIM RPF information table
                        	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs>`
                        
                        .. attribute:: saf_name
                        
                        	SAF name 
                        	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name 
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf, self).__init__()

                            self.yang_name = "saf"
                            self.yang_parent_name = "safs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"rpf-hash-source-groups" : ("rpf_hash_source_groups", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups), "rpf-hash-sources" : ("rpf_hash_sources", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources), "rpfs" : ("rpfs", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs)}
                            self._child_list_classes = {}

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                            self.topology_name = YLeaf(YType.str, "topology-name")

                            self.rpf_hash_source_groups = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                            self.rpf_hash_source_groups.parent = self
                            self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                            self._children_yang_names.add("rpf-hash-source-groups")

                            self.rpf_hash_sources = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                            self.rpf_hash_sources.parent = self
                            self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                            self._children_yang_names.add("rpf-hash-sources")

                            self.rpfs = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs()
                            self.rpfs.parent = self
                            self._children_name_map["rpfs"] = "rpfs"
                            self._children_yang_names.add("rpfs")
                            self._segment_path = lambda: "saf"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf, ['saf_name', 'topology_name'], name, value)


                        class RpfHashSourceGroups(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source_group
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__init__()

                                self.yang_name = "rpf-hash-source-groups"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"rpf-hash-source-group" : ("rpf_hash_source_group", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup)}

                                self.rpf_hash_source_group = YList(self)
                                self._segment_path = lambda: "rpf-hash-source-groups"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, [], name, value)


                            class RpfHashSourceGroup(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: group_address
                                
                                	Group address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: mask_length
                                
                                	Hash mask length
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                    self.yang_name = "rpf-hash-source-group"
                                    self.yang_parent_name = "rpf-hash-source-groups"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress), "secondary-next-hop-address" : ("secondary_next_hop_address", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress)}
                                    self._child_list_classes = {}

                                    self.group_address = YLeaf(YType.str, "group-address")

                                    self.mask_length = YLeaf(YType.int32, "mask-length")

                                    self.mofrr = YLeaf(YType.int32, "mofrr")

                                    self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                    self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                    self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                    self._children_yang_names.add("next-hop-address")

                                    self.secondary_next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._children_yang_names.add("secondary-next-hop-address")
                                    self._segment_path = lambda: "rpf-hash-source-group"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, ['group_address', 'mask_length', 'mofrr', 'next_hop_interface', 'next_hop_multipath_enabled', 'secondary_next_hop_interface', 'source_address'], name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "next-hop-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "secondary-next-hop-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfHashSources(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__init__()

                                self.yang_name = "rpf-hash-sources"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"rpf-hash-source" : ("rpf_hash_source", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource)}

                                self.rpf_hash_source = YList(self)
                                self._segment_path = lambda: "rpf-hash-sources"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources, [], name, value)


                            class RpfHashSource(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                    self.yang_name = "rpf-hash-source"
                                    self.yang_parent_name = "rpf-hash-sources"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress), "secondary-next-hop-address" : ("secondary_next_hop_address", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress)}
                                    self._child_list_classes = {}

                                    self.mofrr = YLeaf(YType.int32, "mofrr")

                                    self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                    self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                    self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                    self._children_yang_names.add("next-hop-address")

                                    self.secondary_next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._children_yang_names.add("secondary-next-hop-address")
                                    self._segment_path = lambda: "rpf-hash-source"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, ['mofrr', 'next_hop_interface', 'next_hop_multipath_enabled', 'secondary_next_hop_interface', 'source_address'], name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "next-hop-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "secondary-next-hop-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Rpfs(Entity):
                            """
                            PIM RPF information table
                            
                            .. attribute:: rpf
                            
                            	PIM RPF information
                            	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs, self).__init__()

                                self.yang_name = "rpfs"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"rpf" : ("rpf", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf)}

                                self.rpf = YList(self)
                                self._segment_path = lambda: "rpfs"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs, [], name, value)


                            class Rpf(Entity):
                                """
                                PIM RPF information
                                
                                .. attribute:: registered_address  <key>
                                
                                	Address for which RPF lookup
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: is_connected
                                
                                	Are we connected ?
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_rpf_bgp_route
                                
                                	Is RPF through BGP route
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_preference
                                
                                	Metric preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: registered_address_xr
                                
                                	Address registered
                                	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                                
                                .. attribute:: rpf_path
                                
                                	RPF Paths list
                                	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__init__()

                                    self.yang_name = "rpf"
                                    self.yang_parent_name = "rpfs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"registered-address-xr" : ("registered_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr)}
                                    self._child_list_classes = {"rpf-path" : ("rpf_path", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath)}

                                    self.registered_address = YLeaf(YType.str, "registered-address")

                                    self.is_connected = YLeaf(YType.uint8, "is-connected")

                                    self.is_rpf_bgp_route = YLeaf(YType.boolean, "is-rpf-bgp-route")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                    self.registered_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                    self.registered_address_xr.parent = self
                                    self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                    self._children_yang_names.add("registered-address-xr")

                                    self.rpf_path = YList(self)
                                    self._segment_path = lambda: "rpf" + "[registered-address='" + self.registered_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, ['registered_address', 'is_connected', 'is_rpf_bgp_route', 'metric', 'metric_preference'], name, value)


                                class RegisteredAddressXr(Entity):
                                    """
                                    Address registered
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                        self.yang_name = "registered-address-xr"
                                        self.yang_parent_name = "rpf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "registered-address-xr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class RpfPath(Entity):
                                    """
                                    RPF Paths list
                                    
                                    .. attribute:: connector
                                    
                                    	Connector Attribute
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: extranet_vrf_name
                                    
                                    	Extranet VRF name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    .. attribute:: is_connector_attribute_present
                                    
                                    	Connector attribute present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rpf_interface_disabled
                                    
                                    	Is the rpf interface disabled ?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_lsm
                                    
                                    	Via LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_mlsm
                                    
                                    	Via Mstatic LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpf_interface_name
                                    
                                    	RPF Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: rpf_neighbor
                                    
                                    	RPF neighbor
                                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                    
                                    .. attribute:: rpf_nexthop
                                    
                                    	RPF nexthop
                                    	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                        self.yang_name = "rpf-path"
                                        self.yang_parent_name = "rpf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rpf-neighbor" : ("rpf_neighbor", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor), "rpf-nexthop" : ("rpf_nexthop", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop)}
                                        self._child_list_classes = {}

                                        self.connector = YLeaf(YType.str, "connector")

                                        self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                        self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                        self.is_rpf_interface_disabled = YLeaf(YType.boolean, "is-rpf-interface-disabled")

                                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                        self.is_via_mlsm = YLeaf(YType.boolean, "is-via-mlsm")

                                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                                        self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                        self.rpf_neighbor.parent = self
                                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                        self._children_yang_names.add("rpf-neighbor")

                                        self.rpf_nexthop = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                        self.rpf_nexthop.parent = self
                                        self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                        self._children_yang_names.add("rpf-nexthop")
                                        self._segment_path = lambda: "rpf-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, ['connector', 'extranet_vrf_name', 'is_connector_attribute_present', 'is_rpf_interface_disabled', 'is_via_lsm', 'is_via_mlsm', 'rpf_interface_name'], name, value)


                                    class RpfNeighbor(Entity):
                                        """
                                        RPF neighbor
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                            self.yang_name = "rpf-neighbor"
                                            self.yang_parent_name = "rpf-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                            self._segment_path = lambda: "rpf-neighbor"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                    class RpfNexthop(Entity):
                                        """
                                        RPF nexthop
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                            self.yang_name = "rpf-nexthop"
                                            self.yang_parent_name = "rpf-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                            self._segment_path = lambda: "rpf-nexthop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Summary(Entity):
                    """
                    PIM summary
                    
                    .. attribute:: bsr_candidate_rp_set_count
                    
                    	Current crp\-set count from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_limit
                    
                    	Maximum crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_threshold
                    
                    	Threshold crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_range_threshold
                    
                    	Threshold group range from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_count
                    
                    	Current group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_limit
                    
                    	Maximum group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_auto_rp_ranges_limit
                    
                    	Global Auto\-RP maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_count
                    
                    	Global BSR current crp\-set count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_limit
                    
                    	Global BSR maximum crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_threshold
                    
                    	Global BSR Threshold crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_count
                    
                    	Global BSR current group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_limit
                    
                    	Global BSR maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_threshold
                    
                    	Global BSR Threshold group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_register_limit
                    
                    	Maximum global registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bsr_ranges_threshold_reached
                    
                    	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_auto_rp_ranges_limit_reached
                    
                    	Is global AutoRP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_bsr_ranges_limit_reached
                    
                    	Is global BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_register_limit_reached
                    
                    	Is global PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_route_limit_reached
                    
                    	Is global route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_rxi_limit_reached
                    
                    	Is global interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_maximum_enforcement_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: is_ranges_limit_reached
                    
                    	Is Auto\-RP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_route_limit_reached
                    
                    	Is route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: ranges_count
                    
                    	Current group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_limit
                    
                    	Maximum group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_threshold
                    
                    	OOR theshold of grange ranges from AutoRP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_count
                    
                    	Current registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit
                    
                    	Maximum registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit_reached
                    
                    	Is PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: register_threshold
                    
                    	Threshold registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_count
                    
                    	Current routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_limit
                    
                    	Maximum routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_low_water_mark
                    
                    	The number of routes below which the throttle on route creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_threshold
                    
                    	Threshold routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_limit_reached
                    
                    	Is interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: rxi_low_water_mark
                    
                    	The rxi below which the throttle on interface creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_count
                    
                    	Current Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_limit
                    
                    	Maximum Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_threshold
                    
                    	Topology Interface State threshold
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                        self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                        self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                        self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                        self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                        self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                        self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                        self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                        self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                        self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                        self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                        self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                        self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                        self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                        self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                        self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                        self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                        self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                        self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                        self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                        self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                        self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                        self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                        self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                        self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                        self.register_count = YLeaf(YType.uint32, "register-count")

                        self.register_limit = YLeaf(YType.uint32, "register-limit")

                        self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                        self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                        self.route_count = YLeaf(YType.uint32, "route-count")

                        self.route_limit = YLeaf(YType.uint32, "route-limit")

                        self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                        self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                        self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                        self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                        self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                        self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                        self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")
                        self._segment_path = lambda: "summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Summary, ['bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_threshold', 'bsr_range_threshold', 'bsr_ranges_count', 'bsr_ranges_limit', 'global_auto_rp_ranges_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_threshold', 'global_bsr_ranges_count', 'global_bsr_ranges_limit', 'global_bsr_ranges_threshold', 'global_register_limit', 'is_bsr_ranges_threshold_reached', 'is_global_auto_rp_ranges_limit_reached', 'is_global_bsr_ranges_limit_reached', 'is_global_register_limit_reached', 'is_global_route_limit_reached', 'is_global_rxi_limit_reached', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'is_ranges_limit_reached', 'is_route_limit_reached', 'ranges_count', 'ranges_limit', 'ranges_threshold', 'register_count', 'register_limit', 'register_limit_reached', 'register_threshold', 'route_count', 'route_limit', 'route_low_water_mark', 'route_threshold', 'rxi_limit_reached', 'rxi_low_water_mark', 'topology_interface_state_count', 'topology_interface_state_limit', 'topology_interface_state_threshold'], name, value)


                class TableContexts(Entity):
                    """
                    PIM table context list
                    
                    .. attribute:: table_context
                    
                    	PIM table context information
                    	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TableContexts.TableContext>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.TableContexts, self).__init__()

                        self.yang_name = "table-contexts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"table-context" : ("table_context", Ipv6Pim.Standby.Vrfs.Vrf.TableContexts.TableContext)}

                        self.table_context = YList(self)
                        self._segment_path = lambda: "table-contexts"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TableContexts, [], name, value)


                    class TableContext(Entity):
                        """
                        PIM table context information
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: saf_name
                        
                        	SAF name
                        	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: topology_name
                        
                        	Topology name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.TableContexts.TableContext, self).__init__()

                            self.yang_name = "table-context"
                            self.yang_parent_name = "table-contexts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                            self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                            self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                            self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                            self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.table_id = YLeaf(YType.uint32, "table-id")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.topology_name = YLeaf(YType.str, "topology-name")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")
                            self._segment_path = lambda: "table-context"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TableContexts.TableContext, ['afi', 'is_active', 'is_ital_registration_done', 'is_rib_convergence', 'is_rib_convergence_received', 'is_rib_registration_done', 'rpf_registrations', 'saf_name', 'safi', 'table_id', 'table_name', 'topology_name', 'vrf_id'], name, value)


                class Topologies(Entity):
                    """
                    PIM topology table
                    
                    .. attribute:: topology
                    
                    	PIM topology information
                    	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies, self).__init__()

                        self.yang_name = "topologies"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"topology" : ("topology", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology)}

                        self.topology = YList(self)
                        self._segment_path = lambda: "topologies"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies, [], name, value)


                    class Topology(Entity):
                        """
                        PIM topology information
                        
                        .. attribute:: alive
                        
                        	Alive time in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: anycast_rp_match
                        
                        	Group matches Anycast\-RP policy
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_route_target
                        
                        	Anycast\-RP RT
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: assume_alive
                        
                        	The Assume Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: bgp_join
                        
                        	BGP C JOIN
                        	**type**\:  bool
                        
                        .. attribute:: bgp_jp_time
                        
                        	BGP C JP Time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: connected
                        
                        	Is Connected ?
                        	**type**\:  bool
                        
                        .. attribute:: crossed_threshold
                        
                        	Incoming traffic crossed threshold. MT flag set
                        	**type**\:  bool
                        
                        .. attribute:: customer_routing_type
                        
                        	Type of Customer Routing in the MVPN
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: data_mdt_addr_assigned
                        
                        	PIM has assigned a Data MDT Address
                        	**type**\:  bool
                        
                        .. attribute:: dont_check_connected
                        
                        	Do we need to make the connected check on this route ?
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	When this entry expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: extranet_route
                        
                        	Is a Extranet route ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr>`
                        
                        .. attribute:: inherit_alive
                        
                        	The Inherit Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: inherit_spt
                        
                        	The Inherit SPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: is_via_lsm
                        
                        	Via LSM
                        	**type**\:  bool
                        
                        .. attribute:: jp_status
                        
                        	Join\-Prune Status
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: kat_state
                        
                        	Keep Alive Timer State
                        	**type**\:  bool
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: limit_reached
                        
                        	Have we throttled the creation of routes or interfaces ?
                        	**type**\:  bool
                        
                        .. attribute:: low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_active
                        
                        	Is MoFRR Active?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_backup
                        
                        	Is this Mofrr Backup?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_primary
                        
                        	Is this Mofrr Primary?
                        	**type**\:  bool
                        
                        .. attribute:: orig_src_address
                        
                        	Orig Src Address
                        	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress>`
                        
                        .. attribute:: outgoing_interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface>`
                        
                        .. attribute:: probe_alive
                        
                        	The Probe Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: proxy
                        
                        	Is the RPF target a proxy?
                        	**type**\:  bool
                        
                        .. attribute:: proxy_address
                        
                        	RPF Proxy address
                        	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress>`
                        
                        .. attribute:: really_alive
                        
                        	The Really Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: register_received
                        
                        	Have registers been received for this source ?
                        	**type**\:  bool
                        
                        .. attribute:: register_received_timer
                        
                        	Register Received Timer in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: remote_source
                        
                        	MSDP told us
                        	**type**\:  bool
                        
                        .. attribute:: rib_mo_frr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rp_address
                        
                        	RP Address (If rpt)
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor>`
                        
                        .. attribute:: rpf_proxy_enabled
                        
                        	Is rpf if proxy enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpt
                        
                        	RPT bit
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpt_xr
                        
                        	Is this on the RPT ?
                        	**type**\:  bool
                        
                        .. attribute:: sa_joined
                        
                        	BGP SA join
                        	**type**\:  bool
                        
                        .. attribute:: sa_received
                        
                        	BGP SA received
                        	**type**\:  bool
                        
                        .. attribute:: sa_sent
                        
                        	BGP SA sent
                        	**type**\:  bool
                        
                        .. attribute:: secondary_rpf_interface_name
                        
                        	Secondary Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: secondary_rpf_neighbor
                        
                        	Secondary RPF Neighbor
                        	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor>`
                        
                        .. attribute:: sending_null_registers
                        
                        	Are we sending null registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: sending_registers
                        
                        	Are we sending registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: signal_sources
                        
                        	Signal Sources on route?
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr>`
                        
                        .. attribute:: spt
                        
                        	Is this on the SPT ?
                        	**type**\:  bool
                        
                        .. attribute:: suppress_registers
                        
                        	When the Null register probe expires
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vxlan
                        
                        	Is this VXLAN?
                        	**type**\:  bool
                        
                        .. attribute:: wildcard
                        
                        	WC \-Wildcard
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology, self).__init__()

                            self.yang_name = "topology"
                            self.yang_parent_name = "topologies"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr), "orig-src-address" : ("orig_src_address", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress), "proxy-address" : ("proxy_address", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress), "rp-address" : ("rp_address", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress), "rpf-neighbor" : ("rpf_neighbor", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor), "rpf-root" : ("rpf_root", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot), "secondary-rpf-neighbor" : ("secondary_rpf_neighbor", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor), "source-address-xr" : ("source_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr)}
                            self._child_list_classes = {"outgoing-interface" : ("outgoing_interface", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface)}

                            self.alive = YLeaf(YType.int32, "alive")

                            self.anycast_rp_match = YLeaf(YType.boolean, "anycast-rp-match")

                            self.anycast_rp_route_target = YLeaf(YType.str, "anycast-rp-route-target")

                            self.assume_alive = YLeaf(YType.boolean, "assume-alive")

                            self.bgp_join = YLeaf(YType.boolean, "bgp-join")

                            self.bgp_jp_time = YLeaf(YType.uint64, "bgp-jp-time")

                            self.connected = YLeaf(YType.boolean, "connected")

                            self.crossed_threshold = YLeaf(YType.boolean, "crossed-threshold")

                            self.customer_routing_type = YLeaf(YType.int32, "customer-routing-type")

                            self.data_mdt_addr_assigned = YLeaf(YType.boolean, "data-mdt-addr-assigned")

                            self.dont_check_connected = YLeaf(YType.boolean, "dont-check-connected")

                            self.expiry = YLeaf(YType.uint64, "expiry")

                            self.extranet_route = YLeaf(YType.boolean, "extranet-route")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.inherit_alive = YLeaf(YType.boolean, "inherit-alive")

                            self.inherit_spt = YLeaf(YType.boolean, "inherit-spt")

                            self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                            self.jp_status = YLeaf(YType.int32, "jp-status")

                            self.jp_timer = YLeaf(YType.int32, "jp-timer")

                            self.kat_state = YLeaf(YType.boolean, "kat-state")

                            self.last_hop = YLeaf(YType.boolean, "last-hop")

                            self.limit_reached = YLeaf(YType.boolean, "limit-reached")

                            self.low_memory = YLeaf(YType.boolean, "low-memory")

                            self.mofrr_active = YLeaf(YType.boolean, "mofrr-active")

                            self.mofrr_backup = YLeaf(YType.boolean, "mofrr-backup")

                            self.mofrr_enabled = YLeaf(YType.boolean, "mofrr-enabled")

                            self.mofrr_primary = YLeaf(YType.boolean, "mofrr-primary")

                            self.probe_alive = YLeaf(YType.boolean, "probe-alive")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.proxy = YLeaf(YType.boolean, "proxy")

                            self.really_alive = YLeaf(YType.boolean, "really-alive")

                            self.register_received = YLeaf(YType.boolean, "register-received")

                            self.register_received_timer = YLeaf(YType.int32, "register-received-timer")

                            self.remote_source = YLeaf(YType.boolean, "remote-source")

                            self.rib_mo_frr_enabled = YLeaf(YType.boolean, "rib-mo-frr-enabled")

                            self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                            self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_proxy_enabled = YLeaf(YType.boolean, "rpf-proxy-enabled")

                            self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                            self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.rpt = YLeaf(YType.int32, "rpt")

                            self.rpt_xr = YLeaf(YType.boolean, "rpt-xr")

                            self.sa_joined = YLeaf(YType.boolean, "sa-joined")

                            self.sa_received = YLeaf(YType.boolean, "sa-received")

                            self.sa_sent = YLeaf(YType.boolean, "sa-sent")

                            self.secondary_rpf_interface_name = YLeaf(YType.str, "secondary-rpf-interface-name")

                            self.sending_null_registers = YLeaf(YType.boolean, "sending-null-registers")

                            self.sending_registers = YLeaf(YType.boolean, "sending-registers")

                            self.signal_sources = YLeaf(YType.boolean, "signal-sources")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.spt = YLeaf(YType.boolean, "spt")

                            self.suppress_registers = YLeaf(YType.int32, "suppress-registers")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.vxlan = YLeaf(YType.boolean, "vxlan")

                            self.wildcard = YLeaf(YType.boolean, "wildcard")

                            self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.orig_src_address = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                            self.orig_src_address.parent = self
                            self._children_name_map["orig_src_address"] = "orig-src-address"
                            self._children_yang_names.add("orig-src-address")

                            self.proxy_address = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                            self.proxy_address.parent = self
                            self._children_name_map["proxy_address"] = "proxy-address"
                            self._children_yang_names.add("proxy-address")

                            self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                            self.rpf_root = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._children_yang_names.add("rpf-root")

                            self.secondary_rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                            self.secondary_rpf_neighbor.parent = self
                            self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                            self._children_yang_names.add("secondary-rpf-neighbor")

                            self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                            self.outgoing_interface = YList(self)
                            self._segment_path = lambda: "topology"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology, ['alive', 'anycast_rp_match', 'anycast_rp_route_target', 'assume_alive', 'bgp_join', 'bgp_jp_time', 'connected', 'crossed_threshold', 'customer_routing_type', 'data_mdt_addr_assigned', 'dont_check_connected', 'expiry', 'extranet_route', 'group_address', 'inherit_alive', 'inherit_spt', 'is_via_lsm', 'jp_status', 'jp_timer', 'kat_state', 'last_hop', 'limit_reached', 'low_memory', 'mofrr_active', 'mofrr_backup', 'mofrr_enabled', 'mofrr_primary', 'probe_alive', 'protocol', 'proxy', 'really_alive', 'register_received', 'register_received_timer', 'remote_source', 'rib_mo_frr_enabled', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_proxy_enabled', 'rpf_safi', 'rpf_table_name', 'rpf_vrf_name', 'rpt', 'rpt_xr', 'sa_joined', 'sa_received', 'sa_sent', 'secondary_rpf_interface_name', 'sending_null_registers', 'sending_registers', 'signal_sources', 'source_address', 'spt', 'suppress_registers', 'uptime', 'vxlan', 'wildcard'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class OrigSrcAddress(Entity):
                            """
                            Orig Src Address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__init__()

                                self.yang_name = "orig-src-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "orig-src-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class OutgoingInterface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: admin_boundary
                            
                            	Is this an administrative boundary ?
                            	**type**\:  bool
                            
                            .. attribute:: assert_state
                            
                            	Assert State
                            	**type**\:  bool
                            
                            .. attribute:: assert_timer
                            
                            	Assert Timer in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: assert_winner
                            
                            	Assert Winner
                            	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner>`
                            
                            .. attribute:: bgp_c_mcast_join
                            
                            	BGP C\-Mcast join
                            	**type**\:  bool
                            
                            .. attribute:: bgp_c_mcast_prune_delay_timer
                            
                            	BGP C\-MCAST Prune Suppression in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: data_mdt_join
                            
                            	Data MDT join
                            	**type**\:  bool
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: extranet_interface
                            
                            	Is this an Extranet Interface ?
                            	**type**\:  bool
                            
                            .. attribute:: forwarding_state
                            
                            	Forward or Prune
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: igmp_membership
                            
                            	IGMP membership
                            	**type**\:  bool
                            
                            .. attribute:: immediate_state
                            
                            	Immediate fwding state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: interface_name
                            
                            	Interface Identifier
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: internal_interest_info
                            
                            	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: internal_interest_information
                            
                            	Internal Interest. Replaces internal\-interest\-info
                            	**type**\:   :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                            
                            .. attribute:: jp_state
                            
                            	Join\-Prune State
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: jp_timer
                            
                            	Join\-Prune Timer (secs)
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: last_hop
                            
                            	Are we last hop ?
                            	**type**\:  bool
                            
                            .. attribute:: local_mdt_join
                            
                            	Default MDT Join
                            	**type**\:  bool
                            
                            .. attribute:: local_members
                            
                            	Local Information. Deprecated \- use 'local\-members\-information' instead
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: local_members_information
                            
                            	Local Information. Replaces local\-members
                            	**type**\:   :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                            
                            .. attribute:: mdt_safi_join
                            
                            	MDT Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mldp_inband_mdt
                            
                            	MLDP Inband MDT interface
                            	**type**\:  bool
                            
                            .. attribute:: mldp_stale
                            
                            	OLE is stale
                            	**type**\:  bool
                            
                            .. attribute:: mvpn_safi_join
                            
                            	MVPN Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mvpnv6_safi_join
                            
                            	MVPN IPv6 Safi join
                            	**type**\:  bool
                            
                            .. attribute:: sa_prune
                            
                            	BGP SA Prune state
                            	**type**\:  bool
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: vrf_name
                            
                            	VRF which physically owns
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__init__()

                                self.yang_name = "outgoing-interface"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"assert-winner" : ("assert_winner", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner)}
                                self._child_list_classes = {}

                                self.admin_boundary = YLeaf(YType.boolean, "admin-boundary")

                                self.assert_state = YLeaf(YType.boolean, "assert-state")

                                self.assert_timer = YLeaf(YType.int32, "assert-timer")

                                self.bgp_c_mcast_join = YLeaf(YType.boolean, "bgp-c-mcast-join")

                                self.bgp_c_mcast_prune_delay_timer = YLeaf(YType.uint64, "bgp-c-mcast-prune-delay-timer")

                                self.data_mdt_join = YLeaf(YType.boolean, "data-mdt-join")

                                self.expiry = YLeaf(YType.uint64, "expiry")

                                self.extranet_interface = YLeaf(YType.boolean, "extranet-interface")

                                self.forwarding_state = YLeaf(YType.int32, "forwarding-state")

                                self.igmp_membership = YLeaf(YType.boolean, "igmp-membership")

                                self.immediate_state = YLeaf(YType.int32, "immediate-state")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.internal_interest_info = YLeaf(YType.int32, "internal-interest-info")

                                self.internal_interest_information = YLeaf(YType.enumeration, "internal-interest-information")

                                self.jp_state = YLeaf(YType.int32, "jp-state")

                                self.jp_timer = YLeaf(YType.int32, "jp-timer")

                                self.last_hop = YLeaf(YType.boolean, "last-hop")

                                self.local_mdt_join = YLeaf(YType.boolean, "local-mdt-join")

                                self.local_members = YLeaf(YType.int32, "local-members")

                                self.local_members_information = YLeaf(YType.enumeration, "local-members-information")

                                self.mdt_safi_join = YLeaf(YType.boolean, "mdt-safi-join")

                                self.mldp_inband_mdt = YLeaf(YType.boolean, "mldp-inband-mdt")

                                self.mldp_stale = YLeaf(YType.boolean, "mldp-stale")

                                self.mvpn_safi_join = YLeaf(YType.boolean, "mvpn-safi-join")

                                self.mvpnv6_safi_join = YLeaf(YType.boolean, "mvpnv6-safi-join")

                                self.sa_prune = YLeaf(YType.boolean, "sa-prune")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.assert_winner = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                self.assert_winner.parent = self
                                self._children_name_map["assert_winner"] = "assert-winner"
                                self._children_yang_names.add("assert-winner")
                                self._segment_path = lambda: "outgoing-interface"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, ['admin_boundary', 'assert_state', 'assert_timer', 'bgp_c_mcast_join', 'bgp_c_mcast_prune_delay_timer', 'data_mdt_join', 'expiry', 'extranet_interface', 'forwarding_state', 'igmp_membership', 'immediate_state', 'interface_name', 'internal_interest_info', 'internal_interest_information', 'jp_state', 'jp_timer', 'last_hop', 'local_mdt_join', 'local_members', 'local_members_information', 'mdt_safi_join', 'mldp_inband_mdt', 'mldp_stale', 'mvpn_safi_join', 'mvpnv6_safi_join', 'sa_prune', 'uptime', 'vrf_name'], name, value)


                            class AssertWinner(Entity):
                                """
                                Assert Winner
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                    self.yang_name = "assert-winner"
                                    self.yang_parent_name = "outgoing-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "assert-winner"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class ProxyAddress(Entity):
                            """
                            RPF Proxy address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__init__()

                                self.yang_name = "proxy-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "proxy-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP Address (If rpt)
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-root"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SecondaryRpfNeighbor(Entity):
                            """
                            Secondary RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                                self.yang_name = "secondary-rpf-neighbor"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "secondary-rpf-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class TopologyEntryFlagRouteCounts(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: topology_entry_flag_route_count
                    
                    	Route count for topology with entry flag set
                    	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-entry-flag-route-counts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"topology-entry-flag-route-count" : ("topology_entry_flag_route_count", Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount)}

                        self.topology_entry_flag_route_count = YList(self)
                        self._segment_path = lambda: "topology-entry-flag-route-counts"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts, [], name, value)


                    class TopologyEntryFlagRouteCount(Entity):
                        """
                        Route count for topology with entry flag set
                        
                        .. attribute:: entry_flag  <key>
                        
                        	entry flag
                        	**type**\:   :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                            self.yang_name = "topology-entry-flag-route-count"
                            self.yang_parent_name = "topology-entry-flag-route-counts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.entry_flag = YLeaf(YType.enumeration, "entry-flag")

                            self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                            self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                            self.groute_count = YLeaf(YType.uint32, "groute-count")

                            self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                            self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                            self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                            self._segment_path = lambda: "topology-entry-flag-route-count" + "[entry-flag='" + self.entry_flag.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, ['entry_flag', 'active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


                class TopologyInterfaceFlagRouteCounts(Entity):
                    """
                    Route count for topology with interface flag set
                    
                    .. attribute:: topology_interface_flag_route_count
                    
                    	Route count for topology with interface flag set
                    	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-interface-flag-route-counts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"topology-interface-flag-route-count" : ("topology_interface_flag_route_count", Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount)}

                        self.topology_interface_flag_route_count = YList(self)
                        self._segment_path = lambda: "topology-interface-flag-route-counts"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, [], name, value)


                    class TopologyInterfaceFlagRouteCount(Entity):
                        """
                        Route count for topology with interface flag
                        set
                        
                        .. attribute:: interface_flag  <key>
                        
                        	Interface flag
                        	**type**\:   :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                            self.yang_name = "topology-interface-flag-route-count"
                            self.yang_parent_name = "topology-interface-flag-route-counts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interface_flag = YLeaf(YType.enumeration, "interface-flag")

                            self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                            self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                            self.groute_count = YLeaf(YType.uint32, "groute-count")

                            self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                            self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                            self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                            self._segment_path = lambda: "topology-interface-flag-route-count" + "[interface-flag='" + self.interface_flag.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, ['interface_flag', 'active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


                class TopologyRouteCount(Entity):
                    """
                    Topology route count information from PIM
                    topology table
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount, self).__init__()

                        self.yang_name = "topology-route-count"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                        self._segment_path = lambda: "topology-route-count"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount, ['active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


                class TrafficCounters(Entity):
                    """
                    PIM message traffic counters
                    
                    .. attribute:: boundary_acl_rx_drop
                    
                    	Inc. JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_tx_drop
                    
                    	Out JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_error
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: format_error
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert_batched
                    
                    	Batched Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_data_register
                    
                    	Data Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_ecmp_redirect
                    
                    	Input Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb_error
                    
                    	No IDB for intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_pim_error
                    
                    	PIM Disabled on intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_error
                    
                    	No VRF for idb error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_null_register
                    
                    	Null Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim_version_error
                    
                    	Invalid PIM version error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inputs
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_destination_packets
                    
                    	Control Packets with Invalid Destination
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_join_prunes
                    
                    	PIM invalid Join/Prunes received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_registers
                    
                    	PIM invalid registers received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_local_source_address
                    
                    	Data MDT Join msgs dropped due to local source addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_idb
                    
                    	Data MDT Join msgs dropped due to idb missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_vrf
                    
                    	Data MDT Join msgs dropped due to vrf missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_null_local_address
                    
                    	Data MDT Join msgs dropped due to null local addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_bad_type
                    
                    	Data MDT TLV bad type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_received
                    
                    	Data MDT Join Msgs received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_sent
                    
                    	Data MDT Join Msgs sent
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_joins_drop_multiple_encapsulation
                    
                    	MDT Join msgs dropped due to multiple Encap limitation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_send_queue_full
                    
                    	Packets dropped since mdt send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_socket_error
                    
                    	MDT Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_invalid_lsm_identifier
                    
                    	 Invalid LSM ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_mdt_socket_connection
                    
                    	Packets dropped since no mdt socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_source_address
                    
                    	Packets dropped since no source address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: non_supported_packets
                    
                    	PIM non supported pckets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert_batched
                    
                    	Batched Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_data_register
                    
                    	Data Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_ecmp_redirect
                    
                    	Output Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello_bytes
                    
                    	Output Hello Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_join_group
                    
                    	Output Join Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_prune_bytes
                    
                    	Output JP Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_loop_error
                    
                    	Output on loopback error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_null_register
                    
                    	Null Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_prune_group
                    
                    	Output Prune Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: outputs
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_packman_error
                    
                    	Packets Dropped due to Pakman Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue
                    
                    	Packet queue state and statistics
                    	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue>`
                    
                    .. attribute:: packet_queue_last_clear
                    
                    	Time in seconds since the last clear of all packet queues stats
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: packet_read_socket_error
                    
                    	Packet Read Socket Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_standby
                    
                    	Packets Dropped due to Standby Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pakman_error
                    
                    	Pakman packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: send_queue_full
                    
                    	Packets dropped since send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_error
                    
                    	Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: standby_packets_error
                    
                    	Packets received in standby state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: truncated_pim_packets
                    
                    	Packets dropped due to truncated Joins or Prunes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"packet-queue" : ("packet_queue", Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue)}

                        self.boundary_acl_rx_drop = YLeaf(YType.uint32, "boundary-acl-rx-drop")

                        self.boundary_acl_tx_drop = YLeaf(YType.uint32, "boundary-acl-tx-drop")

                        self.checksum_error = YLeaf(YType.uint32, "checksum-error")

                        self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                        self.format_error = YLeaf(YType.uint32, "format-error")

                        self.input_assert = YLeaf(YType.uint32, "input-assert")

                        self.input_assert_batched = YLeaf(YType.uint32, "input-assert-batched")

                        self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                        self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                        self.input_data_register = YLeaf(YType.uint32, "input-data-register")

                        self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                        self.input_ecmp_redirect = YLeaf(YType.uint32, "input-ecmp-redirect")

                        self.input_hello = YLeaf(YType.uint32, "input-hello")

                        self.input_jp = YLeaf(YType.uint32, "input-jp")

                        self.input_no_idb_error = YLeaf(YType.uint32, "input-no-idb-error")

                        self.input_no_pim_error = YLeaf(YType.uint32, "input-no-pim-error")

                        self.input_no_vrf_error = YLeaf(YType.uint32, "input-no-vrf-error")

                        self.input_null_register = YLeaf(YType.uint32, "input-null-register")

                        self.input_pim_version_error = YLeaf(YType.uint32, "input-pim-version-error")

                        self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                        self.inputs = YLeaf(YType.uint32, "inputs")

                        self.invalid_destination_packets = YLeaf(YType.uint32, "invalid-destination-packets")

                        self.invalid_join_prunes = YLeaf(YType.uint32, "invalid-join-prunes")

                        self.invalid_registers = YLeaf(YType.uint32, "invalid-registers")

                        self.mdt_drop_local_source_address = YLeaf(YType.uint32, "mdt-drop-local-source-address")

                        self.mdt_drop_no_idb = YLeaf(YType.uint32, "mdt-drop-no-idb")

                        self.mdt_drop_no_vrf = YLeaf(YType.uint32, "mdt-drop-no-vrf")

                        self.mdt_drop_null_local_address = YLeaf(YType.uint32, "mdt-drop-null-local-address")

                        self.mdt_join_bad_type = YLeaf(YType.uint32, "mdt-join-bad-type")

                        self.mdt_join_tlv_received = YLeaf(YType.uint32, "mdt-join-tlv-received")

                        self.mdt_join_tlv_sent = YLeaf(YType.uint32, "mdt-join-tlv-sent")

                        self.mdt_joins_drop_multiple_encapsulation = YLeaf(YType.uint32, "mdt-joins-drop-multiple-encapsulation")

                        self.mdt_send_queue_full = YLeaf(YType.uint32, "mdt-send-queue-full")

                        self.mdt_socket_error = YLeaf(YType.uint32, "mdt-socket-error")

                        self.mldp_mdt_invalid_lsm_identifier = YLeaf(YType.uint32, "mldp-mdt-invalid-lsm-identifier")

                        self.no_mdt_socket_connection = YLeaf(YType.uint32, "no-mdt-socket-connection")

                        self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                        self.no_source_address = YLeaf(YType.uint32, "no-source-address")

                        self.non_supported_packets = YLeaf(YType.uint32, "non-supported-packets")

                        self.output_assert = YLeaf(YType.uint32, "output-assert")

                        self.output_assert_batched = YLeaf(YType.uint32, "output-assert-batched")

                        self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                        self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                        self.output_data_register = YLeaf(YType.uint32, "output-data-register")

                        self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                        self.output_ecmp_redirect = YLeaf(YType.uint32, "output-ecmp-redirect")

                        self.output_hello = YLeaf(YType.uint32, "output-hello")

                        self.output_hello_bytes = YLeaf(YType.uint32, "output-hello-bytes")

                        self.output_join_group = YLeaf(YType.uint32, "output-join-group")

                        self.output_join_prune_bytes = YLeaf(YType.uint32, "output-join-prune-bytes")

                        self.output_jp = YLeaf(YType.uint32, "output-jp")

                        self.output_loop_error = YLeaf(YType.uint32, "output-loop-error")

                        self.output_null_register = YLeaf(YType.uint32, "output-null-register")

                        self.output_prune_group = YLeaf(YType.uint32, "output-prune-group")

                        self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                        self.outputs = YLeaf(YType.uint32, "outputs")

                        self.packet_packman_error = YLeaf(YType.uint32, "packet-packman-error")

                        self.packet_queue_last_clear = YLeaf(YType.uint32, "packet-queue-last-clear")

                        self.packet_read_socket_error = YLeaf(YType.uint32, "packet-read-socket-error")

                        self.packets_standby = YLeaf(YType.uint32, "packets-standby")

                        self.pakman_error = YLeaf(YType.uint32, "pakman-error")

                        self.send_queue_full = YLeaf(YType.uint32, "send-queue-full")

                        self.socket_error = YLeaf(YType.uint32, "socket-error")

                        self.standby_packets_error = YLeaf(YType.uint32, "standby-packets-error")

                        self.truncated_pim_packets = YLeaf(YType.uint32, "truncated-pim-packets")

                        self.packet_queue = YList(self)
                        self._segment_path = lambda: "traffic-counters"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters, ['boundary_acl_rx_drop', 'boundary_acl_tx_drop', 'checksum_error', 'elapsed_time', 'format_error', 'input_assert', 'input_assert_batched', 'input_bsr_message', 'input_candidate_rp_advertisement', 'input_data_register', 'input_df_election', 'input_ecmp_redirect', 'input_hello', 'input_jp', 'input_no_idb_error', 'input_no_pim_error', 'input_no_vrf_error', 'input_null_register', 'input_pim_version_error', 'input_register_stop', 'inputs', 'invalid_destination_packets', 'invalid_join_prunes', 'invalid_registers', 'mdt_drop_local_source_address', 'mdt_drop_no_idb', 'mdt_drop_no_vrf', 'mdt_drop_null_local_address', 'mdt_join_bad_type', 'mdt_join_tlv_received', 'mdt_join_tlv_sent', 'mdt_joins_drop_multiple_encapsulation', 'mdt_send_queue_full', 'mdt_socket_error', 'mldp_mdt_invalid_lsm_identifier', 'no_mdt_socket_connection', 'no_socket_connection', 'no_source_address', 'non_supported_packets', 'output_assert', 'output_assert_batched', 'output_bsr_message', 'output_candidate_rp_advertisement', 'output_data_register', 'output_df_election', 'output_ecmp_redirect', 'output_hello', 'output_hello_bytes', 'output_join_group', 'output_join_prune_bytes', 'output_jp', 'output_loop_error', 'output_null_register', 'output_prune_group', 'output_register_stop', 'outputs', 'packet_packman_error', 'packet_queue_last_clear', 'packet_read_socket_error', 'packets_standby', 'pakman_error', 'send_queue_full', 'socket_error', 'standby_packets_error', 'truncated_pim_packets'], name, value)


                    class PacketQueue(Entity):
                        """
                        Packet queue state and statistics
                        
                        .. attribute:: packet_queue_priority
                        
                        	Priority of this packet queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: packet_queue_state
                        
                        	State of the queue
                        	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState>`
                        
                        .. attribute:: packet_queue_stats
                        
                        	Statistics about the queue
                        	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__init__()

                            self.yang_name = "packet-queue"
                            self.yang_parent_name = "traffic-counters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"packet-queue-state" : ("packet_queue_state", Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState), "packet-queue-stats" : ("packet_queue_stats", Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats)}
                            self._child_list_classes = {}

                            self.packet_queue_priority = YLeaf(YType.uint32, "packet-queue-priority")

                            self.packet_queue_state = Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                            self.packet_queue_state.parent = self
                            self._children_name_map["packet_queue_state"] = "packet-queue-state"
                            self._children_yang_names.add("packet-queue-state")

                            self.packet_queue_stats = Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                            self.packet_queue_stats.parent = self
                            self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                            self._children_yang_names.add("packet-queue-stats")
                            self._segment_path = lambda: "packet-queue"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue, ['packet_queue_priority'], name, value)


                        class PacketQueueState(Entity):
                            """
                            State of the queue
                            
                            .. attribute:: max_queue_size
                            
                            	Maximum size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_bytes
                            
                            	Size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_packets
                            
                            	Size of queue in number of packets
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                                self.yang_name = "packet-queue-state"
                                self.yang_parent_name = "packet-queue"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.max_queue_size = YLeaf(YType.uint32, "max-queue-size")

                                self.queue_size_bytes = YLeaf(YType.uint32, "queue-size-bytes")

                                self.queue_size_packets = YLeaf(YType.uint32, "queue-size-packets")
                                self._segment_path = lambda: "packet-queue-state"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, ['max_queue_size', 'queue_size_bytes', 'queue_size_packets'], name, value)


                        class PacketQueueStats(Entity):
                            """
                            Statistics about the queue
                            
                            .. attribute:: dequeued_packets
                            
                            	Total number of packets dequeued from this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: enqueued_packets
                            
                            	Total number of packets enqueued to this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_bytes
                            
                            	Highest number of bytes enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: high_water_mark_packets
                            
                            	Highest number of packets enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tail_drops
                            
                            	Number packets dropped from this queue due to max size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                                self.yang_name = "packet-queue-stats"
                                self.yang_parent_name = "packet-queue"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.dequeued_packets = YLeaf(YType.uint32, "dequeued-packets")

                                self.enqueued_packets = YLeaf(YType.uint32, "enqueued-packets")

                                self.high_water_mark_bytes = YLeaf(YType.uint32, "high-water-mark-bytes")

                                self.high_water_mark_packets = YLeaf(YType.uint32, "high-water-mark-packets")

                                self.tail_drops = YLeaf(YType.uint32, "tail-drops")
                                self._segment_path = lambda: "packet-queue-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, ['dequeued_packets', 'enqueued_packets', 'high_water_mark_bytes', 'high_water_mark_packets', 'tail_drops'], name, value)


                class Tunnels(Entity):
                    """
                    Tunnels information that PIM has
                    
                    .. attribute:: tunnel
                    
                    	PIM tunnel information
                    	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels, self).__init__()

                        self.yang_name = "tunnels"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"tunnel" : ("tunnel", Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel)}

                        self.tunnel = YList(self)
                        self._segment_path = lambda: "tunnels"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels, [], name, value)


                    class Tunnel(Entity):
                        """
                        PIM tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel, self).__init__()

                            self.yang_name = "tunnel"
                            self.yang_parent_name = "tunnels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-netio" : ("group_address_netio", Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio), "rp-address" : ("rp_address", Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress), "source-address" : ("source_address", Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress), "source-address-netio" : ("source_address_netio", Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio)}
                            self._child_list_classes = {}

                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._children_yang_names.add("group-address-netio")

                            self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.source_address = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                            self.source_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"
                            self._children_yang_names.add("source-address-netio")
                            self._segment_path = lambda: "tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel, ['tunnel_name', 'vrf_name'], name, value)


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-netio"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-netio"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)

    def clone_ptr(self):
        self._top_entity = Ipv6Pim()
        return self._top_entity

class Pim(Entity):
    """
    pim
    
    .. attribute:: active
    
    	Active Process
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active>`
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby>`
    
    

    """

    _prefix = 'ipv4-pim-oper'
    _revision = '2017-06-26'

    def __init__(self):
        super(Pim, self).__init__()
        self._top_entity = None

        self.yang_name = "pim"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-pim-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"active" : ("active", Pim.Active), "standby" : ("standby", Pim.Standby)}
        self._child_list_classes = {}

        self.active = Pim.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"
        self._children_yang_names.add("active")

        self.standby = Pim.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"
        self._children_yang_names.add("standby")
        self._segment_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim"


    class Active(Entity):
        """
        Active Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2017-06-26'

        def __init__(self):
            super(Pim.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "pim"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"default-context" : ("default_context", Pim.Active.DefaultContext), "process" : ("process", Pim.Active.Process), "vrfs" : ("vrfs", Pim.Active.Vrfs)}
            self._child_list_classes = {}

            self.default_context = Pim.Active.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"
            self._children_yang_names.add("default-context")

            self.process = Pim.Active.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"
            self._children_yang_names.add("process")

            self.vrfs = Pim.Active.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._children_yang_names.add("vrfs")
            self._segment_path = lambda: "active"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/%s" % self._segment_path()


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: auto_rp
            
            	PIM Auto\-RP information
            	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.AutoRp>`
            
            .. attribute:: bgp_afs
            
            	PIM BGP SAFI table
            	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs>`
            
            .. attribute:: bidir_df_states
            
            	Bidirectional PIM DF election state table
            	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfStates>`
            
            .. attribute:: bidir_df_winners
            
            	Bidirectional PIM DF election winner table
            	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfWinners>`
            
            .. attribute:: bsr
            
            	PIM BSR information
            	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr>`
            
            .. attribute:: context
            
            	PIM context information
            	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context>`
            
            .. attribute:: global_interfaces
            
            	PIM global interface table
            	**type**\:   :py:class:`GlobalInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GlobalInterfaces>`
            
            .. attribute:: gre
            
            	GRE information
            	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre>`
            
            .. attribute:: group_map_rpfs
            
            	PIM group mapping information
            	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs>`
            
            .. attribute:: group_map_sources
            
            	PIM group\-mapping with source information
            	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources>`
            
            .. attribute:: ifrs_interfaces
            
            	PIM interfaces in forward reference store table
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: ifrs_summary
            
            	PIM interfaces in forward reference store summary
            	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsSummary>`
            
            .. attribute:: interface_old_formats
            
            	PIM interfaces in old format
            	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceOldFormats>`
            
            .. attribute:: interface_statistics
            
            	PIM interface statistics
            	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceStatistics>`
            
            .. attribute:: interfaces
            
            	PIM interfaces
            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Interfaces>`
            
            .. attribute:: jp_statistics
            
            	PIM join prune statistics table
            	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.JpStatistics>`
            
            .. attribute:: mib_databases
            
            	PIM group database for mroute mibs table
            	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases>`
            
            .. attribute:: multicast_static_routes
            
            	PIM multicast static route table
            	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MulticastStaticRoutes>`
            
            .. attribute:: neighbor_old_formats
            
            	PIM neighbor table old format
            	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborOldFormats>`
            
            .. attribute:: neighbor_summaries
            
            	PIM neighbor summary table
            	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborSummaries>`
            
            .. attribute:: neighbors
            
            	PIM neighbor table
            	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Neighbors>`
            
            .. attribute:: net_io_tunnels
            
            	Tunnel information that NETIO has 
            	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels>`
            
            .. attribute:: ranges
            
            	PIM range list information
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges>`
            
            .. attribute:: route_policy
            
            	PIM route policy
            	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy>`
            
            .. attribute:: rpf_redirect
            
            	PIM ECMP RPF\-redirect bundle
            	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect>`
            
            .. attribute:: rpf_summary
            
            	PIM RPF registration summary
            	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfSummary>`
            
            .. attribute:: safs
            
            	SAFI table and type
            	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs>`
            
            .. attribute:: summary
            
            	PIM summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Summary>`
            
            .. attribute:: table_contexts
            
            	PIM table context list
            	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TableContexts>`
            
            .. attribute:: topologies
            
            	PIM topology table
            	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies>`
            
            .. attribute:: topology_entry_flag_route_counts
            
            	Route count for topology with entry flag set
            	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts>`
            
            .. attribute:: topology_interface_flag_route_counts
            
            	Route count for topology with interface flag set
            	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts>`
            
            .. attribute:: topology_route_count
            
            	Topology route count information from PIM topology table
            	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyRouteCount>`
            
            .. attribute:: traffic_counters
            
            	PIM message traffic counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TrafficCounters>`
            
            .. attribute:: tunnels
            
            	Tunnels information that PIM has
            	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Pim.Active.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"auto-rp" : ("auto_rp", Pim.Active.DefaultContext.AutoRp), "bgp-afs" : ("bgp_afs", Pim.Active.DefaultContext.BgpAfs), "bidir-df-states" : ("bidir_df_states", Pim.Active.DefaultContext.BidirDfStates), "bidir-df-winners" : ("bidir_df_winners", Pim.Active.DefaultContext.BidirDfWinners), "bsr" : ("bsr", Pim.Active.DefaultContext.Bsr), "context" : ("context", Pim.Active.DefaultContext.Context), "global-interfaces" : ("global_interfaces", Pim.Active.DefaultContext.GlobalInterfaces), "gre" : ("gre", Pim.Active.DefaultContext.Gre), "group-map-rpfs" : ("group_map_rpfs", Pim.Active.DefaultContext.GroupMapRpfs), "group-map-sources" : ("group_map_sources", Pim.Active.DefaultContext.GroupMapSources), "ifrs-interfaces" : ("ifrs_interfaces", Pim.Active.DefaultContext.IfrsInterfaces), "ifrs-summary" : ("ifrs_summary", Pim.Active.DefaultContext.IfrsSummary), "interface-old-formats" : ("interface_old_formats", Pim.Active.DefaultContext.InterfaceOldFormats), "interface-statistics" : ("interface_statistics", Pim.Active.DefaultContext.InterfaceStatistics), "interfaces" : ("interfaces", Pim.Active.DefaultContext.Interfaces), "jp-statistics" : ("jp_statistics", Pim.Active.DefaultContext.JpStatistics), "mib-databases" : ("mib_databases", Pim.Active.DefaultContext.MibDatabases), "multicast-static-routes" : ("multicast_static_routes", Pim.Active.DefaultContext.MulticastStaticRoutes), "neighbor-old-formats" : ("neighbor_old_formats", Pim.Active.DefaultContext.NeighborOldFormats), "neighbor-summaries" : ("neighbor_summaries", Pim.Active.DefaultContext.NeighborSummaries), "neighbors" : ("neighbors", Pim.Active.DefaultContext.Neighbors), "net-io-tunnels" : ("net_io_tunnels", Pim.Active.DefaultContext.NetIoTunnels), "ranges" : ("ranges", Pim.Active.DefaultContext.Ranges), "route-policy" : ("route_policy", Pim.Active.DefaultContext.RoutePolicy), "rpf-redirect" : ("rpf_redirect", Pim.Active.DefaultContext.RpfRedirect), "rpf-summary" : ("rpf_summary", Pim.Active.DefaultContext.RpfSummary), "safs" : ("safs", Pim.Active.DefaultContext.Safs), "summary" : ("summary", Pim.Active.DefaultContext.Summary), "table-contexts" : ("table_contexts", Pim.Active.DefaultContext.TableContexts), "topologies" : ("topologies", Pim.Active.DefaultContext.Topologies), "topology-entry-flag-route-counts" : ("topology_entry_flag_route_counts", Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts), "topology-interface-flag-route-counts" : ("topology_interface_flag_route_counts", Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts), "topology-route-count" : ("topology_route_count", Pim.Active.DefaultContext.TopologyRouteCount), "traffic-counters" : ("traffic_counters", Pim.Active.DefaultContext.TrafficCounters), "tunnels" : ("tunnels", Pim.Active.DefaultContext.Tunnels)}
                self._child_list_classes = {}

                self.auto_rp = Pim.Active.DefaultContext.AutoRp()
                self.auto_rp.parent = self
                self._children_name_map["auto_rp"] = "auto-rp"
                self._children_yang_names.add("auto-rp")

                self.bgp_afs = Pim.Active.DefaultContext.BgpAfs()
                self.bgp_afs.parent = self
                self._children_name_map["bgp_afs"] = "bgp-afs"
                self._children_yang_names.add("bgp-afs")

                self.bidir_df_states = Pim.Active.DefaultContext.BidirDfStates()
                self.bidir_df_states.parent = self
                self._children_name_map["bidir_df_states"] = "bidir-df-states"
                self._children_yang_names.add("bidir-df-states")

                self.bidir_df_winners = Pim.Active.DefaultContext.BidirDfWinners()
                self.bidir_df_winners.parent = self
                self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                self._children_yang_names.add("bidir-df-winners")

                self.bsr = Pim.Active.DefaultContext.Bsr()
                self.bsr.parent = self
                self._children_name_map["bsr"] = "bsr"
                self._children_yang_names.add("bsr")

                self.context = Pim.Active.DefaultContext.Context()
                self.context.parent = self
                self._children_name_map["context"] = "context"
                self._children_yang_names.add("context")

                self.global_interfaces = Pim.Active.DefaultContext.GlobalInterfaces()
                self.global_interfaces.parent = self
                self._children_name_map["global_interfaces"] = "global-interfaces"
                self._children_yang_names.add("global-interfaces")

                self.gre = Pim.Active.DefaultContext.Gre()
                self.gre.parent = self
                self._children_name_map["gre"] = "gre"
                self._children_yang_names.add("gre")

                self.group_map_rpfs = Pim.Active.DefaultContext.GroupMapRpfs()
                self.group_map_rpfs.parent = self
                self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                self._children_yang_names.add("group-map-rpfs")

                self.group_map_sources = Pim.Active.DefaultContext.GroupMapSources()
                self.group_map_sources.parent = self
                self._children_name_map["group_map_sources"] = "group-map-sources"
                self._children_yang_names.add("group-map-sources")

                self.ifrs_interfaces = Pim.Active.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                self._children_yang_names.add("ifrs-interfaces")

                self.ifrs_summary = Pim.Active.DefaultContext.IfrsSummary()
                self.ifrs_summary.parent = self
                self._children_name_map["ifrs_summary"] = "ifrs-summary"
                self._children_yang_names.add("ifrs-summary")

                self.interface_old_formats = Pim.Active.DefaultContext.InterfaceOldFormats()
                self.interface_old_formats.parent = self
                self._children_name_map["interface_old_formats"] = "interface-old-formats"
                self._children_yang_names.add("interface-old-formats")

                self.interface_statistics = Pim.Active.DefaultContext.InterfaceStatistics()
                self.interface_statistics.parent = self
                self._children_name_map["interface_statistics"] = "interface-statistics"
                self._children_yang_names.add("interface-statistics")

                self.interfaces = Pim.Active.DefaultContext.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"
                self._children_yang_names.add("interfaces")

                self.jp_statistics = Pim.Active.DefaultContext.JpStatistics()
                self.jp_statistics.parent = self
                self._children_name_map["jp_statistics"] = "jp-statistics"
                self._children_yang_names.add("jp-statistics")

                self.mib_databases = Pim.Active.DefaultContext.MibDatabases()
                self.mib_databases.parent = self
                self._children_name_map["mib_databases"] = "mib-databases"
                self._children_yang_names.add("mib-databases")

                self.multicast_static_routes = Pim.Active.DefaultContext.MulticastStaticRoutes()
                self.multicast_static_routes.parent = self
                self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                self._children_yang_names.add("multicast-static-routes")

                self.neighbor_old_formats = Pim.Active.DefaultContext.NeighborOldFormats()
                self.neighbor_old_formats.parent = self
                self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                self._children_yang_names.add("neighbor-old-formats")

                self.neighbor_summaries = Pim.Active.DefaultContext.NeighborSummaries()
                self.neighbor_summaries.parent = self
                self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                self._children_yang_names.add("neighbor-summaries")

                self.neighbors = Pim.Active.DefaultContext.Neighbors()
                self.neighbors.parent = self
                self._children_name_map["neighbors"] = "neighbors"
                self._children_yang_names.add("neighbors")

                self.net_io_tunnels = Pim.Active.DefaultContext.NetIoTunnels()
                self.net_io_tunnels.parent = self
                self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                self._children_yang_names.add("net-io-tunnels")

                self.ranges = Pim.Active.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"
                self._children_yang_names.add("ranges")

                self.route_policy = Pim.Active.DefaultContext.RoutePolicy()
                self.route_policy.parent = self
                self._children_name_map["route_policy"] = "route-policy"
                self._children_yang_names.add("route-policy")

                self.rpf_redirect = Pim.Active.DefaultContext.RpfRedirect()
                self.rpf_redirect.parent = self
                self._children_name_map["rpf_redirect"] = "rpf-redirect"
                self._children_yang_names.add("rpf-redirect")

                self.rpf_summary = Pim.Active.DefaultContext.RpfSummary()
                self.rpf_summary.parent = self
                self._children_name_map["rpf_summary"] = "rpf-summary"
                self._children_yang_names.add("rpf-summary")

                self.safs = Pim.Active.DefaultContext.Safs()
                self.safs.parent = self
                self._children_name_map["safs"] = "safs"
                self._children_yang_names.add("safs")

                self.summary = Pim.Active.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.table_contexts = Pim.Active.DefaultContext.TableContexts()
                self.table_contexts.parent = self
                self._children_name_map["table_contexts"] = "table-contexts"
                self._children_yang_names.add("table-contexts")

                self.topologies = Pim.Active.DefaultContext.Topologies()
                self.topologies.parent = self
                self._children_name_map["topologies"] = "topologies"
                self._children_yang_names.add("topologies")

                self.topology_entry_flag_route_counts = Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts()
                self.topology_entry_flag_route_counts.parent = self
                self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                self._children_yang_names.add("topology-entry-flag-route-counts")

                self.topology_interface_flag_route_counts = Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts()
                self.topology_interface_flag_route_counts.parent = self
                self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                self._children_yang_names.add("topology-interface-flag-route-counts")

                self.topology_route_count = Pim.Active.DefaultContext.TopologyRouteCount()
                self.topology_route_count.parent = self
                self._children_name_map["topology_route_count"] = "topology-route-count"
                self._children_yang_names.add("topology-route-count")

                self.traffic_counters = Pim.Active.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"
                self._children_yang_names.add("traffic-counters")

                self.tunnels = Pim.Active.DefaultContext.Tunnels()
                self.tunnels.parent = self
                self._children_name_map["tunnels"] = "tunnels"
                self._children_yang_names.add("tunnels")
                self._segment_path = lambda: "default-context"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/%s" % self._segment_path()


            class AutoRp(Entity):
                """
                PIM Auto\-RP information
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.AutoRp, self).__init__()

                    self.yang_name = "auto-rp"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self._segment_path = lambda: "auto-rp"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()


            class BgpAfs(Entity):
                """
                PIM BGP SAFI table
                
                .. attribute:: bgp_af
                
                	PIM BGP SAFI information
                	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs.BgpAf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.BgpAfs, self).__init__()

                    self.yang_name = "bgp-afs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"bgp-af" : ("bgp_af", Pim.Active.DefaultContext.BgpAfs.BgpAf)}

                    self.bgp_af = YList(self)
                    self._segment_path = lambda: "bgp-afs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.BgpAfs, [], name, value)


                class BgpAf(Entity):
                    """
                    PIM BGP SAFI information
                    
                    .. attribute:: extranet_path_count
                    
                    	Count of dependent extranet paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group
                    
                    	Group address
                    	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs.BgpAf.Group>`
                    
                    .. attribute:: group_address
                    
                    	Group IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: is_bgp_added
                    
                    	SAFI learnt from BGP
                    	**type**\:  bool
                    
                    .. attribute:: next_hop
                    
                    	Next hop address
                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop>`
                    
                    .. attribute:: route_distinguisher
                    
                    	Router ID
                    	**type**\:  str
                    
                    	**length:** 0..256
                    
                    .. attribute:: source
                    
                    	Source address
                    	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs.BgpAf.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.BgpAfs.BgpAf, self).__init__()

                        self.yang_name = "bgp-af"
                        self.yang_parent_name = "bgp-afs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group" : ("group", Pim.Active.DefaultContext.BgpAfs.BgpAf.Group), "next-hop" : ("next_hop", Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop), "source" : ("source", Pim.Active.DefaultContext.BgpAfs.BgpAf.Source)}
                        self._child_list_classes = {}

                        self.extranet_path_count = YLeaf(YType.uint32, "extranet-path-count")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.is_bgp_added = YLeaf(YType.boolean, "is-bgp-added")

                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group = Pim.Active.DefaultContext.BgpAfs.BgpAf.Group()
                        self.group.parent = self
                        self._children_name_map["group"] = "group"
                        self._children_yang_names.add("group")

                        self.next_hop = Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._children_yang_names.add("next-hop")

                        self.source = Pim.Active.DefaultContext.BgpAfs.BgpAf.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"
                        self._children_yang_names.add("source")
                        self._segment_path = lambda: "bgp-af"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bgp-afs/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.BgpAfs.BgpAf, ['extranet_path_count', 'group_address', 'is_bgp_added', 'route_distinguisher', 'source_address'], name, value)


                    class Group(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.BgpAfs.BgpAf.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bgp-afs/bgp-af/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.BgpAfs.BgpAf.Group, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class NextHop(Entity):
                        """
                        Next hop address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "next-hop"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bgp-afs/bgp-af/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Source(Entity):
                        """
                        Source address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.BgpAfs.BgpAf.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bgp-afs/bgp-af/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.BgpAfs.BgpAf.Source, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class BidirDfStates(Entity):
                """
                Bidirectional PIM DF election state table
                
                .. attribute:: bidir_df_state
                
                	Bidirectional PIM DF Election Table Entry
                	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfStates.BidirDfState>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.BidirDfStates, self).__init__()

                    self.yang_name = "bidir-df-states"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"bidir-df-state" : ("bidir_df_state", Pim.Active.DefaultContext.BidirDfStates.BidirDfState)}

                    self.bidir_df_state = YList(self)
                    self._segment_path = lambda: "bidir-df-states"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.BidirDfStates, [], name, value)


                class BidirDfState(Entity):
                    """
                    Bidirectional PIM DF Election Table Entry
                    
                    .. attribute:: election_state
                    
                    	DF Election State
                    	**type**\:  str
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: our_metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: our_metric_preference
                    
                    	MetricPreference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr>`
                    
                    .. attribute:: time_nano_seconds
                    
                    	Timer expires (nseconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: time_seconds
                    
                    	Timer expires (seconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.BidirDfStates.BidirDfState, self).__init__()

                        self.yang_name = "bidir-df-state"
                        self.yang_parent_name = "bidir-df-states"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rp-address-xr" : ("rp_address_xr", Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr)}
                        self._child_list_classes = {}

                        self.election_state = YLeaf(YType.str, "election-state")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.our_metric = YLeaf(YType.uint32, "our-metric")

                        self.our_metric_preference = YLeaf(YType.uint32, "our-metric-preference")

                        self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.time_nano_seconds = YLeaf(YType.uint64, "time-nano-seconds")

                        self.time_seconds = YLeaf(YType.uint64, "time-seconds")

                        self.rp_address_xr = Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")
                        self._segment_path = lambda: "bidir-df-state"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bidir-df-states/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.BidirDfStates.BidirDfState, ['election_state', 'interface_name', 'our_metric', 'our_metric_preference', 'pim_interface_name', 'rp_address', 'time_nano_seconds', 'time_seconds'], name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-state"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bidir-df-states/bidir-df-state/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class BidirDfWinners(Entity):
                """
                Bidirectional PIM DF election winner table
                
                .. attribute:: bidir_df_winner
                
                	Bidirectional PIM DF election table entry
                	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.BidirDfWinners, self).__init__()

                    self.yang_name = "bidir-df-winners"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"bidir-df-winner" : ("bidir_df_winner", Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner)}

                    self.bidir_df_winner = YList(self)
                    self._segment_path = lambda: "bidir-df-winners"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.BidirDfWinners, [], name, value)


                class BidirDfWinner(Entity):
                    """
                    Bidirectional PIM DF election table entry
                    
                    .. attribute:: are_we_df
                    
                    	Are we DF
                    	**type**\:  bool
                    
                    .. attribute:: df_winner
                    
                    	DF Winner
                    	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner>`
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_preference
                    
                    	Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                    
                    .. attribute:: rp_lan
                    
                    	Is this the RP LAN
                    	**type**\:  bool
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner, self).__init__()

                        self.yang_name = "bidir-df-winner"
                        self.yang_parent_name = "bidir-df-winners"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"df-winner" : ("df_winner", Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner), "rp-address-xr" : ("rp_address_xr", Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr)}
                        self._child_list_classes = {}

                        self.are_we_df = YLeaf(YType.boolean, "are-we-df")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.metric = YLeaf(YType.uint32, "metric")

                        self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                        self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_lan = YLeaf(YType.boolean, "rp-lan")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.df_winner = Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                        self.df_winner.parent = self
                        self._children_name_map["df_winner"] = "df-winner"
                        self._children_yang_names.add("df-winner")

                        self.rp_address_xr = Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")
                        self._segment_path = lambda: "bidir-df-winner"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bidir-df-winners/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner, ['are_we_df', 'interface_name', 'metric', 'metric_preference', 'pim_interface_name', 'rp_address', 'rp_lan', 'uptime'], name, value)


                    class DfWinner(Entity):
                        """
                        DF Winner
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                            self.yang_name = "df-winner"
                            self.yang_parent_name = "bidir-df-winner"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "df-winner"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bidir-df-winners/bidir-df-winner/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-winner"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bidir-df-winners/bidir-df-winner/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Bsr(Entity):
                """
                PIM BSR information
                
                .. attribute:: bsr_elections
                
                	PIM BSR election state
                	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.BsrElections>`
                
                .. attribute:: candidate_rps
                
                	PIM candidate\-RP
                	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.CandidateRps>`
                
                .. attribute:: rp_caches
                
                	PIM BSR RP cache table
                	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Bsr, self).__init__()

                    self.yang_name = "bsr"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"bsr-elections" : ("bsr_elections", Pim.Active.DefaultContext.Bsr.BsrElections), "candidate-rps" : ("candidate_rps", Pim.Active.DefaultContext.Bsr.CandidateRps), "rp-caches" : ("rp_caches", Pim.Active.DefaultContext.Bsr.RpCaches)}
                    self._child_list_classes = {}

                    self.bsr_elections = Pim.Active.DefaultContext.Bsr.BsrElections()
                    self.bsr_elections.parent = self
                    self._children_name_map["bsr_elections"] = "bsr-elections"
                    self._children_yang_names.add("bsr-elections")

                    self.candidate_rps = Pim.Active.DefaultContext.Bsr.CandidateRps()
                    self.candidate_rps.parent = self
                    self._children_name_map["candidate_rps"] = "candidate-rps"
                    self._children_yang_names.add("candidate-rps")

                    self.rp_caches = Pim.Active.DefaultContext.Bsr.RpCaches()
                    self.rp_caches.parent = self
                    self._children_name_map["rp_caches"] = "rp-caches"
                    self._children_yang_names.add("rp-caches")
                    self._segment_path = lambda: "bsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()


                class BsrElections(Entity):
                    """
                    PIM BSR election state
                    
                    .. attribute:: bsr_election
                    
                    	PIM BSR information
                    	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Bsr.BsrElections, self).__init__()

                        self.yang_name = "bsr-elections"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"bsr-election" : ("bsr_election", Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection)}

                        self.bsr_election = YList(self)
                        self._segment_path = lambda: "bsr-elections"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bsr/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Bsr.BsrElections, [], name, value)


                    class BsrElection(Entity):
                        """
                        PIM BSR information
                        
                        .. attribute:: pim_scope  <key>
                        
                        	BSR information
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: bootstrap_timeout
                        
                        	Bootstrap Timeout
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_address
                        
                        	BSR address
                        	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress>`
                        
                        .. attribute:: bsr_election_state
                        
                        	BSR Election State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_mask_length
                        
                        	Hash Function Mask Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_priority
                        
                        	BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_scope
                        
                        	BSR Scope
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_up_time
                        
                        	BSR Uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_address
                        
                        	C\-BSR address
                        	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                        
                        .. attribute:: candidate_bsr_flag
                        
                        	BSR Candidate Config Flag
                        	**type**\:  bool
                        
                        .. attribute:: candidate_bsr_mask_length
                        
                        	C\-BSR Hash Func. Mask Len
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_priority
                        
                        	C\-BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_state
                        
                        	BSR Candidate State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection, self).__init__()

                            self.yang_name = "bsr-election"
                            self.yang_parent_name = "bsr-elections"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"bsr-address" : ("bsr_address", Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress), "candidate-bsr-address" : ("candidate_bsr_address", Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress)}
                            self._child_list_classes = {}

                            self.pim_scope = YLeaf(YType.int32, "pim-scope")

                            self.bootstrap_timeout = YLeaf(YType.uint16, "bootstrap-timeout")

                            self.bsr_election_state = YLeaf(YType.uint32, "bsr-election-state")

                            self.bsr_mask_length = YLeaf(YType.uint8, "bsr-mask-length")

                            self.bsr_priority = YLeaf(YType.uint8, "bsr-priority")

                            self.bsr_scope = YLeaf(YType.uint16, "bsr-scope")

                            self.bsr_up_time = YLeaf(YType.uint16, "bsr-up-time")

                            self.candidate_bsr_flag = YLeaf(YType.boolean, "candidate-bsr-flag")

                            self.candidate_bsr_mask_length = YLeaf(YType.uint8, "candidate-bsr-mask-length")

                            self.candidate_bsr_priority = YLeaf(YType.uint8, "candidate-bsr-priority")

                            self.candidate_bsr_state = YLeaf(YType.uint32, "candidate-bsr-state")

                            self.bsr_address = Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                            self.bsr_address.parent = self
                            self._children_name_map["bsr_address"] = "bsr-address"
                            self._children_yang_names.add("bsr-address")

                            self.candidate_bsr_address = Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                            self.candidate_bsr_address.parent = self
                            self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                            self._children_yang_names.add("candidate-bsr-address")
                            self._segment_path = lambda: "bsr-election" + "[pim-scope='" + self.pim_scope.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bsr/bsr-elections/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection, ['pim_scope', 'bootstrap_timeout', 'bsr_election_state', 'bsr_mask_length', 'bsr_priority', 'bsr_scope', 'bsr_up_time', 'candidate_bsr_flag', 'candidate_bsr_mask_length', 'candidate_bsr_priority', 'candidate_bsr_state'], name, value)


                        class BsrAddress(Entity):
                            """
                            BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                self.yang_name = "bsr-address"
                                self.yang_parent_name = "bsr-election"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "bsr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class CandidateBsrAddress(Entity):
                            """
                            C\-BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                self.yang_name = "candidate-bsr-address"
                                self.yang_parent_name = "bsr-election"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "candidate-bsr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class CandidateRps(Entity):
                    """
                    PIM candidate\-RP
                    
                    .. attribute:: candidate_rp
                    
                    	PIM BSR candidate RP information
                    	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Bsr.CandidateRps, self).__init__()

                        self.yang_name = "candidate-rps"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"candidate-rp" : ("candidate_rp", Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp)}

                        self.candidate_rp = YList(self)
                        self._segment_path = lambda: "candidate-rps"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bsr/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Bsr.CandidateRps, [], name, value)


                    class CandidateRp(Entity):
                        """
                        PIM BSR candidate RP information
                        
                        .. attribute:: rp_address  <key>
                        
                        	Candidate\-RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: acl_name
                        
                        	Group Access\-List Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: candidate_rp
                        
                        	Cand\-RP Address
                        	**type**\:   :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp>`
                        
                        .. attribute:: candidate_rp_advance_interval
                        
                        	Cand\-RP Adv Interval in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: candidate_rp_mode
                        
                        	Cand\-RP Mode
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: candidate_rp_scope
                        
                        	Cand\-RP Scope
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: candidate_rp_uptime
                        
                        	Cand\-RP uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_access
                        
                        	Group Ranges Using this Cand\-RP
                        	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                        
                        .. attribute:: crp_holdtime
                        
                        	Cand\-RP Holdtime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_priority
                        
                        	Cand\-RP Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__init__()

                            self.yang_name = "candidate-rp"
                            self.yang_parent_name = "candidate-rps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"candidate-rp" : ("candidate_rp", Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp)}
                            self._child_list_classes = {"crp-access" : ("crp_access", Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess)}

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.acl_name = YLeaf(YType.str, "acl-name")

                            self.candidate_rp_advance_interval = YLeaf(YType.uint16, "candidate-rp-advance-interval")

                            self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                            self.candidate_rp_scope = YLeaf(YType.int32, "candidate-rp-scope")

                            self.candidate_rp_uptime = YLeaf(YType.uint16, "candidate-rp-uptime")

                            self.crp_holdtime = YLeaf(YType.uint16, "crp-holdtime")

                            self.crp_priority = YLeaf(YType.uint8, "crp-priority")

                            self.candidate_rp = Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp()
                            self.candidate_rp.parent = self
                            self._children_name_map["candidate_rp"] = "candidate-rp"
                            self._children_yang_names.add("candidate-rp")

                            self.crp_access = YList(self)
                            self._segment_path = lambda: "candidate-rp" + "[rp-address='" + self.rp_address.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bsr/candidate-rps/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp, ['rp_address', 'acl_name', 'candidate_rp_advance_interval', 'candidate_rp_mode', 'candidate_rp_scope', 'candidate_rp_uptime', 'crp_holdtime', 'crp_priority'], name, value)


                        class CandidateRp(Entity):
                            """
                            Cand\-RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "candidate-rp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class CrpAccess(Entity):
                            """
                            Group Ranges Using this Cand\-RP
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                self.yang_name = "crp-access"
                                self.yang_parent_name = "candidate-rp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.acl_name = YLeaf(YType.str, "acl-name")

                                self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")
                                self._segment_path = lambda: "crp-access"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, ['acl_name', 'candidate_rp_mode'], name, value)


                class RpCaches(Entity):
                    """
                    PIM BSR RP cache table
                    
                    .. attribute:: rp_cache
                    
                    	PIM BSR RP cache
                    	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Bsr.RpCaches, self).__init__()

                        self.yang_name = "rp-caches"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"rp-cache" : ("rp_cache", Pim.Active.DefaultContext.Bsr.RpCaches.RpCache)}

                        self.rp_cache = YList(self)
                        self._segment_path = lambda: "rp-caches"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bsr/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Bsr.RpCaches, [], name, value)


                    class RpCache(Entity):
                        """
                        PIM BSR RP cache
                        
                        .. attribute:: group_prefix  <key>
                        
                        	Group prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: candidate_rp_group_count
                        
                        	C\-RP count for this Prefix
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: candidate_rp_list
                        
                        	C\-RP list for this prefix
                        	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList>`
                        
                        .. attribute:: group_prefix_length
                        
                        	Group Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_prefix_xr
                        
                        	Group Prefix
                        	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache, self).__init__()

                            self.yang_name = "rp-cache"
                            self.yang_parent_name = "rp-caches"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"candidate-rp-list" : ("candidate_rp_list", Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList), "group-prefix-xr" : ("group_prefix_xr", Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr)}
                            self._child_list_classes = {}

                            self.group_prefix = YLeaf(YType.str, "group-prefix")

                            self.candidate_rp_group_count = YLeaf(YType.uint32, "candidate-rp-group-count")

                            self.group_prefix_length = YLeaf(YType.uint32, "group-prefix-length")

                            self.candidate_rp_list = Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                            self.candidate_rp_list.parent = self
                            self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                            self._children_yang_names.add("candidate-rp-list")

                            self.group_prefix_xr = Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                            self.group_prefix_xr.parent = self
                            self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                            self._children_yang_names.add("group-prefix-xr")
                            self._segment_path = lambda: "rp-cache" + "[group-prefix='" + self.group_prefix.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bsr/rp-caches/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache, ['group_prefix', 'candidate_rp_group_count', 'group_prefix_length'], name, value)


                        class CandidateRpList(Entity):
                            """
                            C\-RP list for this prefix
                            
                            .. attribute:: pim_bsr_crp_bag
                            
                            	pim bsr crp bag
                            	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                self.yang_name = "candidate-rp-list"
                                self.yang_parent_name = "rp-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"pim-bsr-crp-bag" : ("pim_bsr_crp_bag", Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag)}

                                self.pim_bsr_crp_bag = YList(self)
                                self._segment_path = lambda: "candidate-rp-list"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, [], name, value)


                            class PimBsrCrpBag(Entity):
                                """
                                pim bsr crp bag
                                
                                .. attribute:: candidate_rp_address
                                
                                	C\-RP address
                                	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                
                                .. attribute:: candidate_rp_expires
                                
                                	C\-RP Expires
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_holdtime
                                
                                	C\-RP Holdtime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_priority
                                
                                	C\-RP Priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: candidate_rp_up_time
                                
                                	C\-RP Uptime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: protocol
                                
                                	PIM Protocol
                                	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                    self.yang_name = "pim-bsr-crp-bag"
                                    self.yang_parent_name = "candidate-rp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"candidate-rp-address" : ("candidate_rp_address", Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress)}
                                    self._child_list_classes = {}

                                    self.candidate_rp_expires = YLeaf(YType.uint16, "candidate-rp-expires")

                                    self.candidate_rp_holdtime = YLeaf(YType.uint16, "candidate-rp-holdtime")

                                    self.candidate_rp_priority = YLeaf(YType.uint8, "candidate-rp-priority")

                                    self.candidate_rp_up_time = YLeaf(YType.uint16, "candidate-rp-up-time")

                                    self.protocol = YLeaf(YType.enumeration, "protocol")

                                    self.candidate_rp_address = Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                    self.candidate_rp_address.parent = self
                                    self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                    self._children_yang_names.add("candidate-rp-address")
                                    self._segment_path = lambda: "pim-bsr-crp-bag"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, ['candidate_rp_expires', 'candidate_rp_holdtime', 'candidate_rp_priority', 'candidate_rp_up_time', 'protocol'], name, value)


                                class CandidateRpAddress(Entity):
                                    """
                                    C\-RP address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                        self.yang_name = "candidate-rp-address"
                                        self.yang_parent_name = "pim-bsr-crp-bag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "candidate-rp-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class GroupPrefixXr(Entity):
                            """
                            Group Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                self.yang_name = "group-prefix-xr"
                                self.yang_parent_name = "rp-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-prefix-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Context(Entity):
                """
                PIM context information
                
                .. attribute:: active_table_count
                
                	Number of active Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: allow_rp_configured
                
                	Allow RP Configured
                	**type**\:  bool
                
                .. attribute:: allow_rp_group_list
                
                	Allow RP Group\-List ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: allow_rp_rp_list
                
                	Allow RP RP\-list ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: anycast_rp_configured
                
                	Anycast\-RP config
                	**type**\:  bool
                
                .. attribute:: anycast_rp_policy_name
                
                	Anycast\-RP Policy Name
                	**type**\:  str
                
                .. attribute:: anycast_rp_range
                
                	Anycast\-RP Ranges
                	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.AnycastRpRange>`
                
                .. attribute:: bgp_auto_discovery_configured
                
                	BGP Auto\-Discovery configured
                	**type**\:  bool
                
                .. attribute:: bgp_auto_discovery_type
                
                	BGP Auto Discovery Type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_i_pmsi_added
                
                	BGP I\-PMSI Added
                	**type**\:  bool
                
                .. attribute:: bgp_remote_address
                
                	BGP remote interface address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: bgp_remote_interface
                
                	BGP remote interface handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: bgp_remote_interface_name
                
                	BGP remote interface name
                	**type**\:  str
                
                .. attribute:: bgp_remote_on
                
                	BGP remote interface status
                	**type**\:  bool
                
                .. attribute:: bgp_remote_state
                
                	BGP remote interface state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_source_active_announce
                
                	Send BGP Source\-Active Announcements
                	**type**\:  bool
                
                .. attribute:: export_route_target
                
                	Export Route Targets
                	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.ExportRouteTarget>`
                
                .. attribute:: gin_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: gin_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: gin_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: import_route_target
                
                	Import Route Targets
                	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.ImportRouteTarget>`
                
                .. attribute:: in_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: in_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: in_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_signaling_local_enabled
                
                	Inband signaling Local enabled
                	**type**\:  bool
                
                .. attribute:: in_band_signaling_remote_enabled
                
                	Inband signaling Remote enabled
                	**type**\:  bool
                
                .. attribute:: inter_autonomous_system_enabled
                
                	Inter\-AS Enabled
                	**type**\:  bool
                
                .. attribute:: ir_maximum_mdt_aggregation
                
                	IR MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_announce_interval
                
                	IR Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_switchover_interval
                
                	IR Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_interface
                
                	IRMDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: ir_mdt_mtu
                
                	IRMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_name
                
                	IR MDT Name
                	**type**\:  str
                
                .. attribute:: ir_mdt_rpf_identifier
                
                	IR RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_tail_label
                
                	IR Tail Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_active
                
                	Active
                	**type**\:  bool
                
                .. attribute:: is_active_ital
                
                	Active ITAL
                	**type**\:  bool
                
                .. attribute:: is_all_interface_disable_operation
                
                	PIM all interface disable operation
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_enabled
                
                	Auto RP Listen Enabled
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_sock_add
                
                	Auto RP listen sock add
                	**type**\:  bool
                
                .. attribute:: is_create_gin_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_in_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_ir_mdt_interface
                
                	Create IR MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mdt_interface
                
                	Create MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mldp_mdt_interface
                
                	Create MLDP MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_rsvp_te_mdt_interface
                
                	Create RSVP\-TE MDT interface
                	**type**\:  bool
                
                .. attribute:: is_default_granges
                
                	Default granges
                	**type**\:  bool
                
                .. attribute:: is_gin_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_in_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_ir_mdt_owner
                
                	IR MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_add_required
                
                	VRF LPTS filter required on Socket
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_added
                
                	VRF LPTS filter added on Socket
                	**type**\:  bool
                
                .. attribute:: is_m_host_publish_pending
                
                	Publish pending for MHost Default interface
                	**type**\:  bool
                
                .. attribute:: is_mdt_owner
                
                	MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mldp_mdt_owner
                
                	MLDP MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mrib_register
                
                	MRIB Register
                	**type**\:  bool
                
                .. attribute:: is_multicast_rib_registration
                
                	Mcast RIB Registration
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converge_received
                
                	PIM NSF RIB converge received
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converged
                
                	PIM NSF RIB converged
                	**type**\:  bool
                
                .. attribute:: is_redistribution_reset
                
                	Pending redist reset
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_add_required
                
                	VRF LPTS filter required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_added
                
                	VRF LPTS filter added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_add_required
                
                	VRF required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_added
                
                	VRF added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_enabled
                
                	PIM RIB multiplath enabled
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_interface_hash
                
                	PIM RIB multipath interface hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_hash
                
                	PIM RIB multipath source based hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_next_hop_hash
                
                	PIM RIB multipath source\-nexthop hash
                	**type**\:  bool
                
                .. attribute:: is_routing_enabled
                
                	Routing Enabled
                	**type**\:  bool
                
                .. attribute:: is_rsvp_te_mdt_owner
                
                	RSVP\-TE MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_socket_add_required
                
                	VRF required on Socket
                	**type**\:  bool
                
                .. attribute:: is_socket_added
                
                	VRF added on Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_add_required
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_added
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind
                
                	VRF bound on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind_required
                
                	VRF bind required on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_unicast_rib_registration
                
                	Ucast RIB Registration
                	**type**\:  bool
                
                .. attribute:: maximum_mdt_aggregation
                
                	MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_announce_interval
                
                	Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_switchover_interval
                
                	Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_default_group
                
                	MDT Default group
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_gre_remote_rpf_identifier
                
                	GRE\-MDT Remote RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_gre_rpf_identifier
                
                	GRE\-MDT RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_immediate_switch
                
                	MDT Immediate Switch
                	**type**\:  bool
                
                .. attribute:: mdt_interface
                
                	MDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: mdt_mtu
                
                	MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_neighbor_filter_name
                
                	MDT Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: mdt_partitioned_ir_control_identifier
                
                	Partitioned IR MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_mdt_control_identifier
                
                	Partitioned MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_source
                
                	MDT source
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_source_interface
                
                	MDT Source Interface Name
                	**type**\:  str
                
                .. attribute:: mhost_default_interface_config
                
                	Configured Mhost Defint
                	**type**\:  str
                
                .. attribute:: mhost_interface
                
                	MHost handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: mldp_auto_rp_announce_tree_added
                
                	MLDP Autorp Announce Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_auto_rp_discovery_tree_added
                
                	MLDP Autorp Discovery Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_bsr_control_tree_added
                
                	MLDP BSR Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_control_head_lsm_identifier
                
                	MLDP MVPN Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_local_label
                
                	Partitioned MDT Head local label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_lsm_identifier
                
                	MLDP Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_maximum_mdt_aggregation
                
                	MLDP MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_announce_interval
                
                	MLDP Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_switchover_interval
                
                	MLDP Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_interface
                
                	MLDP MDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: mldp_mdt_mtu
                
                	MLDP MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_name
                
                	MLDP MDT Name
                	**type**\:  str
                
                .. attribute:: mldp_mdt_remote_rpf_identifier
                
                	MLDP Remote RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_rpf_identifier
                
                	MLDP RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partioned_mp2m_ptree
                
                	MP2MP Partitioned MDT tree
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_head_lsm_identifier
                
                	Partitioned MDT Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_configured
                
                	MLDP Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_mdt_identifier
                
                	MLDP Partitioned MDT Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_head_lsm_identifier
                
                	MLDP Remote Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_partitioned_mdt_configured
                
                	MLDP Remote Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_root_address
                
                	MLDP Root addresses
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_root_count
                
                	MLDP Root count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: murib_id
                
                	MURIB ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_filter_name
                
                	Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: non_default_vrf_count_on_socket
                
                	Count of non\-default vrfs on raw socket
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: organization_unique_identifier
                
                	OUI for VPN\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mpte_li_drop
                
                	Route LI updates dropped for P2MP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: physical_interface_count
                
                	Enabled Physical Interface Count
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: redistribution_reset_count
                
                	Redist reset count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_default_group
                
                	Remote Default Group
                	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.RemoteDefaultGroup>`
                
                .. attribute:: remote_table_id
                
                	Remote Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_distinguisher
                
                	RD value
                	**type**\:  str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: rpf_default_table
                
                	RPF Default Table
                	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.RpfDefaultTable>`
                
                .. attribute:: rpf_id
                
                	RPF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_policy_name
                
                	RPF topology selection route\-policy name
                	**type**\:  str
                
                .. attribute:: rsvp_te_maximum_mdt_aggregation
                
                	RSVP\-TE MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_announce_interval
                
                	RSVP\-TE Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_switchover_interval
                
                	RSVP\-TE Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_interface
                
                	RSVP\-TEMDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: rsvp_te_mdt_mtu
                
                	RSVP\-TEMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_name
                
                	RSVP\-TE MDT Name
                	**type**\:  str
                
                .. attribute:: rsvp_te_mdt_rpf_identifier
                
                	RSVP\-TE RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_static_p2mp_count
                
                	Number of Static P2MP\-TE MDT
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	PIM is using MuRIB
                	**type**\:  bool
                
                .. attribute:: sg_expiry_time
                
                	S,G Expiry Time Configured, in seconds
                	**type**\:  int
                
                	**range:** 0..65535
                
                	**units**\: second
                
                .. attribute:: sg_expiry_timer_configured
                
                	S,G Expiry Timer Configured
                	**type**\:  bool
                
                .. attribute:: sg_expiry_timer_sg_list
                
                	S,G expiry timer ACL name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: stale_rd_present
                
                	RD is stale
                	**type**\:  bool
                
                .. attribute:: suppress_pim_data_mdt_tlv
                
                	Suppress PIM Data\-MDT TLV Announcements
                	**type**\:  bool
                
                .. attribute:: suppress_shared_tree_join
                
                	Suppress Shared\-Tree Joins
                	**type**\:  bool
                
                .. attribute:: table_count
                
                	Number of configured Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_id
                
                	Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: umh
                
                	Join UMH Core\-Tree
                	**type**\:  bool
                
                .. attribute:: valid_rd_present
                
                	RD is valid
                	**type**\:  bool
                
                .. attribute:: virtual_interface_count
                
                	Enabled Virtual Interface Count
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: virtual_mlc_interface_name
                
                	Virtual master line card Interface
                	**type**\:  str
                
                .. attribute:: vpn_index
                
                	VPN Index
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf_id
                
                	VRF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Context, self).__init__()

                    self.yang_name = "context"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"remote-default-group" : ("remote_default_group", Pim.Active.DefaultContext.Context.RemoteDefaultGroup), "rpf-default-table" : ("rpf_default_table", Pim.Active.DefaultContext.Context.RpfDefaultTable)}
                    self._child_list_classes = {"anycast-rp-range" : ("anycast_rp_range", Pim.Active.DefaultContext.Context.AnycastRpRange), "export-route-target" : ("export_route_target", Pim.Active.DefaultContext.Context.ExportRouteTarget), "import-route-target" : ("import_route_target", Pim.Active.DefaultContext.Context.ImportRouteTarget)}

                    self.active_table_count = YLeaf(YType.uint32, "active-table-count")

                    self.allow_rp_configured = YLeaf(YType.boolean, "allow-rp-configured")

                    self.allow_rp_group_list = YLeaf(YType.str, "allow-rp-group-list")

                    self.allow_rp_rp_list = YLeaf(YType.str, "allow-rp-rp-list")

                    self.anycast_rp_configured = YLeaf(YType.boolean, "anycast-rp-configured")

                    self.anycast_rp_policy_name = YLeaf(YType.str, "anycast-rp-policy-name")

                    self.bgp_auto_discovery_configured = YLeaf(YType.boolean, "bgp-auto-discovery-configured")

                    self.bgp_auto_discovery_type = YLeaf(YType.uint32, "bgp-auto-discovery-type")

                    self.bgp_i_pmsi_added = YLeaf(YType.boolean, "bgp-i-pmsi-added")

                    self.bgp_remote_address = YLeaf(YType.str, "bgp-remote-address")

                    self.bgp_remote_interface = YLeaf(YType.str, "bgp-remote-interface")

                    self.bgp_remote_interface_name = YLeaf(YType.str, "bgp-remote-interface-name")

                    self.bgp_remote_on = YLeaf(YType.boolean, "bgp-remote-on")

                    self.bgp_remote_state = YLeaf(YType.uint32, "bgp-remote-state")

                    self.bgp_source_active_announce = YLeaf(YType.boolean, "bgp-source-active-announce")

                    self.gin_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-announce-interval")

                    self.gin_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-switchover-interval")

                    self.gin_b_and_mdt_interface = YLeaf(YType.str, "gin-b-and-mdt-interface")

                    self.gin_b_and_mdt_mtu = YLeaf(YType.uint32, "gin-b-and-mdt-mtu")

                    self.gin_b_and_mdt_name = YLeaf(YType.str, "gin-b-and-mdt-name")

                    self.gin_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "gin-b-and-mdt-rpf-identifier")

                    self.gin_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "gin-band-maximum-mdt-aggregation")

                    self.in_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-announce-interval")

                    self.in_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-switchover-interval")

                    self.in_b_and_mdt_interface = YLeaf(YType.str, "in-b-and-mdt-interface")

                    self.in_b_and_mdt_mtu = YLeaf(YType.uint32, "in-b-and-mdt-mtu")

                    self.in_b_and_mdt_name = YLeaf(YType.str, "in-b-and-mdt-name")

                    self.in_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "in-b-and-mdt-rpf-identifier")

                    self.in_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "in-band-maximum-mdt-aggregation")

                    self.in_band_signaling_local_enabled = YLeaf(YType.boolean, "in-band-signaling-local-enabled")

                    self.in_band_signaling_remote_enabled = YLeaf(YType.boolean, "in-band-signaling-remote-enabled")

                    self.inter_autonomous_system_enabled = YLeaf(YType.boolean, "inter-autonomous-system-enabled")

                    self.ir_maximum_mdt_aggregation = YLeaf(YType.uint32, "ir-maximum-mdt-aggregation")

                    self.ir_mdt_data_announce_interval = YLeaf(YType.uint32, "ir-mdt-data-announce-interval")

                    self.ir_mdt_data_switchover_interval = YLeaf(YType.uint32, "ir-mdt-data-switchover-interval")

                    self.ir_mdt_interface = YLeaf(YType.str, "ir-mdt-interface")

                    self.ir_mdt_mtu = YLeaf(YType.uint32, "ir-mdt-mtu")

                    self.ir_mdt_name = YLeaf(YType.str, "ir-mdt-name")

                    self.ir_mdt_rpf_identifier = YLeaf(YType.uint32, "ir-mdt-rpf-identifier")

                    self.ir_mdt_tail_label = YLeaf(YType.uint32, "ir-mdt-tail-label")

                    self.is_active = YLeaf(YType.boolean, "is-active")

                    self.is_active_ital = YLeaf(YType.boolean, "is-active-ital")

                    self.is_all_interface_disable_operation = YLeaf(YType.boolean, "is-all-interface-disable-operation")

                    self.is_auto_rp_listen_enabled = YLeaf(YType.boolean, "is-auto-rp-listen-enabled")

                    self.is_auto_rp_listen_sock_add = YLeaf(YType.boolean, "is-auto-rp-listen-sock-add")

                    self.is_create_gin_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-gin-b-and-mdt-interface")

                    self.is_create_in_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-in-b-and-mdt-interface")

                    self.is_create_ir_mdt_interface = YLeaf(YType.boolean, "is-create-ir-mdt-interface")

                    self.is_create_mdt_interface = YLeaf(YType.boolean, "is-create-mdt-interface")

                    self.is_create_mldp_mdt_interface = YLeaf(YType.boolean, "is-create-mldp-mdt-interface")

                    self.is_create_rsvp_te_mdt_interface = YLeaf(YType.boolean, "is-create-rsvp-te-mdt-interface")

                    self.is_default_granges = YLeaf(YType.boolean, "is-default-granges")

                    self.is_gin_b_and_mdt_owner = YLeaf(YType.boolean, "is-gin-b-and-mdt-owner")

                    self.is_in_b_and_mdt_owner = YLeaf(YType.boolean, "is-in-b-and-mdt-owner")

                    self.is_ir_mdt_owner = YLeaf(YType.boolean, "is-ir-mdt-owner")

                    self.is_lpts_socket_add_required = YLeaf(YType.boolean, "is-lpts-socket-add-required")

                    self.is_lpts_socket_added = YLeaf(YType.boolean, "is-lpts-socket-added")

                    self.is_m_host_publish_pending = YLeaf(YType.boolean, "is-m-host-publish-pending")

                    self.is_mdt_owner = YLeaf(YType.boolean, "is-mdt-owner")

                    self.is_mldp_mdt_owner = YLeaf(YType.boolean, "is-mldp-mdt-owner")

                    self.is_mrib_register = YLeaf(YType.boolean, "is-mrib-register")

                    self.is_multicast_rib_registration = YLeaf(YType.boolean, "is-multicast-rib-registration")

                    self.is_pim_nsf_rib_converge_received = YLeaf(YType.boolean, "is-pim-nsf-rib-converge-received")

                    self.is_pim_nsf_rib_converged = YLeaf(YType.boolean, "is-pim-nsf-rib-converged")

                    self.is_redistribution_reset = YLeaf(YType.boolean, "is-redistribution-reset")

                    self.is_register_injection_lpts_socket_add_required = YLeaf(YType.boolean, "is-register-injection-lpts-socket-add-required")

                    self.is_register_injection_lpts_socket_added = YLeaf(YType.boolean, "is-register-injection-lpts-socket-added")

                    self.is_register_injection_socket_add_required = YLeaf(YType.boolean, "is-register-injection-socket-add-required")

                    self.is_register_injection_socket_added = YLeaf(YType.boolean, "is-register-injection-socket-added")

                    self.is_rib_multipath_enabled = YLeaf(YType.boolean, "is-rib-multipath-enabled")

                    self.is_rib_multipath_interface_hash = YLeaf(YType.boolean, "is-rib-multipath-interface-hash")

                    self.is_rib_multipath_source_hash = YLeaf(YType.boolean, "is-rib-multipath-source-hash")

                    self.is_rib_multipath_source_next_hop_hash = YLeaf(YType.boolean, "is-rib-multipath-source-next-hop-hash")

                    self.is_routing_enabled = YLeaf(YType.boolean, "is-routing-enabled")

                    self.is_rsvp_te_mdt_owner = YLeaf(YType.boolean, "is-rsvp-te-mdt-owner")

                    self.is_socket_add_required = YLeaf(YType.boolean, "is-socket-add-required")

                    self.is_socket_added = YLeaf(YType.boolean, "is-socket-added")

                    self.is_udp_socket_add_required = YLeaf(YType.boolean, "is-udp-socket-add-required")

                    self.is_udp_socket_added = YLeaf(YType.boolean, "is-udp-socket-added")

                    self.is_udp_socket_bind = YLeaf(YType.boolean, "is-udp-socket-bind")

                    self.is_udp_socket_bind_required = YLeaf(YType.boolean, "is-udp-socket-bind-required")

                    self.is_unicast_rib_registration = YLeaf(YType.boolean, "is-unicast-rib-registration")

                    self.maximum_mdt_aggregation = YLeaf(YType.uint32, "maximum-mdt-aggregation")

                    self.mdt_data_announce_interval = YLeaf(YType.uint32, "mdt-data-announce-interval")

                    self.mdt_data_switchover_interval = YLeaf(YType.uint32, "mdt-data-switchover-interval")

                    self.mdt_default_group = YLeaf(YType.str, "mdt-default-group")

                    self.mdt_gre_remote_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-remote-rpf-identifier")

                    self.mdt_gre_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-rpf-identifier")

                    self.mdt_immediate_switch = YLeaf(YType.boolean, "mdt-immediate-switch")

                    self.mdt_interface = YLeaf(YType.str, "mdt-interface")

                    self.mdt_mtu = YLeaf(YType.uint32, "mdt-mtu")

                    self.mdt_neighbor_filter_name = YLeaf(YType.str, "mdt-neighbor-filter-name")

                    self.mdt_partitioned_ir_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-ir-control-identifier")

                    self.mdt_partitioned_mdt_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-mdt-control-identifier")

                    self.mdt_source = YLeaf(YType.str, "mdt-source")

                    self.mdt_source_interface = YLeaf(YType.str, "mdt-source-interface")

                    self.mhost_default_interface_config = YLeaf(YType.str, "mhost-default-interface-config")

                    self.mhost_interface = YLeaf(YType.str, "mhost-interface")

                    self.mldp_auto_rp_announce_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-announce-tree-added")

                    self.mldp_auto_rp_discovery_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-discovery-tree-added")

                    self.mldp_bsr_control_tree_added = YLeaf(YType.boolean, "mldp-bsr-control-tree-added")

                    self.mldp_control_head_lsm_identifier = YLeaf(YType.uint32, "mldp-control-head-lsm-identifier")

                    self.mldp_head_local_label = YLeaf(YType.uint32, "mldp-head-local-label")

                    self.mldp_head_lsm_identifier = YLeaf(YType.uint32, "mldp-head-lsm-identifier")

                    self.mldp_maximum_mdt_aggregation = YLeaf(YType.uint32, "mldp-maximum-mdt-aggregation")

                    self.mldp_mdt_data_announce_interval = YLeaf(YType.uint32, "mldp-mdt-data-announce-interval")

                    self.mldp_mdt_data_switchover_interval = YLeaf(YType.uint32, "mldp-mdt-data-switchover-interval")

                    self.mldp_mdt_interface = YLeaf(YType.str, "mldp-mdt-interface")

                    self.mldp_mdt_mtu = YLeaf(YType.uint32, "mldp-mdt-mtu")

                    self.mldp_mdt_name = YLeaf(YType.str, "mldp-mdt-name")

                    self.mldp_mdt_remote_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-remote-rpf-identifier")

                    self.mldp_mdt_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-rpf-identifier")

                    self.mldp_partioned_mp2m_ptree = YLeaf(YType.boolean, "mldp-partioned-mp2m-ptree")

                    self.mldp_partitioned_head_lsm_identifier = YLeaf(YType.uint32, "mldp-partitioned-head-lsm-identifier")

                    self.mldp_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-partitioned-mdt-configured")

                    self.mldp_partitioned_mdt_identifier = YLeaf(YType.uint32, "mldp-partitioned-mdt-identifier")

                    self.mldp_remote_head_lsm_identifier = YLeaf(YType.uint32, "mldp-remote-head-lsm-identifier")

                    self.mldp_remote_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-remote-partitioned-mdt-configured")

                    self.mldp_root_address = YLeafList(YType.uint32, "mldp-root-address")

                    self.mldp_root_count = YLeaf(YType.uint32, "mldp-root-count")

                    self.murib_id = YLeaf(YType.uint32, "murib-id")

                    self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                    self.non_default_vrf_count_on_socket = YLeaf(YType.uint32, "non-default-vrf-count-on-socket")

                    self.organization_unique_identifier = YLeaf(YType.uint32, "organization-unique-identifier")

                    self.p2mpte_li_drop = YLeaf(YType.uint32, "p2mpte-li-drop")

                    self.physical_interface_count = YLeaf(YType.uint64, "physical-interface-count")

                    self.redistribution_reset_count = YLeaf(YType.uint32, "redistribution-reset-count")

                    self.remote_table_id = YLeaf(YType.uint32, "remote-table-id")

                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                    self.rpf_id = YLeaf(YType.uint32, "rpf-id")

                    self.rpf_policy_name = YLeaf(YType.str, "rpf-policy-name")

                    self.rsvp_te_maximum_mdt_aggregation = YLeaf(YType.uint32, "rsvp-te-maximum-mdt-aggregation")

                    self.rsvp_te_mdt_data_announce_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-announce-interval")

                    self.rsvp_te_mdt_data_switchover_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-switchover-interval")

                    self.rsvp_te_mdt_interface = YLeaf(YType.str, "rsvp-te-mdt-interface")

                    self.rsvp_te_mdt_mtu = YLeaf(YType.uint32, "rsvp-te-mdt-mtu")

                    self.rsvp_te_mdt_name = YLeaf(YType.str, "rsvp-te-mdt-name")

                    self.rsvp_te_mdt_rpf_identifier = YLeaf(YType.uint32, "rsvp-te-mdt-rpf-identifier")

                    self.rsvp_te_mdt_static_p2mp_count = YLeaf(YType.uint32, "rsvp-te-mdt-static-p2mp-count")

                    self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                    self.sg_expiry_time = YLeaf(YType.uint16, "sg-expiry-time")

                    self.sg_expiry_timer_configured = YLeaf(YType.boolean, "sg-expiry-timer-configured")

                    self.sg_expiry_timer_sg_list = YLeaf(YType.str, "sg-expiry-timer-sg-list")

                    self.stale_rd_present = YLeaf(YType.boolean, "stale-rd-present")

                    self.suppress_pim_data_mdt_tlv = YLeaf(YType.boolean, "suppress-pim-data-mdt-tlv")

                    self.suppress_shared_tree_join = YLeaf(YType.boolean, "suppress-shared-tree-join")

                    self.table_count = YLeaf(YType.uint32, "table-count")

                    self.table_id = YLeaf(YType.uint32, "table-id")

                    self.umh = YLeaf(YType.boolean, "umh")

                    self.valid_rd_present = YLeaf(YType.boolean, "valid-rd-present")

                    self.virtual_interface_count = YLeaf(YType.uint64, "virtual-interface-count")

                    self.virtual_mlc_interface_name = YLeaf(YType.str, "virtual-mlc-interface-name")

                    self.vpn_index = YLeaf(YType.uint32, "vpn-index")

                    self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                    self.remote_default_group = Pim.Active.DefaultContext.Context.RemoteDefaultGroup()
                    self.remote_default_group.parent = self
                    self._children_name_map["remote_default_group"] = "remote-default-group"
                    self._children_yang_names.add("remote-default-group")

                    self.rpf_default_table = Pim.Active.DefaultContext.Context.RpfDefaultTable()
                    self.rpf_default_table.parent = self
                    self._children_name_map["rpf_default_table"] = "rpf-default-table"
                    self._children_yang_names.add("rpf-default-table")

                    self.anycast_rp_range = YList(self)
                    self.export_route_target = YList(self)
                    self.import_route_target = YList(self)
                    self._segment_path = lambda: "context"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.Context, ['active_table_count', 'allow_rp_configured', 'allow_rp_group_list', 'allow_rp_rp_list', 'anycast_rp_configured', 'anycast_rp_policy_name', 'bgp_auto_discovery_configured', 'bgp_auto_discovery_type', 'bgp_i_pmsi_added', 'bgp_remote_address', 'bgp_remote_interface', 'bgp_remote_interface_name', 'bgp_remote_on', 'bgp_remote_state', 'bgp_source_active_announce', 'gin_b_and_mdt_data_announce_interval', 'gin_b_and_mdt_data_switchover_interval', 'gin_b_and_mdt_interface', 'gin_b_and_mdt_mtu', 'gin_b_and_mdt_name', 'gin_b_and_mdt_rpf_identifier', 'gin_band_maximum_mdt_aggregation', 'in_b_and_mdt_data_announce_interval', 'in_b_and_mdt_data_switchover_interval', 'in_b_and_mdt_interface', 'in_b_and_mdt_mtu', 'in_b_and_mdt_name', 'in_b_and_mdt_rpf_identifier', 'in_band_maximum_mdt_aggregation', 'in_band_signaling_local_enabled', 'in_band_signaling_remote_enabled', 'inter_autonomous_system_enabled', 'ir_maximum_mdt_aggregation', 'ir_mdt_data_announce_interval', 'ir_mdt_data_switchover_interval', 'ir_mdt_interface', 'ir_mdt_mtu', 'ir_mdt_name', 'ir_mdt_rpf_identifier', 'ir_mdt_tail_label', 'is_active', 'is_active_ital', 'is_all_interface_disable_operation', 'is_auto_rp_listen_enabled', 'is_auto_rp_listen_sock_add', 'is_create_gin_b_and_mdt_interface', 'is_create_in_b_and_mdt_interface', 'is_create_ir_mdt_interface', 'is_create_mdt_interface', 'is_create_mldp_mdt_interface', 'is_create_rsvp_te_mdt_interface', 'is_default_granges', 'is_gin_b_and_mdt_owner', 'is_in_b_and_mdt_owner', 'is_ir_mdt_owner', 'is_lpts_socket_add_required', 'is_lpts_socket_added', 'is_m_host_publish_pending', 'is_mdt_owner', 'is_mldp_mdt_owner', 'is_mrib_register', 'is_multicast_rib_registration', 'is_pim_nsf_rib_converge_received', 'is_pim_nsf_rib_converged', 'is_redistribution_reset', 'is_register_injection_lpts_socket_add_required', 'is_register_injection_lpts_socket_added', 'is_register_injection_socket_add_required', 'is_register_injection_socket_added', 'is_rib_multipath_enabled', 'is_rib_multipath_interface_hash', 'is_rib_multipath_source_hash', 'is_rib_multipath_source_next_hop_hash', 'is_routing_enabled', 'is_rsvp_te_mdt_owner', 'is_socket_add_required', 'is_socket_added', 'is_udp_socket_add_required', 'is_udp_socket_added', 'is_udp_socket_bind', 'is_udp_socket_bind_required', 'is_unicast_rib_registration', 'maximum_mdt_aggregation', 'mdt_data_announce_interval', 'mdt_data_switchover_interval', 'mdt_default_group', 'mdt_gre_remote_rpf_identifier', 'mdt_gre_rpf_identifier', 'mdt_immediate_switch', 'mdt_interface', 'mdt_mtu', 'mdt_neighbor_filter_name', 'mdt_partitioned_ir_control_identifier', 'mdt_partitioned_mdt_control_identifier', 'mdt_source', 'mdt_source_interface', 'mhost_default_interface_config', 'mhost_interface', 'mldp_auto_rp_announce_tree_added', 'mldp_auto_rp_discovery_tree_added', 'mldp_bsr_control_tree_added', 'mldp_control_head_lsm_identifier', 'mldp_head_local_label', 'mldp_head_lsm_identifier', 'mldp_maximum_mdt_aggregation', 'mldp_mdt_data_announce_interval', 'mldp_mdt_data_switchover_interval', 'mldp_mdt_interface', 'mldp_mdt_mtu', 'mldp_mdt_name', 'mldp_mdt_remote_rpf_identifier', 'mldp_mdt_rpf_identifier', 'mldp_partioned_mp2m_ptree', 'mldp_partitioned_head_lsm_identifier', 'mldp_partitioned_mdt_configured', 'mldp_partitioned_mdt_identifier', 'mldp_remote_head_lsm_identifier', 'mldp_remote_partitioned_mdt_configured', 'mldp_root_address', 'mldp_root_count', 'murib_id', 'neighbor_filter_name', 'non_default_vrf_count_on_socket', 'organization_unique_identifier', 'p2mpte_li_drop', 'physical_interface_count', 'redistribution_reset_count', 'remote_table_id', 'route_distinguisher', 'rpf_id', 'rpf_policy_name', 'rsvp_te_maximum_mdt_aggregation', 'rsvp_te_mdt_data_announce_interval', 'rsvp_te_mdt_data_switchover_interval', 'rsvp_te_mdt_interface', 'rsvp_te_mdt_mtu', 'rsvp_te_mdt_name', 'rsvp_te_mdt_rpf_identifier', 'rsvp_te_mdt_static_p2mp_count', 'rump_enabled', 'sg_expiry_time', 'sg_expiry_timer_configured', 'sg_expiry_timer_sg_list', 'stale_rd_present', 'suppress_pim_data_mdt_tlv', 'suppress_shared_tree_join', 'table_count', 'table_id', 'umh', 'valid_rd_present', 'virtual_interface_count', 'virtual_mlc_interface_name', 'vpn_index', 'vrf_id'], name, value)


                class AnycastRpRange(Entity):
                    """
                    Anycast\-RP Ranges
                    
                    .. attribute:: ancast_rp_marked
                    
                    	Anycast\-RP Range marked
                    	**type**\:  bool
                    
                    .. attribute:: prefix
                    
                    	Anycast\-RP Range Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Anycast\-RP Range Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Context.AnycastRpRange, self).__init__()

                        self.yang_name = "anycast-rp-range"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"prefix" : ("prefix", Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix)}
                        self._child_list_classes = {}

                        self.ancast_rp_marked = YLeaf(YType.boolean, "ancast-rp-marked")

                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                        self.prefix = Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._children_yang_names.add("prefix")
                        self._segment_path = lambda: "anycast-rp-range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Context.AnycastRpRange, ['ancast_rp_marked', 'prefix_length'], name, value)


                    class Prefix(Entity):
                        """
                        Anycast\-RP Range Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "anycast-rp-range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "prefix"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/context/anycast-rp-range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class ExportRouteTarget(Entity):
                    """
                    Export Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Context.ExportRouteTarget, self).__init__()

                        self.yang_name = "export-route-target"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                        self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                        self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                        self.configured = YLeaf(YType.boolean, "configured")

                        self.route_target = YLeaf(YType.str, "route-target")

                        self.segment_border = YLeaf(YType.boolean, "segment-border")

                        self.update_pending = YLeaf(YType.boolean, "update-pending")
                        self._segment_path = lambda: "export-route-target"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Context.ExportRouteTarget, ['anycast_rp', 'anycast_rp_marked', 'bgp_auto_discovery', 'configured', 'route_target', 'segment_border', 'update_pending'], name, value)


                class ImportRouteTarget(Entity):
                    """
                    Import Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Context.ImportRouteTarget, self).__init__()

                        self.yang_name = "import-route-target"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                        self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                        self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                        self.configured = YLeaf(YType.boolean, "configured")

                        self.route_target = YLeaf(YType.str, "route-target")

                        self.segment_border = YLeaf(YType.boolean, "segment-border")

                        self.update_pending = YLeaf(YType.boolean, "update-pending")
                        self._segment_path = lambda: "import-route-target"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Context.ImportRouteTarget, ['anycast_rp', 'anycast_rp_marked', 'bgp_auto_discovery', 'configured', 'route_target', 'segment_border', 'update_pending'], name, value)


                class RemoteDefaultGroup(Entity):
                    """
                    Remote Default Group
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Context.RemoteDefaultGroup, self).__init__()

                        self.yang_name = "remote-default-group"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.af_name = YLeaf(YType.enumeration, "af-name")

                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                        self._segment_path = lambda: "remote-default-group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Context.RemoteDefaultGroup, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class RpfDefaultTable(Entity):
                    """
                    RPF Default Table
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Context.RpfDefaultTable, self).__init__()

                        self.yang_name = "rpf-default-table"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.uint32, "afi")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                        self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.safi = YLeaf(YType.uint32, "safi")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.table_name = YLeaf(YType.str, "table-name")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")
                        self._segment_path = lambda: "rpf-default-table"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Context.RpfDefaultTable, ['afi', 'is_active', 'is_ital_registration_done', 'is_rib_convergence', 'is_rib_convergence_received', 'is_rib_registration_done', 'rpf_registrations', 'safi', 'table_id', 'table_name', 'vrf_id'], name, value)


            class GlobalInterfaces(Entity):
                """
                PIM global interface table
                
                .. attribute:: global_interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`GlobalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.GlobalInterfaces, self).__init__()

                    self.yang_name = "global-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"global-interface" : ("global_interface", Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface)}

                    self.global_interface = YList(self)
                    self._segment_path = lambda: "global-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.GlobalInterfaces, [], name, value)


                class GlobalInterface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface, self).__init__()

                        self.yang_name = "global-interface"
                        self.yang_parent_name = "global-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"dr-address" : ("dr_address", Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress)}
                        self._child_list_classes = {"interface-address" : ("interface_address", Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "global-interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/global-interfaces/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "global-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "dr-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "global-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "interface-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Gre(Entity):
                """
                GRE information
                
                .. attribute:: gre_hashes
                
                	GRE hash
                	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreHashes>`
                
                .. attribute:: gre_next_hops
                
                	GRE destination neighbor table
                	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Gre, self).__init__()

                    self.yang_name = "gre"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"gre-hashes" : ("gre_hashes", Pim.Active.DefaultContext.Gre.GreHashes), "gre-next-hops" : ("gre_next_hops", Pim.Active.DefaultContext.Gre.GreNextHops)}
                    self._child_list_classes = {}

                    self.gre_hashes = Pim.Active.DefaultContext.Gre.GreHashes()
                    self.gre_hashes.parent = self
                    self._children_name_map["gre_hashes"] = "gre-hashes"
                    self._children_yang_names.add("gre-hashes")

                    self.gre_next_hops = Pim.Active.DefaultContext.Gre.GreNextHops()
                    self.gre_next_hops.parent = self
                    self._children_name_map["gre_next_hops"] = "gre-next-hops"
                    self._children_yang_names.add("gre-next-hops")
                    self._segment_path = lambda: "gre"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()


                class GreHashes(Entity):
                    """
                    GRE hash
                    
                    .. attribute:: gre_hash
                    
                    	PIM GRE Hashed Underlying Interface
                    	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreHashes.GreHash>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Gre.GreHashes, self).__init__()

                        self.yang_name = "gre-hashes"
                        self.yang_parent_name = "gre"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"gre-hash" : ("gre_hash", Pim.Active.DefaultContext.Gre.GreHashes.GreHash)}

                        self.gre_hash = YList(self)
                        self._segment_path = lambda: "gre-hashes"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/gre/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Gre.GreHashes, [], name, value)


                    class GreHash(Entity):
                        """
                        PIM GRE Hashed Underlying Interface
                        
                        .. attribute:: source_address  <key>
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: destination_address  <key>
                        
                        	Destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: ifname  <key>
                        
                        	GRE Tunnel Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: next_hop_interface
                        
                        	Next hop neighbor interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Gre.GreHashes.GreHash, self).__init__()

                            self.yang_name = "gre-hash"
                            self.yang_parent_name = "gre-hashes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.ifname = YLeaf(YType.str, "ifname")

                            self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")
                            self._segment_path = lambda: "gre-hash" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[ifname='" + self.ifname.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/gre/gre-hashes/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Gre.GreHashes.GreHash, ['source_address', 'destination_address', 'ifname', 'next_hop_interface'], name, value)


                class GreNextHops(Entity):
                    """
                    GRE destination neighbor table
                    
                    .. attribute:: gre_next_hop
                    
                    	PIM GRE address next\-hop information
                    	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Gre.GreNextHops, self).__init__()

                        self.yang_name = "gre-next-hops"
                        self.yang_parent_name = "gre"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"gre-next-hop" : ("gre_next_hop", Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop)}

                        self.gre_next_hop = YList(self)
                        self._segment_path = lambda: "gre-next-hops"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/gre/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Gre.GreNextHops, [], name, value)


                    class GreNextHop(Entity):
                        """
                        PIM GRE address next\-hop information
                        
                        .. attribute:: destination_address  <key>
                        
                        	GRE destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: gre_path
                        
                        	GRE Paths list
                        	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath>`
                        
                        .. attribute:: is_connected
                        
                        	Are we connected ?
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: registered_address
                        
                        	Address registered
                        	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop, self).__init__()

                            self.yang_name = "gre-next-hop"
                            self.yang_parent_name = "gre-next-hops"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"registered-address" : ("registered_address", Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress)}
                            self._child_list_classes = {"gre-path" : ("gre_path", Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath)}

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.is_connected = YLeaf(YType.uint8, "is-connected")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                            self.registered_address = Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                            self.registered_address.parent = self
                            self._children_name_map["registered_address"] = "registered-address"
                            self._children_yang_names.add("registered-address")

                            self.gre_path = YList(self)
                            self._segment_path = lambda: "gre-next-hop" + "[destination-address='" + self.destination_address.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/gre/gre-next-hops/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop, ['destination_address', 'is_connected', 'metric', 'metric_preference'], name, value)


                        class GrePath(Entity):
                            """
                            GRE Paths list
                            
                            .. attribute:: extranet_vrf_name
                            
                            	Extranet VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: gre_interface_name
                            
                            	GRE Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: gre_neighbor
                            
                            	GRE neighbor
                            	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                            
                            .. attribute:: gre_next_hop
                            
                            	GRE nexthop
                            	**type**\:   :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop>`
                            
                            .. attribute:: is_connector_attribute_present
                            
                            	Connector attribute present
                            	**type**\:  bool
                            
                            .. attribute:: is_gre_interface_disabled
                            
                            	Is the gre interface disabled ?
                            	**type**\:  bool
                            
                            .. attribute:: is_via_lsm
                            
                            	Via LSM
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                self.yang_name = "gre-path"
                                self.yang_parent_name = "gre-next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"gre-neighbor" : ("gre_neighbor", Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor), "gre-next-hop" : ("gre_next_hop", Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop)}
                                self._child_list_classes = {}

                                self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                self.gre_interface_name = YLeaf(YType.str, "gre-interface-name")

                                self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                self.is_gre_interface_disabled = YLeaf(YType.boolean, "is-gre-interface-disabled")

                                self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                self.gre_neighbor = Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                self.gre_neighbor.parent = self
                                self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                self._children_yang_names.add("gre-neighbor")

                                self.gre_next_hop = Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                self.gre_next_hop.parent = self
                                self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                self._children_yang_names.add("gre-next-hop")
                                self._segment_path = lambda: "gre-path"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, ['extranet_vrf_name', 'gre_interface_name', 'is_connector_attribute_present', 'is_gre_interface_disabled', 'is_via_lsm'], name, value)


                            class GreNeighbor(Entity):
                                """
                                GRE neighbor
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                    self.yang_name = "gre-neighbor"
                                    self.yang_parent_name = "gre-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "gre-neighbor"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class GreNextHop(Entity):
                                """
                                GRE nexthop
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__init__()

                                    self.yang_name = "gre-next-hop"
                                    self.yang_parent_name = "gre-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "gre-next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RegisteredAddress(Entity):
                            """
                            Address registered
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                self.yang_name = "registered-address"
                                self.yang_parent_name = "gre-next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "registered-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class GroupMapRpfs(Entity):
                """
                PIM group mapping information
                
                .. attribute:: group_map_rpf
                
                	PIM group mapping entry
                	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.GroupMapRpfs, self).__init__()

                    self.yang_name = "group-map-rpfs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"group-map-rpf" : ("group_map_rpf", Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf)}

                    self.group_map_rpf = YList(self)
                    self._segment_path = lambda: "group-map-rpfs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.GroupMapRpfs, [], name, value)


                class GroupMapRpf(Entity):
                    """
                    PIM group mapping entry
                    
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_priority
                    
                    	RP priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__init__()

                        self.yang_name = "group-map-rpf"
                        self.yang_parent_name = "group-map-rpfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-map-information" : ("group_map_information", Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation), "rpf-neighbor" : ("rpf_neighbor", Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor)}
                        self._child_list_classes = {}

                        self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                        self.client = YLeaf(YType.enumeration, "client")

                        self.prefix = YLeaf(YType.str, "prefix")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_priority = YLeaf(YType.int32, "rp-priority")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.group_map_information = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.rpf_neighbor = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")
                        self._segment_path = lambda: "group-map-rpf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-rpfs/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf, ['are_we_rp', 'client', 'prefix', 'prefix_length', 'protocol', 'rp_address', 'rp_priority', 'rpf_interface_name', 'rpf_vrf_name'], name, value)


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-rpf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"prefix" : ("prefix", Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix), "rp-address" : ("rp_address", Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress)}
                            self._child_list_classes = {}

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")
                            self._segment_path = lambda: "group-map-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-rpfs/group-map-rpf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, ['client', 'group_count', 'is_override', 'is_used', 'mrib_active', 'prefix_length', 'priority', 'protocol'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "group-map-rpf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-rpfs/group-map-rpf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class GroupMapSources(Entity):
                """
                PIM group\-mapping with source information
                
                .. attribute:: group_map_source
                
                	PIM Group Mapping Entry with source information
                	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.GroupMapSources, self).__init__()

                    self.yang_name = "group-map-sources"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"group-map-source" : ("group_map_source", Pim.Active.DefaultContext.GroupMapSources.GroupMapSource)}

                    self.group_map_source = YList(self)
                    self._segment_path = lambda: "group-map-sources"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.GroupMapSources, [], name, value)


                class GroupMapSource(Entity):
                    """
                    PIM Group Mapping Entry with source information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: priority
                    
                    	RP Priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource, self).__init__()

                        self.yang_name = "group-map-source"
                        self.yang_parent_name = "group-map-sources"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-map-information" : ("group_map_information", Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation), "source-of-information" : ("source_of_information", Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation)}
                        self._child_list_classes = {}

                        self.client = YLeaf(YType.enumeration, "client")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.holdtime = YLeaf(YType.int32, "holdtime")

                        self.prefix = YLeaf(YType.str, "prefix")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.priority = YLeaf(YType.int32, "priority")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_map_information = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.source_of_information = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")
                        self._segment_path = lambda: "group-map-source"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-sources/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource, ['client', 'expires', 'holdtime', 'prefix', 'prefix_length', 'priority', 'protocol', 'rp_address', 'uptime'], name, value)


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"prefix" : ("prefix", Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix), "rp-address" : ("rp_address", Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress)}
                            self._child_list_classes = {}

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")
                            self._segment_path = lambda: "group-map-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-sources/group-map-source/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, ['client', 'group_count', 'is_override', 'is_used', 'mrib_active', 'prefix_length', 'priority', 'protocol'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-sources/group-map-source/group-map-information/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-sources/group-map-source/group-map-information/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceOfInformation(Entity):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "group-map-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-of-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-sources/group-map-source/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class IfrsInterfaces(Entity):
                """
                PIM interfaces in forward reference store table
                
                .. attribute:: ifrs_interface
                
                	PIM IFRS interface information
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"ifrs-interface" : ("ifrs_interface", Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface)}

                    self.ifrs_interface = YList(self)
                    self._segment_path = lambda: "ifrs-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.IfrsInterfaces, [], name, value)


                class IfrsInterface(Entity):
                    """
                    PIM IFRS interface information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"dr-address" : ("dr_address", Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress)}
                        self._child_list_classes = {"interface-address" : ("interface_address", Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ifrs-interfaces/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "dr-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "interface-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class IfrsSummary(Entity):
                """
                PIM interfaces in forward reference store
                summary
                
                .. attribute:: configuration_count
                
                	Configuration counts
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Number of interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.IfrsSummary, self).__init__()

                    self.yang_name = "ifrs-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                    self.interface_count = YLeaf(YType.uint32, "interface-count")
                    self._segment_path = lambda: "ifrs-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.IfrsSummary, ['configuration_count', 'interface_count'], name, value)


            class InterfaceOldFormats(Entity):
                """
                PIM interfaces in old format
                
                .. attribute:: interface_old_format
                
                	PIM interface name
                	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.InterfaceOldFormats, self).__init__()

                    self.yang_name = "interface-old-formats"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-old-format" : ("interface_old_format", Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat)}

                    self.interface_old_format = YList(self)
                    self._segment_path = lambda: "interface-old-formats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.InterfaceOldFormats, [], name, value)


                class InterfaceOldFormat(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                        self.yang_name = "interface-old-format"
                        self.yang_parent_name = "interface-old-formats"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"dr-address" : ("dr_address", Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress)}
                        self._child_list_classes = {"interface-address" : ("interface_address", Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "interface-old-format" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/interface-old-formats/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "dr-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "interface-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceStatistics(Entity):
                """
                PIM interface statistics
                
                .. attribute:: interface_statistic
                
                	PIM interface statistics
                	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.InterfaceStatistics, self).__init__()

                    self.yang_name = "interface-statistics"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-statistic" : ("interface_statistic", Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic)}

                    self.interface_statistic = YList(self)
                    self._segment_path = lambda: "interface-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.InterfaceStatistics, [], name, value)


                class InterfaceStatistic(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_ack_message
                    
                    	Input Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_message
                    
                    	Input Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_miscellaneous
                    
                    	Miscellaneous packet in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register
                    
                    	Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_ack_message
                    
                    	Output Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_message
                    
                    	Output Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register
                    
                    	Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__init__()

                        self.yang_name = "interface-statistic"
                        self.yang_parent_name = "interface-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.input_assert = YLeaf(YType.uint32, "input-assert")

                        self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                        self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                        self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                        self.input_graft_ack_message = YLeaf(YType.uint32, "input-graft-ack-message")

                        self.input_graft_message = YLeaf(YType.uint32, "input-graft-message")

                        self.input_hello = YLeaf(YType.uint32, "input-hello")

                        self.input_jp = YLeaf(YType.uint32, "input-jp")

                        self.input_miscellaneous = YLeaf(YType.uint32, "input-miscellaneous")

                        self.input_register = YLeaf(YType.uint32, "input-register")

                        self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                        self.output_assert = YLeaf(YType.uint32, "output-assert")

                        self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                        self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                        self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                        self.output_graft_ack_message = YLeaf(YType.uint32, "output-graft-ack-message")

                        self.output_graft_message = YLeaf(YType.uint32, "output-graft-message")

                        self.output_hello = YLeaf(YType.uint32, "output-hello")

                        self.output_jp = YLeaf(YType.uint32, "output-jp")

                        self.output_register = YLeaf(YType.uint32, "output-register")

                        self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")
                        self._segment_path = lambda: "interface-statistic" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/interface-statistics/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic, ['interface_name', 'input_assert', 'input_bsr_message', 'input_candidate_rp_advertisement', 'input_df_election', 'input_graft_ack_message', 'input_graft_message', 'input_hello', 'input_jp', 'input_miscellaneous', 'input_register', 'input_register_stop', 'output_assert', 'output_bsr_message', 'output_candidate_rp_advertisement', 'output_df_election', 'output_graft_ack_message', 'output_graft_message', 'output_hello', 'output_jp', 'output_register', 'output_register_stop'], name, value)


            class Interfaces(Entity):
                """
                PIM interfaces
                
                .. attribute:: interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Interfaces.Interface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface" : ("interface", Pim.Active.DefaultContext.Interfaces.Interface)}

                    self.interface = YList(self)
                    self._segment_path = lambda: "interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.Interfaces, [], name, value)


                class Interface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Interfaces.Interface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Interfaces.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"dr-address" : ("dr_address", Pim.Active.DefaultContext.Interfaces.Interface.DrAddress)}
                        self._child_list_classes = {"interface-address" : ("interface_address", Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Pim.Active.DefaultContext.Interfaces.Interface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/interfaces/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Interfaces.Interface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Interfaces.Interface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "dr-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Interfaces.Interface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "interface-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class JpStatistics(Entity):
                """
                PIM join prune statistics table
                
                .. attribute:: jp_statistic
                
                	PIM Join Prune Statistics
                	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.JpStatistics.JpStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.JpStatistics, self).__init__()

                    self.yang_name = "jp-statistics"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"jp-statistic" : ("jp_statistic", Pim.Active.DefaultContext.JpStatistics.JpStatistic)}

                    self.jp_statistic = YList(self)
                    self._segment_path = lambda: "jp-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.JpStatistics, [], name, value)


                class JpStatistic(Entity):
                    """
                    PIM Join Prune Statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mtu
                    
                    	Interface MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received
                    
                    	Received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received100
                    
                    	Received 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_10k
                    
                    	Received 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_1k
                    
                    	Received 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_50k
                    
                    	Deprecated by Received100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted
                    
                    	Transmitted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted100
                    
                    	Transmitted 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_10k
                    
                    	Transmitted 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_1k
                    
                    	Transmitted 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_50k
                    
                    	Deprecated by Transmitted100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.JpStatistics.JpStatistic, self).__init__()

                        self.yang_name = "jp-statistic"
                        self.yang_parent_name = "jp-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.received = YLeaf(YType.uint32, "received")

                        self.received100 = YLeaf(YType.uint16, "received100")

                        self.received_10k = YLeaf(YType.uint16, "received-10k")

                        self.received_1k = YLeaf(YType.uint16, "received-1k")

                        self.received_50k = YLeaf(YType.uint16, "received-50k")

                        self.transmitted = YLeaf(YType.uint32, "transmitted")

                        self.transmitted100 = YLeaf(YType.uint16, "transmitted100")

                        self.transmitted_10k = YLeaf(YType.uint16, "transmitted-10k")

                        self.transmitted_1k = YLeaf(YType.uint16, "transmitted-1k")

                        self.transmitted_50k = YLeaf(YType.uint16, "transmitted-50k")
                        self._segment_path = lambda: "jp-statistic" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/jp-statistics/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.JpStatistics.JpStatistic, ['interface_name', 'interface_name_xr', 'mtu', 'received', 'received100', 'received_10k', 'received_1k', 'received_50k', 'transmitted', 'transmitted100', 'transmitted_10k', 'transmitted_1k', 'transmitted_50k'], name, value)


            class MibDatabases(Entity):
                """
                PIM group database for mroute mibs table
                
                .. attribute:: mib_database
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.MibDatabases, self).__init__()

                    self.yang_name = "mib-databases"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"mib-database" : ("mib_database", Pim.Active.DefaultContext.MibDatabases.MibDatabase)}

                    self.mib_database = YList(self)
                    self._segment_path = lambda: "mib-databases"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.MibDatabases, [], name, value)


                class MibDatabase(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: assert_metric
                    
                    	Assert Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_metric_preference
                    
                    	Assert Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_rpt_bit
                    
                    	Assert RPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: bidirectional_route
                    
                    	Is this Bidir ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Multicast satic route group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr>`
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface name 
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: rpf_mask
                    
                    	Mask of the multicast root
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_neighbor
                    
                    	The RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: source_address
                    
                    	Multicast static route source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr>`
                    
                    .. attribute:: source_netmask
                    
                    	Source mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: spt_bit
                    
                    	Is SPT bit set ?
                    	**type**\:  bool
                    
                    .. attribute:: upstream_assert_timer
                    
                    	Upstream Assert Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime of route
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.MibDatabases.MibDatabase, self).__init__()

                        self.yang_name = "mib-database"
                        self.yang_parent_name = "mib-databases"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr), "rpf-neighbor" : ("rpf_neighbor", Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor), "rpf-root" : ("rpf_root", Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot), "source-address-xr" : ("source_address_xr", Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr)}
                        self._child_list_classes = {}

                        self.assert_metric = YLeaf(YType.uint32, "assert-metric")

                        self.assert_metric_preference = YLeaf(YType.uint32, "assert-metric-preference")

                        self.assert_rpt_bit = YLeaf(YType.boolean, "assert-rpt-bit")

                        self.bidirectional_route = YLeaf(YType.boolean, "bidirectional-route")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                        self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_mask = YLeaf(YType.uint32, "rpf-mask")

                        self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                        self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.source_netmask = YLeaf(YType.int32, "source-netmask")

                        self.spt_bit = YLeaf(YType.boolean, "spt-bit")

                        self.upstream_assert_timer = YLeaf(YType.int32, "upstream-assert-timer")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_address_xr = Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.rpf_neighbor = Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                        self.rpf_root = Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._children_yang_names.add("rpf-root")

                        self.source_address_xr = Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"
                        self._children_yang_names.add("source-address-xr")
                        self._segment_path = lambda: "mib-database"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/mib-databases/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.MibDatabases.MibDatabase, ['assert_metric', 'assert_metric_preference', 'assert_rpt_bit', 'bidirectional_route', 'group_address', 'protocol', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_mask', 'rpf_safi', 'rpf_table_name', 'rpf_vrf_name', 'source_address', 'source_netmask', 'spt_bit', 'upstream_assert_timer', 'uptime'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/mib-databases/mib-database/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        The RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/mib-databases/mib-database/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-root"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/mib-databases/mib-database/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/mib-databases/mib-database/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class MulticastStaticRoutes(Entity):
                """
                PIM multicast static route table
                
                .. attribute:: multicast_static_route
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.MulticastStaticRoutes, self).__init__()

                    self.yang_name = "multicast-static-routes"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"multicast-static-route" : ("multicast_static_route", Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute)}

                    self.multicast_static_route = YList(self)
                    self._segment_path = lambda: "multicast-static-routes"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.MulticastStaticRoutes, [], name, value)


                class MulticastStaticRoute(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: address
                    
                    	Network address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: distance
                    
                    	Distance
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_via_lsm
                    
                    	LSM flag
                    	**type**\:  bool
                    
                    .. attribute:: nexthop
                    
                    	Next Hop
                    	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: prefix_length_xr
                    
                    	Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                        self.yang_name = "multicast-static-route"
                        self.yang_parent_name = "multicast-static-routes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"nexthop" : ("nexthop", Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop), "prefix" : ("prefix", Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix)}
                        self._child_list_classes = {}

                        self.address = YLeaf(YType.str, "address")

                        self.distance = YLeaf(YType.uint32, "distance")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                        self.nexthop = Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                        self.nexthop.parent = self
                        self._children_name_map["nexthop"] = "nexthop"
                        self._children_yang_names.add("nexthop")

                        self.prefix = Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._children_yang_names.add("prefix")
                        self._segment_path = lambda: "multicast-static-route"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/multicast-static-routes/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, ['address', 'distance', 'interface_name', 'is_via_lsm', 'prefix_length', 'prefix_length_xr'], name, value)


                    class Nexthop(Entity):
                        """
                        Next Hop
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                            self.yang_name = "nexthop"
                            self.yang_parent_name = "multicast-static-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "nexthop"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/multicast-static-routes/multicast-static-route/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Prefix(Entity):
                        """
                        Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "multicast-static-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "prefix"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/multicast-static-routes/multicast-static-route/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class NeighborOldFormats(Entity):
                """
                PIM neighbor table old format
                
                .. attribute:: neighbor_old_format
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.NeighborOldFormats, self).__init__()

                    self.yang_name = "neighbor-old-formats"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"neighbor-old-format" : ("neighbor_old_format", Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat)}

                    self.neighbor_old_format = YList(self)
                    self._segment_path = lambda: "neighbor-old-formats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.NeighborOldFormats, [], name, value)


                class NeighborOldFormat(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__init__()

                        self.yang_name = "neighbor-old-format"
                        self.yang_parent_name = "neighbor-old-formats"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr)}

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                        self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                        self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.neighbor_address_xr = YList(self)
                        self._segment_path = lambda: "neighbor-old-format"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/neighbor-old-formats/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat, ['dr_priority', 'expires', 'expiry_timer', 'interface_name', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bfd_state', 'is_bidirectional_capable', 'is_dr_priority_capable', 'is_ecmp_redirect_capable', 'is_proxy_capable', 'is_this_neighbor_dr', 'is_this_neighbor_us', 'neighbor_address', 'override_interval', 'propagation_delay', 'uptime'], name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "neighbor-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/neighbor-old-formats/neighbor-old-format/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class NeighborSummaries(Entity):
                """
                PIM neighbor summary table
                
                .. attribute:: neighbor_summary
                
                	PIM neighbor summary information
                	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.NeighborSummaries, self).__init__()

                    self.yang_name = "neighbor-summaries"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"neighbor-summary" : ("neighbor_summary", Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary)}

                    self.neighbor_summary = YList(self)
                    self._segment_path = lambda: "neighbor-summaries"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.NeighborSummaries, [], name, value)


                class NeighborSummary(Entity):
                    """
                    PIM neighbor summary information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: number_of_external_neighbors
                    
                    	Number of external neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary, self).__init__()

                        self.yang_name = "neighbor-summary"
                        self.yang_parent_name = "neighbor-summaries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.number_of_external_neighbors = YLeaf(YType.int32, "number-of-external-neighbors")

                        self.number_of_neighbors = YLeaf(YType.int32, "number-of-neighbors")
                        self._segment_path = lambda: "neighbor-summary" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/neighbor-summaries/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary, ['interface_name', 'number_of_external_neighbors', 'number_of_neighbors'], name, value)


            class Neighbors(Entity):
                """
                PIM neighbor table
                
                .. attribute:: neighbor
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Neighbors.Neighbor>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Neighbors, self).__init__()

                    self.yang_name = "neighbors"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"neighbor" : ("neighbor", Pim.Active.DefaultContext.Neighbors.Neighbor)}

                    self.neighbor = YList(self)
                    self._segment_path = lambda: "neighbors"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.Neighbors, [], name, value)


                class Neighbor(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Neighbors.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "neighbors"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr)}

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                        self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                        self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.neighbor_address_xr = YList(self)
                        self._segment_path = lambda: "neighbor"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/neighbors/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Neighbors.Neighbor, ['dr_priority', 'expires', 'expiry_timer', 'interface_name', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bfd_state', 'is_bidirectional_capable', 'is_dr_priority_capable', 'is_ecmp_redirect_capable', 'is_proxy_capable', 'is_this_neighbor_dr', 'is_this_neighbor_us', 'neighbor_address', 'override_interval', 'propagation_delay', 'uptime'], name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "neighbor-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/neighbors/neighbor/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class NetIoTunnels(Entity):
                """
                Tunnel information that NETIO has 
                
                .. attribute:: net_io_tunnel
                
                	PIM netio tunnel information
                	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.NetIoTunnels, self).__init__()

                    self.yang_name = "net-io-tunnels"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"net-io-tunnel" : ("net_io_tunnel", Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel)}

                    self.net_io_tunnel = YList(self)
                    self._segment_path = lambda: "net-io-tunnels"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.NetIoTunnels, [], name, value)


                class NetIoTunnel(Entity):
                    """
                    PIM netio tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel, self).__init__()

                        self.yang_name = "net-io-tunnel"
                        self.yang_parent_name = "net-io-tunnels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-netio" : ("group_address_netio", Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio), "rp-address" : ("rp_address", Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress), "source-address" : ("source_address", Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress), "source-address-netio" : ("source_address_netio", Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio)}
                        self._child_list_classes = {}

                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.group_address_netio = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._children_yang_names.add("group-address-netio")

                        self.rp_address = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                        self.source_address_netio = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"
                        self._children_yang_names.add("source-address-netio")
                        self._segment_path = lambda: "net-io-tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/net-io-tunnels/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel, ['tunnel_name', 'vrf_name'], name, value)


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-netio"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address-netio"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Ranges(Entity):
                """
                PIM range list information
                
                .. attribute:: range
                
                	PIM range list information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"range" : ("range", Pim.Active.DefaultContext.Ranges.Range)}

                    self.range = YList(self)
                    self._segment_path = lambda: "ranges"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.Ranges, [], name, value)


                class Range(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: client_xr
                    
                    	Client mapping learnt via
                    	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                    
                    .. attribute:: expires
                    
                    	When mapping expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: group_range
                    
                    	List of group ranges
                    	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.GroupRange>`
                    
                    .. attribute:: protocol
                    
                    	PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	Rendezvous point address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.RpAddressXr>`
                    
                    .. attribute:: source_of_information
                    
                    	Source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rp-address-xr" : ("rp_address_xr", Pim.Active.DefaultContext.Ranges.Range.RpAddressXr), "source-of-information" : ("source_of_information", Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation)}
                        self._child_list_classes = {"group-range" : ("group_range", Pim.Active.DefaultContext.Ranges.Range.GroupRange)}

                        self.client = YLeaf(YType.enumeration, "client")

                        self.client_xr = YLeaf(YType.enumeration, "client-xr")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_address_xr = Pim.Active.DefaultContext.Ranges.Range.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")

                        self.source_of_information = Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")

                        self.group_range = YList(self)
                        self._segment_path = lambda: "range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ranges/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Ranges.Range, ['client', 'client_xr', 'expires', 'protocol', 'rp_address'], name, value)


                    class GroupRange(Entity):
                        """
                        List of group ranges
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Ranges.Range.GroupRange, self).__init__()

                            self.yang_name = "group-range"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"prefix" : ("prefix", Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix), "source-of-information" : ("source_of_information", Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation)}
                            self._child_list_classes = {}

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.prefix = Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.source_of_information = Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")
                            self._segment_path = lambda: "group-range"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ranges/range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Ranges.Range.GroupRange, ['expires', 'prefix_length', 'uptime'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ranges/range/group-range/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-of-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ranges/range/group-range/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddressXr(Entity):
                        """
                        Rendezvous point address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Ranges.Range.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ranges/range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Ranges.Range.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceOfInformation(Entity):
                        """
                        Source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-of-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ranges/range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class RoutePolicy(Entity):
                """
                PIM route policy
                
                .. attribute:: route_policy_statistics
                
                	PIM route policy statistics
                	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics>`
                
                .. attribute:: route_policy_tests
                
                	PIM route policy test run table
                	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.RoutePolicy, self).__init__()

                    self.yang_name = "route-policy"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"route-policy-statistics" : ("route_policy_statistics", Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics), "route-policy-tests" : ("route_policy_tests", Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests)}
                    self._child_list_classes = {}

                    self.route_policy_statistics = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                    self.route_policy_statistics.parent = self
                    self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                    self._children_yang_names.add("route-policy-statistics")

                    self.route_policy_tests = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests()
                    self.route_policy_tests.parent = self
                    self._children_name_map["route_policy_tests"] = "route-policy-tests"
                    self._children_yang_names.add("route-policy-tests")
                    self._segment_path = lambda: "route-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()


                class RoutePolicyStatistics(Entity):
                    """
                    PIM route policy statistics
                    
                    .. attribute:: any_table
                    
                    	Number of RPF lookup in any Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table
                    
                    	Number of RPF lookup in default\-only Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop
                    
                    	Number of RPF drops
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pass_
                    
                    	Number of RPF pass
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: policy_name
                    
                    	RPF policy name
                    	**type**\:  str
                    
                    .. attribute:: requests
                    
                    	Number of RPF lookup requests
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__init__()

                        self.yang_name = "route-policy-statistics"
                        self.yang_parent_name = "route-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.any_table = YLeaf(YType.uint32, "any-table")

                        self.default_table = YLeaf(YType.uint32, "default-table")

                        self.drop = YLeaf(YType.uint32, "drop")

                        self.pass_ = YLeaf(YType.uint32, "pass")

                        self.policy_name = YLeaf(YType.str, "policy-name")

                        self.requests = YLeaf(YType.uint32, "requests")
                        self._segment_path = lambda: "route-policy-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/route-policy/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics, ['any_table', 'default_table', 'drop', 'pass_', 'policy_name', 'requests'], name, value)


                class RoutePolicyTests(Entity):
                    """
                    PIM route policy test run table
                    
                    .. attribute:: route_policy_test
                    
                    	PIM route policy test run
                    	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests, self).__init__()

                        self.yang_name = "route-policy-tests"
                        self.yang_parent_name = "route-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"route-policy-test" : ("route_policy_test", Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest)}

                        self.route_policy_test = YList(self)
                        self._segment_path = lambda: "route-policy-tests"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/route-policy/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests, [], name, value)


                    class RoutePolicyTest(Entity):
                        """
                        PIM route policy test run
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Default table selected
                        	**type**\:  bool
                        
                        .. attribute:: ext_comm
                        
                        	Extended Community
                        	**type**\:  str
                        
                        	**length:** 1..8
                        
                        .. attribute:: extended_community_rt
                        
                        	Route Target
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                        
                        .. attribute:: pass_
                        
                        	Pass
                        	**type**\:  bool
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                        
                        .. attribute:: table_active
                        
                        	Table active
                        	**type**\:  bool
                        
                        .. attribute:: table_exists
                        
                        	Table exists
                        	**type**\:  bool
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_name
                        
                        	VRF name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                            self.yang_name = "route-policy-test"
                            self.yang_parent_name = "route-policy-tests"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr), "source-address-xr" : ("source_address_xr", Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr)}
                            self._child_list_classes = {}

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.default_table = YLeaf(YType.boolean, "default-table")

                            self.ext_comm = YLeaf(YType.str, "ext-comm")

                            self.extended_community_rt = YLeaf(YType.str, "extended-community-rt")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.pass_ = YLeaf(YType.boolean, "pass")

                            self.policy_name = YLeaf(YType.str, "policy-name")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.table_active = YLeaf(YType.boolean, "table-active")

                            self.table_exists = YLeaf(YType.boolean, "table-exists")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_xr = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.source_address_xr = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")
                            self._segment_path = lambda: "route-policy-test"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/route-policy/route-policy-tests/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, ['afi', 'default_table', 'ext_comm', 'extended_community_rt', 'group_address', 'pass_', 'policy_name', 'safi', 'source_address', 'table_active', 'table_exists', 'table_name', 'vrf_name'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "route-policy-test"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "route-policy-test"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class RpfRedirect(Entity):
                """
                PIM ECMP RPF\-redirect bundle
                
                .. attribute:: bundle_interfaces
                
                	PIM ECMP RPF\-redirect bundle information
                	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces>`
                
                .. attribute:: redirect_route_databases
                
                	PIM ECMP RPF\-redirect route database
                	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.RpfRedirect, self).__init__()

                    self.yang_name = "rpf-redirect"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"bundle-interfaces" : ("bundle_interfaces", Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces), "redirect-route-databases" : ("redirect_route_databases", Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases)}
                    self._child_list_classes = {}

                    self.bundle_interfaces = Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces()
                    self.bundle_interfaces.parent = self
                    self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                    self._children_yang_names.add("bundle-interfaces")

                    self.redirect_route_databases = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                    self.redirect_route_databases.parent = self
                    self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                    self._children_yang_names.add("redirect-route-databases")
                    self._segment_path = lambda: "rpf-redirect"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()


                class BundleInterfaces(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle information
                    
                    .. attribute:: bundle_interface
                    
                    	PIM ECMP RPF\-redirect bundle interface information
                    	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces, self).__init__()

                        self.yang_name = "bundle-interfaces"
                        self.yang_parent_name = "rpf-redirect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"bundle-interface" : ("bundle_interface", Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface)}

                        self.bundle_interface = YList(self)
                        self._segment_path = lambda: "bundle-interfaces"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces, [], name, value)


                    class BundleInterface(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle interface
                        information
                        
                        .. attribute:: allocated_bandwidth
                        
                        	Bandwidth allocated in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_threshold_bandwidth
                        
                        	Configured threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_threshold_bandwidth
                        
                        	Available threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: bundle_name
                        
                        	Bundle name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: interface_name
                        
                        	Bundle interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: rpf_redirect_bundle_name
                        
                        	RPF redirect bundle name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_redirect_interface_name
                        
                        	RPF redirect interface name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: snooping_bandwidth_used
                        
                        	Bandwidth used by snooped entries in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: topology_bandwidth_used
                        
                        	Bandwidth used by topology in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: total_bandwidth
                        
                        	Total bandwidth used in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                            self.yang_name = "bundle-interface"
                            self.yang_parent_name = "bundle-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.allocated_bandwidth = YLeaf(YType.int32, "allocated-bandwidth")

                            self.allocated_threshold_bandwidth = YLeaf(YType.int32, "allocated-threshold-bandwidth")

                            self.available_bandwidth = YLeaf(YType.int32, "available-bandwidth")

                            self.available_threshold_bandwidth = YLeaf(YType.int32, "available-threshold-bandwidth")

                            self.bundle_name = YLeaf(YType.str, "bundle-name")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.rpf_redirect_bundle_name = YLeaf(YType.str, "rpf-redirect-bundle-name")

                            self.rpf_redirect_interface_name = YLeaf(YType.str, "rpf-redirect-interface-name")

                            self.snooping_bandwidth_used = YLeaf(YType.int32, "snooping-bandwidth-used")

                            self.topology_bandwidth_used = YLeaf(YType.int32, "topology-bandwidth-used")

                            self.total_bandwidth = YLeaf(YType.int32, "total-bandwidth")
                            self._segment_path = lambda: "bundle-interface"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/bundle-interfaces/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, ['allocated_bandwidth', 'allocated_threshold_bandwidth', 'available_bandwidth', 'available_threshold_bandwidth', 'bundle_name', 'interface_name', 'rpf_redirect_bundle_name', 'rpf_redirect_interface_name', 'snooping_bandwidth_used', 'topology_bandwidth_used', 'total_bandwidth'], name, value)


                class RedirectRouteDatabases(Entity):
                    """
                    PIM ECMP RPF\-redirect route database
                    
                    .. attribute:: redirect_route_database
                    
                    	PIM ECMP RPF\-redirect route information
                    	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__init__()

                        self.yang_name = "redirect-route-databases"
                        self.yang_parent_name = "rpf-redirect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"redirect-route-database" : ("redirect_route_database", Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase)}

                        self.redirect_route_database = YList(self)
                        self._segment_path = lambda: "redirect-route-databases"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases, [], name, value)


                    class RedirectRouteDatabase(Entity):
                        """
                        PIM ECMP RPF\-redirect route information
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group ddress
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                        
                        .. attribute:: interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                            self.yang_name = "redirect-route-database"
                            self.yang_parent_name = "redirect-route-databases"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr), "source-address-xr" : ("source_address_xr", Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr)}
                            self._child_list_classes = {"interface" : ("interface", Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface)}

                            self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.source_address_xr = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                            self.interface = YList(self)
                            self._segment_path = lambda: "redirect-route-database"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/redirect-route-databases/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, ['bandwidth', 'group_address', 'source_address', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group ddress
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Interface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_outgoing_interface
                            
                            	Is outgoing Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_rpf_interface
                            
                            	Is RPF Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_snoop_interface
                            
                            	Is snooping Interface
                            	**type**\:  bool
                            
                            .. attribute:: rpf_address
                            
                            	RPF Address
                            	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"rpf-address" : ("rpf_address", Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress)}
                                self._child_list_classes = {}

                                self.expiry = YLeaf(YType.uint64, "expiry")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.is_outgoing_interface = YLeaf(YType.boolean, "is-outgoing-interface")

                                self.is_rpf_interface = YLeaf(YType.boolean, "is-rpf-interface")

                                self.is_snoop_interface = YLeaf(YType.boolean, "is-snoop-interface")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.rpf_address = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                self.rpf_address.parent = self
                                self._children_name_map["rpf_address"] = "rpf-address"
                                self._children_yang_names.add("rpf-address")
                                self._segment_path = lambda: "interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, ['expiry', 'interface_name', 'is_outgoing_interface', 'is_rpf_interface', 'is_snoop_interface', 'uptime'], name, value)


                            class RpfAddress(Entity):
                                """
                                RPF Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                    self.yang_name = "rpf-address"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "rpf-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class RpfSummary(Entity):
                """
                PIM RPF registration summary
                
                .. attribute:: default_safi
                
                	Default RPF Table SAFI
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: default_table_name
                
                	Default RPF Table Name
                	**type**\:  str
                
                .. attribute:: is_isis_mtr_configured
                
                	Is ISIS MTR configured?
                	**type**\:  bool
                
                .. attribute:: is_isis_te_configured
                
                	Is ISIS TE configured?
                	**type**\:  bool
                
                .. attribute:: is_mbgp_configured
                
                	Is MBGP configured?
                	**type**\:  bool
                
                .. attribute:: is_multipath_enabled
                
                	Is Multipath Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_interface_hash_enabled
                
                	Is Multipath Interface Hash Extension Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_hash_enabled
                
                	Is Multipath Source based Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_next_hop_hash_enabled
                
                	Is Multipath Source\-Nexthop Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_ospf_te_configured
                
                	Is OSPF TE configured?
                	**type**\:  bool
                
                .. attribute:: is_rib_convergence
                
                	RIB Convergence status
                	**type**\:  bool
                
                .. attribute:: mo_frr_configured
                
                	Is MoFRR configured?
                	**type**\:  bool
                
                .. attribute:: rib_convergence_time_left
                
                	RIB convergence time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_convergence_timeout
                
                	RIB convergence timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_mo_frr_configured
                
                	Is MoFRR RIB configured?
                	**type**\:  bool
                
                .. attribute:: rpf_registrations
                
                	RPF Registration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	Is RUMP MuRIB enabled?
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.RpfSummary, self).__init__()

                    self.yang_name = "rpf-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.default_safi = YLeaf(YType.uint32, "default-safi")

                    self.default_table_name = YLeaf(YType.str, "default-table-name")

                    self.is_isis_mtr_configured = YLeaf(YType.boolean, "is-isis-mtr-configured")

                    self.is_isis_te_configured = YLeaf(YType.boolean, "is-isis-te-configured")

                    self.is_mbgp_configured = YLeaf(YType.boolean, "is-mbgp-configured")

                    self.is_multipath_enabled = YLeaf(YType.boolean, "is-multipath-enabled")

                    self.is_multipath_interface_hash_enabled = YLeaf(YType.boolean, "is-multipath-interface-hash-enabled")

                    self.is_multipath_source_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-hash-enabled")

                    self.is_multipath_source_next_hop_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-next-hop-hash-enabled")

                    self.is_ospf_te_configured = YLeaf(YType.boolean, "is-ospf-te-configured")

                    self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                    self.mo_frr_configured = YLeaf(YType.boolean, "mo-frr-configured")

                    self.rib_convergence_time_left = YLeaf(YType.uint32, "rib-convergence-time-left")

                    self.rib_convergence_timeout = YLeaf(YType.uint32, "rib-convergence-timeout")

                    self.rib_mo_frr_configured = YLeaf(YType.boolean, "rib-mo-frr-configured")

                    self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                    self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")
                    self._segment_path = lambda: "rpf-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.RpfSummary, ['default_safi', 'default_table_name', 'is_isis_mtr_configured', 'is_isis_te_configured', 'is_mbgp_configured', 'is_multipath_enabled', 'is_multipath_interface_hash_enabled', 'is_multipath_source_hash_enabled', 'is_multipath_source_next_hop_hash_enabled', 'is_ospf_te_configured', 'is_rib_convergence', 'mo_frr_configured', 'rib_convergence_time_left', 'rib_convergence_timeout', 'rib_mo_frr_configured', 'rpf_registrations', 'rump_enabled'], name, value)


            class Safs(Entity):
                """
                SAFI table and type
                
                .. attribute:: saf
                
                	SAF name 
                	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Safs, self).__init__()

                    self.yang_name = "safs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"saf" : ("saf", Pim.Active.DefaultContext.Safs.Saf)}

                    self.saf = YList(self)
                    self._segment_path = lambda: "safs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.Safs, [], name, value)


                class Saf(Entity):
                    """
                    SAF name 
                    
                    .. attribute:: rpf_hash_source_groups
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups>`
                    
                    .. attribute:: rpf_hash_sources
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSources>`
                    
                    .. attribute:: rpfs
                    
                    	PIM RPF information table
                    	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs>`
                    
                    .. attribute:: saf_name
                    
                    	SAF name 
                    	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name 
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Safs.Saf, self).__init__()

                        self.yang_name = "saf"
                        self.yang_parent_name = "safs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rpf-hash-source-groups" : ("rpf_hash_source_groups", Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups), "rpf-hash-sources" : ("rpf_hash_sources", Pim.Active.DefaultContext.Safs.Saf.RpfHashSources), "rpfs" : ("rpfs", Pim.Active.DefaultContext.Safs.Saf.Rpfs)}
                        self._child_list_classes = {}

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                        self.topology_name = YLeaf(YType.str, "topology-name")

                        self.rpf_hash_source_groups = Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                        self.rpf_hash_source_groups.parent = self
                        self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                        self._children_yang_names.add("rpf-hash-source-groups")

                        self.rpf_hash_sources = Pim.Active.DefaultContext.Safs.Saf.RpfHashSources()
                        self.rpf_hash_sources.parent = self
                        self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                        self._children_yang_names.add("rpf-hash-sources")

                        self.rpfs = Pim.Active.DefaultContext.Safs.Saf.Rpfs()
                        self.rpfs.parent = self
                        self._children_name_map["rpfs"] = "rpfs"
                        self._children_yang_names.add("rpfs")
                        self._segment_path = lambda: "saf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf, ['saf_name', 'topology_name'], name, value)


                    class RpfHashSourceGroups(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source_group
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__init__()

                            self.yang_name = "rpf-hash-source-groups"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"rpf-hash-source-group" : ("rpf_hash_source_group", Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup)}

                            self.rpf_hash_source_group = YList(self)
                            self._segment_path = lambda: "rpf-hash-source-groups"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups, [], name, value)


                        class RpfHashSourceGroup(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: mask_length
                            
                            	Hash mask length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                self.yang_name = "rpf-hash-source-group"
                                self.yang_parent_name = "rpf-hash-source-groups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"next-hop-address" : ("next_hop_address", Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress), "secondary-next-hop-address" : ("secondary_next_hop_address", Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress)}
                                self._child_list_classes = {}

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.mask_length = YLeaf(YType.int32, "mask-length")

                                self.mofrr = YLeaf(YType.int32, "mofrr")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                self._children_yang_names.add("next-hop-address")

                                self.secondary_next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._children_yang_names.add("secondary-next-hop-address")
                                self._segment_path = lambda: "rpf-hash-source-group"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpf-hash-source-groups/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, ['group_address', 'mask_length', 'mofrr', 'next_hop_interface', 'next_hop_multipath_enabled', 'secondary_next_hop_interface', 'source_address'], name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "secondary-next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfHashSources(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources, self).__init__()

                            self.yang_name = "rpf-hash-sources"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"rpf-hash-source" : ("rpf_hash_source", Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource)}

                            self.rpf_hash_source = YList(self)
                            self._segment_path = lambda: "rpf-hash-sources"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources, [], name, value)


                        class RpfHashSource(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                self.yang_name = "rpf-hash-source"
                                self.yang_parent_name = "rpf-hash-sources"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"next-hop-address" : ("next_hop_address", Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress), "secondary-next-hop-address" : ("secondary_next_hop_address", Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress)}
                                self._child_list_classes = {}

                                self.mofrr = YLeaf(YType.int32, "mofrr")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                self._children_yang_names.add("next-hop-address")

                                self.secondary_next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._children_yang_names.add("secondary-next-hop-address")
                                self._segment_path = lambda: "rpf-hash-source"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpf-hash-sources/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, ['mofrr', 'next_hop_interface', 'next_hop_multipath_enabled', 'secondary_next_hop_interface', 'source_address'], name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "secondary-next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Rpfs(Entity):
                        """
                        PIM RPF information table
                        
                        .. attribute:: rpf
                        
                        	PIM RPF information
                        	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Safs.Saf.Rpfs, self).__init__()

                            self.yang_name = "rpfs"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"rpf" : ("rpf", Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf)}

                            self.rpf = YList(self)
                            self._segment_path = lambda: "rpfs"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.Rpfs, [], name, value)


                        class Rpf(Entity):
                            """
                            PIM RPF information
                            
                            .. attribute:: registered_address  <key>
                            
                            	Address for which RPF lookup
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_rpf_bgp_route
                            
                            	Is RPF through BGP route
                            	**type**\:  bool
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address_xr
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                            
                            .. attribute:: rpf_path
                            
                            	RPF Paths list
                            	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__init__()

                                self.yang_name = "rpf"
                                self.yang_parent_name = "rpfs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"registered-address-xr" : ("registered_address_xr", Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr)}
                                self._child_list_classes = {"rpf-path" : ("rpf_path", Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath)}

                                self.registered_address = YLeaf(YType.str, "registered-address")

                                self.is_connected = YLeaf(YType.uint8, "is-connected")

                                self.is_rpf_bgp_route = YLeaf(YType.boolean, "is-rpf-bgp-route")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                self.registered_address_xr = Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                self.registered_address_xr.parent = self
                                self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                self._children_yang_names.add("registered-address-xr")

                                self.rpf_path = YList(self)
                                self._segment_path = lambda: "rpf" + "[registered-address='" + self.registered_address.get() + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpfs/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf, ['registered_address', 'is_connected', 'is_rpf_bgp_route', 'metric', 'metric_preference'], name, value)


                            class RegisteredAddressXr(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                    self.yang_name = "registered-address-xr"
                                    self.yang_parent_name = "rpf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "registered-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class RpfPath(Entity):
                                """
                                RPF Paths list
                                
                                .. attribute:: connector
                                
                                	Connector Attribute
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface_disabled
                                
                                	Is the rpf interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                .. attribute:: is_via_mlsm
                                
                                	Via Mstatic LSM
                                	**type**\:  bool
                                
                                .. attribute:: rpf_interface_name
                                
                                	RPF Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: rpf_neighbor
                                
                                	RPF neighbor
                                	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                
                                .. attribute:: rpf_nexthop
                                
                                	RPF nexthop
                                	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                    self.yang_name = "rpf-path"
                                    self.yang_parent_name = "rpf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"rpf-neighbor" : ("rpf_neighbor", Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor), "rpf-nexthop" : ("rpf_nexthop", Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop)}
                                    self._child_list_classes = {}

                                    self.connector = YLeaf(YType.str, "connector")

                                    self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                    self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                    self.is_rpf_interface_disabled = YLeaf(YType.boolean, "is-rpf-interface-disabled")

                                    self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                    self.is_via_mlsm = YLeaf(YType.boolean, "is-via-mlsm")

                                    self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                                    self.rpf_neighbor = Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                    self._children_yang_names.add("rpf-neighbor")

                                    self.rpf_nexthop = Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                    self.rpf_nexthop.parent = self
                                    self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                    self._children_yang_names.add("rpf-nexthop")
                                    self._segment_path = lambda: "rpf-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, ['connector', 'extranet_vrf_name', 'is_connector_attribute_present', 'is_rpf_interface_disabled', 'is_via_lsm', 'is_via_mlsm', 'rpf_interface_name'], name, value)


                                class RpfNeighbor(Entity):
                                    """
                                    RPF neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                        self.yang_name = "rpf-neighbor"
                                        self.yang_parent_name = "rpf-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "rpf-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class RpfNexthop(Entity):
                                    """
                                    RPF nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                        self.yang_name = "rpf-nexthop"
                                        self.yang_parent_name = "rpf-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "rpf-nexthop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Summary(Entity):
                """
                PIM summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                    self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                    self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                    self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                    self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                    self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                    self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                    self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                    self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                    self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                    self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                    self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                    self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                    self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                    self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                    self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                    self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                    self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                    self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                    self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                    self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                    self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                    self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                    self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                    self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                    self.register_count = YLeaf(YType.uint32, "register-count")

                    self.register_limit = YLeaf(YType.uint32, "register-limit")

                    self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                    self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                    self.route_count = YLeaf(YType.uint32, "route-count")

                    self.route_limit = YLeaf(YType.uint32, "route-limit")

                    self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                    self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                    self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                    self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                    self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                    self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                    self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.Summary, ['bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_threshold', 'bsr_range_threshold', 'bsr_ranges_count', 'bsr_ranges_limit', 'global_auto_rp_ranges_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_threshold', 'global_bsr_ranges_count', 'global_bsr_ranges_limit', 'global_bsr_ranges_threshold', 'global_register_limit', 'is_bsr_ranges_threshold_reached', 'is_global_auto_rp_ranges_limit_reached', 'is_global_bsr_ranges_limit_reached', 'is_global_register_limit_reached', 'is_global_route_limit_reached', 'is_global_rxi_limit_reached', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'is_ranges_limit_reached', 'is_route_limit_reached', 'ranges_count', 'ranges_limit', 'ranges_threshold', 'register_count', 'register_limit', 'register_limit_reached', 'register_threshold', 'route_count', 'route_limit', 'route_low_water_mark', 'route_threshold', 'rxi_limit_reached', 'rxi_low_water_mark', 'topology_interface_state_count', 'topology_interface_state_limit', 'topology_interface_state_threshold'], name, value)


            class TableContexts(Entity):
                """
                PIM table context list
                
                .. attribute:: table_context
                
                	PIM table context information
                	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TableContexts.TableContext>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.TableContexts, self).__init__()

                    self.yang_name = "table-contexts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"table-context" : ("table_context", Pim.Active.DefaultContext.TableContexts.TableContext)}

                    self.table_context = YList(self)
                    self._segment_path = lambda: "table-contexts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.TableContexts, [], name, value)


                class TableContext(Entity):
                    """
                    PIM table context information
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saf_name
                    
                    	SAF name
                    	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: topology_name
                    
                    	Topology name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.TableContexts.TableContext, self).__init__()

                        self.yang_name = "table-context"
                        self.yang_parent_name = "table-contexts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.uint32, "afi")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                        self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                        self.safi = YLeaf(YType.uint32, "safi")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.table_name = YLeaf(YType.str, "table-name")

                        self.topology_name = YLeaf(YType.str, "topology-name")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")
                        self._segment_path = lambda: "table-context"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/table-contexts/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.TableContexts.TableContext, ['afi', 'is_active', 'is_ital_registration_done', 'is_rib_convergence', 'is_rib_convergence_received', 'is_rib_registration_done', 'rpf_registrations', 'saf_name', 'safi', 'table_id', 'table_name', 'topology_name', 'vrf_id'], name, value)


            class Topologies(Entity):
                """
                PIM topology table
                
                .. attribute:: topology
                
                	PIM topology information
                	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Topologies, self).__init__()

                    self.yang_name = "topologies"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"topology" : ("topology", Pim.Active.DefaultContext.Topologies.Topology)}

                    self.topology = YList(self)
                    self._segment_path = lambda: "topologies"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.Topologies, [], name, value)


                class Topology(Entity):
                    """
                    PIM topology information
                    
                    .. attribute:: alive
                    
                    	Alive time in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: anycast_rp_match
                    
                    	Group matches Anycast\-RP policy
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_route_target
                    
                    	Anycast\-RP RT
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: assume_alive
                    
                    	The Assume Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: bgp_join
                    
                    	BGP C JOIN
                    	**type**\:  bool
                    
                    .. attribute:: bgp_jp_time
                    
                    	BGP C JP Time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: connected
                    
                    	Is Connected ?
                    	**type**\:  bool
                    
                    .. attribute:: crossed_threshold
                    
                    	Incoming traffic crossed threshold. MT flag set
                    	**type**\:  bool
                    
                    .. attribute:: customer_routing_type
                    
                    	Type of Customer Routing in the MVPN
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: data_mdt_addr_assigned
                    
                    	PIM has assigned a Data MDT Address
                    	**type**\:  bool
                    
                    .. attribute:: dont_check_connected
                    
                    	Do we need to make the connected check on this route ?
                    	**type**\:  bool
                    
                    .. attribute:: expiry
                    
                    	When this entry expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: extranet_route
                    
                    	Is a Extranet route ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr>`
                    
                    .. attribute:: inherit_alive
                    
                    	The Inherit Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: inherit_spt
                    
                    	The Inherit SPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: is_via_lsm
                    
                    	Via LSM
                    	**type**\:  bool
                    
                    .. attribute:: jp_status
                    
                    	Join\-Prune Status
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: jp_timer
                    
                    	Join\-Prune Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: kat_state
                    
                    	Keep Alive Timer State
                    	**type**\:  bool
                    
                    .. attribute:: last_hop
                    
                    	Are we last hop ?
                    	**type**\:  bool
                    
                    .. attribute:: limit_reached
                    
                    	Have we throttled the creation of routes or interfaces ?
                    	**type**\:  bool
                    
                    .. attribute:: low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_active
                    
                    	Is MoFRR Active?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_backup
                    
                    	Is this Mofrr Backup?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_primary
                    
                    	Is this Mofrr Primary?
                    	**type**\:  bool
                    
                    .. attribute:: orig_src_address
                    
                    	Orig Src Address
                    	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress>`
                    
                    .. attribute:: outgoing_interface
                    
                    	Outgoing interface list
                    	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface>`
                    
                    .. attribute:: probe_alive
                    
                    	The Probe Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: proxy
                    
                    	Is the RPF target a proxy?
                    	**type**\:  bool
                    
                    .. attribute:: proxy_address
                    
                    	RPF Proxy address
                    	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress>`
                    
                    .. attribute:: really_alive
                    
                    	The Really Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: register_received
                    
                    	Have registers been received for this source ?
                    	**type**\:  bool
                    
                    .. attribute:: register_received_timer
                    
                    	Register Received Timer in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: remote_source
                    
                    	MSDP told us
                    	**type**\:  bool
                    
                    .. attribute:: rib_mo_frr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rp_address
                    
                    	RP Address (If rpt)
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.RpAddress>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor>`
                    
                    .. attribute:: rpf_proxy_enabled
                    
                    	Is rpf if proxy enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: rpt
                    
                    	RPT bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpt_xr
                    
                    	Is this on the RPT ?
                    	**type**\:  bool
                    
                    .. attribute:: sa_joined
                    
                    	BGP SA join
                    	**type**\:  bool
                    
                    .. attribute:: sa_received
                    
                    	BGP SA received
                    	**type**\:  bool
                    
                    .. attribute:: sa_sent
                    
                    	BGP SA sent
                    	**type**\:  bool
                    
                    .. attribute:: secondary_rpf_interface_name
                    
                    	Secondary Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: secondary_rpf_neighbor
                    
                    	Secondary RPF Neighbor
                    	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor>`
                    
                    .. attribute:: sending_null_registers
                    
                    	Are we sending null registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: sending_registers
                    
                    	Are we sending registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: signal_sources
                    
                    	Signal Sources on route?
                    	**type**\:  bool
                    
                    .. attribute:: source_address
                    
                    	Source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr>`
                    
                    .. attribute:: spt
                    
                    	Is this on the SPT ?
                    	**type**\:  bool
                    
                    .. attribute:: suppress_registers
                    
                    	When the Null register probe expires
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: vxlan
                    
                    	Is this VXLAN?
                    	**type**\:  bool
                    
                    .. attribute:: wildcard
                    
                    	WC \-Wildcard
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Topologies.Topology, self).__init__()

                        self.yang_name = "topology"
                        self.yang_parent_name = "topologies"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr), "orig-src-address" : ("orig_src_address", Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress), "proxy-address" : ("proxy_address", Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress), "rp-address" : ("rp_address", Pim.Active.DefaultContext.Topologies.Topology.RpAddress), "rpf-neighbor" : ("rpf_neighbor", Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor), "rpf-root" : ("rpf_root", Pim.Active.DefaultContext.Topologies.Topology.RpfRoot), "secondary-rpf-neighbor" : ("secondary_rpf_neighbor", Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor), "source-address-xr" : ("source_address_xr", Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr)}
                        self._child_list_classes = {"outgoing-interface" : ("outgoing_interface", Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface)}

                        self.alive = YLeaf(YType.int32, "alive")

                        self.anycast_rp_match = YLeaf(YType.boolean, "anycast-rp-match")

                        self.anycast_rp_route_target = YLeaf(YType.str, "anycast-rp-route-target")

                        self.assume_alive = YLeaf(YType.boolean, "assume-alive")

                        self.bgp_join = YLeaf(YType.boolean, "bgp-join")

                        self.bgp_jp_time = YLeaf(YType.uint64, "bgp-jp-time")

                        self.connected = YLeaf(YType.boolean, "connected")

                        self.crossed_threshold = YLeaf(YType.boolean, "crossed-threshold")

                        self.customer_routing_type = YLeaf(YType.int32, "customer-routing-type")

                        self.data_mdt_addr_assigned = YLeaf(YType.boolean, "data-mdt-addr-assigned")

                        self.dont_check_connected = YLeaf(YType.boolean, "dont-check-connected")

                        self.expiry = YLeaf(YType.uint64, "expiry")

                        self.extranet_route = YLeaf(YType.boolean, "extranet-route")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.inherit_alive = YLeaf(YType.boolean, "inherit-alive")

                        self.inherit_spt = YLeaf(YType.boolean, "inherit-spt")

                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                        self.jp_status = YLeaf(YType.int32, "jp-status")

                        self.jp_timer = YLeaf(YType.int32, "jp-timer")

                        self.kat_state = YLeaf(YType.boolean, "kat-state")

                        self.last_hop = YLeaf(YType.boolean, "last-hop")

                        self.limit_reached = YLeaf(YType.boolean, "limit-reached")

                        self.low_memory = YLeaf(YType.boolean, "low-memory")

                        self.mofrr_active = YLeaf(YType.boolean, "mofrr-active")

                        self.mofrr_backup = YLeaf(YType.boolean, "mofrr-backup")

                        self.mofrr_enabled = YLeaf(YType.boolean, "mofrr-enabled")

                        self.mofrr_primary = YLeaf(YType.boolean, "mofrr-primary")

                        self.probe_alive = YLeaf(YType.boolean, "probe-alive")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.proxy = YLeaf(YType.boolean, "proxy")

                        self.really_alive = YLeaf(YType.boolean, "really-alive")

                        self.register_received = YLeaf(YType.boolean, "register-received")

                        self.register_received_timer = YLeaf(YType.int32, "register-received-timer")

                        self.remote_source = YLeaf(YType.boolean, "remote-source")

                        self.rib_mo_frr_enabled = YLeaf(YType.boolean, "rib-mo-frr-enabled")

                        self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                        self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_proxy_enabled = YLeaf(YType.boolean, "rpf-proxy-enabled")

                        self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                        self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.rpt = YLeaf(YType.int32, "rpt")

                        self.rpt_xr = YLeaf(YType.boolean, "rpt-xr")

                        self.sa_joined = YLeaf(YType.boolean, "sa-joined")

                        self.sa_received = YLeaf(YType.boolean, "sa-received")

                        self.sa_sent = YLeaf(YType.boolean, "sa-sent")

                        self.secondary_rpf_interface_name = YLeaf(YType.str, "secondary-rpf-interface-name")

                        self.sending_null_registers = YLeaf(YType.boolean, "sending-null-registers")

                        self.sending_registers = YLeaf(YType.boolean, "sending-registers")

                        self.signal_sources = YLeaf(YType.boolean, "signal-sources")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.spt = YLeaf(YType.boolean, "spt")

                        self.suppress_registers = YLeaf(YType.int32, "suppress-registers")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.vxlan = YLeaf(YType.boolean, "vxlan")

                        self.wildcard = YLeaf(YType.boolean, "wildcard")

                        self.group_address_xr = Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.orig_src_address = Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress()
                        self.orig_src_address.parent = self
                        self._children_name_map["orig_src_address"] = "orig-src-address"
                        self._children_yang_names.add("orig-src-address")

                        self.proxy_address = Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress()
                        self.proxy_address.parent = self
                        self._children_name_map["proxy_address"] = "proxy-address"
                        self._children_yang_names.add("proxy-address")

                        self.rp_address = Pim.Active.DefaultContext.Topologies.Topology.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.rpf_neighbor = Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                        self.rpf_root = Pim.Active.DefaultContext.Topologies.Topology.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._children_yang_names.add("rpf-root")

                        self.secondary_rpf_neighbor = Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                        self.secondary_rpf_neighbor.parent = self
                        self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                        self._children_yang_names.add("secondary-rpf-neighbor")

                        self.source_address_xr = Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"
                        self._children_yang_names.add("source-address-xr")

                        self.outgoing_interface = YList(self)
                        self._segment_path = lambda: "topology"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology, ['alive', 'anycast_rp_match', 'anycast_rp_route_target', 'assume_alive', 'bgp_join', 'bgp_jp_time', 'connected', 'crossed_threshold', 'customer_routing_type', 'data_mdt_addr_assigned', 'dont_check_connected', 'expiry', 'extranet_route', 'group_address', 'inherit_alive', 'inherit_spt', 'is_via_lsm', 'jp_status', 'jp_timer', 'kat_state', 'last_hop', 'limit_reached', 'low_memory', 'mofrr_active', 'mofrr_backup', 'mofrr_enabled', 'mofrr_primary', 'probe_alive', 'protocol', 'proxy', 'really_alive', 'register_received', 'register_received_timer', 'remote_source', 'rib_mo_frr_enabled', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_proxy_enabled', 'rpf_safi', 'rpf_table_name', 'rpf_vrf_name', 'rpt', 'rpt_xr', 'sa_joined', 'sa_received', 'sa_sent', 'secondary_rpf_interface_name', 'sending_null_registers', 'sending_registers', 'signal_sources', 'source_address', 'spt', 'suppress_registers', 'uptime', 'vxlan', 'wildcard'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class OrigSrcAddress(Entity):
                        """
                        Orig Src Address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__init__()

                            self.yang_name = "orig-src-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "orig-src-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class OutgoingInterface(Entity):
                        """
                        Outgoing interface list
                        
                        .. attribute:: admin_boundary
                        
                        	Is this an administrative boundary ?
                        	**type**\:  bool
                        
                        .. attribute:: assert_state
                        
                        	Assert State
                        	**type**\:  bool
                        
                        .. attribute:: assert_timer
                        
                        	Assert Timer in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: assert_winner
                        
                        	Assert Winner
                        	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner>`
                        
                        .. attribute:: bgp_c_mcast_join
                        
                        	BGP C\-Mcast join
                        	**type**\:  bool
                        
                        .. attribute:: bgp_c_mcast_prune_delay_timer
                        
                        	BGP C\-MCAST Prune Suppression in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: data_mdt_join
                        
                        	Data MDT join
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	Expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: extranet_interface
                        
                        	Is this an Extranet Interface ?
                        	**type**\:  bool
                        
                        .. attribute:: forwarding_state
                        
                        	Forward or Prune
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: igmp_membership
                        
                        	IGMP membership
                        	**type**\:  bool
                        
                        .. attribute:: immediate_state
                        
                        	Immediate fwding state
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: internal_interest_info
                        
                        	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: internal_interest_information
                        
                        	Internal Interest. Replaces internal\-interest\-info
                        	**type**\:   :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                        
                        .. attribute:: jp_state
                        
                        	Join\-Prune State
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer (secs)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: local_mdt_join
                        
                        	Default MDT Join
                        	**type**\:  bool
                        
                        .. attribute:: local_members
                        
                        	Local Information. Deprecated \- use 'local\-members\-information' instead
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: local_members_information
                        
                        	Local Information. Replaces local\-members
                        	**type**\:   :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                        
                        .. attribute:: mdt_safi_join
                        
                        	MDT Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mldp_inband_mdt
                        
                        	MLDP Inband MDT interface
                        	**type**\:  bool
                        
                        .. attribute:: mldp_stale
                        
                        	OLE is stale
                        	**type**\:  bool
                        
                        .. attribute:: mvpn_safi_join
                        
                        	MVPN Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mvpnv6_safi_join
                        
                        	MVPN IPv6 Safi join
                        	**type**\:  bool
                        
                        .. attribute:: sa_prune
                        
                        	BGP SA Prune state
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vrf_name
                        
                        	VRF which physically owns
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface, self).__init__()

                            self.yang_name = "outgoing-interface"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"assert-winner" : ("assert_winner", Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner)}
                            self._child_list_classes = {}

                            self.admin_boundary = YLeaf(YType.boolean, "admin-boundary")

                            self.assert_state = YLeaf(YType.boolean, "assert-state")

                            self.assert_timer = YLeaf(YType.int32, "assert-timer")

                            self.bgp_c_mcast_join = YLeaf(YType.boolean, "bgp-c-mcast-join")

                            self.bgp_c_mcast_prune_delay_timer = YLeaf(YType.uint64, "bgp-c-mcast-prune-delay-timer")

                            self.data_mdt_join = YLeaf(YType.boolean, "data-mdt-join")

                            self.expiry = YLeaf(YType.uint64, "expiry")

                            self.extranet_interface = YLeaf(YType.boolean, "extranet-interface")

                            self.forwarding_state = YLeaf(YType.int32, "forwarding-state")

                            self.igmp_membership = YLeaf(YType.boolean, "igmp-membership")

                            self.immediate_state = YLeaf(YType.int32, "immediate-state")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.internal_interest_info = YLeaf(YType.int32, "internal-interest-info")

                            self.internal_interest_information = YLeaf(YType.enumeration, "internal-interest-information")

                            self.jp_state = YLeaf(YType.int32, "jp-state")

                            self.jp_timer = YLeaf(YType.int32, "jp-timer")

                            self.last_hop = YLeaf(YType.boolean, "last-hop")

                            self.local_mdt_join = YLeaf(YType.boolean, "local-mdt-join")

                            self.local_members = YLeaf(YType.int32, "local-members")

                            self.local_members_information = YLeaf(YType.enumeration, "local-members-information")

                            self.mdt_safi_join = YLeaf(YType.boolean, "mdt-safi-join")

                            self.mldp_inband_mdt = YLeaf(YType.boolean, "mldp-inband-mdt")

                            self.mldp_stale = YLeaf(YType.boolean, "mldp-stale")

                            self.mvpn_safi_join = YLeaf(YType.boolean, "mvpn-safi-join")

                            self.mvpnv6_safi_join = YLeaf(YType.boolean, "mvpnv6-safi-join")

                            self.sa_prune = YLeaf(YType.boolean, "sa-prune")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.assert_winner = Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                            self.assert_winner.parent = self
                            self._children_name_map["assert_winner"] = "assert-winner"
                            self._children_yang_names.add("assert-winner")
                            self._segment_path = lambda: "outgoing-interface"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface, ['admin_boundary', 'assert_state', 'assert_timer', 'bgp_c_mcast_join', 'bgp_c_mcast_prune_delay_timer', 'data_mdt_join', 'expiry', 'extranet_interface', 'forwarding_state', 'igmp_membership', 'immediate_state', 'interface_name', 'internal_interest_info', 'internal_interest_information', 'jp_state', 'jp_timer', 'last_hop', 'local_mdt_join', 'local_members', 'local_members_information', 'mdt_safi_join', 'mldp_inband_mdt', 'mldp_stale', 'mvpn_safi_join', 'mvpnv6_safi_join', 'sa_prune', 'uptime', 'vrf_name'], name, value)


                        class AssertWinner(Entity):
                            """
                            Assert Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                self.yang_name = "assert-winner"
                                self.yang_parent_name = "outgoing-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "assert-winner"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/outgoing-interface/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class ProxyAddress(Entity):
                        """
                        RPF Proxy address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress, self).__init__()

                            self.yang_name = "proxy-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "proxy-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address (If rpt)
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-root"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.RpfRoot, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SecondaryRpfNeighbor(Entity):
                        """
                        Secondary RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                            self.yang_name = "secondary-rpf-neighbor"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "secondary-rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class TopologyEntryFlagRouteCounts(Entity):
                """
                Route count for topology with entry flag set
                
                .. attribute:: topology_entry_flag_route_count
                
                	Route count for topology with entry flag set
                	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-entry-flag-route-counts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"topology-entry-flag-route-count" : ("topology_entry_flag_route_count", Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount)}

                    self.topology_entry_flag_route_count = YList(self)
                    self._segment_path = lambda: "topology-entry-flag-route-counts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts, [], name, value)


                class TopologyEntryFlagRouteCount(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: entry_flag  <key>
                    
                    	entry flag
                    	**type**\:   :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                        self.yang_name = "topology-entry-flag-route-count"
                        self.yang_parent_name = "topology-entry-flag-route-counts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.entry_flag = YLeaf(YType.enumeration, "entry-flag")

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                        self._segment_path = lambda: "topology-entry-flag-route-count" + "[entry-flag='" + self.entry_flag.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topology-entry-flag-route-counts/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, ['entry_flag', 'active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


            class TopologyInterfaceFlagRouteCounts(Entity):
                """
                Route count for topology with interface flag set
                
                .. attribute:: topology_interface_flag_route_count
                
                	Route count for topology with interface flag set
                	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-interface-flag-route-counts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"topology-interface-flag-route-count" : ("topology_interface_flag_route_count", Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount)}

                    self.topology_interface_flag_route_count = YList(self)
                    self._segment_path = lambda: "topology-interface-flag-route-counts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts, [], name, value)


                class TopologyInterfaceFlagRouteCount(Entity):
                    """
                    Route count for topology with interface flag
                    set
                    
                    .. attribute:: interface_flag  <key>
                    
                    	Interface flag
                    	**type**\:   :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                        self.yang_name = "topology-interface-flag-route-count"
                        self.yang_parent_name = "topology-interface-flag-route-counts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.interface_flag = YLeaf(YType.enumeration, "interface-flag")

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                        self._segment_path = lambda: "topology-interface-flag-route-count" + "[interface-flag='" + self.interface_flag.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topology-interface-flag-route-counts/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, ['interface_flag', 'active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


            class TopologyRouteCount(Entity):
                """
                Topology route count information from PIM
                topology table
                
                .. attribute:: active_group_ranges
                
                	No. of (\*,G/M) routes active in mrib
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_ranges
                
                	No. of (\*,G/M) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groute_count
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: sg_route_count
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sgr_route_count
                
                	No. of (S,G)RPT routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.TopologyRouteCount, self).__init__()

                    self.yang_name = "topology-route-count"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                    self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                    self.groute_count = YLeaf(YType.uint32, "groute-count")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                    self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                    self._segment_path = lambda: "topology-route-count"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.TopologyRouteCount, ['active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


            class TrafficCounters(Entity):
                """
                PIM message traffic counters
                
                .. attribute:: boundary_acl_rx_drop
                
                	Inc. JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_tx_drop
                
                	Out JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_error
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: format_error
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert
                
                	Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert_batched
                
                	Batched Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_bsr_message
                
                	Input BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_candidate_rp_advertisement
                
                	Input Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_data_register
                
                	Data Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_df_election
                
                	DF Election packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_ecmp_redirect
                
                	Input Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_hello
                
                	Hello packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_jp
                
                	Join Prune packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb_error
                
                	No IDB for intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_pim_error
                
                	PIM Disabled on intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_error
                
                	No VRF for idb error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_null_register
                
                	Null Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim_version_error
                
                	Invalid PIM version error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_register_stop
                
                	Register Stop packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: inputs
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_destination_packets
                
                	Control Packets with Invalid Destination
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_join_prunes
                
                	PIM invalid Join/Prunes received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_registers
                
                	PIM invalid registers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_local_source_address
                
                	Data MDT Join msgs dropped due to local source addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_idb
                
                	Data MDT Join msgs dropped due to idb missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_vrf
                
                	Data MDT Join msgs dropped due to vrf missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_null_local_address
                
                	Data MDT Join msgs dropped due to null local addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_bad_type
                
                	Data MDT TLV bad type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_received
                
                	Data MDT Join Msgs received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_sent
                
                	Data MDT Join Msgs sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_joins_drop_multiple_encapsulation
                
                	MDT Join msgs dropped due to multiple Encap limitation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_send_queue_full
                
                	Packets dropped since mdt send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_socket_error
                
                	MDT Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_invalid_lsm_identifier
                
                	 Invalid LSM ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_mdt_socket_connection
                
                	Packets dropped since no mdt socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_source_address
                
                	Packets dropped since no source address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: non_supported_packets
                
                	PIM non supported pckets
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert
                
                	Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert_batched
                
                	Batched Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_bsr_message
                
                	Output BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_candidate_rp_advertisement
                
                	Output Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_data_register
                
                	Data Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_df_election
                
                	DF Election packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_ecmp_redirect
                
                	Output Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello
                
                	Hello packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello_bytes
                
                	Output Hello Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_join_group
                
                	Output Join Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_prune_bytes
                
                	Output JP Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_jp
                
                	Join Prune packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_loop_error
                
                	Output on loopback error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_null_register
                
                	Null Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_prune_group
                
                	Output Prune Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_register_stop
                
                	Register Stop packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outputs
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_packman_error
                
                	Packets Dropped due to Pakman Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue
                
                	Packet queue state and statistics
                	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TrafficCounters.PacketQueue>`
                
                .. attribute:: packet_queue_last_clear
                
                	Time in seconds since the last clear of all packet queues stats
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: packet_read_socket_error
                
                	Packet Read Socket Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_standby
                
                	Packets Dropped due to Standby Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pakman_error
                
                	Pakman packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_queue_full
                
                	Packets dropped since send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_error
                
                	Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_packets_error
                
                	Packets received in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: truncated_pim_packets
                
                	Packets dropped due to truncated Joins or Prunes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"packet-queue" : ("packet_queue", Pim.Active.DefaultContext.TrafficCounters.PacketQueue)}

                    self.boundary_acl_rx_drop = YLeaf(YType.uint32, "boundary-acl-rx-drop")

                    self.boundary_acl_tx_drop = YLeaf(YType.uint32, "boundary-acl-tx-drop")

                    self.checksum_error = YLeaf(YType.uint32, "checksum-error")

                    self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                    self.format_error = YLeaf(YType.uint32, "format-error")

                    self.input_assert = YLeaf(YType.uint32, "input-assert")

                    self.input_assert_batched = YLeaf(YType.uint32, "input-assert-batched")

                    self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                    self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                    self.input_data_register = YLeaf(YType.uint32, "input-data-register")

                    self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                    self.input_ecmp_redirect = YLeaf(YType.uint32, "input-ecmp-redirect")

                    self.input_hello = YLeaf(YType.uint32, "input-hello")

                    self.input_jp = YLeaf(YType.uint32, "input-jp")

                    self.input_no_idb_error = YLeaf(YType.uint32, "input-no-idb-error")

                    self.input_no_pim_error = YLeaf(YType.uint32, "input-no-pim-error")

                    self.input_no_vrf_error = YLeaf(YType.uint32, "input-no-vrf-error")

                    self.input_null_register = YLeaf(YType.uint32, "input-null-register")

                    self.input_pim_version_error = YLeaf(YType.uint32, "input-pim-version-error")

                    self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                    self.inputs = YLeaf(YType.uint32, "inputs")

                    self.invalid_destination_packets = YLeaf(YType.uint32, "invalid-destination-packets")

                    self.invalid_join_prunes = YLeaf(YType.uint32, "invalid-join-prunes")

                    self.invalid_registers = YLeaf(YType.uint32, "invalid-registers")

                    self.mdt_drop_local_source_address = YLeaf(YType.uint32, "mdt-drop-local-source-address")

                    self.mdt_drop_no_idb = YLeaf(YType.uint32, "mdt-drop-no-idb")

                    self.mdt_drop_no_vrf = YLeaf(YType.uint32, "mdt-drop-no-vrf")

                    self.mdt_drop_null_local_address = YLeaf(YType.uint32, "mdt-drop-null-local-address")

                    self.mdt_join_bad_type = YLeaf(YType.uint32, "mdt-join-bad-type")

                    self.mdt_join_tlv_received = YLeaf(YType.uint32, "mdt-join-tlv-received")

                    self.mdt_join_tlv_sent = YLeaf(YType.uint32, "mdt-join-tlv-sent")

                    self.mdt_joins_drop_multiple_encapsulation = YLeaf(YType.uint32, "mdt-joins-drop-multiple-encapsulation")

                    self.mdt_send_queue_full = YLeaf(YType.uint32, "mdt-send-queue-full")

                    self.mdt_socket_error = YLeaf(YType.uint32, "mdt-socket-error")

                    self.mldp_mdt_invalid_lsm_identifier = YLeaf(YType.uint32, "mldp-mdt-invalid-lsm-identifier")

                    self.no_mdt_socket_connection = YLeaf(YType.uint32, "no-mdt-socket-connection")

                    self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                    self.no_source_address = YLeaf(YType.uint32, "no-source-address")

                    self.non_supported_packets = YLeaf(YType.uint32, "non-supported-packets")

                    self.output_assert = YLeaf(YType.uint32, "output-assert")

                    self.output_assert_batched = YLeaf(YType.uint32, "output-assert-batched")

                    self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                    self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                    self.output_data_register = YLeaf(YType.uint32, "output-data-register")

                    self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                    self.output_ecmp_redirect = YLeaf(YType.uint32, "output-ecmp-redirect")

                    self.output_hello = YLeaf(YType.uint32, "output-hello")

                    self.output_hello_bytes = YLeaf(YType.uint32, "output-hello-bytes")

                    self.output_join_group = YLeaf(YType.uint32, "output-join-group")

                    self.output_join_prune_bytes = YLeaf(YType.uint32, "output-join-prune-bytes")

                    self.output_jp = YLeaf(YType.uint32, "output-jp")

                    self.output_loop_error = YLeaf(YType.uint32, "output-loop-error")

                    self.output_null_register = YLeaf(YType.uint32, "output-null-register")

                    self.output_prune_group = YLeaf(YType.uint32, "output-prune-group")

                    self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                    self.outputs = YLeaf(YType.uint32, "outputs")

                    self.packet_packman_error = YLeaf(YType.uint32, "packet-packman-error")

                    self.packet_queue_last_clear = YLeaf(YType.uint32, "packet-queue-last-clear")

                    self.packet_read_socket_error = YLeaf(YType.uint32, "packet-read-socket-error")

                    self.packets_standby = YLeaf(YType.uint32, "packets-standby")

                    self.pakman_error = YLeaf(YType.uint32, "pakman-error")

                    self.send_queue_full = YLeaf(YType.uint32, "send-queue-full")

                    self.socket_error = YLeaf(YType.uint32, "socket-error")

                    self.standby_packets_error = YLeaf(YType.uint32, "standby-packets-error")

                    self.truncated_pim_packets = YLeaf(YType.uint32, "truncated-pim-packets")

                    self.packet_queue = YList(self)
                    self._segment_path = lambda: "traffic-counters"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.TrafficCounters, ['boundary_acl_rx_drop', 'boundary_acl_tx_drop', 'checksum_error', 'elapsed_time', 'format_error', 'input_assert', 'input_assert_batched', 'input_bsr_message', 'input_candidate_rp_advertisement', 'input_data_register', 'input_df_election', 'input_ecmp_redirect', 'input_hello', 'input_jp', 'input_no_idb_error', 'input_no_pim_error', 'input_no_vrf_error', 'input_null_register', 'input_pim_version_error', 'input_register_stop', 'inputs', 'invalid_destination_packets', 'invalid_join_prunes', 'invalid_registers', 'mdt_drop_local_source_address', 'mdt_drop_no_idb', 'mdt_drop_no_vrf', 'mdt_drop_null_local_address', 'mdt_join_bad_type', 'mdt_join_tlv_received', 'mdt_join_tlv_sent', 'mdt_joins_drop_multiple_encapsulation', 'mdt_send_queue_full', 'mdt_socket_error', 'mldp_mdt_invalid_lsm_identifier', 'no_mdt_socket_connection', 'no_socket_connection', 'no_source_address', 'non_supported_packets', 'output_assert', 'output_assert_batched', 'output_bsr_message', 'output_candidate_rp_advertisement', 'output_data_register', 'output_df_election', 'output_ecmp_redirect', 'output_hello', 'output_hello_bytes', 'output_join_group', 'output_join_prune_bytes', 'output_jp', 'output_loop_error', 'output_null_register', 'output_prune_group', 'output_register_stop', 'outputs', 'packet_packman_error', 'packet_queue_last_clear', 'packet_read_socket_error', 'packets_standby', 'pakman_error', 'send_queue_full', 'socket_error', 'standby_packets_error', 'truncated_pim_packets'], name, value)


                class PacketQueue(Entity):
                    """
                    Packet queue state and statistics
                    
                    .. attribute:: packet_queue_priority
                    
                    	Priority of this packet queue
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_state
                    
                    	State of the queue
                    	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState>`
                    
                    .. attribute:: packet_queue_stats
                    
                    	Statistics about the queue
                    	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.TrafficCounters.PacketQueue, self).__init__()

                        self.yang_name = "packet-queue"
                        self.yang_parent_name = "traffic-counters"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"packet-queue-state" : ("packet_queue_state", Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState), "packet-queue-stats" : ("packet_queue_stats", Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats)}
                        self._child_list_classes = {}

                        self.packet_queue_priority = YLeaf(YType.uint32, "packet-queue-priority")

                        self.packet_queue_state = Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                        self.packet_queue_state.parent = self
                        self._children_name_map["packet_queue_state"] = "packet-queue-state"
                        self._children_yang_names.add("packet-queue-state")

                        self.packet_queue_stats = Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                        self.packet_queue_stats.parent = self
                        self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                        self._children_yang_names.add("packet-queue-stats")
                        self._segment_path = lambda: "packet-queue"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/traffic-counters/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.TrafficCounters.PacketQueue, ['packet_queue_priority'], name, value)


                    class PacketQueueState(Entity):
                        """
                        State of the queue
                        
                        .. attribute:: max_queue_size
                        
                        	Maximum size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_bytes
                        
                        	Size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_packets
                        
                        	Size of queue in number of packets
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                            self.yang_name = "packet-queue-state"
                            self.yang_parent_name = "packet-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.max_queue_size = YLeaf(YType.uint32, "max-queue-size")

                            self.queue_size_bytes = YLeaf(YType.uint32, "queue-size-bytes")

                            self.queue_size_packets = YLeaf(YType.uint32, "queue-size-packets")
                            self._segment_path = lambda: "packet-queue-state"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/traffic-counters/packet-queue/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, ['max_queue_size', 'queue_size_bytes', 'queue_size_packets'], name, value)


                    class PacketQueueStats(Entity):
                        """
                        Statistics about the queue
                        
                        .. attribute:: dequeued_packets
                        
                        	Total number of packets dequeued from this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: enqueued_packets
                        
                        	Total number of packets enqueued to this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_bytes
                        
                        	Highest number of bytes enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: high_water_mark_packets
                        
                        	Highest number of packets enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tail_drops
                        
                        	Number packets dropped from this queue due to max size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                            self.yang_name = "packet-queue-stats"
                            self.yang_parent_name = "packet-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.dequeued_packets = YLeaf(YType.uint32, "dequeued-packets")

                            self.enqueued_packets = YLeaf(YType.uint32, "enqueued-packets")

                            self.high_water_mark_bytes = YLeaf(YType.uint32, "high-water-mark-bytes")

                            self.high_water_mark_packets = YLeaf(YType.uint32, "high-water-mark-packets")

                            self.tail_drops = YLeaf(YType.uint32, "tail-drops")
                            self._segment_path = lambda: "packet-queue-stats"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/traffic-counters/packet-queue/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, ['dequeued_packets', 'enqueued_packets', 'high_water_mark_bytes', 'high_water_mark_packets', 'tail_drops'], name, value)


            class Tunnels(Entity):
                """
                Tunnels information that PIM has
                
                .. attribute:: tunnel
                
                	PIM tunnel information
                	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Tunnels, self).__init__()

                    self.yang_name = "tunnels"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"tunnel" : ("tunnel", Pim.Active.DefaultContext.Tunnels.Tunnel)}

                    self.tunnel = YList(self)
                    self._segment_path = lambda: "tunnels"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.Tunnels, [], name, value)


                class Tunnel(Entity):
                    """
                    PIM tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Tunnels.Tunnel, self).__init__()

                        self.yang_name = "tunnel"
                        self.yang_parent_name = "tunnels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-netio" : ("group_address_netio", Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio), "rp-address" : ("rp_address", Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress), "source-address" : ("source_address", Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress), "source-address-netio" : ("source_address_netio", Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio)}
                        self._child_list_classes = {}

                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.group_address_netio = Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._children_yang_names.add("group-address-netio")

                        self.rp_address = Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                        self.source_address_netio = Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"
                        self._children_yang_names.add("source-address-netio")
                        self._segment_path = lambda: "tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/tunnels/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Tunnels.Tunnel, ['tunnel_name', 'vrf_name'], name, value)


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-netio"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address-netio"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


        class Process(Entity):
            """
            Process
            
            .. attribute:: issu
            
            	ISSU Information
            	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.Issu>`
            
            .. attribute:: nsf
            
            	PIM NSF information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.Nsr>`
            
            .. attribute:: summary
            
            	PIM Global Summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.Summary>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Pim.Active.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"issu" : ("issu", Pim.Active.Process.Issu), "nsf" : ("nsf", Pim.Active.Process.Nsf), "nsr" : ("nsr", Pim.Active.Process.Nsr), "summary" : ("summary", Pim.Active.Process.Summary)}
                self._child_list_classes = {}

                self.issu = Pim.Active.Process.Issu()
                self.issu.parent = self
                self._children_name_map["issu"] = "issu"
                self._children_yang_names.add("issu")

                self.nsf = Pim.Active.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"
                self._children_yang_names.add("nsf")

                self.nsr = Pim.Active.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
                self._children_yang_names.add("nsr")

                self.summary = Pim.Active.Process.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")
                self._segment_path = lambda: "process"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/%s" % self._segment_path()


            class Issu(Entity):
                """
                ISSU Information
                
                .. attribute:: checkpoint_idt_timestamp
                
                	Time when Checkpoint IDT done
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: eoc_received_timestamp
                
                	Time when EOC was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: ihms_received_timestamp
                
                	Time when IHMS done was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: informationvalid
                
                	Is Information valid ?
                	**type**\:  bool
                
                .. attribute:: is_checkpoint_idt_done
                
                	Was Checkpoint IDT done ?
                	**type**\:  bool
                
                .. attribute:: is_eoc_received
                
                	Was EOC received ?
                	**type**\:  bool
                
                .. attribute:: is_ihms_done_received
                
                	Was IHMS done received ?
                	**type**\:  bool
                
                .. attribute:: is_nbr_sync_received
                
                	Was NBR Sync achieved ?
                	**type**\:  bool
                
                .. attribute:: is_rib_sync_received
                
                	Was RIB Sync received ?
                	**type**\:  bool
                
                .. attribute:: last_ha_role_notification_received
                
                	Time when last HA role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_phase_notification_received
                
                	Time when last ISSU Phase nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_role_notification_received
                
                	Time when last ISSU role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: nbr_sync_received_timestamp
                
                	Time when NBR Sync was achieved
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: phase_issu
                
                	ISSU Phase
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: rib_sync_received_timestamp
                
                	Time when RIB Sync was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: role_ha
                
                	HA role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: role_issu
                
                	ISSU role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.Process.Issu, self).__init__()

                    self.yang_name = "issu"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.checkpoint_idt_timestamp = YLeaf(YType.uint64, "checkpoint-idt-timestamp")

                    self.eoc_received_timestamp = YLeaf(YType.uint64, "eoc-received-timestamp")

                    self.ihms_received_timestamp = YLeaf(YType.uint64, "ihms-received-timestamp")

                    self.informationvalid = YLeaf(YType.boolean, "informationvalid")

                    self.is_checkpoint_idt_done = YLeaf(YType.boolean, "is-checkpoint-idt-done")

                    self.is_eoc_received = YLeaf(YType.boolean, "is-eoc-received")

                    self.is_ihms_done_received = YLeaf(YType.boolean, "is-ihms-done-received")

                    self.is_nbr_sync_received = YLeaf(YType.boolean, "is-nbr-sync-received")

                    self.is_rib_sync_received = YLeaf(YType.boolean, "is-rib-sync-received")

                    self.last_ha_role_notification_received = YLeaf(YType.uint64, "last-ha-role-notification-received")

                    self.last_issu_phase_notification_received = YLeaf(YType.uint64, "last-issu-phase-notification-received")

                    self.last_issu_role_notification_received = YLeaf(YType.uint64, "last-issu-role-notification-received")

                    self.nbr_sync_received_timestamp = YLeaf(YType.uint64, "nbr-sync-received-timestamp")

                    self.phase_issu = YLeaf(YType.int32, "phase-issu")

                    self.rib_sync_received_timestamp = YLeaf(YType.uint64, "rib-sync-received-timestamp")

                    self.role_ha = YLeaf(YType.int32, "role-ha")

                    self.role_issu = YLeaf(YType.int32, "role-issu")
                    self._segment_path = lambda: "issu"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.Process.Issu, ['checkpoint_idt_timestamp', 'eoc_received_timestamp', 'ihms_received_timestamp', 'informationvalid', 'is_checkpoint_idt_done', 'is_eoc_received', 'is_ihms_done_received', 'is_nbr_sync_received', 'is_rib_sync_received', 'last_ha_role_notification_received', 'last_issu_phase_notification_received', 'last_issu_role_notification_received', 'nbr_sync_received_timestamp', 'phase_issu', 'rib_sync_received_timestamp', 'role_ha', 'role_issu'], name, value)


            class Nsf(Entity):
                """
                PIM NSF information
                
                .. attribute:: configured_state
                
                	Is Multicast NSF Configured
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_sec
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_sec
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_sec
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: nsf_state
                
                	Are we currently in NSF
                	**type**\:  bool
                
                .. attribute:: nsf_time_left
                
                	Multicast NSF time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: nsf_timeout
                
                	Multicast NSF timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: waiting_membership
                
                	Waiting for IGMP/MLD
                	**type**\:  bool
                
                .. attribute:: waiting_timer
                
                	Waiting for NSF timer expiry
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.configured_state = YLeaf(YType.boolean, "configured-state")

                    self.last_icd_notif_recv = YLeaf(YType.int64, "last-icd-notif-recv")

                    self.last_icd_notif_recv_sec = YLeaf(YType.int32, "last-icd-notif-recv-sec")

                    self.last_nsf_off = YLeaf(YType.int64, "last-nsf-off")

                    self.last_nsf_off_sec = YLeaf(YType.int32, "last-nsf-off-sec")

                    self.last_nsf_on = YLeaf(YType.int64, "last-nsf-on")

                    self.last_nsf_on_sec = YLeaf(YType.int32, "last-nsf-on-sec")

                    self.nsf_state = YLeaf(YType.boolean, "nsf-state")

                    self.nsf_time_left = YLeaf(YType.uint32, "nsf-time-left")

                    self.nsf_timeout = YLeaf(YType.uint32, "nsf-timeout")

                    self.respawn_count = YLeaf(YType.uint32, "respawn-count")

                    self.waiting_membership = YLeaf(YType.boolean, "waiting-membership")

                    self.waiting_timer = YLeaf(YType.boolean, "waiting-timer")
                    self._segment_path = lambda: "nsf"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.Process.Nsf, ['configured_state', 'last_icd_notif_recv', 'last_icd_notif_recv_sec', 'last_nsf_off', 'last_nsf_off_sec', 'last_nsf_on', 'last_nsf_on_sec', 'nsf_state', 'nsf_time_left', 'nsf_timeout', 'respawn_count', 'waiting_membership', 'waiting_timer'], name, value)


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: count_connection_dn
                
                	No. of times connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_connection_up
                
                	No. of times connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_connection_dn
                
                	Time when connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_up
                
                	Time when connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: rmf_timer_expiry
                
                	Time for RMF timer to expire
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: rmf_timer_valid
                
                	Is RMF timer running ?
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.count_connection_dn = YLeaf(YType.uint32, "count-connection-dn")

                    self.count_connection_up = YLeaf(YType.uint32, "count-connection-up")

                    self.count_rmf_not_ready = YLeaf(YType.uint32, "count-rmf-not-ready")

                    self.count_rmf_ready = YLeaf(YType.uint32, "count-rmf-ready")

                    self.last_connection_dn = YLeaf(YType.uint64, "last-connection-dn")

                    self.last_connection_up = YLeaf(YType.uint64, "last-connection-up")

                    self.last_rmf_not_ready = YLeaf(YType.uint64, "last-rmf-not-ready")

                    self.last_rmf_ready = YLeaf(YType.uint64, "last-rmf-ready")

                    self.partner_connected = YLeaf(YType.boolean, "partner-connected")

                    self.rmf_notification_done = YLeaf(YType.boolean, "rmf-notification-done")

                    self.rmf_timer_expiry = YLeaf(YType.uint64, "rmf-timer-expiry")

                    self.rmf_timer_valid = YLeaf(YType.boolean, "rmf-timer-valid")

                    self.state = YLeaf(YType.uint8, "state")
                    self._segment_path = lambda: "nsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.Process.Nsr, ['count_connection_dn', 'count_connection_up', 'count_rmf_not_ready', 'count_rmf_ready', 'last_connection_dn', 'last_connection_up', 'last_rmf_not_ready', 'last_rmf_ready', 'partner_connected', 'rmf_notification_done', 'rmf_timer_expiry', 'rmf_timer_valid', 'state'], name, value)


            class Summary(Entity):
                """
                PIM Global Summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.Process.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                    self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                    self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                    self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                    self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                    self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                    self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                    self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                    self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                    self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                    self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                    self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                    self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                    self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                    self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                    self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                    self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                    self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                    self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                    self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                    self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                    self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                    self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                    self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                    self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                    self.register_count = YLeaf(YType.uint32, "register-count")

                    self.register_limit = YLeaf(YType.uint32, "register-limit")

                    self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                    self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                    self.route_count = YLeaf(YType.uint32, "route-count")

                    self.route_limit = YLeaf(YType.uint32, "route-limit")

                    self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                    self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                    self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                    self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                    self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                    self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                    self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.Process.Summary, ['bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_threshold', 'bsr_range_threshold', 'bsr_ranges_count', 'bsr_ranges_limit', 'global_auto_rp_ranges_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_threshold', 'global_bsr_ranges_count', 'global_bsr_ranges_limit', 'global_bsr_ranges_threshold', 'global_register_limit', 'is_bsr_ranges_threshold_reached', 'is_global_auto_rp_ranges_limit_reached', 'is_global_bsr_ranges_limit_reached', 'is_global_register_limit_reached', 'is_global_route_limit_reached', 'is_global_rxi_limit_reached', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'is_ranges_limit_reached', 'is_route_limit_reached', 'ranges_count', 'ranges_limit', 'ranges_threshold', 'register_count', 'register_limit', 'register_limit_reached', 'register_threshold', 'route_count', 'route_limit', 'route_low_water_mark', 'route_threshold', 'rxi_limit_reached', 'rxi_low_water_mark', 'topology_interface_state_count', 'topology_interface_state_limit', 'topology_interface_state_threshold'], name, value)


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF name
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Pim.Active.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"vrf" : ("vrf", Pim.Active.Vrfs.Vrf)}

                self.vrf = YList(self)
                self._segment_path = lambda: "vrfs"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Pim.Active.Vrfs, [], name, value)


            class Vrf(Entity):
                """
                VRF name
                
                .. attribute:: vrf_name  <key>
                
                	VRF name 
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: auto_rp
                
                	PIM Auto\-RP information
                	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.AutoRp>`
                
                .. attribute:: bgp_afs
                
                	PIM BGP SAFI table
                	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs>`
                
                .. attribute:: bidir_df_states
                
                	Bidirectional PIM DF election state table
                	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfStates>`
                
                .. attribute:: bidir_df_winners
                
                	Bidirectional PIM DF election winner table
                	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfWinners>`
                
                .. attribute:: bsr
                
                	PIM BSR information
                	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr>`
                
                .. attribute:: context
                
                	PIM context information
                	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context>`
                
                .. attribute:: gre
                
                	GRE information
                	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre>`
                
                .. attribute:: group_map_rpfs
                
                	PIM group mapping information
                	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs>`
                
                .. attribute:: group_map_sources
                
                	PIM group\-mapping with source information
                	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources>`
                
                .. attribute:: ifrs_interfaces
                
                	PIM interfaces in forward reference store table
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: ifrs_summary
                
                	PIM interfaces in forward reference store summary
                	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsSummary>`
                
                .. attribute:: interface_old_formats
                
                	PIM interfaces in old format
                	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceOldFormats>`
                
                .. attribute:: interface_statistics
                
                	PIM interface statistics
                	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceStatistics>`
                
                .. attribute:: interfaces
                
                	PIM interfaces
                	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Interfaces>`
                
                .. attribute:: jp_statistics
                
                	PIM join prune statistics table
                	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.JpStatistics>`
                
                .. attribute:: mib_databases
                
                	PIM group database for mroute mibs table
                	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases>`
                
                .. attribute:: multicast_static_routes
                
                	PIM multicast static route table
                	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MulticastStaticRoutes>`
                
                .. attribute:: neighbor_old_formats
                
                	PIM neighbor table old format
                	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborOldFormats>`
                
                .. attribute:: neighbor_summaries
                
                	PIM neighbor summary table
                	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborSummaries>`
                
                .. attribute:: neighbors
                
                	PIM neighbor table
                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Neighbors>`
                
                .. attribute:: net_io_tunnels
                
                	Tunnel information that NETIO has 
                	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels>`
                
                .. attribute:: ranges
                
                	PIM range list information
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges>`
                
                .. attribute:: route_policy
                
                	PIM route policy
                	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy>`
                
                .. attribute:: rpf_redirect
                
                	PIM ECMP RPF\-redirect bundle
                	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect>`
                
                .. attribute:: rpf_summary
                
                	PIM RPF registration summary
                	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfSummary>`
                
                .. attribute:: safs
                
                	SAFI table and type
                	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs>`
                
                .. attribute:: summary
                
                	PIM summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Summary>`
                
                .. attribute:: table_contexts
                
                	PIM table context list
                	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TableContexts>`
                
                .. attribute:: topologies
                
                	PIM topology table
                	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies>`
                
                .. attribute:: topology_entry_flag_route_counts
                
                	Route count for topology with entry flag set
                	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts>`
                
                .. attribute:: topology_interface_flag_route_counts
                
                	Route count for topology with interface flag set
                	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts>`
                
                .. attribute:: topology_route_count
                
                	Topology route count information from PIM topology table
                	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyRouteCount>`
                
                .. attribute:: traffic_counters
                
                	PIM message traffic counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TrafficCounters>`
                
                .. attribute:: tunnels
                
                	Tunnels information that PIM has
                	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Active.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"auto-rp" : ("auto_rp", Pim.Active.Vrfs.Vrf.AutoRp), "bgp-afs" : ("bgp_afs", Pim.Active.Vrfs.Vrf.BgpAfs), "bidir-df-states" : ("bidir_df_states", Pim.Active.Vrfs.Vrf.BidirDfStates), "bidir-df-winners" : ("bidir_df_winners", Pim.Active.Vrfs.Vrf.BidirDfWinners), "bsr" : ("bsr", Pim.Active.Vrfs.Vrf.Bsr), "context" : ("context", Pim.Active.Vrfs.Vrf.Context), "gre" : ("gre", Pim.Active.Vrfs.Vrf.Gre), "group-map-rpfs" : ("group_map_rpfs", Pim.Active.Vrfs.Vrf.GroupMapRpfs), "group-map-sources" : ("group_map_sources", Pim.Active.Vrfs.Vrf.GroupMapSources), "ifrs-interfaces" : ("ifrs_interfaces", Pim.Active.Vrfs.Vrf.IfrsInterfaces), "ifrs-summary" : ("ifrs_summary", Pim.Active.Vrfs.Vrf.IfrsSummary), "interface-old-formats" : ("interface_old_formats", Pim.Active.Vrfs.Vrf.InterfaceOldFormats), "interface-statistics" : ("interface_statistics", Pim.Active.Vrfs.Vrf.InterfaceStatistics), "interfaces" : ("interfaces", Pim.Active.Vrfs.Vrf.Interfaces), "jp-statistics" : ("jp_statistics", Pim.Active.Vrfs.Vrf.JpStatistics), "mib-databases" : ("mib_databases", Pim.Active.Vrfs.Vrf.MibDatabases), "multicast-static-routes" : ("multicast_static_routes", Pim.Active.Vrfs.Vrf.MulticastStaticRoutes), "neighbor-old-formats" : ("neighbor_old_formats", Pim.Active.Vrfs.Vrf.NeighborOldFormats), "neighbor-summaries" : ("neighbor_summaries", Pim.Active.Vrfs.Vrf.NeighborSummaries), "neighbors" : ("neighbors", Pim.Active.Vrfs.Vrf.Neighbors), "net-io-tunnels" : ("net_io_tunnels", Pim.Active.Vrfs.Vrf.NetIoTunnels), "ranges" : ("ranges", Pim.Active.Vrfs.Vrf.Ranges), "route-policy" : ("route_policy", Pim.Active.Vrfs.Vrf.RoutePolicy), "rpf-redirect" : ("rpf_redirect", Pim.Active.Vrfs.Vrf.RpfRedirect), "rpf-summary" : ("rpf_summary", Pim.Active.Vrfs.Vrf.RpfSummary), "safs" : ("safs", Pim.Active.Vrfs.Vrf.Safs), "summary" : ("summary", Pim.Active.Vrfs.Vrf.Summary), "table-contexts" : ("table_contexts", Pim.Active.Vrfs.Vrf.TableContexts), "topologies" : ("topologies", Pim.Active.Vrfs.Vrf.Topologies), "topology-entry-flag-route-counts" : ("topology_entry_flag_route_counts", Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts), "topology-interface-flag-route-counts" : ("topology_interface_flag_route_counts", Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts), "topology-route-count" : ("topology_route_count", Pim.Active.Vrfs.Vrf.TopologyRouteCount), "traffic-counters" : ("traffic_counters", Pim.Active.Vrfs.Vrf.TrafficCounters), "tunnels" : ("tunnels", Pim.Active.Vrfs.Vrf.Tunnels)}
                    self._child_list_classes = {}

                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                    self.auto_rp = Pim.Active.Vrfs.Vrf.AutoRp()
                    self.auto_rp.parent = self
                    self._children_name_map["auto_rp"] = "auto-rp"
                    self._children_yang_names.add("auto-rp")

                    self.bgp_afs = Pim.Active.Vrfs.Vrf.BgpAfs()
                    self.bgp_afs.parent = self
                    self._children_name_map["bgp_afs"] = "bgp-afs"
                    self._children_yang_names.add("bgp-afs")

                    self.bidir_df_states = Pim.Active.Vrfs.Vrf.BidirDfStates()
                    self.bidir_df_states.parent = self
                    self._children_name_map["bidir_df_states"] = "bidir-df-states"
                    self._children_yang_names.add("bidir-df-states")

                    self.bidir_df_winners = Pim.Active.Vrfs.Vrf.BidirDfWinners()
                    self.bidir_df_winners.parent = self
                    self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                    self._children_yang_names.add("bidir-df-winners")

                    self.bsr = Pim.Active.Vrfs.Vrf.Bsr()
                    self.bsr.parent = self
                    self._children_name_map["bsr"] = "bsr"
                    self._children_yang_names.add("bsr")

                    self.context = Pim.Active.Vrfs.Vrf.Context()
                    self.context.parent = self
                    self._children_name_map["context"] = "context"
                    self._children_yang_names.add("context")

                    self.gre = Pim.Active.Vrfs.Vrf.Gre()
                    self.gre.parent = self
                    self._children_name_map["gre"] = "gre"
                    self._children_yang_names.add("gre")

                    self.group_map_rpfs = Pim.Active.Vrfs.Vrf.GroupMapRpfs()
                    self.group_map_rpfs.parent = self
                    self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                    self._children_yang_names.add("group-map-rpfs")

                    self.group_map_sources = Pim.Active.Vrfs.Vrf.GroupMapSources()
                    self.group_map_sources.parent = self
                    self._children_name_map["group_map_sources"] = "group-map-sources"
                    self._children_yang_names.add("group-map-sources")

                    self.ifrs_interfaces = Pim.Active.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    self._children_yang_names.add("ifrs-interfaces")

                    self.ifrs_summary = Pim.Active.Vrfs.Vrf.IfrsSummary()
                    self.ifrs_summary.parent = self
                    self._children_name_map["ifrs_summary"] = "ifrs-summary"
                    self._children_yang_names.add("ifrs-summary")

                    self.interface_old_formats = Pim.Active.Vrfs.Vrf.InterfaceOldFormats()
                    self.interface_old_formats.parent = self
                    self._children_name_map["interface_old_formats"] = "interface-old-formats"
                    self._children_yang_names.add("interface-old-formats")

                    self.interface_statistics = Pim.Active.Vrfs.Vrf.InterfaceStatistics()
                    self.interface_statistics.parent = self
                    self._children_name_map["interface_statistics"] = "interface-statistics"
                    self._children_yang_names.add("interface-statistics")

                    self.interfaces = Pim.Active.Vrfs.Vrf.Interfaces()
                    self.interfaces.parent = self
                    self._children_name_map["interfaces"] = "interfaces"
                    self._children_yang_names.add("interfaces")

                    self.jp_statistics = Pim.Active.Vrfs.Vrf.JpStatistics()
                    self.jp_statistics.parent = self
                    self._children_name_map["jp_statistics"] = "jp-statistics"
                    self._children_yang_names.add("jp-statistics")

                    self.mib_databases = Pim.Active.Vrfs.Vrf.MibDatabases()
                    self.mib_databases.parent = self
                    self._children_name_map["mib_databases"] = "mib-databases"
                    self._children_yang_names.add("mib-databases")

                    self.multicast_static_routes = Pim.Active.Vrfs.Vrf.MulticastStaticRoutes()
                    self.multicast_static_routes.parent = self
                    self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                    self._children_yang_names.add("multicast-static-routes")

                    self.neighbor_old_formats = Pim.Active.Vrfs.Vrf.NeighborOldFormats()
                    self.neighbor_old_formats.parent = self
                    self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                    self._children_yang_names.add("neighbor-old-formats")

                    self.neighbor_summaries = Pim.Active.Vrfs.Vrf.NeighborSummaries()
                    self.neighbor_summaries.parent = self
                    self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                    self._children_yang_names.add("neighbor-summaries")

                    self.neighbors = Pim.Active.Vrfs.Vrf.Neighbors()
                    self.neighbors.parent = self
                    self._children_name_map["neighbors"] = "neighbors"
                    self._children_yang_names.add("neighbors")

                    self.net_io_tunnels = Pim.Active.Vrfs.Vrf.NetIoTunnels()
                    self.net_io_tunnels.parent = self
                    self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                    self._children_yang_names.add("net-io-tunnels")

                    self.ranges = Pim.Active.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"
                    self._children_yang_names.add("ranges")

                    self.route_policy = Pim.Active.Vrfs.Vrf.RoutePolicy()
                    self.route_policy.parent = self
                    self._children_name_map["route_policy"] = "route-policy"
                    self._children_yang_names.add("route-policy")

                    self.rpf_redirect = Pim.Active.Vrfs.Vrf.RpfRedirect()
                    self.rpf_redirect.parent = self
                    self._children_name_map["rpf_redirect"] = "rpf-redirect"
                    self._children_yang_names.add("rpf-redirect")

                    self.rpf_summary = Pim.Active.Vrfs.Vrf.RpfSummary()
                    self.rpf_summary.parent = self
                    self._children_name_map["rpf_summary"] = "rpf-summary"
                    self._children_yang_names.add("rpf-summary")

                    self.safs = Pim.Active.Vrfs.Vrf.Safs()
                    self.safs.parent = self
                    self._children_name_map["safs"] = "safs"
                    self._children_yang_names.add("safs")

                    self.summary = Pim.Active.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.table_contexts = Pim.Active.Vrfs.Vrf.TableContexts()
                    self.table_contexts.parent = self
                    self._children_name_map["table_contexts"] = "table-contexts"
                    self._children_yang_names.add("table-contexts")

                    self.topologies = Pim.Active.Vrfs.Vrf.Topologies()
                    self.topologies.parent = self
                    self._children_name_map["topologies"] = "topologies"
                    self._children_yang_names.add("topologies")

                    self.topology_entry_flag_route_counts = Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                    self.topology_entry_flag_route_counts.parent = self
                    self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                    self._children_yang_names.add("topology-entry-flag-route-counts")

                    self.topology_interface_flag_route_counts = Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                    self.topology_interface_flag_route_counts.parent = self
                    self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                    self._children_yang_names.add("topology-interface-flag-route-counts")

                    self.topology_route_count = Pim.Active.Vrfs.Vrf.TopologyRouteCount()
                    self.topology_route_count.parent = self
                    self._children_name_map["topology_route_count"] = "topology-route-count"
                    self._children_yang_names.add("topology-route-count")

                    self.traffic_counters = Pim.Active.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"
                    self._children_yang_names.add("traffic-counters")

                    self.tunnels = Pim.Active.Vrfs.Vrf.Tunnels()
                    self.tunnels.parent = self
                    self._children_name_map["tunnels"] = "tunnels"
                    self._children_yang_names.add("tunnels")
                    self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/vrfs/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.Vrfs.Vrf, ['vrf_name'], name, value)


                class AutoRp(Entity):
                    """
                    PIM Auto\-RP information
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.AutoRp, self).__init__()

                        self.yang_name = "auto-rp"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self._segment_path = lambda: "auto-rp"


                class BgpAfs(Entity):
                    """
                    PIM BGP SAFI table
                    
                    .. attribute:: bgp_af
                    
                    	PIM BGP SAFI information
                    	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.BgpAfs, self).__init__()

                        self.yang_name = "bgp-afs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"bgp-af" : ("bgp_af", Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf)}

                        self.bgp_af = YList(self)
                        self._segment_path = lambda: "bgp-afs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.BgpAfs, [], name, value)


                    class BgpAf(Entity):
                        """
                        PIM BGP SAFI information
                        
                        .. attribute:: extranet_path_count
                        
                        	Count of dependent extranet paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group
                        
                        	Group address
                        	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group>`
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: is_bgp_added
                        
                        	SAFI learnt from BGP
                        	**type**\:  bool
                        
                        .. attribute:: next_hop
                        
                        	Next hop address
                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop>`
                        
                        .. attribute:: route_distinguisher
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**length:** 0..256
                        
                        .. attribute:: source
                        
                        	Source address
                        	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf, self).__init__()

                            self.yang_name = "bgp-af"
                            self.yang_parent_name = "bgp-afs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group" : ("group", Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group), "next-hop" : ("next_hop", Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop), "source" : ("source", Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source)}
                            self._child_list_classes = {}

                            self.extranet_path_count = YLeaf(YType.uint32, "extranet-path-count")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.is_bgp_added = YLeaf(YType.boolean, "is-bgp-added")

                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group = Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                            self.group.parent = self
                            self._children_name_map["group"] = "group"
                            self._children_yang_names.add("group")

                            self.next_hop = Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"
                            self._children_yang_names.add("next-hop")

                            self.source = Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._children_yang_names.add("source")
                            self._segment_path = lambda: "bgp-af"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf, ['extranet_path_count', 'group_address', 'is_bgp_added', 'route_distinguisher', 'source_address'], name, value)


                        class Group(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__init__()

                                self.yang_name = "group"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class NextHop(Entity):
                            """
                            Next hop address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "next-hop"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Source(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class BidirDfStates(Entity):
                    """
                    Bidirectional PIM DF election state table
                    
                    .. attribute:: bidir_df_state
                    
                    	Bidirectional PIM DF Election Table Entry
                    	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.BidirDfStates, self).__init__()

                        self.yang_name = "bidir-df-states"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"bidir-df-state" : ("bidir_df_state", Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState)}

                        self.bidir_df_state = YList(self)
                        self._segment_path = lambda: "bidir-df-states"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.BidirDfStates, [], name, value)


                    class BidirDfState(Entity):
                        """
                        Bidirectional PIM DF Election Table Entry
                        
                        .. attribute:: election_state
                        
                        	DF Election State
                        	**type**\:  str
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: our_metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: our_metric_preference
                        
                        	MetricPreference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr>`
                        
                        .. attribute:: time_nano_seconds
                        
                        	Timer expires (nseconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: time_seconds
                        
                        	Timer expires (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__init__()

                            self.yang_name = "bidir-df-state"
                            self.yang_parent_name = "bidir-df-states"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"rp-address-xr" : ("rp_address_xr", Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr)}
                            self._child_list_classes = {}

                            self.election_state = YLeaf(YType.str, "election-state")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.our_metric = YLeaf(YType.uint32, "our-metric")

                            self.our_metric_preference = YLeaf(YType.uint32, "our-metric-preference")

                            self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.time_nano_seconds = YLeaf(YType.uint64, "time-nano-seconds")

                            self.time_seconds = YLeaf(YType.uint64, "time-seconds")

                            self.rp_address_xr = Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")
                            self._segment_path = lambda: "bidir-df-state"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState, ['election_state', 'interface_name', 'our_metric', 'our_metric_preference', 'pim_interface_name', 'rp_address', 'time_nano_seconds', 'time_seconds'], name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class BidirDfWinners(Entity):
                    """
                    Bidirectional PIM DF election winner table
                    
                    .. attribute:: bidir_df_winner
                    
                    	Bidirectional PIM DF election table entry
                    	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.BidirDfWinners, self).__init__()

                        self.yang_name = "bidir-df-winners"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"bidir-df-winner" : ("bidir_df_winner", Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner)}

                        self.bidir_df_winner = YList(self)
                        self._segment_path = lambda: "bidir-df-winners"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.BidirDfWinners, [], name, value)


                    class BidirDfWinner(Entity):
                        """
                        Bidirectional PIM DF election table entry
                        
                        .. attribute:: are_we_df
                        
                        	Are we DF
                        	**type**\:  bool
                        
                        .. attribute:: df_winner
                        
                        	DF Winner
                        	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner>`
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                        
                        .. attribute:: rp_lan
                        
                        	Is this the RP LAN
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__init__()

                            self.yang_name = "bidir-df-winner"
                            self.yang_parent_name = "bidir-df-winners"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"df-winner" : ("df_winner", Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner), "rp-address-xr" : ("rp_address_xr", Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr)}
                            self._child_list_classes = {}

                            self.are_we_df = YLeaf(YType.boolean, "are-we-df")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                            self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_lan = YLeaf(YType.boolean, "rp-lan")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.df_winner = Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                            self.df_winner.parent = self
                            self._children_name_map["df_winner"] = "df-winner"
                            self._children_yang_names.add("df-winner")

                            self.rp_address_xr = Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")
                            self._segment_path = lambda: "bidir-df-winner"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, ['are_we_df', 'interface_name', 'metric', 'metric_preference', 'pim_interface_name', 'rp_address', 'rp_lan', 'uptime'], name, value)


                        class DfWinner(Entity):
                            """
                            DF Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                                self.yang_name = "df-winner"
                                self.yang_parent_name = "bidir-df-winner"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "df-winner"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-winner"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Bsr(Entity):
                    """
                    PIM BSR information
                    
                    .. attribute:: bsr_elections
                    
                    	PIM BSR election state
                    	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.BsrElections>`
                    
                    .. attribute:: candidate_rps
                    
                    	PIM candidate\-RP
                    	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.CandidateRps>`
                    
                    .. attribute:: rp_caches
                    
                    	PIM BSR RP cache table
                    	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Bsr, self).__init__()

                        self.yang_name = "bsr"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"bsr-elections" : ("bsr_elections", Pim.Active.Vrfs.Vrf.Bsr.BsrElections), "candidate-rps" : ("candidate_rps", Pim.Active.Vrfs.Vrf.Bsr.CandidateRps), "rp-caches" : ("rp_caches", Pim.Active.Vrfs.Vrf.Bsr.RpCaches)}
                        self._child_list_classes = {}

                        self.bsr_elections = Pim.Active.Vrfs.Vrf.Bsr.BsrElections()
                        self.bsr_elections.parent = self
                        self._children_name_map["bsr_elections"] = "bsr-elections"
                        self._children_yang_names.add("bsr-elections")

                        self.candidate_rps = Pim.Active.Vrfs.Vrf.Bsr.CandidateRps()
                        self.candidate_rps.parent = self
                        self._children_name_map["candidate_rps"] = "candidate-rps"
                        self._children_yang_names.add("candidate-rps")

                        self.rp_caches = Pim.Active.Vrfs.Vrf.Bsr.RpCaches()
                        self.rp_caches.parent = self
                        self._children_name_map["rp_caches"] = "rp-caches"
                        self._children_yang_names.add("rp-caches")
                        self._segment_path = lambda: "bsr"


                    class BsrElections(Entity):
                        """
                        PIM BSR election state
                        
                        .. attribute:: bsr_election
                        
                        	PIM BSR information
                        	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections, self).__init__()

                            self.yang_name = "bsr-elections"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"bsr-election" : ("bsr_election", Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection)}

                            self.bsr_election = YList(self)
                            self._segment_path = lambda: "bsr-elections"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.BsrElections, [], name, value)


                        class BsrElection(Entity):
                            """
                            PIM BSR information
                            
                            .. attribute:: pim_scope  <key>
                            
                            	BSR information
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: bootstrap_timeout
                            
                            	Bootstrap Timeout
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_address
                            
                            	BSR address
                            	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress>`
                            
                            .. attribute:: bsr_election_state
                            
                            	BSR Election State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_mask_length
                            
                            	Hash Function Mask Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_priority
                            
                            	BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_scope
                            
                            	BSR Scope
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_up_time
                            
                            	BSR Uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_address
                            
                            	C\-BSR address
                            	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                            
                            .. attribute:: candidate_bsr_flag
                            
                            	BSR Candidate Config Flag
                            	**type**\:  bool
                            
                            .. attribute:: candidate_bsr_mask_length
                            
                            	C\-BSR Hash Func. Mask Len
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_priority
                            
                            	C\-BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_state
                            
                            	BSR Candidate State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__init__()

                                self.yang_name = "bsr-election"
                                self.yang_parent_name = "bsr-elections"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"bsr-address" : ("bsr_address", Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress), "candidate-bsr-address" : ("candidate_bsr_address", Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress)}
                                self._child_list_classes = {}

                                self.pim_scope = YLeaf(YType.int32, "pim-scope")

                                self.bootstrap_timeout = YLeaf(YType.uint16, "bootstrap-timeout")

                                self.bsr_election_state = YLeaf(YType.uint32, "bsr-election-state")

                                self.bsr_mask_length = YLeaf(YType.uint8, "bsr-mask-length")

                                self.bsr_priority = YLeaf(YType.uint8, "bsr-priority")

                                self.bsr_scope = YLeaf(YType.uint16, "bsr-scope")

                                self.bsr_up_time = YLeaf(YType.uint16, "bsr-up-time")

                                self.candidate_bsr_flag = YLeaf(YType.boolean, "candidate-bsr-flag")

                                self.candidate_bsr_mask_length = YLeaf(YType.uint8, "candidate-bsr-mask-length")

                                self.candidate_bsr_priority = YLeaf(YType.uint8, "candidate-bsr-priority")

                                self.candidate_bsr_state = YLeaf(YType.uint32, "candidate-bsr-state")

                                self.bsr_address = Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                self.bsr_address.parent = self
                                self._children_name_map["bsr_address"] = "bsr-address"
                                self._children_yang_names.add("bsr-address")

                                self.candidate_bsr_address = Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                self.candidate_bsr_address.parent = self
                                self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                self._children_yang_names.add("candidate-bsr-address")
                                self._segment_path = lambda: "bsr-election" + "[pim-scope='" + self.pim_scope.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection, ['pim_scope', 'bootstrap_timeout', 'bsr_election_state', 'bsr_mask_length', 'bsr_priority', 'bsr_scope', 'bsr_up_time', 'candidate_bsr_flag', 'candidate_bsr_mask_length', 'candidate_bsr_priority', 'candidate_bsr_state'], name, value)


                            class BsrAddress(Entity):
                                """
                                BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                    self.yang_name = "bsr-address"
                                    self.yang_parent_name = "bsr-election"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "bsr-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class CandidateBsrAddress(Entity):
                                """
                                C\-BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                    self.yang_name = "candidate-bsr-address"
                                    self.yang_parent_name = "bsr-election"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "candidate-bsr-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class CandidateRps(Entity):
                        """
                        PIM candidate\-RP
                        
                        .. attribute:: candidate_rp
                        
                        	PIM BSR candidate RP information
                        	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps, self).__init__()

                            self.yang_name = "candidate-rps"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"candidate-rp" : ("candidate_rp", Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp)}

                            self.candidate_rp = YList(self)
                            self._segment_path = lambda: "candidate-rps"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps, [], name, value)


                        class CandidateRp(Entity):
                            """
                            PIM BSR candidate RP information
                            
                            .. attribute:: rp_address  <key>
                            
                            	Candidate\-RP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp
                            
                            	Cand\-RP Address
                            	**type**\:   :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp>`
                            
                            .. attribute:: candidate_rp_advance_interval
                            
                            	Cand\-RP Adv Interval in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: candidate_rp_scope
                            
                            	Cand\-RP Scope
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: candidate_rp_uptime
                            
                            	Cand\-RP uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_access
                            
                            	Group Ranges Using this Cand\-RP
                            	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                            
                            .. attribute:: crp_holdtime
                            
                            	Cand\-RP Holdtime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_priority
                            
                            	Cand\-RP Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rps"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"candidate-rp" : ("candidate_rp", Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp)}
                                self._child_list_classes = {"crp-access" : ("crp_access", Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess)}

                                self.rp_address = YLeaf(YType.str, "rp-address")

                                self.acl_name = YLeaf(YType.str, "acl-name")

                                self.candidate_rp_advance_interval = YLeaf(YType.uint16, "candidate-rp-advance-interval")

                                self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                                self.candidate_rp_scope = YLeaf(YType.int32, "candidate-rp-scope")

                                self.candidate_rp_uptime = YLeaf(YType.uint16, "candidate-rp-uptime")

                                self.crp_holdtime = YLeaf(YType.uint16, "crp-holdtime")

                                self.crp_priority = YLeaf(YType.uint8, "crp-priority")

                                self.candidate_rp = Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp()
                                self.candidate_rp.parent = self
                                self._children_name_map["candidate_rp"] = "candidate-rp"
                                self._children_yang_names.add("candidate-rp")

                                self.crp_access = YList(self)
                                self._segment_path = lambda: "candidate-rp" + "[rp-address='" + self.rp_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, ['rp_address', 'acl_name', 'candidate_rp_advance_interval', 'candidate_rp_mode', 'candidate_rp_scope', 'candidate_rp_uptime', 'crp_holdtime', 'crp_priority'], name, value)


                            class CandidateRp(Entity):
                                """
                                Cand\-RP Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__init__()

                                    self.yang_name = "candidate-rp"
                                    self.yang_parent_name = "candidate-rp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "candidate-rp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class CrpAccess(Entity):
                                """
                                Group Ranges Using this Cand\-RP
                                
                                .. attribute:: acl_name
                                
                                	Group Access\-List Name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: candidate_rp_mode
                                
                                	Cand\-RP Mode
                                	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                    self.yang_name = "crp-access"
                                    self.yang_parent_name = "candidate-rp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.acl_name = YLeaf(YType.str, "acl-name")

                                    self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")
                                    self._segment_path = lambda: "crp-access"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, ['acl_name', 'candidate_rp_mode'], name, value)


                    class RpCaches(Entity):
                        """
                        PIM BSR RP cache table
                        
                        .. attribute:: rp_cache
                        
                        	PIM BSR RP cache
                        	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches, self).__init__()

                            self.yang_name = "rp-caches"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"rp-cache" : ("rp_cache", Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache)}

                            self.rp_cache = YList(self)
                            self._segment_path = lambda: "rp-caches"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.RpCaches, [], name, value)


                        class RpCache(Entity):
                            """
                            PIM BSR RP cache
                            
                            .. attribute:: group_prefix  <key>
                            
                            	Group prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: candidate_rp_group_count
                            
                            	C\-RP count for this Prefix
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: candidate_rp_list
                            
                            	C\-RP list for this prefix
                            	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList>`
                            
                            .. attribute:: group_prefix_length
                            
                            	Group Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_prefix_xr
                            
                            	Group Prefix
                            	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__init__()

                                self.yang_name = "rp-cache"
                                self.yang_parent_name = "rp-caches"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"candidate-rp-list" : ("candidate_rp_list", Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList), "group-prefix-xr" : ("group_prefix_xr", Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr)}
                                self._child_list_classes = {}

                                self.group_prefix = YLeaf(YType.str, "group-prefix")

                                self.candidate_rp_group_count = YLeaf(YType.uint32, "candidate-rp-group-count")

                                self.group_prefix_length = YLeaf(YType.uint32, "group-prefix-length")

                                self.candidate_rp_list = Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                self.candidate_rp_list.parent = self
                                self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                self._children_yang_names.add("candidate-rp-list")

                                self.group_prefix_xr = Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                self.group_prefix_xr.parent = self
                                self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                                self._children_yang_names.add("group-prefix-xr")
                                self._segment_path = lambda: "rp-cache" + "[group-prefix='" + self.group_prefix.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache, ['group_prefix', 'candidate_rp_group_count', 'group_prefix_length'], name, value)


                            class CandidateRpList(Entity):
                                """
                                C\-RP list for this prefix
                                
                                .. attribute:: pim_bsr_crp_bag
                                
                                	pim bsr crp bag
                                	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                    self.yang_name = "candidate-rp-list"
                                    self.yang_parent_name = "rp-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"pim-bsr-crp-bag" : ("pim_bsr_crp_bag", Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag)}

                                    self.pim_bsr_crp_bag = YList(self)
                                    self._segment_path = lambda: "candidate-rp-list"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, [], name, value)


                                class PimBsrCrpBag(Entity):
                                    """
                                    pim bsr crp bag
                                    
                                    .. attribute:: candidate_rp_address
                                    
                                    	C\-RP address
                                    	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                    
                                    .. attribute:: candidate_rp_expires
                                    
                                    	C\-RP Expires
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_holdtime
                                    
                                    	C\-RP Holdtime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_priority
                                    
                                    	C\-RP Priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: candidate_rp_up_time
                                    
                                    	C\-RP Uptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protocol
                                    
                                    	PIM Protocol
                                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                        self.yang_name = "pim-bsr-crp-bag"
                                        self.yang_parent_name = "candidate-rp-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"candidate-rp-address" : ("candidate_rp_address", Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress)}
                                        self._child_list_classes = {}

                                        self.candidate_rp_expires = YLeaf(YType.uint16, "candidate-rp-expires")

                                        self.candidate_rp_holdtime = YLeaf(YType.uint16, "candidate-rp-holdtime")

                                        self.candidate_rp_priority = YLeaf(YType.uint8, "candidate-rp-priority")

                                        self.candidate_rp_up_time = YLeaf(YType.uint16, "candidate-rp-up-time")

                                        self.protocol = YLeaf(YType.enumeration, "protocol")

                                        self.candidate_rp_address = Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                        self.candidate_rp_address.parent = self
                                        self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                        self._children_yang_names.add("candidate-rp-address")
                                        self._segment_path = lambda: "pim-bsr-crp-bag"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, ['candidate_rp_expires', 'candidate_rp_holdtime', 'candidate_rp_priority', 'candidate_rp_up_time', 'protocol'], name, value)


                                    class CandidateRpAddress(Entity):
                                        """
                                        C\-RP address
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                            self.yang_name = "candidate-rp-address"
                                            self.yang_parent_name = "pim-bsr-crp-bag"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                            self._segment_path = lambda: "candidate-rp-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class GroupPrefixXr(Entity):
                                """
                                Group Prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                    self.yang_name = "group-prefix-xr"
                                    self.yang_parent_name = "rp-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-prefix-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Context(Entity):
                    """
                    PIM context information
                    
                    .. attribute:: active_table_count
                    
                    	Number of active Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: allow_rp_configured
                    
                    	Allow RP Configured
                    	**type**\:  bool
                    
                    .. attribute:: allow_rp_group_list
                    
                    	Allow RP Group\-List ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: allow_rp_rp_list
                    
                    	Allow RP RP\-list ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: anycast_rp_configured
                    
                    	Anycast\-RP config
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_policy_name
                    
                    	Anycast\-RP Policy Name
                    	**type**\:  str
                    
                    .. attribute:: anycast_rp_range
                    
                    	Anycast\-RP Ranges
                    	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.AnycastRpRange>`
                    
                    .. attribute:: bgp_auto_discovery_configured
                    
                    	BGP Auto\-Discovery configured
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery_type
                    
                    	BGP Auto Discovery Type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_i_pmsi_added
                    
                    	BGP I\-PMSI Added
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_address
                    
                    	BGP remote interface address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_remote_interface
                    
                    	BGP remote interface handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: bgp_remote_interface_name
                    
                    	BGP remote interface name
                    	**type**\:  str
                    
                    .. attribute:: bgp_remote_on
                    
                    	BGP remote interface status
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_state
                    
                    	BGP remote interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_source_active_announce
                    
                    	Send BGP Source\-Active Announcements
                    	**type**\:  bool
                    
                    .. attribute:: export_route_target
                    
                    	Export Route Targets
                    	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget>`
                    
                    .. attribute:: gin_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: gin_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: gin_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: import_route_target
                    
                    	Import Route Targets
                    	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget>`
                    
                    .. attribute:: in_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: in_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: in_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_signaling_local_enabled
                    
                    	Inband signaling Local enabled
                    	**type**\:  bool
                    
                    .. attribute:: in_band_signaling_remote_enabled
                    
                    	Inband signaling Remote enabled
                    	**type**\:  bool
                    
                    .. attribute:: inter_autonomous_system_enabled
                    
                    	Inter\-AS Enabled
                    	**type**\:  bool
                    
                    .. attribute:: ir_maximum_mdt_aggregation
                    
                    	IR MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_announce_interval
                    
                    	IR Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_switchover_interval
                    
                    	IR Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_interface
                    
                    	IRMDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: ir_mdt_mtu
                    
                    	IRMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_name
                    
                    	IR MDT Name
                    	**type**\:  str
                    
                    .. attribute:: ir_mdt_rpf_identifier
                    
                    	IR RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_tail_label
                    
                    	IR Tail Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active
                    	**type**\:  bool
                    
                    .. attribute:: is_active_ital
                    
                    	Active ITAL
                    	**type**\:  bool
                    
                    .. attribute:: is_all_interface_disable_operation
                    
                    	PIM all interface disable operation
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_enabled
                    
                    	Auto RP Listen Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_sock_add
                    
                    	Auto RP listen sock add
                    	**type**\:  bool
                    
                    .. attribute:: is_create_gin_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_in_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_ir_mdt_interface
                    
                    	Create IR MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mdt_interface
                    
                    	Create MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mldp_mdt_interface
                    
                    	Create MLDP MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_rsvp_te_mdt_interface
                    
                    	Create RSVP\-TE MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_default_granges
                    
                    	Default granges
                    	**type**\:  bool
                    
                    .. attribute:: is_gin_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_in_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_ir_mdt_owner
                    
                    	IR MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_added
                    
                    	VRF LPTS filter added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_m_host_publish_pending
                    
                    	Publish pending for MHost Default interface
                    	**type**\:  bool
                    
                    .. attribute:: is_mdt_owner
                    
                    	MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mldp_mdt_owner
                    
                    	MLDP MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mrib_register
                    
                    	MRIB Register
                    	**type**\:  bool
                    
                    .. attribute:: is_multicast_rib_registration
                    
                    	Mcast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converge_received
                    
                    	PIM NSF RIB converge received
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converged
                    
                    	PIM NSF RIB converged
                    	**type**\:  bool
                    
                    .. attribute:: is_redistribution_reset
                    
                    	Pending redist reset
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_added
                    
                    	VRF LPTS filter added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_add_required
                    
                    	VRF required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_added
                    
                    	VRF added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_enabled
                    
                    	PIM RIB multiplath enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_interface_hash
                    
                    	PIM RIB multipath interface hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_hash
                    
                    	PIM RIB multipath source based hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_next_hop_hash
                    
                    	PIM RIB multipath source\-nexthop hash
                    	**type**\:  bool
                    
                    .. attribute:: is_routing_enabled
                    
                    	Routing Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rsvp_te_mdt_owner
                    
                    	RSVP\-TE MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_add_required
                    
                    	VRF required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_added
                    
                    	VRF added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_add_required
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_added
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind
                    
                    	VRF bound on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind_required
                    
                    	VRF bind required on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_unicast_rib_registration
                    
                    	Ucast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: maximum_mdt_aggregation
                    
                    	MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_announce_interval
                    
                    	Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_switchover_interval
                    
                    	Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_default_group
                    
                    	MDT Default group
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_gre_remote_rpf_identifier
                    
                    	GRE\-MDT Remote RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_gre_rpf_identifier
                    
                    	GRE\-MDT RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_immediate_switch
                    
                    	MDT Immediate Switch
                    	**type**\:  bool
                    
                    .. attribute:: mdt_interface
                    
                    	MDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mdt_mtu
                    
                    	MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_neighbor_filter_name
                    
                    	MDT Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: mdt_partitioned_ir_control_identifier
                    
                    	Partitioned IR MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_mdt_control_identifier
                    
                    	Partitioned MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_source
                    
                    	MDT source
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_source_interface
                    
                    	MDT Source Interface Name
                    	**type**\:  str
                    
                    .. attribute:: mhost_default_interface_config
                    
                    	Configured Mhost Defint
                    	**type**\:  str
                    
                    .. attribute:: mhost_interface
                    
                    	MHost handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mldp_auto_rp_announce_tree_added
                    
                    	MLDP Autorp Announce Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_auto_rp_discovery_tree_added
                    
                    	MLDP Autorp Discovery Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_bsr_control_tree_added
                    
                    	MLDP BSR Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_control_head_lsm_identifier
                    
                    	MLDP MVPN Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_local_label
                    
                    	Partitioned MDT Head local label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_lsm_identifier
                    
                    	MLDP Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_maximum_mdt_aggregation
                    
                    	MLDP MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_announce_interval
                    
                    	MLDP Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_switchover_interval
                    
                    	MLDP Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_interface
                    
                    	MLDP MDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mldp_mdt_mtu
                    
                    	MLDP MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_name
                    
                    	MLDP MDT Name
                    	**type**\:  str
                    
                    .. attribute:: mldp_mdt_remote_rpf_identifier
                    
                    	MLDP Remote RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_rpf_identifier
                    
                    	MLDP RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partioned_mp2m_ptree
                    
                    	MP2MP Partitioned MDT tree
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_head_lsm_identifier
                    
                    	Partitioned MDT Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_configured
                    
                    	MLDP Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_mdt_identifier
                    
                    	MLDP Partitioned MDT Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_head_lsm_identifier
                    
                    	MLDP Remote Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_partitioned_mdt_configured
                    
                    	MLDP Remote Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_root_address
                    
                    	MLDP Root addresses
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_root_count
                    
                    	MLDP Root count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: murib_id
                    
                    	MURIB ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: non_default_vrf_count_on_socket
                    
                    	Count of non\-default vrfs on raw socket
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: organization_unique_identifier
                    
                    	OUI for VPN\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mpte_li_drop
                    
                    	Route LI updates dropped for P2MP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: physical_interface_count
                    
                    	Enabled Physical Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: redistribution_reset_count
                    
                    	Redist reset count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_default_group
                    
                    	Remote Default Group
                    	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup>`
                    
                    .. attribute:: remote_table_id
                    
                    	Remote Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_distinguisher
                    
                    	RD value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: rpf_default_table
                    
                    	RPF Default Table
                    	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable>`
                    
                    .. attribute:: rpf_id
                    
                    	RPF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_policy_name
                    
                    	RPF topology selection route\-policy name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_maximum_mdt_aggregation
                    
                    	RSVP\-TE MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_announce_interval
                    
                    	RSVP\-TE Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_switchover_interval
                    
                    	RSVP\-TE Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_interface
                    
                    	RSVP\-TEMDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: rsvp_te_mdt_mtu
                    
                    	RSVP\-TEMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_name
                    
                    	RSVP\-TE MDT Name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_mdt_rpf_identifier
                    
                    	RSVP\-TE RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_static_p2mp_count
                    
                    	Number of Static P2MP\-TE MDT
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	PIM is using MuRIB
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_time
                    
                    	S,G Expiry Time Configured, in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sg_expiry_timer_configured
                    
                    	S,G Expiry Timer Configured
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_timer_sg_list
                    
                    	S,G expiry timer ACL name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: stale_rd_present
                    
                    	RD is stale
                    	**type**\:  bool
                    
                    .. attribute:: suppress_pim_data_mdt_tlv
                    
                    	Suppress PIM Data\-MDT TLV Announcements
                    	**type**\:  bool
                    
                    .. attribute:: suppress_shared_tree_join
                    
                    	Suppress Shared\-Tree Joins
                    	**type**\:  bool
                    
                    .. attribute:: table_count
                    
                    	Number of configured Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: umh
                    
                    	Join UMH Core\-Tree
                    	**type**\:  bool
                    
                    .. attribute:: valid_rd_present
                    
                    	RD is valid
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface_count
                    
                    	Enabled Virtual Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: virtual_mlc_interface_name
                    
                    	Virtual master line card Interface
                    	**type**\:  str
                    
                    .. attribute:: vpn_index
                    
                    	VPN Index
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Context, self).__init__()

                        self.yang_name = "context"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"remote-default-group" : ("remote_default_group", Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup), "rpf-default-table" : ("rpf_default_table", Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable)}
                        self._child_list_classes = {"anycast-rp-range" : ("anycast_rp_range", Pim.Active.Vrfs.Vrf.Context.AnycastRpRange), "export-route-target" : ("export_route_target", Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget), "import-route-target" : ("import_route_target", Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget)}

                        self.active_table_count = YLeaf(YType.uint32, "active-table-count")

                        self.allow_rp_configured = YLeaf(YType.boolean, "allow-rp-configured")

                        self.allow_rp_group_list = YLeaf(YType.str, "allow-rp-group-list")

                        self.allow_rp_rp_list = YLeaf(YType.str, "allow-rp-rp-list")

                        self.anycast_rp_configured = YLeaf(YType.boolean, "anycast-rp-configured")

                        self.anycast_rp_policy_name = YLeaf(YType.str, "anycast-rp-policy-name")

                        self.bgp_auto_discovery_configured = YLeaf(YType.boolean, "bgp-auto-discovery-configured")

                        self.bgp_auto_discovery_type = YLeaf(YType.uint32, "bgp-auto-discovery-type")

                        self.bgp_i_pmsi_added = YLeaf(YType.boolean, "bgp-i-pmsi-added")

                        self.bgp_remote_address = YLeaf(YType.str, "bgp-remote-address")

                        self.bgp_remote_interface = YLeaf(YType.str, "bgp-remote-interface")

                        self.bgp_remote_interface_name = YLeaf(YType.str, "bgp-remote-interface-name")

                        self.bgp_remote_on = YLeaf(YType.boolean, "bgp-remote-on")

                        self.bgp_remote_state = YLeaf(YType.uint32, "bgp-remote-state")

                        self.bgp_source_active_announce = YLeaf(YType.boolean, "bgp-source-active-announce")

                        self.gin_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-announce-interval")

                        self.gin_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-switchover-interval")

                        self.gin_b_and_mdt_interface = YLeaf(YType.str, "gin-b-and-mdt-interface")

                        self.gin_b_and_mdt_mtu = YLeaf(YType.uint32, "gin-b-and-mdt-mtu")

                        self.gin_b_and_mdt_name = YLeaf(YType.str, "gin-b-and-mdt-name")

                        self.gin_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "gin-b-and-mdt-rpf-identifier")

                        self.gin_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "gin-band-maximum-mdt-aggregation")

                        self.in_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-announce-interval")

                        self.in_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-switchover-interval")

                        self.in_b_and_mdt_interface = YLeaf(YType.str, "in-b-and-mdt-interface")

                        self.in_b_and_mdt_mtu = YLeaf(YType.uint32, "in-b-and-mdt-mtu")

                        self.in_b_and_mdt_name = YLeaf(YType.str, "in-b-and-mdt-name")

                        self.in_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "in-b-and-mdt-rpf-identifier")

                        self.in_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "in-band-maximum-mdt-aggregation")

                        self.in_band_signaling_local_enabled = YLeaf(YType.boolean, "in-band-signaling-local-enabled")

                        self.in_band_signaling_remote_enabled = YLeaf(YType.boolean, "in-band-signaling-remote-enabled")

                        self.inter_autonomous_system_enabled = YLeaf(YType.boolean, "inter-autonomous-system-enabled")

                        self.ir_maximum_mdt_aggregation = YLeaf(YType.uint32, "ir-maximum-mdt-aggregation")

                        self.ir_mdt_data_announce_interval = YLeaf(YType.uint32, "ir-mdt-data-announce-interval")

                        self.ir_mdt_data_switchover_interval = YLeaf(YType.uint32, "ir-mdt-data-switchover-interval")

                        self.ir_mdt_interface = YLeaf(YType.str, "ir-mdt-interface")

                        self.ir_mdt_mtu = YLeaf(YType.uint32, "ir-mdt-mtu")

                        self.ir_mdt_name = YLeaf(YType.str, "ir-mdt-name")

                        self.ir_mdt_rpf_identifier = YLeaf(YType.uint32, "ir-mdt-rpf-identifier")

                        self.ir_mdt_tail_label = YLeaf(YType.uint32, "ir-mdt-tail-label")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_active_ital = YLeaf(YType.boolean, "is-active-ital")

                        self.is_all_interface_disable_operation = YLeaf(YType.boolean, "is-all-interface-disable-operation")

                        self.is_auto_rp_listen_enabled = YLeaf(YType.boolean, "is-auto-rp-listen-enabled")

                        self.is_auto_rp_listen_sock_add = YLeaf(YType.boolean, "is-auto-rp-listen-sock-add")

                        self.is_create_gin_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-gin-b-and-mdt-interface")

                        self.is_create_in_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-in-b-and-mdt-interface")

                        self.is_create_ir_mdt_interface = YLeaf(YType.boolean, "is-create-ir-mdt-interface")

                        self.is_create_mdt_interface = YLeaf(YType.boolean, "is-create-mdt-interface")

                        self.is_create_mldp_mdt_interface = YLeaf(YType.boolean, "is-create-mldp-mdt-interface")

                        self.is_create_rsvp_te_mdt_interface = YLeaf(YType.boolean, "is-create-rsvp-te-mdt-interface")

                        self.is_default_granges = YLeaf(YType.boolean, "is-default-granges")

                        self.is_gin_b_and_mdt_owner = YLeaf(YType.boolean, "is-gin-b-and-mdt-owner")

                        self.is_in_b_and_mdt_owner = YLeaf(YType.boolean, "is-in-b-and-mdt-owner")

                        self.is_ir_mdt_owner = YLeaf(YType.boolean, "is-ir-mdt-owner")

                        self.is_lpts_socket_add_required = YLeaf(YType.boolean, "is-lpts-socket-add-required")

                        self.is_lpts_socket_added = YLeaf(YType.boolean, "is-lpts-socket-added")

                        self.is_m_host_publish_pending = YLeaf(YType.boolean, "is-m-host-publish-pending")

                        self.is_mdt_owner = YLeaf(YType.boolean, "is-mdt-owner")

                        self.is_mldp_mdt_owner = YLeaf(YType.boolean, "is-mldp-mdt-owner")

                        self.is_mrib_register = YLeaf(YType.boolean, "is-mrib-register")

                        self.is_multicast_rib_registration = YLeaf(YType.boolean, "is-multicast-rib-registration")

                        self.is_pim_nsf_rib_converge_received = YLeaf(YType.boolean, "is-pim-nsf-rib-converge-received")

                        self.is_pim_nsf_rib_converged = YLeaf(YType.boolean, "is-pim-nsf-rib-converged")

                        self.is_redistribution_reset = YLeaf(YType.boolean, "is-redistribution-reset")

                        self.is_register_injection_lpts_socket_add_required = YLeaf(YType.boolean, "is-register-injection-lpts-socket-add-required")

                        self.is_register_injection_lpts_socket_added = YLeaf(YType.boolean, "is-register-injection-lpts-socket-added")

                        self.is_register_injection_socket_add_required = YLeaf(YType.boolean, "is-register-injection-socket-add-required")

                        self.is_register_injection_socket_added = YLeaf(YType.boolean, "is-register-injection-socket-added")

                        self.is_rib_multipath_enabled = YLeaf(YType.boolean, "is-rib-multipath-enabled")

                        self.is_rib_multipath_interface_hash = YLeaf(YType.boolean, "is-rib-multipath-interface-hash")

                        self.is_rib_multipath_source_hash = YLeaf(YType.boolean, "is-rib-multipath-source-hash")

                        self.is_rib_multipath_source_next_hop_hash = YLeaf(YType.boolean, "is-rib-multipath-source-next-hop-hash")

                        self.is_routing_enabled = YLeaf(YType.boolean, "is-routing-enabled")

                        self.is_rsvp_te_mdt_owner = YLeaf(YType.boolean, "is-rsvp-te-mdt-owner")

                        self.is_socket_add_required = YLeaf(YType.boolean, "is-socket-add-required")

                        self.is_socket_added = YLeaf(YType.boolean, "is-socket-added")

                        self.is_udp_socket_add_required = YLeaf(YType.boolean, "is-udp-socket-add-required")

                        self.is_udp_socket_added = YLeaf(YType.boolean, "is-udp-socket-added")

                        self.is_udp_socket_bind = YLeaf(YType.boolean, "is-udp-socket-bind")

                        self.is_udp_socket_bind_required = YLeaf(YType.boolean, "is-udp-socket-bind-required")

                        self.is_unicast_rib_registration = YLeaf(YType.boolean, "is-unicast-rib-registration")

                        self.maximum_mdt_aggregation = YLeaf(YType.uint32, "maximum-mdt-aggregation")

                        self.mdt_data_announce_interval = YLeaf(YType.uint32, "mdt-data-announce-interval")

                        self.mdt_data_switchover_interval = YLeaf(YType.uint32, "mdt-data-switchover-interval")

                        self.mdt_default_group = YLeaf(YType.str, "mdt-default-group")

                        self.mdt_gre_remote_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-remote-rpf-identifier")

                        self.mdt_gre_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-rpf-identifier")

                        self.mdt_immediate_switch = YLeaf(YType.boolean, "mdt-immediate-switch")

                        self.mdt_interface = YLeaf(YType.str, "mdt-interface")

                        self.mdt_mtu = YLeaf(YType.uint32, "mdt-mtu")

                        self.mdt_neighbor_filter_name = YLeaf(YType.str, "mdt-neighbor-filter-name")

                        self.mdt_partitioned_ir_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-ir-control-identifier")

                        self.mdt_partitioned_mdt_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-mdt-control-identifier")

                        self.mdt_source = YLeaf(YType.str, "mdt-source")

                        self.mdt_source_interface = YLeaf(YType.str, "mdt-source-interface")

                        self.mhost_default_interface_config = YLeaf(YType.str, "mhost-default-interface-config")

                        self.mhost_interface = YLeaf(YType.str, "mhost-interface")

                        self.mldp_auto_rp_announce_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-announce-tree-added")

                        self.mldp_auto_rp_discovery_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-discovery-tree-added")

                        self.mldp_bsr_control_tree_added = YLeaf(YType.boolean, "mldp-bsr-control-tree-added")

                        self.mldp_control_head_lsm_identifier = YLeaf(YType.uint32, "mldp-control-head-lsm-identifier")

                        self.mldp_head_local_label = YLeaf(YType.uint32, "mldp-head-local-label")

                        self.mldp_head_lsm_identifier = YLeaf(YType.uint32, "mldp-head-lsm-identifier")

                        self.mldp_maximum_mdt_aggregation = YLeaf(YType.uint32, "mldp-maximum-mdt-aggregation")

                        self.mldp_mdt_data_announce_interval = YLeaf(YType.uint32, "mldp-mdt-data-announce-interval")

                        self.mldp_mdt_data_switchover_interval = YLeaf(YType.uint32, "mldp-mdt-data-switchover-interval")

                        self.mldp_mdt_interface = YLeaf(YType.str, "mldp-mdt-interface")

                        self.mldp_mdt_mtu = YLeaf(YType.uint32, "mldp-mdt-mtu")

                        self.mldp_mdt_name = YLeaf(YType.str, "mldp-mdt-name")

                        self.mldp_mdt_remote_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-remote-rpf-identifier")

                        self.mldp_mdt_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-rpf-identifier")

                        self.mldp_partioned_mp2m_ptree = YLeaf(YType.boolean, "mldp-partioned-mp2m-ptree")

                        self.mldp_partitioned_head_lsm_identifier = YLeaf(YType.uint32, "mldp-partitioned-head-lsm-identifier")

                        self.mldp_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-partitioned-mdt-configured")

                        self.mldp_partitioned_mdt_identifier = YLeaf(YType.uint32, "mldp-partitioned-mdt-identifier")

                        self.mldp_remote_head_lsm_identifier = YLeaf(YType.uint32, "mldp-remote-head-lsm-identifier")

                        self.mldp_remote_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-remote-partitioned-mdt-configured")

                        self.mldp_root_address = YLeafList(YType.uint32, "mldp-root-address")

                        self.mldp_root_count = YLeaf(YType.uint32, "mldp-root-count")

                        self.murib_id = YLeaf(YType.uint32, "murib-id")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.non_default_vrf_count_on_socket = YLeaf(YType.uint32, "non-default-vrf-count-on-socket")

                        self.organization_unique_identifier = YLeaf(YType.uint32, "organization-unique-identifier")

                        self.p2mpte_li_drop = YLeaf(YType.uint32, "p2mpte-li-drop")

                        self.physical_interface_count = YLeaf(YType.uint64, "physical-interface-count")

                        self.redistribution_reset_count = YLeaf(YType.uint32, "redistribution-reset-count")

                        self.remote_table_id = YLeaf(YType.uint32, "remote-table-id")

                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                        self.rpf_id = YLeaf(YType.uint32, "rpf-id")

                        self.rpf_policy_name = YLeaf(YType.str, "rpf-policy-name")

                        self.rsvp_te_maximum_mdt_aggregation = YLeaf(YType.uint32, "rsvp-te-maximum-mdt-aggregation")

                        self.rsvp_te_mdt_data_announce_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-announce-interval")

                        self.rsvp_te_mdt_data_switchover_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-switchover-interval")

                        self.rsvp_te_mdt_interface = YLeaf(YType.str, "rsvp-te-mdt-interface")

                        self.rsvp_te_mdt_mtu = YLeaf(YType.uint32, "rsvp-te-mdt-mtu")

                        self.rsvp_te_mdt_name = YLeaf(YType.str, "rsvp-te-mdt-name")

                        self.rsvp_te_mdt_rpf_identifier = YLeaf(YType.uint32, "rsvp-te-mdt-rpf-identifier")

                        self.rsvp_te_mdt_static_p2mp_count = YLeaf(YType.uint32, "rsvp-te-mdt-static-p2mp-count")

                        self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                        self.sg_expiry_time = YLeaf(YType.uint16, "sg-expiry-time")

                        self.sg_expiry_timer_configured = YLeaf(YType.boolean, "sg-expiry-timer-configured")

                        self.sg_expiry_timer_sg_list = YLeaf(YType.str, "sg-expiry-timer-sg-list")

                        self.stale_rd_present = YLeaf(YType.boolean, "stale-rd-present")

                        self.suppress_pim_data_mdt_tlv = YLeaf(YType.boolean, "suppress-pim-data-mdt-tlv")

                        self.suppress_shared_tree_join = YLeaf(YType.boolean, "suppress-shared-tree-join")

                        self.table_count = YLeaf(YType.uint32, "table-count")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.umh = YLeaf(YType.boolean, "umh")

                        self.valid_rd_present = YLeaf(YType.boolean, "valid-rd-present")

                        self.virtual_interface_count = YLeaf(YType.uint64, "virtual-interface-count")

                        self.virtual_mlc_interface_name = YLeaf(YType.str, "virtual-mlc-interface-name")

                        self.vpn_index = YLeaf(YType.uint32, "vpn-index")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.remote_default_group = Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup()
                        self.remote_default_group.parent = self
                        self._children_name_map["remote_default_group"] = "remote-default-group"
                        self._children_yang_names.add("remote-default-group")

                        self.rpf_default_table = Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable()
                        self.rpf_default_table.parent = self
                        self._children_name_map["rpf_default_table"] = "rpf-default-table"
                        self._children_yang_names.add("rpf-default-table")

                        self.anycast_rp_range = YList(self)
                        self.export_route_target = YList(self)
                        self.import_route_target = YList(self)
                        self._segment_path = lambda: "context"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Context, ['active_table_count', 'allow_rp_configured', 'allow_rp_group_list', 'allow_rp_rp_list', 'anycast_rp_configured', 'anycast_rp_policy_name', 'bgp_auto_discovery_configured', 'bgp_auto_discovery_type', 'bgp_i_pmsi_added', 'bgp_remote_address', 'bgp_remote_interface', 'bgp_remote_interface_name', 'bgp_remote_on', 'bgp_remote_state', 'bgp_source_active_announce', 'gin_b_and_mdt_data_announce_interval', 'gin_b_and_mdt_data_switchover_interval', 'gin_b_and_mdt_interface', 'gin_b_and_mdt_mtu', 'gin_b_and_mdt_name', 'gin_b_and_mdt_rpf_identifier', 'gin_band_maximum_mdt_aggregation', 'in_b_and_mdt_data_announce_interval', 'in_b_and_mdt_data_switchover_interval', 'in_b_and_mdt_interface', 'in_b_and_mdt_mtu', 'in_b_and_mdt_name', 'in_b_and_mdt_rpf_identifier', 'in_band_maximum_mdt_aggregation', 'in_band_signaling_local_enabled', 'in_band_signaling_remote_enabled', 'inter_autonomous_system_enabled', 'ir_maximum_mdt_aggregation', 'ir_mdt_data_announce_interval', 'ir_mdt_data_switchover_interval', 'ir_mdt_interface', 'ir_mdt_mtu', 'ir_mdt_name', 'ir_mdt_rpf_identifier', 'ir_mdt_tail_label', 'is_active', 'is_active_ital', 'is_all_interface_disable_operation', 'is_auto_rp_listen_enabled', 'is_auto_rp_listen_sock_add', 'is_create_gin_b_and_mdt_interface', 'is_create_in_b_and_mdt_interface', 'is_create_ir_mdt_interface', 'is_create_mdt_interface', 'is_create_mldp_mdt_interface', 'is_create_rsvp_te_mdt_interface', 'is_default_granges', 'is_gin_b_and_mdt_owner', 'is_in_b_and_mdt_owner', 'is_ir_mdt_owner', 'is_lpts_socket_add_required', 'is_lpts_socket_added', 'is_m_host_publish_pending', 'is_mdt_owner', 'is_mldp_mdt_owner', 'is_mrib_register', 'is_multicast_rib_registration', 'is_pim_nsf_rib_converge_received', 'is_pim_nsf_rib_converged', 'is_redistribution_reset', 'is_register_injection_lpts_socket_add_required', 'is_register_injection_lpts_socket_added', 'is_register_injection_socket_add_required', 'is_register_injection_socket_added', 'is_rib_multipath_enabled', 'is_rib_multipath_interface_hash', 'is_rib_multipath_source_hash', 'is_rib_multipath_source_next_hop_hash', 'is_routing_enabled', 'is_rsvp_te_mdt_owner', 'is_socket_add_required', 'is_socket_added', 'is_udp_socket_add_required', 'is_udp_socket_added', 'is_udp_socket_bind', 'is_udp_socket_bind_required', 'is_unicast_rib_registration', 'maximum_mdt_aggregation', 'mdt_data_announce_interval', 'mdt_data_switchover_interval', 'mdt_default_group', 'mdt_gre_remote_rpf_identifier', 'mdt_gre_rpf_identifier', 'mdt_immediate_switch', 'mdt_interface', 'mdt_mtu', 'mdt_neighbor_filter_name', 'mdt_partitioned_ir_control_identifier', 'mdt_partitioned_mdt_control_identifier', 'mdt_source', 'mdt_source_interface', 'mhost_default_interface_config', 'mhost_interface', 'mldp_auto_rp_announce_tree_added', 'mldp_auto_rp_discovery_tree_added', 'mldp_bsr_control_tree_added', 'mldp_control_head_lsm_identifier', 'mldp_head_local_label', 'mldp_head_lsm_identifier', 'mldp_maximum_mdt_aggregation', 'mldp_mdt_data_announce_interval', 'mldp_mdt_data_switchover_interval', 'mldp_mdt_interface', 'mldp_mdt_mtu', 'mldp_mdt_name', 'mldp_mdt_remote_rpf_identifier', 'mldp_mdt_rpf_identifier', 'mldp_partioned_mp2m_ptree', 'mldp_partitioned_head_lsm_identifier', 'mldp_partitioned_mdt_configured', 'mldp_partitioned_mdt_identifier', 'mldp_remote_head_lsm_identifier', 'mldp_remote_partitioned_mdt_configured', 'mldp_root_address', 'mldp_root_count', 'murib_id', 'neighbor_filter_name', 'non_default_vrf_count_on_socket', 'organization_unique_identifier', 'p2mpte_li_drop', 'physical_interface_count', 'redistribution_reset_count', 'remote_table_id', 'route_distinguisher', 'rpf_id', 'rpf_policy_name', 'rsvp_te_maximum_mdt_aggregation', 'rsvp_te_mdt_data_announce_interval', 'rsvp_te_mdt_data_switchover_interval', 'rsvp_te_mdt_interface', 'rsvp_te_mdt_mtu', 'rsvp_te_mdt_name', 'rsvp_te_mdt_rpf_identifier', 'rsvp_te_mdt_static_p2mp_count', 'rump_enabled', 'sg_expiry_time', 'sg_expiry_timer_configured', 'sg_expiry_timer_sg_list', 'stale_rd_present', 'suppress_pim_data_mdt_tlv', 'suppress_shared_tree_join', 'table_count', 'table_id', 'umh', 'valid_rd_present', 'virtual_interface_count', 'virtual_mlc_interface_name', 'vpn_index', 'vrf_id'], name, value)


                    class AnycastRpRange(Entity):
                        """
                        Anycast\-RP Ranges
                        
                        .. attribute:: ancast_rp_marked
                        
                        	Anycast\-RP Range marked
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Anycast\-RP Range Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Anycast\-RP Range Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Context.AnycastRpRange, self).__init__()

                            self.yang_name = "anycast-rp-range"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"prefix" : ("prefix", Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix)}
                            self._child_list_classes = {}

                            self.ancast_rp_marked = YLeaf(YType.boolean, "ancast-rp-marked")

                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                            self.prefix = Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")
                            self._segment_path = lambda: "anycast-rp-range"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Context.AnycastRpRange, ['ancast_rp_marked', 'prefix_length'], name, value)


                        class Prefix(Entity):
                            """
                            Anycast\-RP Range Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "anycast-rp-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class ExportRouteTarget(Entity):
                        """
                        Export Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget, self).__init__()

                            self.yang_name = "export-route-target"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                            self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                            self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                            self.configured = YLeaf(YType.boolean, "configured")

                            self.route_target = YLeaf(YType.str, "route-target")

                            self.segment_border = YLeaf(YType.boolean, "segment-border")

                            self.update_pending = YLeaf(YType.boolean, "update-pending")
                            self._segment_path = lambda: "export-route-target"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget, ['anycast_rp', 'anycast_rp_marked', 'bgp_auto_discovery', 'configured', 'route_target', 'segment_border', 'update_pending'], name, value)


                    class ImportRouteTarget(Entity):
                        """
                        Import Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget, self).__init__()

                            self.yang_name = "import-route-target"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                            self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                            self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                            self.configured = YLeaf(YType.boolean, "configured")

                            self.route_target = YLeaf(YType.str, "route-target")

                            self.segment_border = YLeaf(YType.boolean, "segment-border")

                            self.update_pending = YLeaf(YType.boolean, "update-pending")
                            self._segment_path = lambda: "import-route-target"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget, ['anycast_rp', 'anycast_rp_marked', 'bgp_auto_discovery', 'configured', 'route_target', 'segment_border', 'update_pending'], name, value)


                    class RemoteDefaultGroup(Entity):
                        """
                        Remote Default Group
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__init__()

                            self.yang_name = "remote-default-group"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "remote-default-group"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfDefaultTable(Entity):
                        """
                        RPF Default Table
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable, self).__init__()

                            self.yang_name = "rpf-default-table"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                            self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                            self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                            self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                            self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.table_id = YLeaf(YType.uint32, "table-id")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")
                            self._segment_path = lambda: "rpf-default-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable, ['afi', 'is_active', 'is_ital_registration_done', 'is_rib_convergence', 'is_rib_convergence_received', 'is_rib_registration_done', 'rpf_registrations', 'safi', 'table_id', 'table_name', 'vrf_id'], name, value)


                class Gre(Entity):
                    """
                    GRE information
                    
                    .. attribute:: gre_hashes
                    
                    	GRE hash
                    	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreHashes>`
                    
                    .. attribute:: gre_next_hops
                    
                    	GRE destination neighbor table
                    	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Gre, self).__init__()

                        self.yang_name = "gre"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"gre-hashes" : ("gre_hashes", Pim.Active.Vrfs.Vrf.Gre.GreHashes), "gre-next-hops" : ("gre_next_hops", Pim.Active.Vrfs.Vrf.Gre.GreNextHops)}
                        self._child_list_classes = {}

                        self.gre_hashes = Pim.Active.Vrfs.Vrf.Gre.GreHashes()
                        self.gre_hashes.parent = self
                        self._children_name_map["gre_hashes"] = "gre-hashes"
                        self._children_yang_names.add("gre-hashes")

                        self.gre_next_hops = Pim.Active.Vrfs.Vrf.Gre.GreNextHops()
                        self.gre_next_hops.parent = self
                        self._children_name_map["gre_next_hops"] = "gre-next-hops"
                        self._children_yang_names.add("gre-next-hops")
                        self._segment_path = lambda: "gre"


                    class GreHashes(Entity):
                        """
                        GRE hash
                        
                        .. attribute:: gre_hash
                        
                        	PIM GRE Hashed Underlying Interface
                        	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Gre.GreHashes, self).__init__()

                            self.yang_name = "gre-hashes"
                            self.yang_parent_name = "gre"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"gre-hash" : ("gre_hash", Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash)}

                            self.gre_hash = YList(self)
                            self._segment_path = lambda: "gre-hashes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Gre.GreHashes, [], name, value)


                        class GreHash(Entity):
                            """
                            PIM GRE Hashed Underlying Interface
                            
                            .. attribute:: source_address  <key>
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: destination_address  <key>
                            
                            	Destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: ifname  <key>
                            
                            	GRE Tunnel Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__init__()

                                self.yang_name = "gre-hash"
                                self.yang_parent_name = "gre-hashes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.ifname = YLeaf(YType.str, "ifname")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")
                                self._segment_path = lambda: "gre-hash" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[ifname='" + self.ifname.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash, ['source_address', 'destination_address', 'ifname', 'next_hop_interface'], name, value)


                    class GreNextHops(Entity):
                        """
                        GRE destination neighbor table
                        
                        .. attribute:: gre_next_hop
                        
                        	PIM GRE address next\-hop information
                        	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops, self).__init__()

                            self.yang_name = "gre-next-hops"
                            self.yang_parent_name = "gre"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"gre-next-hop" : ("gre_next_hop", Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop)}

                            self.gre_next_hop = YList(self)
                            self._segment_path = lambda: "gre-next-hops"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Gre.GreNextHops, [], name, value)


                        class GreNextHop(Entity):
                            """
                            PIM GRE address next\-hop information
                            
                            .. attribute:: destination_address  <key>
                            
                            	GRE destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: gre_path
                            
                            	GRE Paths list
                            	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath>`
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__init__()

                                self.yang_name = "gre-next-hop"
                                self.yang_parent_name = "gre-next-hops"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"registered-address" : ("registered_address", Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress)}
                                self._child_list_classes = {"gre-path" : ("gre_path", Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath)}

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.is_connected = YLeaf(YType.uint8, "is-connected")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                self.registered_address = Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                self.registered_address.parent = self
                                self._children_name_map["registered_address"] = "registered-address"
                                self._children_yang_names.add("registered-address")

                                self.gre_path = YList(self)
                                self._segment_path = lambda: "gre-next-hop" + "[destination-address='" + self.destination_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, ['destination_address', 'is_connected', 'metric', 'metric_preference'], name, value)


                            class GrePath(Entity):
                                """
                                GRE Paths list
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: gre_interface_name
                                
                                	GRE Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: gre_neighbor
                                
                                	GRE neighbor
                                	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                                
                                .. attribute:: gre_next_hop
                                
                                	GRE nexthop
                                	**type**\:   :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop>`
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_gre_interface_disabled
                                
                                	Is the gre interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                    self.yang_name = "gre-path"
                                    self.yang_parent_name = "gre-next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"gre-neighbor" : ("gre_neighbor", Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor), "gre-next-hop" : ("gre_next_hop", Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop)}
                                    self._child_list_classes = {}

                                    self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                    self.gre_interface_name = YLeaf(YType.str, "gre-interface-name")

                                    self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                    self.is_gre_interface_disabled = YLeaf(YType.boolean, "is-gre-interface-disabled")

                                    self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                    self.gre_neighbor = Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                    self.gre_neighbor.parent = self
                                    self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                    self._children_yang_names.add("gre-neighbor")

                                    self.gre_next_hop = Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                    self.gre_next_hop.parent = self
                                    self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                    self._children_yang_names.add("gre-next-hop")
                                    self._segment_path = lambda: "gre-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, ['extranet_vrf_name', 'gre_interface_name', 'is_connector_attribute_present', 'is_gre_interface_disabled', 'is_via_lsm'], name, value)


                                class GreNeighbor(Entity):
                                    """
                                    GRE neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                        self.yang_name = "gre-neighbor"
                                        self.yang_parent_name = "gre-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "gre-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class GreNextHop(Entity):
                                    """
                                    GRE nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__init__()

                                        self.yang_name = "gre-next-hop"
                                        self.yang_parent_name = "gre-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "gre-next-hop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class RegisteredAddress(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                    self.yang_name = "registered-address"
                                    self.yang_parent_name = "gre-next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "registered-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class GroupMapRpfs(Entity):
                    """
                    PIM group mapping information
                    
                    .. attribute:: group_map_rpf
                    
                    	PIM group mapping entry
                    	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.GroupMapRpfs, self).__init__()

                        self.yang_name = "group-map-rpfs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"group-map-rpf" : ("group_map_rpf", Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf)}

                        self.group_map_rpf = YList(self)
                        self._segment_path = lambda: "group-map-rpfs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapRpfs, [], name, value)


                    class GroupMapRpf(Entity):
                        """
                        PIM group mapping entry
                        
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_priority
                        
                        	RP priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__init__()

                            self.yang_name = "group-map-rpf"
                            self.yang_parent_name = "group-map-rpfs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-map-information" : ("group_map_information", Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation), "rpf-neighbor" : ("rpf_neighbor", Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor)}
                            self._child_list_classes = {}

                            self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                            self.client = YLeaf(YType.enumeration, "client")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_priority = YLeaf(YType.int32, "rp-priority")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.group_map_information = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.rpf_neighbor = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")
                            self._segment_path = lambda: "group-map-rpf"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, ['are_we_rp', 'client', 'prefix', 'prefix_length', 'protocol', 'rp_address', 'rp_priority', 'rpf_interface_name', 'rpf_vrf_name'], name, value)


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-rpf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"prefix" : ("prefix", Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix), "rp-address" : ("rp_address", Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress)}
                                self._child_list_classes = {}

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")
                                self._segment_path = lambda: "group-map-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, ['client', 'group_count', 'is_override', 'is_used', 'mrib_active', 'prefix_length', 'priority', 'protocol'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "prefix"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "rp-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "group-map-rpf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class GroupMapSources(Entity):
                    """
                    PIM group\-mapping with source information
                    
                    .. attribute:: group_map_source
                    
                    	PIM Group Mapping Entry with source information
                    	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.GroupMapSources, self).__init__()

                        self.yang_name = "group-map-sources"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"group-map-source" : ("group_map_source", Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource)}

                        self.group_map_source = YList(self)
                        self._segment_path = lambda: "group-map-sources"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapSources, [], name, value)


                    class GroupMapSource(Entity):
                        """
                        PIM Group Mapping Entry with source information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	RP Priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__init__()

                            self.yang_name = "group-map-source"
                            self.yang_parent_name = "group-map-sources"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-map-information" : ("group_map_information", Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation), "source-of-information" : ("source_of_information", Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation)}
                            self._child_list_classes = {}

                            self.client = YLeaf(YType.enumeration, "client")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.holdtime = YLeaf(YType.int32, "holdtime")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.int32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_map_information = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.source_of_information = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")
                            self._segment_path = lambda: "group-map-source"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource, ['client', 'expires', 'holdtime', 'prefix', 'prefix_length', 'priority', 'protocol', 'rp_address', 'uptime'], name, value)


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"prefix" : ("prefix", Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix), "rp-address" : ("rp_address", Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress)}
                                self._child_list_classes = {}

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")
                                self._segment_path = lambda: "group-map-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, ['client', 'group_count', 'is_override', 'is_used', 'mrib_active', 'prefix_length', 'priority', 'protocol'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "prefix"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "rp-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-map-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-of-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class IfrsInterfaces(Entity):
                    """
                    PIM interfaces in forward reference store table
                    
                    .. attribute:: ifrs_interface
                    
                    	PIM IFRS interface information
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ifrs-interface" : ("ifrs_interface", Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface)}

                        self.ifrs_interface = YList(self)
                        self._segment_path = lambda: "ifrs-interfaces"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.IfrsInterfaces, [], name, value)


                    class IfrsInterface(Entity):
                        """
                        PIM IFRS interface information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"dr-address" : ("dr_address", Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress)}
                            self._child_list_classes = {"interface-address" : ("interface_address", Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "dr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "interface-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class IfrsSummary(Entity):
                    """
                    PIM interfaces in forward reference store
                    summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration counts
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Number of interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.IfrsSummary, self).__init__()

                        self.yang_name = "ifrs-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                        self.interface_count = YLeaf(YType.uint32, "interface-count")
                        self._segment_path = lambda: "ifrs-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.IfrsSummary, ['configuration_count', 'interface_count'], name, value)


                class InterfaceOldFormats(Entity):
                    """
                    PIM interfaces in old format
                    
                    .. attribute:: interface_old_format
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats, self).__init__()

                        self.yang_name = "interface-old-formats"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-old-format" : ("interface_old_format", Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat)}

                        self.interface_old_format = YList(self)
                        self._segment_path = lambda: "interface-old-formats"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.InterfaceOldFormats, [], name, value)


                    class InterfaceOldFormat(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                            self.yang_name = "interface-old-format"
                            self.yang_parent_name = "interface-old-formats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"dr-address" : ("dr_address", Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress)}
                            self._child_list_classes = {"interface-address" : ("interface_address", Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "interface-old-format" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "dr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "interface-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceStatistics(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_statistic
                    
                    	PIM interface statistics
                    	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.InterfaceStatistics, self).__init__()

                        self.yang_name = "interface-statistics"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-statistic" : ("interface_statistic", Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic)}

                        self.interface_statistic = YList(self)
                        self._segment_path = lambda: "interface-statistics"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.InterfaceStatistics, [], name, value)


                    class InterfaceStatistic(Entity):
                        """
                        PIM interface statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: input_assert
                        
                        	Assert packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_bsr_message
                        
                        	Input BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_candidate_rp_advertisement
                        
                        	Input Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_df_election
                        
                        	DF Election packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_ack_message
                        
                        	Input Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_message
                        
                        	Input Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_hello
                        
                        	Hello packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_jp
                        
                        	Join Prune packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_miscellaneous
                        
                        	Miscellaneous packet in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register
                        
                        	Register packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register_stop
                        
                        	Register Stop packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_assert
                        
                        	Assert packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_bsr_message
                        
                        	Output BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_candidate_rp_advertisement
                        
                        	Output Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_df_election
                        
                        	DF Election packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_ack_message
                        
                        	Output Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_message
                        
                        	Output Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_hello
                        
                        	Hello packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_jp
                        
                        	Join Prune packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register
                        
                        	Register packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register_stop
                        
                        	Register Stop packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__init__()

                            self.yang_name = "interface-statistic"
                            self.yang_parent_name = "interface-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.input_assert = YLeaf(YType.uint32, "input-assert")

                            self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                            self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                            self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                            self.input_graft_ack_message = YLeaf(YType.uint32, "input-graft-ack-message")

                            self.input_graft_message = YLeaf(YType.uint32, "input-graft-message")

                            self.input_hello = YLeaf(YType.uint32, "input-hello")

                            self.input_jp = YLeaf(YType.uint32, "input-jp")

                            self.input_miscellaneous = YLeaf(YType.uint32, "input-miscellaneous")

                            self.input_register = YLeaf(YType.uint32, "input-register")

                            self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                            self.output_assert = YLeaf(YType.uint32, "output-assert")

                            self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                            self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                            self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                            self.output_graft_ack_message = YLeaf(YType.uint32, "output-graft-ack-message")

                            self.output_graft_message = YLeaf(YType.uint32, "output-graft-message")

                            self.output_hello = YLeaf(YType.uint32, "output-hello")

                            self.output_jp = YLeaf(YType.uint32, "output-jp")

                            self.output_register = YLeaf(YType.uint32, "output-register")

                            self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")
                            self._segment_path = lambda: "interface-statistic" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, ['interface_name', 'input_assert', 'input_bsr_message', 'input_candidate_rp_advertisement', 'input_df_election', 'input_graft_ack_message', 'input_graft_message', 'input_hello', 'input_jp', 'input_miscellaneous', 'input_register', 'input_register_stop', 'output_assert', 'output_bsr_message', 'output_candidate_rp_advertisement', 'output_df_election', 'output_graft_ack_message', 'output_graft_message', 'output_hello', 'output_jp', 'output_register', 'output_register_stop'], name, value)


                class Interfaces(Entity):
                    """
                    PIM interfaces
                    
                    .. attribute:: interface
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Interfaces, self).__init__()

                        self.yang_name = "interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface" : ("interface", Pim.Active.Vrfs.Vrf.Interfaces.Interface)}

                        self.interface = YList(self)
                        self._segment_path = lambda: "interfaces"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Interfaces, [], name, value)


                    class Interface(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Interfaces.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"dr-address" : ("dr_address", Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress)}
                            self._child_list_classes = {"interface-address" : ("interface_address", Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Interfaces.Interface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "dr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "interface-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class JpStatistics(Entity):
                    """
                    PIM join prune statistics table
                    
                    .. attribute:: jp_statistic
                    
                    	PIM Join Prune Statistics
                    	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.JpStatistics, self).__init__()

                        self.yang_name = "jp-statistics"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"jp-statistic" : ("jp_statistic", Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic)}

                        self.jp_statistic = YList(self)
                        self._segment_path = lambda: "jp-statistics"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.JpStatistics, [], name, value)


                    class JpStatistic(Entity):
                        """
                        PIM Join Prune Statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received
                        
                        	Received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received100
                        
                        	Received 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_10k
                        
                        	Received 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_1k
                        
                        	Received 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_50k
                        
                        	Deprecated by Received100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted
                        
                        	Transmitted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted100
                        
                        	Transmitted 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_10k
                        
                        	Transmitted 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_1k
                        
                        	Transmitted 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_50k
                        
                        	Deprecated by Transmitted100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic, self).__init__()

                            self.yang_name = "jp-statistic"
                            self.yang_parent_name = "jp-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.received = YLeaf(YType.uint32, "received")

                            self.received100 = YLeaf(YType.uint16, "received100")

                            self.received_10k = YLeaf(YType.uint16, "received-10k")

                            self.received_1k = YLeaf(YType.uint16, "received-1k")

                            self.received_50k = YLeaf(YType.uint16, "received-50k")

                            self.transmitted = YLeaf(YType.uint32, "transmitted")

                            self.transmitted100 = YLeaf(YType.uint16, "transmitted100")

                            self.transmitted_10k = YLeaf(YType.uint16, "transmitted-10k")

                            self.transmitted_1k = YLeaf(YType.uint16, "transmitted-1k")

                            self.transmitted_50k = YLeaf(YType.uint16, "transmitted-50k")
                            self._segment_path = lambda: "jp-statistic" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic, ['interface_name', 'interface_name_xr', 'mtu', 'received', 'received100', 'received_10k', 'received_1k', 'received_50k', 'transmitted', 'transmitted100', 'transmitted_10k', 'transmitted_1k', 'transmitted_50k'], name, value)


                class MibDatabases(Entity):
                    """
                    PIM group database for mroute mibs table
                    
                    .. attribute:: mib_database
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.MibDatabases, self).__init__()

                        self.yang_name = "mib-databases"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"mib-database" : ("mib_database", Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase)}

                        self.mib_database = YList(self)
                        self._segment_path = lambda: "mib-databases"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.MibDatabases, [], name, value)


                    class MibDatabase(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: assert_metric
                        
                        	Assert Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_metric_preference
                        
                        	Assert Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_rpt_bit
                        
                        	Assert RPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: bidirectional_route
                        
                        	Is this Bidir ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Multicast satic route group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr>`
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface name 
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: rpf_mask
                        
                        	Mask of the multicast root
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_neighbor
                        
                        	The RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: source_address
                        
                        	Multicast static route source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr>`
                        
                        .. attribute:: source_netmask
                        
                        	Source mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: spt_bit
                        
                        	Is SPT bit set ?
                        	**type**\:  bool
                        
                        .. attribute:: upstream_assert_timer
                        
                        	Upstream Assert Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime of route
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase, self).__init__()

                            self.yang_name = "mib-database"
                            self.yang_parent_name = "mib-databases"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr), "rpf-neighbor" : ("rpf_neighbor", Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor), "rpf-root" : ("rpf_root", Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot), "source-address-xr" : ("source_address_xr", Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr)}
                            self._child_list_classes = {}

                            self.assert_metric = YLeaf(YType.uint32, "assert-metric")

                            self.assert_metric_preference = YLeaf(YType.uint32, "assert-metric-preference")

                            self.assert_rpt_bit = YLeaf(YType.boolean, "assert-rpt-bit")

                            self.bidirectional_route = YLeaf(YType.boolean, "bidirectional-route")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                            self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_mask = YLeaf(YType.uint32, "rpf-mask")

                            self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                            self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_netmask = YLeaf(YType.int32, "source-netmask")

                            self.spt_bit = YLeaf(YType.boolean, "spt-bit")

                            self.upstream_assert_timer = YLeaf(YType.int32, "upstream-assert-timer")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.rpf_neighbor = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                            self.rpf_root = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._children_yang_names.add("rpf-root")

                            self.source_address_xr = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")
                            self._segment_path = lambda: "mib-database"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase, ['assert_metric', 'assert_metric_preference', 'assert_rpt_bit', 'bidirectional_route', 'group_address', 'protocol', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_mask', 'rpf_safi', 'rpf_table_name', 'rpf_vrf_name', 'source_address', 'source_netmask', 'spt_bit', 'upstream_assert_timer', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            The RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-root"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class MulticastStaticRoutes(Entity):
                    """
                    PIM multicast static route table
                    
                    .. attribute:: multicast_static_route
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes, self).__init__()

                        self.yang_name = "multicast-static-routes"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"multicast-static-route" : ("multicast_static_route", Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute)}

                        self.multicast_static_route = YList(self)
                        self._segment_path = lambda: "multicast-static-routes"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes, [], name, value)


                    class MulticastStaticRoute(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: address
                        
                        	Network address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: distance
                        
                        	Distance
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_via_lsm
                        
                        	LSM flag
                        	**type**\:  bool
                        
                        .. attribute:: nexthop
                        
                        	Next Hop
                        	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: prefix_length_xr
                        
                        	Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                            self.yang_name = "multicast-static-route"
                            self.yang_parent_name = "multicast-static-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"nexthop" : ("nexthop", Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop), "prefix" : ("prefix", Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix)}
                            self._child_list_classes = {}

                            self.address = YLeaf(YType.str, "address")

                            self.distance = YLeaf(YType.uint32, "distance")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                            self.nexthop = Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                            self.nexthop.parent = self
                            self._children_name_map["nexthop"] = "nexthop"
                            self._children_yang_names.add("nexthop")

                            self.prefix = Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")
                            self._segment_path = lambda: "multicast-static-route"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, ['address', 'distance', 'interface_name', 'is_via_lsm', 'prefix_length', 'prefix_length_xr'], name, value)


                        class Nexthop(Entity):
                            """
                            Next Hop
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                                self.yang_name = "nexthop"
                                self.yang_parent_name = "multicast-static-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "nexthop"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Prefix(Entity):
                            """
                            Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "multicast-static-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class NeighborOldFormats(Entity):
                    """
                    PIM neighbor table old format
                    
                    .. attribute:: neighbor_old_format
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.NeighborOldFormats, self).__init__()

                        self.yang_name = "neighbor-old-formats"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-old-format" : ("neighbor_old_format", Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat)}

                        self.neighbor_old_format = YList(self)
                        self._segment_path = lambda: "neighbor-old-formats"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.NeighborOldFormats, [], name, value)


                    class NeighborOldFormat(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__init__()

                            self.yang_name = "neighbor-old-format"
                            self.yang_parent_name = "neighbor-old-formats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr)}

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                            self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                            self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.neighbor_address_xr = YList(self)
                            self._segment_path = lambda: "neighbor-old-format"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, ['dr_priority', 'expires', 'expiry_timer', 'interface_name', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bfd_state', 'is_bidirectional_capable', 'is_dr_priority_capable', 'is_ecmp_redirect_capable', 'is_proxy_capable', 'is_this_neighbor_dr', 'is_this_neighbor_us', 'neighbor_address', 'override_interval', 'propagation_delay', 'uptime'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "neighbor-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class NeighborSummaries(Entity):
                    """
                    PIM neighbor summary table
                    
                    .. attribute:: neighbor_summary
                    
                    	PIM neighbor summary information
                    	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.NeighborSummaries, self).__init__()

                        self.yang_name = "neighbor-summaries"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-summary" : ("neighbor_summary", Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary)}

                        self.neighbor_summary = YList(self)
                        self._segment_path = lambda: "neighbor-summaries"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.NeighborSummaries, [], name, value)


                    class NeighborSummary(Entity):
                        """
                        PIM neighbor summary information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: number_of_external_neighbors
                        
                        	Number of external neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__init__()

                            self.yang_name = "neighbor-summary"
                            self.yang_parent_name = "neighbor-summaries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.number_of_external_neighbors = YLeaf(YType.int32, "number-of-external-neighbors")

                            self.number_of_neighbors = YLeaf(YType.int32, "number-of-neighbors")
                            self._segment_path = lambda: "neighbor-summary" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary, ['interface_name', 'number_of_external_neighbors', 'number_of_neighbors'], name, value)


                class Neighbors(Entity):
                    """
                    PIM neighbor table
                    
                    .. attribute:: neighbor
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Neighbors, self).__init__()

                        self.yang_name = "neighbors"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor" : ("neighbor", Pim.Active.Vrfs.Vrf.Neighbors.Neighbor)}

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "neighbors"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Neighbors, [], name, value)


                    class Neighbor(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbors"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr)}

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                            self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                            self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.neighbor_address_xr = YList(self)
                            self._segment_path = lambda: "neighbor"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Neighbors.Neighbor, ['dr_priority', 'expires', 'expiry_timer', 'interface_name', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bfd_state', 'is_bidirectional_capable', 'is_dr_priority_capable', 'is_ecmp_redirect_capable', 'is_proxy_capable', 'is_this_neighbor_dr', 'is_this_neighbor_us', 'neighbor_address', 'override_interval', 'propagation_delay', 'uptime'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "neighbor-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class NetIoTunnels(Entity):
                    """
                    Tunnel information that NETIO has 
                    
                    .. attribute:: net_io_tunnel
                    
                    	PIM netio tunnel information
                    	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.NetIoTunnels, self).__init__()

                        self.yang_name = "net-io-tunnels"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"net-io-tunnel" : ("net_io_tunnel", Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel)}

                        self.net_io_tunnel = YList(self)
                        self._segment_path = lambda: "net-io-tunnels"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.NetIoTunnels, [], name, value)


                    class NetIoTunnel(Entity):
                        """
                        PIM netio tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__init__()

                            self.yang_name = "net-io-tunnel"
                            self.yang_parent_name = "net-io-tunnels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-netio" : ("group_address_netio", Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio), "rp-address" : ("rp_address", Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress), "source-address" : ("source_address", Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress), "source-address-netio" : ("source_address_netio", Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio)}
                            self._child_list_classes = {}

                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_netio = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._children_yang_names.add("group-address-netio")

                            self.rp_address = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.source_address = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                            self.source_address_netio = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"
                            self._children_yang_names.add("source-address-netio")
                            self._segment_path = lambda: "net-io-tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, ['tunnel_name', 'vrf_name'], name, value)


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-netio"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-netio"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Ranges(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: range
                    
                    	PIM range list information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"range" : ("range", Pim.Active.Vrfs.Vrf.Ranges.Range)}

                        self.range = YList(self)
                        self._segment_path = lambda: "ranges"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Ranges, [], name, value)


                    class Range(Entity):
                        """
                        PIM range list information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: client_xr
                        
                        	Client mapping learnt via
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: group_range
                        
                        	List of group ranges
                        	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange>`
                        
                        .. attribute:: protocol
                        
                        	PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	Rendezvous point address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"rp-address-xr" : ("rp_address_xr", Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr), "source-of-information" : ("source_of_information", Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation)}
                            self._child_list_classes = {"group-range" : ("group_range", Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange)}

                            self.client = YLeaf(YType.enumeration, "client")

                            self.client_xr = YLeaf(YType.enumeration, "client-xr")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_address_xr = Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")

                            self.source_of_information = Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                            self.group_range = YList(self)
                            self._segment_path = lambda: "range"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Ranges.Range, ['client', 'client_xr', 'expires', 'protocol', 'rp_address'], name, value)


                        class GroupRange(Entity):
                            """
                            List of group ranges
                            
                            .. attribute:: expires
                            
                            	When mapping expires
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: source_of_information
                            
                            	Source of information
                            	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange, self).__init__()

                                self.yang_name = "group-range"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"prefix" : ("prefix", Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix), "source-of-information" : ("source_of_information", Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation)}
                                self._child_list_classes = {}

                                self.expires = YLeaf(YType.uint64, "expires")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.prefix = Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.source_of_information = Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                                self._children_yang_names.add("source-of-information")
                                self._segment_path = lambda: "group-range"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange, ['expires', 'prefix_length', 'uptime'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "prefix"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceOfInformation(Entity):
                                """
                                Source of information
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                    self.yang_name = "source-of-information"
                                    self.yang_parent_name = "group-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-of-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddressXr(Entity):
                            """
                            Rendezvous point address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-of-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class RoutePolicy(Entity):
                    """
                    PIM route policy
                    
                    .. attribute:: route_policy_statistics
                    
                    	PIM route policy statistics
                    	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics>`
                    
                    .. attribute:: route_policy_tests
                    
                    	PIM route policy test run table
                    	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.RoutePolicy, self).__init__()

                        self.yang_name = "route-policy"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"route-policy-statistics" : ("route_policy_statistics", Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics), "route-policy-tests" : ("route_policy_tests", Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests)}
                        self._child_list_classes = {}

                        self.route_policy_statistics = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                        self.route_policy_statistics.parent = self
                        self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                        self._children_yang_names.add("route-policy-statistics")

                        self.route_policy_tests = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                        self.route_policy_tests.parent = self
                        self._children_name_map["route_policy_tests"] = "route-policy-tests"
                        self._children_yang_names.add("route-policy-tests")
                        self._segment_path = lambda: "route-policy"


                    class RoutePolicyStatistics(Entity):
                        """
                        PIM route policy statistics
                        
                        .. attribute:: any_table
                        
                        	Number of RPF lookup in any Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Number of RPF lookup in default\-only Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop
                        
                        	Number of RPF drops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pass_
                        
                        	Number of RPF pass
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: requests
                        
                        	Number of RPF lookup requests
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__init__()

                            self.yang_name = "route-policy-statistics"
                            self.yang_parent_name = "route-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.any_table = YLeaf(YType.uint32, "any-table")

                            self.default_table = YLeaf(YType.uint32, "default-table")

                            self.drop = YLeaf(YType.uint32, "drop")

                            self.pass_ = YLeaf(YType.uint32, "pass")

                            self.policy_name = YLeaf(YType.str, "policy-name")

                            self.requests = YLeaf(YType.uint32, "requests")
                            self._segment_path = lambda: "route-policy-statistics"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, ['any_table', 'default_table', 'drop', 'pass_', 'policy_name', 'requests'], name, value)


                    class RoutePolicyTests(Entity):
                        """
                        PIM route policy test run table
                        
                        .. attribute:: route_policy_test
                        
                        	PIM route policy test run
                        	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__init__()

                            self.yang_name = "route-policy-tests"
                            self.yang_parent_name = "route-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"route-policy-test" : ("route_policy_test", Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest)}

                            self.route_policy_test = YList(self)
                            self._segment_path = lambda: "route-policy-tests"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, [], name, value)


                        class RoutePolicyTest(Entity):
                            """
                            PIM route policy test run
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_table
                            
                            	Default table selected
                            	**type**\:  bool
                            
                            .. attribute:: ext_comm
                            
                            	Extended Community
                            	**type**\:  str
                            
                            	**length:** 1..8
                            
                            .. attribute:: extended_community_rt
                            
                            	Route Target
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: group_address
                            
                            	Group IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                            
                            .. attribute:: pass_
                            
                            	Pass
                            	**type**\:  bool
                            
                            .. attribute:: policy_name
                            
                            	RPF policy name
                            	**type**\:  str
                            
                            .. attribute:: safi
                            
                            	SAFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_address
                            
                            	Source IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                            
                            .. attribute:: table_active
                            
                            	Table active
                            	**type**\:  bool
                            
                            .. attribute:: table_exists
                            
                            	Table exists
                            	**type**\:  bool
                            
                            .. attribute:: table_name
                            
                            	Table name
                            	**type**\:  str
                            
                            .. attribute:: vrf_name
                            
                            	VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                                self.yang_name = "route-policy-test"
                                self.yang_parent_name = "route-policy-tests"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr), "source-address-xr" : ("source_address_xr", Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr)}
                                self._child_list_classes = {}

                                self.afi = YLeaf(YType.uint32, "afi")

                                self.default_table = YLeaf(YType.boolean, "default-table")

                                self.ext_comm = YLeaf(YType.str, "ext-comm")

                                self.extended_community_rt = YLeaf(YType.str, "extended-community-rt")

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.pass_ = YLeaf(YType.boolean, "pass")

                                self.policy_name = YLeaf(YType.str, "policy-name")

                                self.safi = YLeaf(YType.uint32, "safi")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.table_active = YLeaf(YType.boolean, "table-active")

                                self.table_exists = YLeaf(YType.boolean, "table-exists")

                                self.table_name = YLeaf(YType.str, "table-name")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.group_address_xr = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.source_address_xr = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                                self._children_yang_names.add("source-address-xr")
                                self._segment_path = lambda: "route-policy-test"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, ['afi', 'default_table', 'ext_comm', 'extended_community_rt', 'group_address', 'pass_', 'policy_name', 'safi', 'source_address', 'table_active', 'table_exists', 'table_name', 'vrf_name'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "route-policy-test"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "route-policy-test"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class RpfRedirect(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle
                    
                    .. attribute:: bundle_interfaces
                    
                    	PIM ECMP RPF\-redirect bundle information
                    	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces>`
                    
                    .. attribute:: redirect_route_databases
                    
                    	PIM ECMP RPF\-redirect route database
                    	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.RpfRedirect, self).__init__()

                        self.yang_name = "rpf-redirect"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"bundle-interfaces" : ("bundle_interfaces", Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces), "redirect-route-databases" : ("redirect_route_databases", Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases)}
                        self._child_list_classes = {}

                        self.bundle_interfaces = Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                        self.bundle_interfaces.parent = self
                        self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                        self._children_yang_names.add("bundle-interfaces")

                        self.redirect_route_databases = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                        self.redirect_route_databases.parent = self
                        self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                        self._children_yang_names.add("redirect-route-databases")
                        self._segment_path = lambda: "rpf-redirect"


                    class BundleInterfaces(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle information
                        
                        .. attribute:: bundle_interface
                        
                        	PIM ECMP RPF\-redirect bundle interface information
                        	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__init__()

                            self.yang_name = "bundle-interfaces"
                            self.yang_parent_name = "rpf-redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"bundle-interface" : ("bundle_interface", Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface)}

                            self.bundle_interface = YList(self)
                            self._segment_path = lambda: "bundle-interfaces"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces, [], name, value)


                        class BundleInterface(Entity):
                            """
                            PIM ECMP RPF\-redirect bundle interface
                            information
                            
                            .. attribute:: allocated_bandwidth
                            
                            	Bandwidth allocated in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_threshold_bandwidth
                            
                            	Configured threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_bandwidth
                            
                            	Bandwidth available in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_threshold_bandwidth
                            
                            	Available threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\:  str
                            
                            	**length:** 1..32
                            
                            .. attribute:: interface_name
                            
                            	Bundle interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: rpf_redirect_bundle_name
                            
                            	RPF redirect bundle name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: rpf_redirect_interface_name
                            
                            	RPF redirect interface name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: snooping_bandwidth_used
                            
                            	Bandwidth used by snooped entries in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: topology_bandwidth_used
                            
                            	Bandwidth used by topology in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: total_bandwidth
                            
                            	Total bandwidth used in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                                self.yang_name = "bundle-interface"
                                self.yang_parent_name = "bundle-interfaces"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.allocated_bandwidth = YLeaf(YType.int32, "allocated-bandwidth")

                                self.allocated_threshold_bandwidth = YLeaf(YType.int32, "allocated-threshold-bandwidth")

                                self.available_bandwidth = YLeaf(YType.int32, "available-bandwidth")

                                self.available_threshold_bandwidth = YLeaf(YType.int32, "available-threshold-bandwidth")

                                self.bundle_name = YLeaf(YType.str, "bundle-name")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.rpf_redirect_bundle_name = YLeaf(YType.str, "rpf-redirect-bundle-name")

                                self.rpf_redirect_interface_name = YLeaf(YType.str, "rpf-redirect-interface-name")

                                self.snooping_bandwidth_used = YLeaf(YType.int32, "snooping-bandwidth-used")

                                self.topology_bandwidth_used = YLeaf(YType.int32, "topology-bandwidth-used")

                                self.total_bandwidth = YLeaf(YType.int32, "total-bandwidth")
                                self._segment_path = lambda: "bundle-interface"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, ['allocated_bandwidth', 'allocated_threshold_bandwidth', 'available_bandwidth', 'available_threshold_bandwidth', 'bundle_name', 'interface_name', 'rpf_redirect_bundle_name', 'rpf_redirect_interface_name', 'snooping_bandwidth_used', 'topology_bandwidth_used', 'total_bandwidth'], name, value)


                    class RedirectRouteDatabases(Entity):
                        """
                        PIM ECMP RPF\-redirect route database
                        
                        .. attribute:: redirect_route_database
                        
                        	PIM ECMP RPF\-redirect route information
                        	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__init__()

                            self.yang_name = "redirect-route-databases"
                            self.yang_parent_name = "rpf-redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"redirect-route-database" : ("redirect_route_database", Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase)}

                            self.redirect_route_database = YList(self)
                            self._segment_path = lambda: "redirect-route-databases"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, [], name, value)


                        class RedirectRouteDatabase(Entity):
                            """
                            PIM ECMP RPF\-redirect route information
                            
                            .. attribute:: bandwidth
                            
                            	Bandwidth in Kbps
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Group ddress
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                            
                            .. attribute:: interface
                            
                            	Outgoing interface list
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                                self.yang_name = "redirect-route-database"
                                self.yang_parent_name = "redirect-route-databases"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr), "source-address-xr" : ("source_address_xr", Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr)}
                                self._child_list_classes = {"interface" : ("interface", Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface)}

                                self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.source_address_xr = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                                self._children_yang_names.add("source-address-xr")

                                self.interface = YList(self)
                                self._segment_path = lambda: "redirect-route-database"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, ['bandwidth', 'group_address', 'source_address', 'uptime'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group ddress
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class Interface(Entity):
                                """
                                Outgoing interface list
                                
                                .. attribute:: expiry
                                
                                	Expiry in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: is_outgoing_interface
                                
                                	Is outgoing Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface
                                
                                	Is RPF Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_snoop_interface
                                
                                	Is snooping Interface
                                	**type**\:  bool
                                
                                .. attribute:: rpf_address
                                
                                	RPF Address
                                	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                                
                                .. attribute:: uptime
                                
                                	Uptime in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"rpf-address" : ("rpf_address", Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress)}
                                    self._child_list_classes = {}

                                    self.expiry = YLeaf(YType.uint64, "expiry")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.is_outgoing_interface = YLeaf(YType.boolean, "is-outgoing-interface")

                                    self.is_rpf_interface = YLeaf(YType.boolean, "is-rpf-interface")

                                    self.is_snoop_interface = YLeaf(YType.boolean, "is-snoop-interface")

                                    self.uptime = YLeaf(YType.uint64, "uptime")

                                    self.rpf_address = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                    self.rpf_address.parent = self
                                    self._children_name_map["rpf_address"] = "rpf-address"
                                    self._children_yang_names.add("rpf-address")
                                    self._segment_path = lambda: "interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, ['expiry', 'interface_name', 'is_outgoing_interface', 'is_rpf_interface', 'is_snoop_interface', 'uptime'], name, value)


                                class RpfAddress(Entity):
                                    """
                                    RPF Address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                        self.yang_name = "rpf-address"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "rpf-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class RpfSummary(Entity):
                    """
                    PIM RPF registration summary
                    
                    .. attribute:: default_safi
                    
                    	Default RPF Table SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table_name
                    
                    	Default RPF Table Name
                    	**type**\:  str
                    
                    .. attribute:: is_isis_mtr_configured
                    
                    	Is ISIS MTR configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_isis_te_configured
                    
                    	Is ISIS TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_mbgp_configured
                    
                    	Is MBGP configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_enabled
                    
                    	Is Multipath Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_interface_hash_enabled
                    
                    	Is Multipath Interface Hash Extension Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_hash_enabled
                    
                    	Is Multipath Source based Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_next_hop_hash_enabled
                    
                    	Is Multipath Source\-Nexthop Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ospf_te_configured
                    
                    	Is OSPF TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: mo_frr_configured
                    
                    	Is MoFRR configured?
                    	**type**\:  bool
                    
                    .. attribute:: rib_convergence_time_left
                    
                    	RIB convergence time left in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_convergence_timeout
                    
                    	RIB convergence timeout in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_mo_frr_configured
                    
                    	Is MoFRR RIB configured?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	Is RUMP MuRIB enabled?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.RpfSummary, self).__init__()

                        self.yang_name = "rpf-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.default_safi = YLeaf(YType.uint32, "default-safi")

                        self.default_table_name = YLeaf(YType.str, "default-table-name")

                        self.is_isis_mtr_configured = YLeaf(YType.boolean, "is-isis-mtr-configured")

                        self.is_isis_te_configured = YLeaf(YType.boolean, "is-isis-te-configured")

                        self.is_mbgp_configured = YLeaf(YType.boolean, "is-mbgp-configured")

                        self.is_multipath_enabled = YLeaf(YType.boolean, "is-multipath-enabled")

                        self.is_multipath_interface_hash_enabled = YLeaf(YType.boolean, "is-multipath-interface-hash-enabled")

                        self.is_multipath_source_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-hash-enabled")

                        self.is_multipath_source_next_hop_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-next-hop-hash-enabled")

                        self.is_ospf_te_configured = YLeaf(YType.boolean, "is-ospf-te-configured")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.mo_frr_configured = YLeaf(YType.boolean, "mo-frr-configured")

                        self.rib_convergence_time_left = YLeaf(YType.uint32, "rib-convergence-time-left")

                        self.rib_convergence_timeout = YLeaf(YType.uint32, "rib-convergence-timeout")

                        self.rib_mo_frr_configured = YLeaf(YType.boolean, "rib-mo-frr-configured")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")
                        self._segment_path = lambda: "rpf-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfSummary, ['default_safi', 'default_table_name', 'is_isis_mtr_configured', 'is_isis_te_configured', 'is_mbgp_configured', 'is_multipath_enabled', 'is_multipath_interface_hash_enabled', 'is_multipath_source_hash_enabled', 'is_multipath_source_next_hop_hash_enabled', 'is_ospf_te_configured', 'is_rib_convergence', 'mo_frr_configured', 'rib_convergence_time_left', 'rib_convergence_timeout', 'rib_mo_frr_configured', 'rpf_registrations', 'rump_enabled'], name, value)


                class Safs(Entity):
                    """
                    SAFI table and type
                    
                    .. attribute:: saf
                    
                    	SAF name 
                    	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Safs, self).__init__()

                        self.yang_name = "safs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"saf" : ("saf", Pim.Active.Vrfs.Vrf.Safs.Saf)}

                        self.saf = YList(self)
                        self._segment_path = lambda: "safs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs, [], name, value)


                    class Saf(Entity):
                        """
                        SAF name 
                        
                        .. attribute:: rpf_hash_source_groups
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups>`
                        
                        .. attribute:: rpf_hash_sources
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources>`
                        
                        .. attribute:: rpfs
                        
                        	PIM RPF information table
                        	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs>`
                        
                        .. attribute:: saf_name
                        
                        	SAF name 
                        	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name 
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Safs.Saf, self).__init__()

                            self.yang_name = "saf"
                            self.yang_parent_name = "safs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"rpf-hash-source-groups" : ("rpf_hash_source_groups", Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups), "rpf-hash-sources" : ("rpf_hash_sources", Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources), "rpfs" : ("rpfs", Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs)}
                            self._child_list_classes = {}

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                            self.topology_name = YLeaf(YType.str, "topology-name")

                            self.rpf_hash_source_groups = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                            self.rpf_hash_source_groups.parent = self
                            self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                            self._children_yang_names.add("rpf-hash-source-groups")

                            self.rpf_hash_sources = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                            self.rpf_hash_sources.parent = self
                            self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                            self._children_yang_names.add("rpf-hash-sources")

                            self.rpfs = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs()
                            self.rpfs.parent = self
                            self._children_name_map["rpfs"] = "rpfs"
                            self._children_yang_names.add("rpfs")
                            self._segment_path = lambda: "saf"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf, ['saf_name', 'topology_name'], name, value)


                        class RpfHashSourceGroups(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source_group
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__init__()

                                self.yang_name = "rpf-hash-source-groups"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"rpf-hash-source-group" : ("rpf_hash_source_group", Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup)}

                                self.rpf_hash_source_group = YList(self)
                                self._segment_path = lambda: "rpf-hash-source-groups"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, [], name, value)


                            class RpfHashSourceGroup(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: group_address
                                
                                	Group address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: mask_length
                                
                                	Hash mask length
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                    self.yang_name = "rpf-hash-source-group"
                                    self.yang_parent_name = "rpf-hash-source-groups"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress), "secondary-next-hop-address" : ("secondary_next_hop_address", Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress)}
                                    self._child_list_classes = {}

                                    self.group_address = YLeaf(YType.str, "group-address")

                                    self.mask_length = YLeaf(YType.int32, "mask-length")

                                    self.mofrr = YLeaf(YType.int32, "mofrr")

                                    self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                    self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                    self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                    self._children_yang_names.add("next-hop-address")

                                    self.secondary_next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._children_yang_names.add("secondary-next-hop-address")
                                    self._segment_path = lambda: "rpf-hash-source-group"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, ['group_address', 'mask_length', 'mofrr', 'next_hop_interface', 'next_hop_multipath_enabled', 'secondary_next_hop_interface', 'source_address'], name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "next-hop-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "secondary-next-hop-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfHashSources(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__init__()

                                self.yang_name = "rpf-hash-sources"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"rpf-hash-source" : ("rpf_hash_source", Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource)}

                                self.rpf_hash_source = YList(self)
                                self._segment_path = lambda: "rpf-hash-sources"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources, [], name, value)


                            class RpfHashSource(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                    self.yang_name = "rpf-hash-source"
                                    self.yang_parent_name = "rpf-hash-sources"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress), "secondary-next-hop-address" : ("secondary_next_hop_address", Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress)}
                                    self._child_list_classes = {}

                                    self.mofrr = YLeaf(YType.int32, "mofrr")

                                    self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                    self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                    self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                    self._children_yang_names.add("next-hop-address")

                                    self.secondary_next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._children_yang_names.add("secondary-next-hop-address")
                                    self._segment_path = lambda: "rpf-hash-source"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, ['mofrr', 'next_hop_interface', 'next_hop_multipath_enabled', 'secondary_next_hop_interface', 'source_address'], name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "next-hop-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "secondary-next-hop-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Rpfs(Entity):
                            """
                            PIM RPF information table
                            
                            .. attribute:: rpf
                            
                            	PIM RPF information
                            	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs, self).__init__()

                                self.yang_name = "rpfs"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"rpf" : ("rpf", Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf)}

                                self.rpf = YList(self)
                                self._segment_path = lambda: "rpfs"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs, [], name, value)


                            class Rpf(Entity):
                                """
                                PIM RPF information
                                
                                .. attribute:: registered_address  <key>
                                
                                	Address for which RPF lookup
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: is_connected
                                
                                	Are we connected ?
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_rpf_bgp_route
                                
                                	Is RPF through BGP route
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_preference
                                
                                	Metric preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: registered_address_xr
                                
                                	Address registered
                                	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                                
                                .. attribute:: rpf_path
                                
                                	RPF Paths list
                                	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__init__()

                                    self.yang_name = "rpf"
                                    self.yang_parent_name = "rpfs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"registered-address-xr" : ("registered_address_xr", Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr)}
                                    self._child_list_classes = {"rpf-path" : ("rpf_path", Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath)}

                                    self.registered_address = YLeaf(YType.str, "registered-address")

                                    self.is_connected = YLeaf(YType.uint8, "is-connected")

                                    self.is_rpf_bgp_route = YLeaf(YType.boolean, "is-rpf-bgp-route")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                    self.registered_address_xr = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                    self.registered_address_xr.parent = self
                                    self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                    self._children_yang_names.add("registered-address-xr")

                                    self.rpf_path = YList(self)
                                    self._segment_path = lambda: "rpf" + "[registered-address='" + self.registered_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, ['registered_address', 'is_connected', 'is_rpf_bgp_route', 'metric', 'metric_preference'], name, value)


                                class RegisteredAddressXr(Entity):
                                    """
                                    Address registered
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                        self.yang_name = "registered-address-xr"
                                        self.yang_parent_name = "rpf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "registered-address-xr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class RpfPath(Entity):
                                    """
                                    RPF Paths list
                                    
                                    .. attribute:: connector
                                    
                                    	Connector Attribute
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: extranet_vrf_name
                                    
                                    	Extranet VRF name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    .. attribute:: is_connector_attribute_present
                                    
                                    	Connector attribute present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rpf_interface_disabled
                                    
                                    	Is the rpf interface disabled ?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_lsm
                                    
                                    	Via LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_mlsm
                                    
                                    	Via Mstatic LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpf_interface_name
                                    
                                    	RPF Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: rpf_neighbor
                                    
                                    	RPF neighbor
                                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                    
                                    .. attribute:: rpf_nexthop
                                    
                                    	RPF nexthop
                                    	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                        self.yang_name = "rpf-path"
                                        self.yang_parent_name = "rpf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rpf-neighbor" : ("rpf_neighbor", Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor), "rpf-nexthop" : ("rpf_nexthop", Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop)}
                                        self._child_list_classes = {}

                                        self.connector = YLeaf(YType.str, "connector")

                                        self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                        self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                        self.is_rpf_interface_disabled = YLeaf(YType.boolean, "is-rpf-interface-disabled")

                                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                        self.is_via_mlsm = YLeaf(YType.boolean, "is-via-mlsm")

                                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                                        self.rpf_neighbor = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                        self.rpf_neighbor.parent = self
                                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                        self._children_yang_names.add("rpf-neighbor")

                                        self.rpf_nexthop = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                        self.rpf_nexthop.parent = self
                                        self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                        self._children_yang_names.add("rpf-nexthop")
                                        self._segment_path = lambda: "rpf-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, ['connector', 'extranet_vrf_name', 'is_connector_attribute_present', 'is_rpf_interface_disabled', 'is_via_lsm', 'is_via_mlsm', 'rpf_interface_name'], name, value)


                                    class RpfNeighbor(Entity):
                                        """
                                        RPF neighbor
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                            self.yang_name = "rpf-neighbor"
                                            self.yang_parent_name = "rpf-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                            self._segment_path = lambda: "rpf-neighbor"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                    class RpfNexthop(Entity):
                                        """
                                        RPF nexthop
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                            self.yang_name = "rpf-nexthop"
                                            self.yang_parent_name = "rpf-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                            self._segment_path = lambda: "rpf-nexthop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Summary(Entity):
                    """
                    PIM summary
                    
                    .. attribute:: bsr_candidate_rp_set_count
                    
                    	Current crp\-set count from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_limit
                    
                    	Maximum crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_threshold
                    
                    	Threshold crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_range_threshold
                    
                    	Threshold group range from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_count
                    
                    	Current group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_limit
                    
                    	Maximum group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_auto_rp_ranges_limit
                    
                    	Global Auto\-RP maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_count
                    
                    	Global BSR current crp\-set count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_limit
                    
                    	Global BSR maximum crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_threshold
                    
                    	Global BSR Threshold crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_count
                    
                    	Global BSR current group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_limit
                    
                    	Global BSR maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_threshold
                    
                    	Global BSR Threshold group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_register_limit
                    
                    	Maximum global registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bsr_ranges_threshold_reached
                    
                    	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_auto_rp_ranges_limit_reached
                    
                    	Is global AutoRP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_bsr_ranges_limit_reached
                    
                    	Is global BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_register_limit_reached
                    
                    	Is global PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_route_limit_reached
                    
                    	Is global route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_rxi_limit_reached
                    
                    	Is global interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_maximum_enforcement_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: is_ranges_limit_reached
                    
                    	Is Auto\-RP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_route_limit_reached
                    
                    	Is route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: ranges_count
                    
                    	Current group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_limit
                    
                    	Maximum group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_threshold
                    
                    	OOR theshold of grange ranges from AutoRP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_count
                    
                    	Current registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit
                    
                    	Maximum registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit_reached
                    
                    	Is PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: register_threshold
                    
                    	Threshold registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_count
                    
                    	Current routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_limit
                    
                    	Maximum routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_low_water_mark
                    
                    	The number of routes below which the throttle on route creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_threshold
                    
                    	Threshold routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_limit_reached
                    
                    	Is interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: rxi_low_water_mark
                    
                    	The rxi below which the throttle on interface creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_count
                    
                    	Current Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_limit
                    
                    	Maximum Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_threshold
                    
                    	Topology Interface State threshold
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                        self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                        self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                        self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                        self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                        self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                        self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                        self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                        self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                        self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                        self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                        self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                        self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                        self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                        self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                        self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                        self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                        self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                        self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                        self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                        self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                        self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                        self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                        self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                        self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                        self.register_count = YLeaf(YType.uint32, "register-count")

                        self.register_limit = YLeaf(YType.uint32, "register-limit")

                        self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                        self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                        self.route_count = YLeaf(YType.uint32, "route-count")

                        self.route_limit = YLeaf(YType.uint32, "route-limit")

                        self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                        self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                        self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                        self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                        self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                        self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                        self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")
                        self._segment_path = lambda: "summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Summary, ['bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_threshold', 'bsr_range_threshold', 'bsr_ranges_count', 'bsr_ranges_limit', 'global_auto_rp_ranges_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_threshold', 'global_bsr_ranges_count', 'global_bsr_ranges_limit', 'global_bsr_ranges_threshold', 'global_register_limit', 'is_bsr_ranges_threshold_reached', 'is_global_auto_rp_ranges_limit_reached', 'is_global_bsr_ranges_limit_reached', 'is_global_register_limit_reached', 'is_global_route_limit_reached', 'is_global_rxi_limit_reached', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'is_ranges_limit_reached', 'is_route_limit_reached', 'ranges_count', 'ranges_limit', 'ranges_threshold', 'register_count', 'register_limit', 'register_limit_reached', 'register_threshold', 'route_count', 'route_limit', 'route_low_water_mark', 'route_threshold', 'rxi_limit_reached', 'rxi_low_water_mark', 'topology_interface_state_count', 'topology_interface_state_limit', 'topology_interface_state_threshold'], name, value)


                class TableContexts(Entity):
                    """
                    PIM table context list
                    
                    .. attribute:: table_context
                    
                    	PIM table context information
                    	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TableContexts.TableContext>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.TableContexts, self).__init__()

                        self.yang_name = "table-contexts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"table-context" : ("table_context", Pim.Active.Vrfs.Vrf.TableContexts.TableContext)}

                        self.table_context = YList(self)
                        self._segment_path = lambda: "table-contexts"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.TableContexts, [], name, value)


                    class TableContext(Entity):
                        """
                        PIM table context information
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: saf_name
                        
                        	SAF name
                        	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: topology_name
                        
                        	Topology name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.TableContexts.TableContext, self).__init__()

                            self.yang_name = "table-context"
                            self.yang_parent_name = "table-contexts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                            self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                            self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                            self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                            self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.table_id = YLeaf(YType.uint32, "table-id")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.topology_name = YLeaf(YType.str, "topology-name")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")
                            self._segment_path = lambda: "table-context"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.TableContexts.TableContext, ['afi', 'is_active', 'is_ital_registration_done', 'is_rib_convergence', 'is_rib_convergence_received', 'is_rib_registration_done', 'rpf_registrations', 'saf_name', 'safi', 'table_id', 'table_name', 'topology_name', 'vrf_id'], name, value)


                class Topologies(Entity):
                    """
                    PIM topology table
                    
                    .. attribute:: topology
                    
                    	PIM topology information
                    	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Topologies, self).__init__()

                        self.yang_name = "topologies"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"topology" : ("topology", Pim.Active.Vrfs.Vrf.Topologies.Topology)}

                        self.topology = YList(self)
                        self._segment_path = lambda: "topologies"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies, [], name, value)


                    class Topology(Entity):
                        """
                        PIM topology information
                        
                        .. attribute:: alive
                        
                        	Alive time in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: anycast_rp_match
                        
                        	Group matches Anycast\-RP policy
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_route_target
                        
                        	Anycast\-RP RT
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: assume_alive
                        
                        	The Assume Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: bgp_join
                        
                        	BGP C JOIN
                        	**type**\:  bool
                        
                        .. attribute:: bgp_jp_time
                        
                        	BGP C JP Time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: connected
                        
                        	Is Connected ?
                        	**type**\:  bool
                        
                        .. attribute:: crossed_threshold
                        
                        	Incoming traffic crossed threshold. MT flag set
                        	**type**\:  bool
                        
                        .. attribute:: customer_routing_type
                        
                        	Type of Customer Routing in the MVPN
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: data_mdt_addr_assigned
                        
                        	PIM has assigned a Data MDT Address
                        	**type**\:  bool
                        
                        .. attribute:: dont_check_connected
                        
                        	Do we need to make the connected check on this route ?
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	When this entry expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: extranet_route
                        
                        	Is a Extranet route ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr>`
                        
                        .. attribute:: inherit_alive
                        
                        	The Inherit Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: inherit_spt
                        
                        	The Inherit SPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: is_via_lsm
                        
                        	Via LSM
                        	**type**\:  bool
                        
                        .. attribute:: jp_status
                        
                        	Join\-Prune Status
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: kat_state
                        
                        	Keep Alive Timer State
                        	**type**\:  bool
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: limit_reached
                        
                        	Have we throttled the creation of routes or interfaces ?
                        	**type**\:  bool
                        
                        .. attribute:: low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_active
                        
                        	Is MoFRR Active?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_backup
                        
                        	Is this Mofrr Backup?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_primary
                        
                        	Is this Mofrr Primary?
                        	**type**\:  bool
                        
                        .. attribute:: orig_src_address
                        
                        	Orig Src Address
                        	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress>`
                        
                        .. attribute:: outgoing_interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface>`
                        
                        .. attribute:: probe_alive
                        
                        	The Probe Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: proxy
                        
                        	Is the RPF target a proxy?
                        	**type**\:  bool
                        
                        .. attribute:: proxy_address
                        
                        	RPF Proxy address
                        	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress>`
                        
                        .. attribute:: really_alive
                        
                        	The Really Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: register_received
                        
                        	Have registers been received for this source ?
                        	**type**\:  bool
                        
                        .. attribute:: register_received_timer
                        
                        	Register Received Timer in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: remote_source
                        
                        	MSDP told us
                        	**type**\:  bool
                        
                        .. attribute:: rib_mo_frr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rp_address
                        
                        	RP Address (If rpt)
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor>`
                        
                        .. attribute:: rpf_proxy_enabled
                        
                        	Is rpf if proxy enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpt
                        
                        	RPT bit
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpt_xr
                        
                        	Is this on the RPT ?
                        	**type**\:  bool
                        
                        .. attribute:: sa_joined
                        
                        	BGP SA join
                        	**type**\:  bool
                        
                        .. attribute:: sa_received
                        
                        	BGP SA received
                        	**type**\:  bool
                        
                        .. attribute:: sa_sent
                        
                        	BGP SA sent
                        	**type**\:  bool
                        
                        .. attribute:: secondary_rpf_interface_name
                        
                        	Secondary Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: secondary_rpf_neighbor
                        
                        	Secondary RPF Neighbor
                        	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor>`
                        
                        .. attribute:: sending_null_registers
                        
                        	Are we sending null registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: sending_registers
                        
                        	Are we sending registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: signal_sources
                        
                        	Signal Sources on route?
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr>`
                        
                        .. attribute:: spt
                        
                        	Is this on the SPT ?
                        	**type**\:  bool
                        
                        .. attribute:: suppress_registers
                        
                        	When the Null register probe expires
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vxlan
                        
                        	Is this VXLAN?
                        	**type**\:  bool
                        
                        .. attribute:: wildcard
                        
                        	WC \-Wildcard
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Topologies.Topology, self).__init__()

                            self.yang_name = "topology"
                            self.yang_parent_name = "topologies"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr), "orig-src-address" : ("orig_src_address", Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress), "proxy-address" : ("proxy_address", Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress), "rp-address" : ("rp_address", Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress), "rpf-neighbor" : ("rpf_neighbor", Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor), "rpf-root" : ("rpf_root", Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot), "secondary-rpf-neighbor" : ("secondary_rpf_neighbor", Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor), "source-address-xr" : ("source_address_xr", Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr)}
                            self._child_list_classes = {"outgoing-interface" : ("outgoing_interface", Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface)}

                            self.alive = YLeaf(YType.int32, "alive")

                            self.anycast_rp_match = YLeaf(YType.boolean, "anycast-rp-match")

                            self.anycast_rp_route_target = YLeaf(YType.str, "anycast-rp-route-target")

                            self.assume_alive = YLeaf(YType.boolean, "assume-alive")

                            self.bgp_join = YLeaf(YType.boolean, "bgp-join")

                            self.bgp_jp_time = YLeaf(YType.uint64, "bgp-jp-time")

                            self.connected = YLeaf(YType.boolean, "connected")

                            self.crossed_threshold = YLeaf(YType.boolean, "crossed-threshold")

                            self.customer_routing_type = YLeaf(YType.int32, "customer-routing-type")

                            self.data_mdt_addr_assigned = YLeaf(YType.boolean, "data-mdt-addr-assigned")

                            self.dont_check_connected = YLeaf(YType.boolean, "dont-check-connected")

                            self.expiry = YLeaf(YType.uint64, "expiry")

                            self.extranet_route = YLeaf(YType.boolean, "extranet-route")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.inherit_alive = YLeaf(YType.boolean, "inherit-alive")

                            self.inherit_spt = YLeaf(YType.boolean, "inherit-spt")

                            self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                            self.jp_status = YLeaf(YType.int32, "jp-status")

                            self.jp_timer = YLeaf(YType.int32, "jp-timer")

                            self.kat_state = YLeaf(YType.boolean, "kat-state")

                            self.last_hop = YLeaf(YType.boolean, "last-hop")

                            self.limit_reached = YLeaf(YType.boolean, "limit-reached")

                            self.low_memory = YLeaf(YType.boolean, "low-memory")

                            self.mofrr_active = YLeaf(YType.boolean, "mofrr-active")

                            self.mofrr_backup = YLeaf(YType.boolean, "mofrr-backup")

                            self.mofrr_enabled = YLeaf(YType.boolean, "mofrr-enabled")

                            self.mofrr_primary = YLeaf(YType.boolean, "mofrr-primary")

                            self.probe_alive = YLeaf(YType.boolean, "probe-alive")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.proxy = YLeaf(YType.boolean, "proxy")

                            self.really_alive = YLeaf(YType.boolean, "really-alive")

                            self.register_received = YLeaf(YType.boolean, "register-received")

                            self.register_received_timer = YLeaf(YType.int32, "register-received-timer")

                            self.remote_source = YLeaf(YType.boolean, "remote-source")

                            self.rib_mo_frr_enabled = YLeaf(YType.boolean, "rib-mo-frr-enabled")

                            self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                            self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_proxy_enabled = YLeaf(YType.boolean, "rpf-proxy-enabled")

                            self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                            self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.rpt = YLeaf(YType.int32, "rpt")

                            self.rpt_xr = YLeaf(YType.boolean, "rpt-xr")

                            self.sa_joined = YLeaf(YType.boolean, "sa-joined")

                            self.sa_received = YLeaf(YType.boolean, "sa-received")

                            self.sa_sent = YLeaf(YType.boolean, "sa-sent")

                            self.secondary_rpf_interface_name = YLeaf(YType.str, "secondary-rpf-interface-name")

                            self.sending_null_registers = YLeaf(YType.boolean, "sending-null-registers")

                            self.sending_registers = YLeaf(YType.boolean, "sending-registers")

                            self.signal_sources = YLeaf(YType.boolean, "signal-sources")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.spt = YLeaf(YType.boolean, "spt")

                            self.suppress_registers = YLeaf(YType.int32, "suppress-registers")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.vxlan = YLeaf(YType.boolean, "vxlan")

                            self.wildcard = YLeaf(YType.boolean, "wildcard")

                            self.group_address_xr = Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.orig_src_address = Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                            self.orig_src_address.parent = self
                            self._children_name_map["orig_src_address"] = "orig-src-address"
                            self._children_yang_names.add("orig-src-address")

                            self.proxy_address = Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                            self.proxy_address.parent = self
                            self._children_name_map["proxy_address"] = "proxy-address"
                            self._children_yang_names.add("proxy-address")

                            self.rp_address = Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.rpf_neighbor = Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                            self.rpf_root = Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._children_yang_names.add("rpf-root")

                            self.secondary_rpf_neighbor = Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                            self.secondary_rpf_neighbor.parent = self
                            self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                            self._children_yang_names.add("secondary-rpf-neighbor")

                            self.source_address_xr = Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                            self.outgoing_interface = YList(self)
                            self._segment_path = lambda: "topology"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology, ['alive', 'anycast_rp_match', 'anycast_rp_route_target', 'assume_alive', 'bgp_join', 'bgp_jp_time', 'connected', 'crossed_threshold', 'customer_routing_type', 'data_mdt_addr_assigned', 'dont_check_connected', 'expiry', 'extranet_route', 'group_address', 'inherit_alive', 'inherit_spt', 'is_via_lsm', 'jp_status', 'jp_timer', 'kat_state', 'last_hop', 'limit_reached', 'low_memory', 'mofrr_active', 'mofrr_backup', 'mofrr_enabled', 'mofrr_primary', 'probe_alive', 'protocol', 'proxy', 'really_alive', 'register_received', 'register_received_timer', 'remote_source', 'rib_mo_frr_enabled', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_proxy_enabled', 'rpf_safi', 'rpf_table_name', 'rpf_vrf_name', 'rpt', 'rpt_xr', 'sa_joined', 'sa_received', 'sa_sent', 'secondary_rpf_interface_name', 'sending_null_registers', 'sending_registers', 'signal_sources', 'source_address', 'spt', 'suppress_registers', 'uptime', 'vxlan', 'wildcard'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class OrigSrcAddress(Entity):
                            """
                            Orig Src Address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__init__()

                                self.yang_name = "orig-src-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "orig-src-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class OutgoingInterface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: admin_boundary
                            
                            	Is this an administrative boundary ?
                            	**type**\:  bool
                            
                            .. attribute:: assert_state
                            
                            	Assert State
                            	**type**\:  bool
                            
                            .. attribute:: assert_timer
                            
                            	Assert Timer in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: assert_winner
                            
                            	Assert Winner
                            	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner>`
                            
                            .. attribute:: bgp_c_mcast_join
                            
                            	BGP C\-Mcast join
                            	**type**\:  bool
                            
                            .. attribute:: bgp_c_mcast_prune_delay_timer
                            
                            	BGP C\-MCAST Prune Suppression in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: data_mdt_join
                            
                            	Data MDT join
                            	**type**\:  bool
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: extranet_interface
                            
                            	Is this an Extranet Interface ?
                            	**type**\:  bool
                            
                            .. attribute:: forwarding_state
                            
                            	Forward or Prune
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: igmp_membership
                            
                            	IGMP membership
                            	**type**\:  bool
                            
                            .. attribute:: immediate_state
                            
                            	Immediate fwding state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: interface_name
                            
                            	Interface Identifier
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: internal_interest_info
                            
                            	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: internal_interest_information
                            
                            	Internal Interest. Replaces internal\-interest\-info
                            	**type**\:   :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                            
                            .. attribute:: jp_state
                            
                            	Join\-Prune State
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: jp_timer
                            
                            	Join\-Prune Timer (secs)
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: last_hop
                            
                            	Are we last hop ?
                            	**type**\:  bool
                            
                            .. attribute:: local_mdt_join
                            
                            	Default MDT Join
                            	**type**\:  bool
                            
                            .. attribute:: local_members
                            
                            	Local Information. Deprecated \- use 'local\-members\-information' instead
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: local_members_information
                            
                            	Local Information. Replaces local\-members
                            	**type**\:   :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                            
                            .. attribute:: mdt_safi_join
                            
                            	MDT Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mldp_inband_mdt
                            
                            	MLDP Inband MDT interface
                            	**type**\:  bool
                            
                            .. attribute:: mldp_stale
                            
                            	OLE is stale
                            	**type**\:  bool
                            
                            .. attribute:: mvpn_safi_join
                            
                            	MVPN Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mvpnv6_safi_join
                            
                            	MVPN IPv6 Safi join
                            	**type**\:  bool
                            
                            .. attribute:: sa_prune
                            
                            	BGP SA Prune state
                            	**type**\:  bool
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: vrf_name
                            
                            	VRF which physically owns
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__init__()

                                self.yang_name = "outgoing-interface"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"assert-winner" : ("assert_winner", Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner)}
                                self._child_list_classes = {}

                                self.admin_boundary = YLeaf(YType.boolean, "admin-boundary")

                                self.assert_state = YLeaf(YType.boolean, "assert-state")

                                self.assert_timer = YLeaf(YType.int32, "assert-timer")

                                self.bgp_c_mcast_join = YLeaf(YType.boolean, "bgp-c-mcast-join")

                                self.bgp_c_mcast_prune_delay_timer = YLeaf(YType.uint64, "bgp-c-mcast-prune-delay-timer")

                                self.data_mdt_join = YLeaf(YType.boolean, "data-mdt-join")

                                self.expiry = YLeaf(YType.uint64, "expiry")

                                self.extranet_interface = YLeaf(YType.boolean, "extranet-interface")

                                self.forwarding_state = YLeaf(YType.int32, "forwarding-state")

                                self.igmp_membership = YLeaf(YType.boolean, "igmp-membership")

                                self.immediate_state = YLeaf(YType.int32, "immediate-state")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.internal_interest_info = YLeaf(YType.int32, "internal-interest-info")

                                self.internal_interest_information = YLeaf(YType.enumeration, "internal-interest-information")

                                self.jp_state = YLeaf(YType.int32, "jp-state")

                                self.jp_timer = YLeaf(YType.int32, "jp-timer")

                                self.last_hop = YLeaf(YType.boolean, "last-hop")

                                self.local_mdt_join = YLeaf(YType.boolean, "local-mdt-join")

                                self.local_members = YLeaf(YType.int32, "local-members")

                                self.local_members_information = YLeaf(YType.enumeration, "local-members-information")

                                self.mdt_safi_join = YLeaf(YType.boolean, "mdt-safi-join")

                                self.mldp_inband_mdt = YLeaf(YType.boolean, "mldp-inband-mdt")

                                self.mldp_stale = YLeaf(YType.boolean, "mldp-stale")

                                self.mvpn_safi_join = YLeaf(YType.boolean, "mvpn-safi-join")

                                self.mvpnv6_safi_join = YLeaf(YType.boolean, "mvpnv6-safi-join")

                                self.sa_prune = YLeaf(YType.boolean, "sa-prune")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.assert_winner = Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                self.assert_winner.parent = self
                                self._children_name_map["assert_winner"] = "assert-winner"
                                self._children_yang_names.add("assert-winner")
                                self._segment_path = lambda: "outgoing-interface"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, ['admin_boundary', 'assert_state', 'assert_timer', 'bgp_c_mcast_join', 'bgp_c_mcast_prune_delay_timer', 'data_mdt_join', 'expiry', 'extranet_interface', 'forwarding_state', 'igmp_membership', 'immediate_state', 'interface_name', 'internal_interest_info', 'internal_interest_information', 'jp_state', 'jp_timer', 'last_hop', 'local_mdt_join', 'local_members', 'local_members_information', 'mdt_safi_join', 'mldp_inband_mdt', 'mldp_stale', 'mvpn_safi_join', 'mvpnv6_safi_join', 'sa_prune', 'uptime', 'vrf_name'], name, value)


                            class AssertWinner(Entity):
                                """
                                Assert Winner
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                    self.yang_name = "assert-winner"
                                    self.yang_parent_name = "outgoing-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "assert-winner"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class ProxyAddress(Entity):
                            """
                            RPF Proxy address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__init__()

                                self.yang_name = "proxy-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "proxy-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP Address (If rpt)
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-root"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SecondaryRpfNeighbor(Entity):
                            """
                            Secondary RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                                self.yang_name = "secondary-rpf-neighbor"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "secondary-rpf-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class TopologyEntryFlagRouteCounts(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: topology_entry_flag_route_count
                    
                    	Route count for topology with entry flag set
                    	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-entry-flag-route-counts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"topology-entry-flag-route-count" : ("topology_entry_flag_route_count", Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount)}

                        self.topology_entry_flag_route_count = YList(self)
                        self._segment_path = lambda: "topology-entry-flag-route-counts"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts, [], name, value)


                    class TopologyEntryFlagRouteCount(Entity):
                        """
                        Route count for topology with entry flag set
                        
                        .. attribute:: entry_flag  <key>
                        
                        	entry flag
                        	**type**\:   :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                            self.yang_name = "topology-entry-flag-route-count"
                            self.yang_parent_name = "topology-entry-flag-route-counts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.entry_flag = YLeaf(YType.enumeration, "entry-flag")

                            self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                            self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                            self.groute_count = YLeaf(YType.uint32, "groute-count")

                            self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                            self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                            self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                            self._segment_path = lambda: "topology-entry-flag-route-count" + "[entry-flag='" + self.entry_flag.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, ['entry_flag', 'active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


                class TopologyInterfaceFlagRouteCounts(Entity):
                    """
                    Route count for topology with interface flag set
                    
                    .. attribute:: topology_interface_flag_route_count
                    
                    	Route count for topology with interface flag set
                    	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-interface-flag-route-counts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"topology-interface-flag-route-count" : ("topology_interface_flag_route_count", Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount)}

                        self.topology_interface_flag_route_count = YList(self)
                        self._segment_path = lambda: "topology-interface-flag-route-counts"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, [], name, value)


                    class TopologyInterfaceFlagRouteCount(Entity):
                        """
                        Route count for topology with interface flag
                        set
                        
                        .. attribute:: interface_flag  <key>
                        
                        	Interface flag
                        	**type**\:   :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                            self.yang_name = "topology-interface-flag-route-count"
                            self.yang_parent_name = "topology-interface-flag-route-counts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interface_flag = YLeaf(YType.enumeration, "interface-flag")

                            self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                            self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                            self.groute_count = YLeaf(YType.uint32, "groute-count")

                            self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                            self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                            self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                            self._segment_path = lambda: "topology-interface-flag-route-count" + "[interface-flag='" + self.interface_flag.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, ['interface_flag', 'active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


                class TopologyRouteCount(Entity):
                    """
                    Topology route count information from PIM
                    topology table
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.TopologyRouteCount, self).__init__()

                        self.yang_name = "topology-route-count"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                        self._segment_path = lambda: "topology-route-count"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.TopologyRouteCount, ['active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


                class TrafficCounters(Entity):
                    """
                    PIM message traffic counters
                    
                    .. attribute:: boundary_acl_rx_drop
                    
                    	Inc. JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_tx_drop
                    
                    	Out JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_error
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: format_error
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert_batched
                    
                    	Batched Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_data_register
                    
                    	Data Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_ecmp_redirect
                    
                    	Input Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb_error
                    
                    	No IDB for intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_pim_error
                    
                    	PIM Disabled on intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_error
                    
                    	No VRF for idb error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_null_register
                    
                    	Null Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim_version_error
                    
                    	Invalid PIM version error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inputs
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_destination_packets
                    
                    	Control Packets with Invalid Destination
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_join_prunes
                    
                    	PIM invalid Join/Prunes received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_registers
                    
                    	PIM invalid registers received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_local_source_address
                    
                    	Data MDT Join msgs dropped due to local source addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_idb
                    
                    	Data MDT Join msgs dropped due to idb missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_vrf
                    
                    	Data MDT Join msgs dropped due to vrf missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_null_local_address
                    
                    	Data MDT Join msgs dropped due to null local addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_bad_type
                    
                    	Data MDT TLV bad type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_received
                    
                    	Data MDT Join Msgs received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_sent
                    
                    	Data MDT Join Msgs sent
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_joins_drop_multiple_encapsulation
                    
                    	MDT Join msgs dropped due to multiple Encap limitation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_send_queue_full
                    
                    	Packets dropped since mdt send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_socket_error
                    
                    	MDT Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_invalid_lsm_identifier
                    
                    	 Invalid LSM ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_mdt_socket_connection
                    
                    	Packets dropped since no mdt socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_source_address
                    
                    	Packets dropped since no source address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: non_supported_packets
                    
                    	PIM non supported pckets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert_batched
                    
                    	Batched Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_data_register
                    
                    	Data Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_ecmp_redirect
                    
                    	Output Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello_bytes
                    
                    	Output Hello Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_join_group
                    
                    	Output Join Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_prune_bytes
                    
                    	Output JP Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_loop_error
                    
                    	Output on loopback error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_null_register
                    
                    	Null Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_prune_group
                    
                    	Output Prune Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: outputs
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_packman_error
                    
                    	Packets Dropped due to Pakman Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue
                    
                    	Packet queue state and statistics
                    	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue>`
                    
                    .. attribute:: packet_queue_last_clear
                    
                    	Time in seconds since the last clear of all packet queues stats
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: packet_read_socket_error
                    
                    	Packet Read Socket Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_standby
                    
                    	Packets Dropped due to Standby Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pakman_error
                    
                    	Pakman packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: send_queue_full
                    
                    	Packets dropped since send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_error
                    
                    	Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: standby_packets_error
                    
                    	Packets received in standby state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: truncated_pim_packets
                    
                    	Packets dropped due to truncated Joins or Prunes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"packet-queue" : ("packet_queue", Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue)}

                        self.boundary_acl_rx_drop = YLeaf(YType.uint32, "boundary-acl-rx-drop")

                        self.boundary_acl_tx_drop = YLeaf(YType.uint32, "boundary-acl-tx-drop")

                        self.checksum_error = YLeaf(YType.uint32, "checksum-error")

                        self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                        self.format_error = YLeaf(YType.uint32, "format-error")

                        self.input_assert = YLeaf(YType.uint32, "input-assert")

                        self.input_assert_batched = YLeaf(YType.uint32, "input-assert-batched")

                        self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                        self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                        self.input_data_register = YLeaf(YType.uint32, "input-data-register")

                        self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                        self.input_ecmp_redirect = YLeaf(YType.uint32, "input-ecmp-redirect")

                        self.input_hello = YLeaf(YType.uint32, "input-hello")

                        self.input_jp = YLeaf(YType.uint32, "input-jp")

                        self.input_no_idb_error = YLeaf(YType.uint32, "input-no-idb-error")

                        self.input_no_pim_error = YLeaf(YType.uint32, "input-no-pim-error")

                        self.input_no_vrf_error = YLeaf(YType.uint32, "input-no-vrf-error")

                        self.input_null_register = YLeaf(YType.uint32, "input-null-register")

                        self.input_pim_version_error = YLeaf(YType.uint32, "input-pim-version-error")

                        self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                        self.inputs = YLeaf(YType.uint32, "inputs")

                        self.invalid_destination_packets = YLeaf(YType.uint32, "invalid-destination-packets")

                        self.invalid_join_prunes = YLeaf(YType.uint32, "invalid-join-prunes")

                        self.invalid_registers = YLeaf(YType.uint32, "invalid-registers")

                        self.mdt_drop_local_source_address = YLeaf(YType.uint32, "mdt-drop-local-source-address")

                        self.mdt_drop_no_idb = YLeaf(YType.uint32, "mdt-drop-no-idb")

                        self.mdt_drop_no_vrf = YLeaf(YType.uint32, "mdt-drop-no-vrf")

                        self.mdt_drop_null_local_address = YLeaf(YType.uint32, "mdt-drop-null-local-address")

                        self.mdt_join_bad_type = YLeaf(YType.uint32, "mdt-join-bad-type")

                        self.mdt_join_tlv_received = YLeaf(YType.uint32, "mdt-join-tlv-received")

                        self.mdt_join_tlv_sent = YLeaf(YType.uint32, "mdt-join-tlv-sent")

                        self.mdt_joins_drop_multiple_encapsulation = YLeaf(YType.uint32, "mdt-joins-drop-multiple-encapsulation")

                        self.mdt_send_queue_full = YLeaf(YType.uint32, "mdt-send-queue-full")

                        self.mdt_socket_error = YLeaf(YType.uint32, "mdt-socket-error")

                        self.mldp_mdt_invalid_lsm_identifier = YLeaf(YType.uint32, "mldp-mdt-invalid-lsm-identifier")

                        self.no_mdt_socket_connection = YLeaf(YType.uint32, "no-mdt-socket-connection")

                        self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                        self.no_source_address = YLeaf(YType.uint32, "no-source-address")

                        self.non_supported_packets = YLeaf(YType.uint32, "non-supported-packets")

                        self.output_assert = YLeaf(YType.uint32, "output-assert")

                        self.output_assert_batched = YLeaf(YType.uint32, "output-assert-batched")

                        self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                        self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                        self.output_data_register = YLeaf(YType.uint32, "output-data-register")

                        self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                        self.output_ecmp_redirect = YLeaf(YType.uint32, "output-ecmp-redirect")

                        self.output_hello = YLeaf(YType.uint32, "output-hello")

                        self.output_hello_bytes = YLeaf(YType.uint32, "output-hello-bytes")

                        self.output_join_group = YLeaf(YType.uint32, "output-join-group")

                        self.output_join_prune_bytes = YLeaf(YType.uint32, "output-join-prune-bytes")

                        self.output_jp = YLeaf(YType.uint32, "output-jp")

                        self.output_loop_error = YLeaf(YType.uint32, "output-loop-error")

                        self.output_null_register = YLeaf(YType.uint32, "output-null-register")

                        self.output_prune_group = YLeaf(YType.uint32, "output-prune-group")

                        self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                        self.outputs = YLeaf(YType.uint32, "outputs")

                        self.packet_packman_error = YLeaf(YType.uint32, "packet-packman-error")

                        self.packet_queue_last_clear = YLeaf(YType.uint32, "packet-queue-last-clear")

                        self.packet_read_socket_error = YLeaf(YType.uint32, "packet-read-socket-error")

                        self.packets_standby = YLeaf(YType.uint32, "packets-standby")

                        self.pakman_error = YLeaf(YType.uint32, "pakman-error")

                        self.send_queue_full = YLeaf(YType.uint32, "send-queue-full")

                        self.socket_error = YLeaf(YType.uint32, "socket-error")

                        self.standby_packets_error = YLeaf(YType.uint32, "standby-packets-error")

                        self.truncated_pim_packets = YLeaf(YType.uint32, "truncated-pim-packets")

                        self.packet_queue = YList(self)
                        self._segment_path = lambda: "traffic-counters"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.TrafficCounters, ['boundary_acl_rx_drop', 'boundary_acl_tx_drop', 'checksum_error', 'elapsed_time', 'format_error', 'input_assert', 'input_assert_batched', 'input_bsr_message', 'input_candidate_rp_advertisement', 'input_data_register', 'input_df_election', 'input_ecmp_redirect', 'input_hello', 'input_jp', 'input_no_idb_error', 'input_no_pim_error', 'input_no_vrf_error', 'input_null_register', 'input_pim_version_error', 'input_register_stop', 'inputs', 'invalid_destination_packets', 'invalid_join_prunes', 'invalid_registers', 'mdt_drop_local_source_address', 'mdt_drop_no_idb', 'mdt_drop_no_vrf', 'mdt_drop_null_local_address', 'mdt_join_bad_type', 'mdt_join_tlv_received', 'mdt_join_tlv_sent', 'mdt_joins_drop_multiple_encapsulation', 'mdt_send_queue_full', 'mdt_socket_error', 'mldp_mdt_invalid_lsm_identifier', 'no_mdt_socket_connection', 'no_socket_connection', 'no_source_address', 'non_supported_packets', 'output_assert', 'output_assert_batched', 'output_bsr_message', 'output_candidate_rp_advertisement', 'output_data_register', 'output_df_election', 'output_ecmp_redirect', 'output_hello', 'output_hello_bytes', 'output_join_group', 'output_join_prune_bytes', 'output_jp', 'output_loop_error', 'output_null_register', 'output_prune_group', 'output_register_stop', 'outputs', 'packet_packman_error', 'packet_queue_last_clear', 'packet_read_socket_error', 'packets_standby', 'pakman_error', 'send_queue_full', 'socket_error', 'standby_packets_error', 'truncated_pim_packets'], name, value)


                    class PacketQueue(Entity):
                        """
                        Packet queue state and statistics
                        
                        .. attribute:: packet_queue_priority
                        
                        	Priority of this packet queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: packet_queue_state
                        
                        	State of the queue
                        	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState>`
                        
                        .. attribute:: packet_queue_stats
                        
                        	Statistics about the queue
                        	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__init__()

                            self.yang_name = "packet-queue"
                            self.yang_parent_name = "traffic-counters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"packet-queue-state" : ("packet_queue_state", Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState), "packet-queue-stats" : ("packet_queue_stats", Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats)}
                            self._child_list_classes = {}

                            self.packet_queue_priority = YLeaf(YType.uint32, "packet-queue-priority")

                            self.packet_queue_state = Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                            self.packet_queue_state.parent = self
                            self._children_name_map["packet_queue_state"] = "packet-queue-state"
                            self._children_yang_names.add("packet-queue-state")

                            self.packet_queue_stats = Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                            self.packet_queue_stats.parent = self
                            self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                            self._children_yang_names.add("packet-queue-stats")
                            self._segment_path = lambda: "packet-queue"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue, ['packet_queue_priority'], name, value)


                        class PacketQueueState(Entity):
                            """
                            State of the queue
                            
                            .. attribute:: max_queue_size
                            
                            	Maximum size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_bytes
                            
                            	Size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_packets
                            
                            	Size of queue in number of packets
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                                self.yang_name = "packet-queue-state"
                                self.yang_parent_name = "packet-queue"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.max_queue_size = YLeaf(YType.uint32, "max-queue-size")

                                self.queue_size_bytes = YLeaf(YType.uint32, "queue-size-bytes")

                                self.queue_size_packets = YLeaf(YType.uint32, "queue-size-packets")
                                self._segment_path = lambda: "packet-queue-state"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, ['max_queue_size', 'queue_size_bytes', 'queue_size_packets'], name, value)


                        class PacketQueueStats(Entity):
                            """
                            Statistics about the queue
                            
                            .. attribute:: dequeued_packets
                            
                            	Total number of packets dequeued from this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: enqueued_packets
                            
                            	Total number of packets enqueued to this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_bytes
                            
                            	Highest number of bytes enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: high_water_mark_packets
                            
                            	Highest number of packets enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tail_drops
                            
                            	Number packets dropped from this queue due to max size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                                self.yang_name = "packet-queue-stats"
                                self.yang_parent_name = "packet-queue"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.dequeued_packets = YLeaf(YType.uint32, "dequeued-packets")

                                self.enqueued_packets = YLeaf(YType.uint32, "enqueued-packets")

                                self.high_water_mark_bytes = YLeaf(YType.uint32, "high-water-mark-bytes")

                                self.high_water_mark_packets = YLeaf(YType.uint32, "high-water-mark-packets")

                                self.tail_drops = YLeaf(YType.uint32, "tail-drops")
                                self._segment_path = lambda: "packet-queue-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, ['dequeued_packets', 'enqueued_packets', 'high_water_mark_bytes', 'high_water_mark_packets', 'tail_drops'], name, value)


                class Tunnels(Entity):
                    """
                    Tunnels information that PIM has
                    
                    .. attribute:: tunnel
                    
                    	PIM tunnel information
                    	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Tunnels, self).__init__()

                        self.yang_name = "tunnels"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"tunnel" : ("tunnel", Pim.Active.Vrfs.Vrf.Tunnels.Tunnel)}

                        self.tunnel = YList(self)
                        self._segment_path = lambda: "tunnels"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Tunnels, [], name, value)


                    class Tunnel(Entity):
                        """
                        PIM tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel, self).__init__()

                            self.yang_name = "tunnel"
                            self.yang_parent_name = "tunnels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-netio" : ("group_address_netio", Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio), "rp-address" : ("rp_address", Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress), "source-address" : ("source_address", Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress), "source-address-netio" : ("source_address_netio", Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio)}
                            self._child_list_classes = {}

                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_netio = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._children_yang_names.add("group-address-netio")

                            self.rp_address = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.source_address = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                            self.source_address_netio = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"
                            self._children_yang_names.add("source-address-netio")
                            self._segment_path = lambda: "tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel, ['tunnel_name', 'vrf_name'], name, value)


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-netio"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-netio"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


    class Standby(Entity):
        """
        Standby Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2017-06-26'

        def __init__(self):
            super(Pim.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "pim"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"default-context" : ("default_context", Pim.Standby.DefaultContext), "process" : ("process", Pim.Standby.Process), "vrfs" : ("vrfs", Pim.Standby.Vrfs)}
            self._child_list_classes = {}

            self.default_context = Pim.Standby.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"
            self._children_yang_names.add("default-context")

            self.process = Pim.Standby.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"
            self._children_yang_names.add("process")

            self.vrfs = Pim.Standby.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._children_yang_names.add("vrfs")
            self._segment_path = lambda: "standby"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/%s" % self._segment_path()


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: auto_rp
            
            	PIM Auto\-RP information
            	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.AutoRp>`
            
            .. attribute:: bgp_afs
            
            	PIM BGP SAFI table
            	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs>`
            
            .. attribute:: bidir_df_states
            
            	Bidirectional PIM DF election state table
            	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfStates>`
            
            .. attribute:: bidir_df_winners
            
            	Bidirectional PIM DF election winner table
            	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfWinners>`
            
            .. attribute:: bsr
            
            	PIM BSR information
            	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr>`
            
            .. attribute:: context
            
            	PIM context information
            	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context>`
            
            .. attribute:: global_interfaces
            
            	PIM global interface table
            	**type**\:   :py:class:`GlobalInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GlobalInterfaces>`
            
            .. attribute:: gre
            
            	GRE information
            	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre>`
            
            .. attribute:: group_map_rpfs
            
            	PIM group mapping information
            	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs>`
            
            .. attribute:: group_map_sources
            
            	PIM group\-mapping with source information
            	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources>`
            
            .. attribute:: ifrs_interfaces
            
            	PIM interfaces in forward reference store table
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: ifrs_summary
            
            	PIM interfaces in forward reference store summary
            	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsSummary>`
            
            .. attribute:: interface_old_formats
            
            	PIM interfaces in old format
            	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceOldFormats>`
            
            .. attribute:: interface_statistics
            
            	PIM interface statistics
            	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceStatistics>`
            
            .. attribute:: interfaces
            
            	PIM interfaces
            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Interfaces>`
            
            .. attribute:: jp_statistics
            
            	PIM join prune statistics table
            	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.JpStatistics>`
            
            .. attribute:: mib_databases
            
            	PIM group database for mroute mibs table
            	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases>`
            
            .. attribute:: multicast_static_routes
            
            	PIM multicast static route table
            	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MulticastStaticRoutes>`
            
            .. attribute:: neighbor_old_formats
            
            	PIM neighbor table old format
            	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborOldFormats>`
            
            .. attribute:: neighbor_summaries
            
            	PIM neighbor summary table
            	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborSummaries>`
            
            .. attribute:: neighbors
            
            	PIM neighbor table
            	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Neighbors>`
            
            .. attribute:: net_io_tunnels
            
            	Tunnel information that NETIO has 
            	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels>`
            
            .. attribute:: ranges
            
            	PIM range list information
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges>`
            
            .. attribute:: route_policy
            
            	PIM route policy
            	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy>`
            
            .. attribute:: rpf_redirect
            
            	PIM ECMP RPF\-redirect bundle
            	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect>`
            
            .. attribute:: rpf_summary
            
            	PIM RPF registration summary
            	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfSummary>`
            
            .. attribute:: safs
            
            	SAFI table and type
            	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs>`
            
            .. attribute:: summary
            
            	PIM summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Summary>`
            
            .. attribute:: table_contexts
            
            	PIM table context list
            	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TableContexts>`
            
            .. attribute:: topologies
            
            	PIM topology table
            	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies>`
            
            .. attribute:: topology_entry_flag_route_counts
            
            	Route count for topology with entry flag set
            	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts>`
            
            .. attribute:: topology_interface_flag_route_counts
            
            	Route count for topology with interface flag set
            	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts>`
            
            .. attribute:: topology_route_count
            
            	Topology route count information from PIM topology table
            	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyRouteCount>`
            
            .. attribute:: traffic_counters
            
            	PIM message traffic counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TrafficCounters>`
            
            .. attribute:: tunnels
            
            	Tunnels information that PIM has
            	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Pim.Standby.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"auto-rp" : ("auto_rp", Pim.Standby.DefaultContext.AutoRp), "bgp-afs" : ("bgp_afs", Pim.Standby.DefaultContext.BgpAfs), "bidir-df-states" : ("bidir_df_states", Pim.Standby.DefaultContext.BidirDfStates), "bidir-df-winners" : ("bidir_df_winners", Pim.Standby.DefaultContext.BidirDfWinners), "bsr" : ("bsr", Pim.Standby.DefaultContext.Bsr), "context" : ("context", Pim.Standby.DefaultContext.Context), "global-interfaces" : ("global_interfaces", Pim.Standby.DefaultContext.GlobalInterfaces), "gre" : ("gre", Pim.Standby.DefaultContext.Gre), "group-map-rpfs" : ("group_map_rpfs", Pim.Standby.DefaultContext.GroupMapRpfs), "group-map-sources" : ("group_map_sources", Pim.Standby.DefaultContext.GroupMapSources), "ifrs-interfaces" : ("ifrs_interfaces", Pim.Standby.DefaultContext.IfrsInterfaces), "ifrs-summary" : ("ifrs_summary", Pim.Standby.DefaultContext.IfrsSummary), "interface-old-formats" : ("interface_old_formats", Pim.Standby.DefaultContext.InterfaceOldFormats), "interface-statistics" : ("interface_statistics", Pim.Standby.DefaultContext.InterfaceStatistics), "interfaces" : ("interfaces", Pim.Standby.DefaultContext.Interfaces), "jp-statistics" : ("jp_statistics", Pim.Standby.DefaultContext.JpStatistics), "mib-databases" : ("mib_databases", Pim.Standby.DefaultContext.MibDatabases), "multicast-static-routes" : ("multicast_static_routes", Pim.Standby.DefaultContext.MulticastStaticRoutes), "neighbor-old-formats" : ("neighbor_old_formats", Pim.Standby.DefaultContext.NeighborOldFormats), "neighbor-summaries" : ("neighbor_summaries", Pim.Standby.DefaultContext.NeighborSummaries), "neighbors" : ("neighbors", Pim.Standby.DefaultContext.Neighbors), "net-io-tunnels" : ("net_io_tunnels", Pim.Standby.DefaultContext.NetIoTunnels), "ranges" : ("ranges", Pim.Standby.DefaultContext.Ranges), "route-policy" : ("route_policy", Pim.Standby.DefaultContext.RoutePolicy), "rpf-redirect" : ("rpf_redirect", Pim.Standby.DefaultContext.RpfRedirect), "rpf-summary" : ("rpf_summary", Pim.Standby.DefaultContext.RpfSummary), "safs" : ("safs", Pim.Standby.DefaultContext.Safs), "summary" : ("summary", Pim.Standby.DefaultContext.Summary), "table-contexts" : ("table_contexts", Pim.Standby.DefaultContext.TableContexts), "topologies" : ("topologies", Pim.Standby.DefaultContext.Topologies), "topology-entry-flag-route-counts" : ("topology_entry_flag_route_counts", Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts), "topology-interface-flag-route-counts" : ("topology_interface_flag_route_counts", Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts), "topology-route-count" : ("topology_route_count", Pim.Standby.DefaultContext.TopologyRouteCount), "traffic-counters" : ("traffic_counters", Pim.Standby.DefaultContext.TrafficCounters), "tunnels" : ("tunnels", Pim.Standby.DefaultContext.Tunnels)}
                self._child_list_classes = {}

                self.auto_rp = Pim.Standby.DefaultContext.AutoRp()
                self.auto_rp.parent = self
                self._children_name_map["auto_rp"] = "auto-rp"
                self._children_yang_names.add("auto-rp")

                self.bgp_afs = Pim.Standby.DefaultContext.BgpAfs()
                self.bgp_afs.parent = self
                self._children_name_map["bgp_afs"] = "bgp-afs"
                self._children_yang_names.add("bgp-afs")

                self.bidir_df_states = Pim.Standby.DefaultContext.BidirDfStates()
                self.bidir_df_states.parent = self
                self._children_name_map["bidir_df_states"] = "bidir-df-states"
                self._children_yang_names.add("bidir-df-states")

                self.bidir_df_winners = Pim.Standby.DefaultContext.BidirDfWinners()
                self.bidir_df_winners.parent = self
                self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                self._children_yang_names.add("bidir-df-winners")

                self.bsr = Pim.Standby.DefaultContext.Bsr()
                self.bsr.parent = self
                self._children_name_map["bsr"] = "bsr"
                self._children_yang_names.add("bsr")

                self.context = Pim.Standby.DefaultContext.Context()
                self.context.parent = self
                self._children_name_map["context"] = "context"
                self._children_yang_names.add("context")

                self.global_interfaces = Pim.Standby.DefaultContext.GlobalInterfaces()
                self.global_interfaces.parent = self
                self._children_name_map["global_interfaces"] = "global-interfaces"
                self._children_yang_names.add("global-interfaces")

                self.gre = Pim.Standby.DefaultContext.Gre()
                self.gre.parent = self
                self._children_name_map["gre"] = "gre"
                self._children_yang_names.add("gre")

                self.group_map_rpfs = Pim.Standby.DefaultContext.GroupMapRpfs()
                self.group_map_rpfs.parent = self
                self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                self._children_yang_names.add("group-map-rpfs")

                self.group_map_sources = Pim.Standby.DefaultContext.GroupMapSources()
                self.group_map_sources.parent = self
                self._children_name_map["group_map_sources"] = "group-map-sources"
                self._children_yang_names.add("group-map-sources")

                self.ifrs_interfaces = Pim.Standby.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                self._children_yang_names.add("ifrs-interfaces")

                self.ifrs_summary = Pim.Standby.DefaultContext.IfrsSummary()
                self.ifrs_summary.parent = self
                self._children_name_map["ifrs_summary"] = "ifrs-summary"
                self._children_yang_names.add("ifrs-summary")

                self.interface_old_formats = Pim.Standby.DefaultContext.InterfaceOldFormats()
                self.interface_old_formats.parent = self
                self._children_name_map["interface_old_formats"] = "interface-old-formats"
                self._children_yang_names.add("interface-old-formats")

                self.interface_statistics = Pim.Standby.DefaultContext.InterfaceStatistics()
                self.interface_statistics.parent = self
                self._children_name_map["interface_statistics"] = "interface-statistics"
                self._children_yang_names.add("interface-statistics")

                self.interfaces = Pim.Standby.DefaultContext.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"
                self._children_yang_names.add("interfaces")

                self.jp_statistics = Pim.Standby.DefaultContext.JpStatistics()
                self.jp_statistics.parent = self
                self._children_name_map["jp_statistics"] = "jp-statistics"
                self._children_yang_names.add("jp-statistics")

                self.mib_databases = Pim.Standby.DefaultContext.MibDatabases()
                self.mib_databases.parent = self
                self._children_name_map["mib_databases"] = "mib-databases"
                self._children_yang_names.add("mib-databases")

                self.multicast_static_routes = Pim.Standby.DefaultContext.MulticastStaticRoutes()
                self.multicast_static_routes.parent = self
                self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                self._children_yang_names.add("multicast-static-routes")

                self.neighbor_old_formats = Pim.Standby.DefaultContext.NeighborOldFormats()
                self.neighbor_old_formats.parent = self
                self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                self._children_yang_names.add("neighbor-old-formats")

                self.neighbor_summaries = Pim.Standby.DefaultContext.NeighborSummaries()
                self.neighbor_summaries.parent = self
                self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                self._children_yang_names.add("neighbor-summaries")

                self.neighbors = Pim.Standby.DefaultContext.Neighbors()
                self.neighbors.parent = self
                self._children_name_map["neighbors"] = "neighbors"
                self._children_yang_names.add("neighbors")

                self.net_io_tunnels = Pim.Standby.DefaultContext.NetIoTunnels()
                self.net_io_tunnels.parent = self
                self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                self._children_yang_names.add("net-io-tunnels")

                self.ranges = Pim.Standby.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"
                self._children_yang_names.add("ranges")

                self.route_policy = Pim.Standby.DefaultContext.RoutePolicy()
                self.route_policy.parent = self
                self._children_name_map["route_policy"] = "route-policy"
                self._children_yang_names.add("route-policy")

                self.rpf_redirect = Pim.Standby.DefaultContext.RpfRedirect()
                self.rpf_redirect.parent = self
                self._children_name_map["rpf_redirect"] = "rpf-redirect"
                self._children_yang_names.add("rpf-redirect")

                self.rpf_summary = Pim.Standby.DefaultContext.RpfSummary()
                self.rpf_summary.parent = self
                self._children_name_map["rpf_summary"] = "rpf-summary"
                self._children_yang_names.add("rpf-summary")

                self.safs = Pim.Standby.DefaultContext.Safs()
                self.safs.parent = self
                self._children_name_map["safs"] = "safs"
                self._children_yang_names.add("safs")

                self.summary = Pim.Standby.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.table_contexts = Pim.Standby.DefaultContext.TableContexts()
                self.table_contexts.parent = self
                self._children_name_map["table_contexts"] = "table-contexts"
                self._children_yang_names.add("table-contexts")

                self.topologies = Pim.Standby.DefaultContext.Topologies()
                self.topologies.parent = self
                self._children_name_map["topologies"] = "topologies"
                self._children_yang_names.add("topologies")

                self.topology_entry_flag_route_counts = Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts()
                self.topology_entry_flag_route_counts.parent = self
                self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                self._children_yang_names.add("topology-entry-flag-route-counts")

                self.topology_interface_flag_route_counts = Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts()
                self.topology_interface_flag_route_counts.parent = self
                self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                self._children_yang_names.add("topology-interface-flag-route-counts")

                self.topology_route_count = Pim.Standby.DefaultContext.TopologyRouteCount()
                self.topology_route_count.parent = self
                self._children_name_map["topology_route_count"] = "topology-route-count"
                self._children_yang_names.add("topology-route-count")

                self.traffic_counters = Pim.Standby.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"
                self._children_yang_names.add("traffic-counters")

                self.tunnels = Pim.Standby.DefaultContext.Tunnels()
                self.tunnels.parent = self
                self._children_name_map["tunnels"] = "tunnels"
                self._children_yang_names.add("tunnels")
                self._segment_path = lambda: "default-context"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/%s" % self._segment_path()


            class AutoRp(Entity):
                """
                PIM Auto\-RP information
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.AutoRp, self).__init__()

                    self.yang_name = "auto-rp"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self._segment_path = lambda: "auto-rp"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()


            class BgpAfs(Entity):
                """
                PIM BGP SAFI table
                
                .. attribute:: bgp_af
                
                	PIM BGP SAFI information
                	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs.BgpAf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.BgpAfs, self).__init__()

                    self.yang_name = "bgp-afs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"bgp-af" : ("bgp_af", Pim.Standby.DefaultContext.BgpAfs.BgpAf)}

                    self.bgp_af = YList(self)
                    self._segment_path = lambda: "bgp-afs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.BgpAfs, [], name, value)


                class BgpAf(Entity):
                    """
                    PIM BGP SAFI information
                    
                    .. attribute:: extranet_path_count
                    
                    	Count of dependent extranet paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group
                    
                    	Group address
                    	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group>`
                    
                    .. attribute:: group_address
                    
                    	Group IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: is_bgp_added
                    
                    	SAFI learnt from BGP
                    	**type**\:  bool
                    
                    .. attribute:: next_hop
                    
                    	Next hop address
                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop>`
                    
                    .. attribute:: route_distinguisher
                    
                    	Router ID
                    	**type**\:  str
                    
                    	**length:** 0..256
                    
                    .. attribute:: source
                    
                    	Source address
                    	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.BgpAfs.BgpAf, self).__init__()

                        self.yang_name = "bgp-af"
                        self.yang_parent_name = "bgp-afs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group" : ("group", Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group), "next-hop" : ("next_hop", Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop), "source" : ("source", Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source)}
                        self._child_list_classes = {}

                        self.extranet_path_count = YLeaf(YType.uint32, "extranet-path-count")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.is_bgp_added = YLeaf(YType.boolean, "is-bgp-added")

                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group = Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group()
                        self.group.parent = self
                        self._children_name_map["group"] = "group"
                        self._children_yang_names.add("group")

                        self.next_hop = Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._children_yang_names.add("next-hop")

                        self.source = Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"
                        self._children_yang_names.add("source")
                        self._segment_path = lambda: "bgp-af"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bgp-afs/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.BgpAfs.BgpAf, ['extranet_path_count', 'group_address', 'is_bgp_added', 'route_distinguisher', 'source_address'], name, value)


                    class Group(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bgp-afs/bgp-af/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class NextHop(Entity):
                        """
                        Next hop address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "next-hop"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bgp-afs/bgp-af/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Source(Entity):
                        """
                        Source address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bgp-afs/bgp-af/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class BidirDfStates(Entity):
                """
                Bidirectional PIM DF election state table
                
                .. attribute:: bidir_df_state
                
                	Bidirectional PIM DF Election Table Entry
                	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfStates.BidirDfState>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.BidirDfStates, self).__init__()

                    self.yang_name = "bidir-df-states"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"bidir-df-state" : ("bidir_df_state", Pim.Standby.DefaultContext.BidirDfStates.BidirDfState)}

                    self.bidir_df_state = YList(self)
                    self._segment_path = lambda: "bidir-df-states"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.BidirDfStates, [], name, value)


                class BidirDfState(Entity):
                    """
                    Bidirectional PIM DF Election Table Entry
                    
                    .. attribute:: election_state
                    
                    	DF Election State
                    	**type**\:  str
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: our_metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: our_metric_preference
                    
                    	MetricPreference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr>`
                    
                    .. attribute:: time_nano_seconds
                    
                    	Timer expires (nseconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: time_seconds
                    
                    	Timer expires (seconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.BidirDfStates.BidirDfState, self).__init__()

                        self.yang_name = "bidir-df-state"
                        self.yang_parent_name = "bidir-df-states"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rp-address-xr" : ("rp_address_xr", Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr)}
                        self._child_list_classes = {}

                        self.election_state = YLeaf(YType.str, "election-state")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.our_metric = YLeaf(YType.uint32, "our-metric")

                        self.our_metric_preference = YLeaf(YType.uint32, "our-metric-preference")

                        self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.time_nano_seconds = YLeaf(YType.uint64, "time-nano-seconds")

                        self.time_seconds = YLeaf(YType.uint64, "time-seconds")

                        self.rp_address_xr = Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")
                        self._segment_path = lambda: "bidir-df-state"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bidir-df-states/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.BidirDfStates.BidirDfState, ['election_state', 'interface_name', 'our_metric', 'our_metric_preference', 'pim_interface_name', 'rp_address', 'time_nano_seconds', 'time_seconds'], name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-state"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bidir-df-states/bidir-df-state/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class BidirDfWinners(Entity):
                """
                Bidirectional PIM DF election winner table
                
                .. attribute:: bidir_df_winner
                
                	Bidirectional PIM DF election table entry
                	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.BidirDfWinners, self).__init__()

                    self.yang_name = "bidir-df-winners"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"bidir-df-winner" : ("bidir_df_winner", Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner)}

                    self.bidir_df_winner = YList(self)
                    self._segment_path = lambda: "bidir-df-winners"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.BidirDfWinners, [], name, value)


                class BidirDfWinner(Entity):
                    """
                    Bidirectional PIM DF election table entry
                    
                    .. attribute:: are_we_df
                    
                    	Are we DF
                    	**type**\:  bool
                    
                    .. attribute:: df_winner
                    
                    	DF Winner
                    	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner>`
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_preference
                    
                    	Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                    
                    .. attribute:: rp_lan
                    
                    	Is this the RP LAN
                    	**type**\:  bool
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner, self).__init__()

                        self.yang_name = "bidir-df-winner"
                        self.yang_parent_name = "bidir-df-winners"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"df-winner" : ("df_winner", Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner), "rp-address-xr" : ("rp_address_xr", Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr)}
                        self._child_list_classes = {}

                        self.are_we_df = YLeaf(YType.boolean, "are-we-df")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.metric = YLeaf(YType.uint32, "metric")

                        self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                        self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_lan = YLeaf(YType.boolean, "rp-lan")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.df_winner = Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                        self.df_winner.parent = self
                        self._children_name_map["df_winner"] = "df-winner"
                        self._children_yang_names.add("df-winner")

                        self.rp_address_xr = Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")
                        self._segment_path = lambda: "bidir-df-winner"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bidir-df-winners/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner, ['are_we_df', 'interface_name', 'metric', 'metric_preference', 'pim_interface_name', 'rp_address', 'rp_lan', 'uptime'], name, value)


                    class DfWinner(Entity):
                        """
                        DF Winner
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                            self.yang_name = "df-winner"
                            self.yang_parent_name = "bidir-df-winner"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "df-winner"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bidir-df-winners/bidir-df-winner/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-winner"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bidir-df-winners/bidir-df-winner/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Bsr(Entity):
                """
                PIM BSR information
                
                .. attribute:: bsr_elections
                
                	PIM BSR election state
                	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.BsrElections>`
                
                .. attribute:: candidate_rps
                
                	PIM candidate\-RP
                	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.CandidateRps>`
                
                .. attribute:: rp_caches
                
                	PIM BSR RP cache table
                	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Bsr, self).__init__()

                    self.yang_name = "bsr"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"bsr-elections" : ("bsr_elections", Pim.Standby.DefaultContext.Bsr.BsrElections), "candidate-rps" : ("candidate_rps", Pim.Standby.DefaultContext.Bsr.CandidateRps), "rp-caches" : ("rp_caches", Pim.Standby.DefaultContext.Bsr.RpCaches)}
                    self._child_list_classes = {}

                    self.bsr_elections = Pim.Standby.DefaultContext.Bsr.BsrElections()
                    self.bsr_elections.parent = self
                    self._children_name_map["bsr_elections"] = "bsr-elections"
                    self._children_yang_names.add("bsr-elections")

                    self.candidate_rps = Pim.Standby.DefaultContext.Bsr.CandidateRps()
                    self.candidate_rps.parent = self
                    self._children_name_map["candidate_rps"] = "candidate-rps"
                    self._children_yang_names.add("candidate-rps")

                    self.rp_caches = Pim.Standby.DefaultContext.Bsr.RpCaches()
                    self.rp_caches.parent = self
                    self._children_name_map["rp_caches"] = "rp-caches"
                    self._children_yang_names.add("rp-caches")
                    self._segment_path = lambda: "bsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()


                class BsrElections(Entity):
                    """
                    PIM BSR election state
                    
                    .. attribute:: bsr_election
                    
                    	PIM BSR information
                    	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Bsr.BsrElections, self).__init__()

                        self.yang_name = "bsr-elections"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"bsr-election" : ("bsr_election", Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection)}

                        self.bsr_election = YList(self)
                        self._segment_path = lambda: "bsr-elections"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bsr/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Bsr.BsrElections, [], name, value)


                    class BsrElection(Entity):
                        """
                        PIM BSR information
                        
                        .. attribute:: pim_scope  <key>
                        
                        	BSR information
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: bootstrap_timeout
                        
                        	Bootstrap Timeout
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_address
                        
                        	BSR address
                        	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress>`
                        
                        .. attribute:: bsr_election_state
                        
                        	BSR Election State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_mask_length
                        
                        	Hash Function Mask Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_priority
                        
                        	BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_scope
                        
                        	BSR Scope
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_up_time
                        
                        	BSR Uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_address
                        
                        	C\-BSR address
                        	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                        
                        .. attribute:: candidate_bsr_flag
                        
                        	BSR Candidate Config Flag
                        	**type**\:  bool
                        
                        .. attribute:: candidate_bsr_mask_length
                        
                        	C\-BSR Hash Func. Mask Len
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_priority
                        
                        	C\-BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_state
                        
                        	BSR Candidate State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection, self).__init__()

                            self.yang_name = "bsr-election"
                            self.yang_parent_name = "bsr-elections"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"bsr-address" : ("bsr_address", Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress), "candidate-bsr-address" : ("candidate_bsr_address", Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress)}
                            self._child_list_classes = {}

                            self.pim_scope = YLeaf(YType.int32, "pim-scope")

                            self.bootstrap_timeout = YLeaf(YType.uint16, "bootstrap-timeout")

                            self.bsr_election_state = YLeaf(YType.uint32, "bsr-election-state")

                            self.bsr_mask_length = YLeaf(YType.uint8, "bsr-mask-length")

                            self.bsr_priority = YLeaf(YType.uint8, "bsr-priority")

                            self.bsr_scope = YLeaf(YType.uint16, "bsr-scope")

                            self.bsr_up_time = YLeaf(YType.uint16, "bsr-up-time")

                            self.candidate_bsr_flag = YLeaf(YType.boolean, "candidate-bsr-flag")

                            self.candidate_bsr_mask_length = YLeaf(YType.uint8, "candidate-bsr-mask-length")

                            self.candidate_bsr_priority = YLeaf(YType.uint8, "candidate-bsr-priority")

                            self.candidate_bsr_state = YLeaf(YType.uint32, "candidate-bsr-state")

                            self.bsr_address = Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                            self.bsr_address.parent = self
                            self._children_name_map["bsr_address"] = "bsr-address"
                            self._children_yang_names.add("bsr-address")

                            self.candidate_bsr_address = Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                            self.candidate_bsr_address.parent = self
                            self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                            self._children_yang_names.add("candidate-bsr-address")
                            self._segment_path = lambda: "bsr-election" + "[pim-scope='" + self.pim_scope.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bsr/bsr-elections/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection, ['pim_scope', 'bootstrap_timeout', 'bsr_election_state', 'bsr_mask_length', 'bsr_priority', 'bsr_scope', 'bsr_up_time', 'candidate_bsr_flag', 'candidate_bsr_mask_length', 'candidate_bsr_priority', 'candidate_bsr_state'], name, value)


                        class BsrAddress(Entity):
                            """
                            BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                self.yang_name = "bsr-address"
                                self.yang_parent_name = "bsr-election"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "bsr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class CandidateBsrAddress(Entity):
                            """
                            C\-BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                self.yang_name = "candidate-bsr-address"
                                self.yang_parent_name = "bsr-election"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "candidate-bsr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class CandidateRps(Entity):
                    """
                    PIM candidate\-RP
                    
                    .. attribute:: candidate_rp
                    
                    	PIM BSR candidate RP information
                    	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Bsr.CandidateRps, self).__init__()

                        self.yang_name = "candidate-rps"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"candidate-rp" : ("candidate_rp", Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp)}

                        self.candidate_rp = YList(self)
                        self._segment_path = lambda: "candidate-rps"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bsr/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Bsr.CandidateRps, [], name, value)


                    class CandidateRp(Entity):
                        """
                        PIM BSR candidate RP information
                        
                        .. attribute:: rp_address  <key>
                        
                        	Candidate\-RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: acl_name
                        
                        	Group Access\-List Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: candidate_rp
                        
                        	Cand\-RP Address
                        	**type**\:   :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp>`
                        
                        .. attribute:: candidate_rp_advance_interval
                        
                        	Cand\-RP Adv Interval in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: candidate_rp_mode
                        
                        	Cand\-RP Mode
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: candidate_rp_scope
                        
                        	Cand\-RP Scope
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: candidate_rp_uptime
                        
                        	Cand\-RP uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_access
                        
                        	Group Ranges Using this Cand\-RP
                        	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                        
                        .. attribute:: crp_holdtime
                        
                        	Cand\-RP Holdtime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_priority
                        
                        	Cand\-RP Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__init__()

                            self.yang_name = "candidate-rp"
                            self.yang_parent_name = "candidate-rps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"candidate-rp" : ("candidate_rp", Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp)}
                            self._child_list_classes = {"crp-access" : ("crp_access", Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess)}

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.acl_name = YLeaf(YType.str, "acl-name")

                            self.candidate_rp_advance_interval = YLeaf(YType.uint16, "candidate-rp-advance-interval")

                            self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                            self.candidate_rp_scope = YLeaf(YType.int32, "candidate-rp-scope")

                            self.candidate_rp_uptime = YLeaf(YType.uint16, "candidate-rp-uptime")

                            self.crp_holdtime = YLeaf(YType.uint16, "crp-holdtime")

                            self.crp_priority = YLeaf(YType.uint8, "crp-priority")

                            self.candidate_rp = Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp()
                            self.candidate_rp.parent = self
                            self._children_name_map["candidate_rp"] = "candidate-rp"
                            self._children_yang_names.add("candidate-rp")

                            self.crp_access = YList(self)
                            self._segment_path = lambda: "candidate-rp" + "[rp-address='" + self.rp_address.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bsr/candidate-rps/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp, ['rp_address', 'acl_name', 'candidate_rp_advance_interval', 'candidate_rp_mode', 'candidate_rp_scope', 'candidate_rp_uptime', 'crp_holdtime', 'crp_priority'], name, value)


                        class CandidateRp(Entity):
                            """
                            Cand\-RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "candidate-rp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class CrpAccess(Entity):
                            """
                            Group Ranges Using this Cand\-RP
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                self.yang_name = "crp-access"
                                self.yang_parent_name = "candidate-rp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.acl_name = YLeaf(YType.str, "acl-name")

                                self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")
                                self._segment_path = lambda: "crp-access"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, ['acl_name', 'candidate_rp_mode'], name, value)


                class RpCaches(Entity):
                    """
                    PIM BSR RP cache table
                    
                    .. attribute:: rp_cache
                    
                    	PIM BSR RP cache
                    	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Bsr.RpCaches, self).__init__()

                        self.yang_name = "rp-caches"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"rp-cache" : ("rp_cache", Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache)}

                        self.rp_cache = YList(self)
                        self._segment_path = lambda: "rp-caches"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bsr/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Bsr.RpCaches, [], name, value)


                    class RpCache(Entity):
                        """
                        PIM BSR RP cache
                        
                        .. attribute:: group_prefix  <key>
                        
                        	Group prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: candidate_rp_group_count
                        
                        	C\-RP count for this Prefix
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: candidate_rp_list
                        
                        	C\-RP list for this prefix
                        	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList>`
                        
                        .. attribute:: group_prefix_length
                        
                        	Group Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_prefix_xr
                        
                        	Group Prefix
                        	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache, self).__init__()

                            self.yang_name = "rp-cache"
                            self.yang_parent_name = "rp-caches"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"candidate-rp-list" : ("candidate_rp_list", Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList), "group-prefix-xr" : ("group_prefix_xr", Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr)}
                            self._child_list_classes = {}

                            self.group_prefix = YLeaf(YType.str, "group-prefix")

                            self.candidate_rp_group_count = YLeaf(YType.uint32, "candidate-rp-group-count")

                            self.group_prefix_length = YLeaf(YType.uint32, "group-prefix-length")

                            self.candidate_rp_list = Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                            self.candidate_rp_list.parent = self
                            self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                            self._children_yang_names.add("candidate-rp-list")

                            self.group_prefix_xr = Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                            self.group_prefix_xr.parent = self
                            self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                            self._children_yang_names.add("group-prefix-xr")
                            self._segment_path = lambda: "rp-cache" + "[group-prefix='" + self.group_prefix.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bsr/rp-caches/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache, ['group_prefix', 'candidate_rp_group_count', 'group_prefix_length'], name, value)


                        class CandidateRpList(Entity):
                            """
                            C\-RP list for this prefix
                            
                            .. attribute:: pim_bsr_crp_bag
                            
                            	pim bsr crp bag
                            	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                self.yang_name = "candidate-rp-list"
                                self.yang_parent_name = "rp-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"pim-bsr-crp-bag" : ("pim_bsr_crp_bag", Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag)}

                                self.pim_bsr_crp_bag = YList(self)
                                self._segment_path = lambda: "candidate-rp-list"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, [], name, value)


                            class PimBsrCrpBag(Entity):
                                """
                                pim bsr crp bag
                                
                                .. attribute:: candidate_rp_address
                                
                                	C\-RP address
                                	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                
                                .. attribute:: candidate_rp_expires
                                
                                	C\-RP Expires
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_holdtime
                                
                                	C\-RP Holdtime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_priority
                                
                                	C\-RP Priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: candidate_rp_up_time
                                
                                	C\-RP Uptime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: protocol
                                
                                	PIM Protocol
                                	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                    self.yang_name = "pim-bsr-crp-bag"
                                    self.yang_parent_name = "candidate-rp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"candidate-rp-address" : ("candidate_rp_address", Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress)}
                                    self._child_list_classes = {}

                                    self.candidate_rp_expires = YLeaf(YType.uint16, "candidate-rp-expires")

                                    self.candidate_rp_holdtime = YLeaf(YType.uint16, "candidate-rp-holdtime")

                                    self.candidate_rp_priority = YLeaf(YType.uint8, "candidate-rp-priority")

                                    self.candidate_rp_up_time = YLeaf(YType.uint16, "candidate-rp-up-time")

                                    self.protocol = YLeaf(YType.enumeration, "protocol")

                                    self.candidate_rp_address = Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                    self.candidate_rp_address.parent = self
                                    self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                    self._children_yang_names.add("candidate-rp-address")
                                    self._segment_path = lambda: "pim-bsr-crp-bag"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, ['candidate_rp_expires', 'candidate_rp_holdtime', 'candidate_rp_priority', 'candidate_rp_up_time', 'protocol'], name, value)


                                class CandidateRpAddress(Entity):
                                    """
                                    C\-RP address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                        self.yang_name = "candidate-rp-address"
                                        self.yang_parent_name = "pim-bsr-crp-bag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "candidate-rp-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class GroupPrefixXr(Entity):
                            """
                            Group Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                self.yang_name = "group-prefix-xr"
                                self.yang_parent_name = "rp-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-prefix-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Context(Entity):
                """
                PIM context information
                
                .. attribute:: active_table_count
                
                	Number of active Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: allow_rp_configured
                
                	Allow RP Configured
                	**type**\:  bool
                
                .. attribute:: allow_rp_group_list
                
                	Allow RP Group\-List ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: allow_rp_rp_list
                
                	Allow RP RP\-list ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: anycast_rp_configured
                
                	Anycast\-RP config
                	**type**\:  bool
                
                .. attribute:: anycast_rp_policy_name
                
                	Anycast\-RP Policy Name
                	**type**\:  str
                
                .. attribute:: anycast_rp_range
                
                	Anycast\-RP Ranges
                	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.AnycastRpRange>`
                
                .. attribute:: bgp_auto_discovery_configured
                
                	BGP Auto\-Discovery configured
                	**type**\:  bool
                
                .. attribute:: bgp_auto_discovery_type
                
                	BGP Auto Discovery Type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_i_pmsi_added
                
                	BGP I\-PMSI Added
                	**type**\:  bool
                
                .. attribute:: bgp_remote_address
                
                	BGP remote interface address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: bgp_remote_interface
                
                	BGP remote interface handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: bgp_remote_interface_name
                
                	BGP remote interface name
                	**type**\:  str
                
                .. attribute:: bgp_remote_on
                
                	BGP remote interface status
                	**type**\:  bool
                
                .. attribute:: bgp_remote_state
                
                	BGP remote interface state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_source_active_announce
                
                	Send BGP Source\-Active Announcements
                	**type**\:  bool
                
                .. attribute:: export_route_target
                
                	Export Route Targets
                	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.ExportRouteTarget>`
                
                .. attribute:: gin_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: gin_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: gin_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: import_route_target
                
                	Import Route Targets
                	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.ImportRouteTarget>`
                
                .. attribute:: in_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: in_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: in_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_signaling_local_enabled
                
                	Inband signaling Local enabled
                	**type**\:  bool
                
                .. attribute:: in_band_signaling_remote_enabled
                
                	Inband signaling Remote enabled
                	**type**\:  bool
                
                .. attribute:: inter_autonomous_system_enabled
                
                	Inter\-AS Enabled
                	**type**\:  bool
                
                .. attribute:: ir_maximum_mdt_aggregation
                
                	IR MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_announce_interval
                
                	IR Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_switchover_interval
                
                	IR Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_interface
                
                	IRMDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: ir_mdt_mtu
                
                	IRMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_name
                
                	IR MDT Name
                	**type**\:  str
                
                .. attribute:: ir_mdt_rpf_identifier
                
                	IR RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_tail_label
                
                	IR Tail Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_active
                
                	Active
                	**type**\:  bool
                
                .. attribute:: is_active_ital
                
                	Active ITAL
                	**type**\:  bool
                
                .. attribute:: is_all_interface_disable_operation
                
                	PIM all interface disable operation
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_enabled
                
                	Auto RP Listen Enabled
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_sock_add
                
                	Auto RP listen sock add
                	**type**\:  bool
                
                .. attribute:: is_create_gin_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_in_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_ir_mdt_interface
                
                	Create IR MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mdt_interface
                
                	Create MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mldp_mdt_interface
                
                	Create MLDP MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_rsvp_te_mdt_interface
                
                	Create RSVP\-TE MDT interface
                	**type**\:  bool
                
                .. attribute:: is_default_granges
                
                	Default granges
                	**type**\:  bool
                
                .. attribute:: is_gin_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_in_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_ir_mdt_owner
                
                	IR MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_add_required
                
                	VRF LPTS filter required on Socket
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_added
                
                	VRF LPTS filter added on Socket
                	**type**\:  bool
                
                .. attribute:: is_m_host_publish_pending
                
                	Publish pending for MHost Default interface
                	**type**\:  bool
                
                .. attribute:: is_mdt_owner
                
                	MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mldp_mdt_owner
                
                	MLDP MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mrib_register
                
                	MRIB Register
                	**type**\:  bool
                
                .. attribute:: is_multicast_rib_registration
                
                	Mcast RIB Registration
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converge_received
                
                	PIM NSF RIB converge received
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converged
                
                	PIM NSF RIB converged
                	**type**\:  bool
                
                .. attribute:: is_redistribution_reset
                
                	Pending redist reset
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_add_required
                
                	VRF LPTS filter required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_added
                
                	VRF LPTS filter added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_add_required
                
                	VRF required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_added
                
                	VRF added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_enabled
                
                	PIM RIB multiplath enabled
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_interface_hash
                
                	PIM RIB multipath interface hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_hash
                
                	PIM RIB multipath source based hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_next_hop_hash
                
                	PIM RIB multipath source\-nexthop hash
                	**type**\:  bool
                
                .. attribute:: is_routing_enabled
                
                	Routing Enabled
                	**type**\:  bool
                
                .. attribute:: is_rsvp_te_mdt_owner
                
                	RSVP\-TE MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_socket_add_required
                
                	VRF required on Socket
                	**type**\:  bool
                
                .. attribute:: is_socket_added
                
                	VRF added on Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_add_required
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_added
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind
                
                	VRF bound on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind_required
                
                	VRF bind required on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_unicast_rib_registration
                
                	Ucast RIB Registration
                	**type**\:  bool
                
                .. attribute:: maximum_mdt_aggregation
                
                	MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_announce_interval
                
                	Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_switchover_interval
                
                	Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_default_group
                
                	MDT Default group
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_gre_remote_rpf_identifier
                
                	GRE\-MDT Remote RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_gre_rpf_identifier
                
                	GRE\-MDT RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_immediate_switch
                
                	MDT Immediate Switch
                	**type**\:  bool
                
                .. attribute:: mdt_interface
                
                	MDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: mdt_mtu
                
                	MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_neighbor_filter_name
                
                	MDT Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: mdt_partitioned_ir_control_identifier
                
                	Partitioned IR MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_mdt_control_identifier
                
                	Partitioned MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_source
                
                	MDT source
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_source_interface
                
                	MDT Source Interface Name
                	**type**\:  str
                
                .. attribute:: mhost_default_interface_config
                
                	Configured Mhost Defint
                	**type**\:  str
                
                .. attribute:: mhost_interface
                
                	MHost handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: mldp_auto_rp_announce_tree_added
                
                	MLDP Autorp Announce Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_auto_rp_discovery_tree_added
                
                	MLDP Autorp Discovery Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_bsr_control_tree_added
                
                	MLDP BSR Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_control_head_lsm_identifier
                
                	MLDP MVPN Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_local_label
                
                	Partitioned MDT Head local label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_lsm_identifier
                
                	MLDP Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_maximum_mdt_aggregation
                
                	MLDP MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_announce_interval
                
                	MLDP Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_switchover_interval
                
                	MLDP Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_interface
                
                	MLDP MDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: mldp_mdt_mtu
                
                	MLDP MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_name
                
                	MLDP MDT Name
                	**type**\:  str
                
                .. attribute:: mldp_mdt_remote_rpf_identifier
                
                	MLDP Remote RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_rpf_identifier
                
                	MLDP RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partioned_mp2m_ptree
                
                	MP2MP Partitioned MDT tree
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_head_lsm_identifier
                
                	Partitioned MDT Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_configured
                
                	MLDP Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_mdt_identifier
                
                	MLDP Partitioned MDT Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_head_lsm_identifier
                
                	MLDP Remote Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_partitioned_mdt_configured
                
                	MLDP Remote Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_root_address
                
                	MLDP Root addresses
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_root_count
                
                	MLDP Root count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: murib_id
                
                	MURIB ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_filter_name
                
                	Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: non_default_vrf_count_on_socket
                
                	Count of non\-default vrfs on raw socket
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: organization_unique_identifier
                
                	OUI for VPN\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mpte_li_drop
                
                	Route LI updates dropped for P2MP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: physical_interface_count
                
                	Enabled Physical Interface Count
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: redistribution_reset_count
                
                	Redist reset count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_default_group
                
                	Remote Default Group
                	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.RemoteDefaultGroup>`
                
                .. attribute:: remote_table_id
                
                	Remote Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_distinguisher
                
                	RD value
                	**type**\:  str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: rpf_default_table
                
                	RPF Default Table
                	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.RpfDefaultTable>`
                
                .. attribute:: rpf_id
                
                	RPF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_policy_name
                
                	RPF topology selection route\-policy name
                	**type**\:  str
                
                .. attribute:: rsvp_te_maximum_mdt_aggregation
                
                	RSVP\-TE MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_announce_interval
                
                	RSVP\-TE Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_switchover_interval
                
                	RSVP\-TE Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_interface
                
                	RSVP\-TEMDT handle
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: rsvp_te_mdt_mtu
                
                	RSVP\-TEMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_name
                
                	RSVP\-TE MDT Name
                	**type**\:  str
                
                .. attribute:: rsvp_te_mdt_rpf_identifier
                
                	RSVP\-TE RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_static_p2mp_count
                
                	Number of Static P2MP\-TE MDT
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	PIM is using MuRIB
                	**type**\:  bool
                
                .. attribute:: sg_expiry_time
                
                	S,G Expiry Time Configured, in seconds
                	**type**\:  int
                
                	**range:** 0..65535
                
                	**units**\: second
                
                .. attribute:: sg_expiry_timer_configured
                
                	S,G Expiry Timer Configured
                	**type**\:  bool
                
                .. attribute:: sg_expiry_timer_sg_list
                
                	S,G expiry timer ACL name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: stale_rd_present
                
                	RD is stale
                	**type**\:  bool
                
                .. attribute:: suppress_pim_data_mdt_tlv
                
                	Suppress PIM Data\-MDT TLV Announcements
                	**type**\:  bool
                
                .. attribute:: suppress_shared_tree_join
                
                	Suppress Shared\-Tree Joins
                	**type**\:  bool
                
                .. attribute:: table_count
                
                	Number of configured Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_id
                
                	Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: umh
                
                	Join UMH Core\-Tree
                	**type**\:  bool
                
                .. attribute:: valid_rd_present
                
                	RD is valid
                	**type**\:  bool
                
                .. attribute:: virtual_interface_count
                
                	Enabled Virtual Interface Count
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: virtual_mlc_interface_name
                
                	Virtual master line card Interface
                	**type**\:  str
                
                .. attribute:: vpn_index
                
                	VPN Index
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf_id
                
                	VRF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Context, self).__init__()

                    self.yang_name = "context"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"remote-default-group" : ("remote_default_group", Pim.Standby.DefaultContext.Context.RemoteDefaultGroup), "rpf-default-table" : ("rpf_default_table", Pim.Standby.DefaultContext.Context.RpfDefaultTable)}
                    self._child_list_classes = {"anycast-rp-range" : ("anycast_rp_range", Pim.Standby.DefaultContext.Context.AnycastRpRange), "export-route-target" : ("export_route_target", Pim.Standby.DefaultContext.Context.ExportRouteTarget), "import-route-target" : ("import_route_target", Pim.Standby.DefaultContext.Context.ImportRouteTarget)}

                    self.active_table_count = YLeaf(YType.uint32, "active-table-count")

                    self.allow_rp_configured = YLeaf(YType.boolean, "allow-rp-configured")

                    self.allow_rp_group_list = YLeaf(YType.str, "allow-rp-group-list")

                    self.allow_rp_rp_list = YLeaf(YType.str, "allow-rp-rp-list")

                    self.anycast_rp_configured = YLeaf(YType.boolean, "anycast-rp-configured")

                    self.anycast_rp_policy_name = YLeaf(YType.str, "anycast-rp-policy-name")

                    self.bgp_auto_discovery_configured = YLeaf(YType.boolean, "bgp-auto-discovery-configured")

                    self.bgp_auto_discovery_type = YLeaf(YType.uint32, "bgp-auto-discovery-type")

                    self.bgp_i_pmsi_added = YLeaf(YType.boolean, "bgp-i-pmsi-added")

                    self.bgp_remote_address = YLeaf(YType.str, "bgp-remote-address")

                    self.bgp_remote_interface = YLeaf(YType.str, "bgp-remote-interface")

                    self.bgp_remote_interface_name = YLeaf(YType.str, "bgp-remote-interface-name")

                    self.bgp_remote_on = YLeaf(YType.boolean, "bgp-remote-on")

                    self.bgp_remote_state = YLeaf(YType.uint32, "bgp-remote-state")

                    self.bgp_source_active_announce = YLeaf(YType.boolean, "bgp-source-active-announce")

                    self.gin_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-announce-interval")

                    self.gin_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-switchover-interval")

                    self.gin_b_and_mdt_interface = YLeaf(YType.str, "gin-b-and-mdt-interface")

                    self.gin_b_and_mdt_mtu = YLeaf(YType.uint32, "gin-b-and-mdt-mtu")

                    self.gin_b_and_mdt_name = YLeaf(YType.str, "gin-b-and-mdt-name")

                    self.gin_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "gin-b-and-mdt-rpf-identifier")

                    self.gin_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "gin-band-maximum-mdt-aggregation")

                    self.in_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-announce-interval")

                    self.in_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-switchover-interval")

                    self.in_b_and_mdt_interface = YLeaf(YType.str, "in-b-and-mdt-interface")

                    self.in_b_and_mdt_mtu = YLeaf(YType.uint32, "in-b-and-mdt-mtu")

                    self.in_b_and_mdt_name = YLeaf(YType.str, "in-b-and-mdt-name")

                    self.in_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "in-b-and-mdt-rpf-identifier")

                    self.in_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "in-band-maximum-mdt-aggregation")

                    self.in_band_signaling_local_enabled = YLeaf(YType.boolean, "in-band-signaling-local-enabled")

                    self.in_band_signaling_remote_enabled = YLeaf(YType.boolean, "in-band-signaling-remote-enabled")

                    self.inter_autonomous_system_enabled = YLeaf(YType.boolean, "inter-autonomous-system-enabled")

                    self.ir_maximum_mdt_aggregation = YLeaf(YType.uint32, "ir-maximum-mdt-aggregation")

                    self.ir_mdt_data_announce_interval = YLeaf(YType.uint32, "ir-mdt-data-announce-interval")

                    self.ir_mdt_data_switchover_interval = YLeaf(YType.uint32, "ir-mdt-data-switchover-interval")

                    self.ir_mdt_interface = YLeaf(YType.str, "ir-mdt-interface")

                    self.ir_mdt_mtu = YLeaf(YType.uint32, "ir-mdt-mtu")

                    self.ir_mdt_name = YLeaf(YType.str, "ir-mdt-name")

                    self.ir_mdt_rpf_identifier = YLeaf(YType.uint32, "ir-mdt-rpf-identifier")

                    self.ir_mdt_tail_label = YLeaf(YType.uint32, "ir-mdt-tail-label")

                    self.is_active = YLeaf(YType.boolean, "is-active")

                    self.is_active_ital = YLeaf(YType.boolean, "is-active-ital")

                    self.is_all_interface_disable_operation = YLeaf(YType.boolean, "is-all-interface-disable-operation")

                    self.is_auto_rp_listen_enabled = YLeaf(YType.boolean, "is-auto-rp-listen-enabled")

                    self.is_auto_rp_listen_sock_add = YLeaf(YType.boolean, "is-auto-rp-listen-sock-add")

                    self.is_create_gin_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-gin-b-and-mdt-interface")

                    self.is_create_in_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-in-b-and-mdt-interface")

                    self.is_create_ir_mdt_interface = YLeaf(YType.boolean, "is-create-ir-mdt-interface")

                    self.is_create_mdt_interface = YLeaf(YType.boolean, "is-create-mdt-interface")

                    self.is_create_mldp_mdt_interface = YLeaf(YType.boolean, "is-create-mldp-mdt-interface")

                    self.is_create_rsvp_te_mdt_interface = YLeaf(YType.boolean, "is-create-rsvp-te-mdt-interface")

                    self.is_default_granges = YLeaf(YType.boolean, "is-default-granges")

                    self.is_gin_b_and_mdt_owner = YLeaf(YType.boolean, "is-gin-b-and-mdt-owner")

                    self.is_in_b_and_mdt_owner = YLeaf(YType.boolean, "is-in-b-and-mdt-owner")

                    self.is_ir_mdt_owner = YLeaf(YType.boolean, "is-ir-mdt-owner")

                    self.is_lpts_socket_add_required = YLeaf(YType.boolean, "is-lpts-socket-add-required")

                    self.is_lpts_socket_added = YLeaf(YType.boolean, "is-lpts-socket-added")

                    self.is_m_host_publish_pending = YLeaf(YType.boolean, "is-m-host-publish-pending")

                    self.is_mdt_owner = YLeaf(YType.boolean, "is-mdt-owner")

                    self.is_mldp_mdt_owner = YLeaf(YType.boolean, "is-mldp-mdt-owner")

                    self.is_mrib_register = YLeaf(YType.boolean, "is-mrib-register")

                    self.is_multicast_rib_registration = YLeaf(YType.boolean, "is-multicast-rib-registration")

                    self.is_pim_nsf_rib_converge_received = YLeaf(YType.boolean, "is-pim-nsf-rib-converge-received")

                    self.is_pim_nsf_rib_converged = YLeaf(YType.boolean, "is-pim-nsf-rib-converged")

                    self.is_redistribution_reset = YLeaf(YType.boolean, "is-redistribution-reset")

                    self.is_register_injection_lpts_socket_add_required = YLeaf(YType.boolean, "is-register-injection-lpts-socket-add-required")

                    self.is_register_injection_lpts_socket_added = YLeaf(YType.boolean, "is-register-injection-lpts-socket-added")

                    self.is_register_injection_socket_add_required = YLeaf(YType.boolean, "is-register-injection-socket-add-required")

                    self.is_register_injection_socket_added = YLeaf(YType.boolean, "is-register-injection-socket-added")

                    self.is_rib_multipath_enabled = YLeaf(YType.boolean, "is-rib-multipath-enabled")

                    self.is_rib_multipath_interface_hash = YLeaf(YType.boolean, "is-rib-multipath-interface-hash")

                    self.is_rib_multipath_source_hash = YLeaf(YType.boolean, "is-rib-multipath-source-hash")

                    self.is_rib_multipath_source_next_hop_hash = YLeaf(YType.boolean, "is-rib-multipath-source-next-hop-hash")

                    self.is_routing_enabled = YLeaf(YType.boolean, "is-routing-enabled")

                    self.is_rsvp_te_mdt_owner = YLeaf(YType.boolean, "is-rsvp-te-mdt-owner")

                    self.is_socket_add_required = YLeaf(YType.boolean, "is-socket-add-required")

                    self.is_socket_added = YLeaf(YType.boolean, "is-socket-added")

                    self.is_udp_socket_add_required = YLeaf(YType.boolean, "is-udp-socket-add-required")

                    self.is_udp_socket_added = YLeaf(YType.boolean, "is-udp-socket-added")

                    self.is_udp_socket_bind = YLeaf(YType.boolean, "is-udp-socket-bind")

                    self.is_udp_socket_bind_required = YLeaf(YType.boolean, "is-udp-socket-bind-required")

                    self.is_unicast_rib_registration = YLeaf(YType.boolean, "is-unicast-rib-registration")

                    self.maximum_mdt_aggregation = YLeaf(YType.uint32, "maximum-mdt-aggregation")

                    self.mdt_data_announce_interval = YLeaf(YType.uint32, "mdt-data-announce-interval")

                    self.mdt_data_switchover_interval = YLeaf(YType.uint32, "mdt-data-switchover-interval")

                    self.mdt_default_group = YLeaf(YType.str, "mdt-default-group")

                    self.mdt_gre_remote_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-remote-rpf-identifier")

                    self.mdt_gre_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-rpf-identifier")

                    self.mdt_immediate_switch = YLeaf(YType.boolean, "mdt-immediate-switch")

                    self.mdt_interface = YLeaf(YType.str, "mdt-interface")

                    self.mdt_mtu = YLeaf(YType.uint32, "mdt-mtu")

                    self.mdt_neighbor_filter_name = YLeaf(YType.str, "mdt-neighbor-filter-name")

                    self.mdt_partitioned_ir_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-ir-control-identifier")

                    self.mdt_partitioned_mdt_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-mdt-control-identifier")

                    self.mdt_source = YLeaf(YType.str, "mdt-source")

                    self.mdt_source_interface = YLeaf(YType.str, "mdt-source-interface")

                    self.mhost_default_interface_config = YLeaf(YType.str, "mhost-default-interface-config")

                    self.mhost_interface = YLeaf(YType.str, "mhost-interface")

                    self.mldp_auto_rp_announce_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-announce-tree-added")

                    self.mldp_auto_rp_discovery_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-discovery-tree-added")

                    self.mldp_bsr_control_tree_added = YLeaf(YType.boolean, "mldp-bsr-control-tree-added")

                    self.mldp_control_head_lsm_identifier = YLeaf(YType.uint32, "mldp-control-head-lsm-identifier")

                    self.mldp_head_local_label = YLeaf(YType.uint32, "mldp-head-local-label")

                    self.mldp_head_lsm_identifier = YLeaf(YType.uint32, "mldp-head-lsm-identifier")

                    self.mldp_maximum_mdt_aggregation = YLeaf(YType.uint32, "mldp-maximum-mdt-aggregation")

                    self.mldp_mdt_data_announce_interval = YLeaf(YType.uint32, "mldp-mdt-data-announce-interval")

                    self.mldp_mdt_data_switchover_interval = YLeaf(YType.uint32, "mldp-mdt-data-switchover-interval")

                    self.mldp_mdt_interface = YLeaf(YType.str, "mldp-mdt-interface")

                    self.mldp_mdt_mtu = YLeaf(YType.uint32, "mldp-mdt-mtu")

                    self.mldp_mdt_name = YLeaf(YType.str, "mldp-mdt-name")

                    self.mldp_mdt_remote_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-remote-rpf-identifier")

                    self.mldp_mdt_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-rpf-identifier")

                    self.mldp_partioned_mp2m_ptree = YLeaf(YType.boolean, "mldp-partioned-mp2m-ptree")

                    self.mldp_partitioned_head_lsm_identifier = YLeaf(YType.uint32, "mldp-partitioned-head-lsm-identifier")

                    self.mldp_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-partitioned-mdt-configured")

                    self.mldp_partitioned_mdt_identifier = YLeaf(YType.uint32, "mldp-partitioned-mdt-identifier")

                    self.mldp_remote_head_lsm_identifier = YLeaf(YType.uint32, "mldp-remote-head-lsm-identifier")

                    self.mldp_remote_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-remote-partitioned-mdt-configured")

                    self.mldp_root_address = YLeafList(YType.uint32, "mldp-root-address")

                    self.mldp_root_count = YLeaf(YType.uint32, "mldp-root-count")

                    self.murib_id = YLeaf(YType.uint32, "murib-id")

                    self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                    self.non_default_vrf_count_on_socket = YLeaf(YType.uint32, "non-default-vrf-count-on-socket")

                    self.organization_unique_identifier = YLeaf(YType.uint32, "organization-unique-identifier")

                    self.p2mpte_li_drop = YLeaf(YType.uint32, "p2mpte-li-drop")

                    self.physical_interface_count = YLeaf(YType.uint64, "physical-interface-count")

                    self.redistribution_reset_count = YLeaf(YType.uint32, "redistribution-reset-count")

                    self.remote_table_id = YLeaf(YType.uint32, "remote-table-id")

                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                    self.rpf_id = YLeaf(YType.uint32, "rpf-id")

                    self.rpf_policy_name = YLeaf(YType.str, "rpf-policy-name")

                    self.rsvp_te_maximum_mdt_aggregation = YLeaf(YType.uint32, "rsvp-te-maximum-mdt-aggregation")

                    self.rsvp_te_mdt_data_announce_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-announce-interval")

                    self.rsvp_te_mdt_data_switchover_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-switchover-interval")

                    self.rsvp_te_mdt_interface = YLeaf(YType.str, "rsvp-te-mdt-interface")

                    self.rsvp_te_mdt_mtu = YLeaf(YType.uint32, "rsvp-te-mdt-mtu")

                    self.rsvp_te_mdt_name = YLeaf(YType.str, "rsvp-te-mdt-name")

                    self.rsvp_te_mdt_rpf_identifier = YLeaf(YType.uint32, "rsvp-te-mdt-rpf-identifier")

                    self.rsvp_te_mdt_static_p2mp_count = YLeaf(YType.uint32, "rsvp-te-mdt-static-p2mp-count")

                    self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                    self.sg_expiry_time = YLeaf(YType.uint16, "sg-expiry-time")

                    self.sg_expiry_timer_configured = YLeaf(YType.boolean, "sg-expiry-timer-configured")

                    self.sg_expiry_timer_sg_list = YLeaf(YType.str, "sg-expiry-timer-sg-list")

                    self.stale_rd_present = YLeaf(YType.boolean, "stale-rd-present")

                    self.suppress_pim_data_mdt_tlv = YLeaf(YType.boolean, "suppress-pim-data-mdt-tlv")

                    self.suppress_shared_tree_join = YLeaf(YType.boolean, "suppress-shared-tree-join")

                    self.table_count = YLeaf(YType.uint32, "table-count")

                    self.table_id = YLeaf(YType.uint32, "table-id")

                    self.umh = YLeaf(YType.boolean, "umh")

                    self.valid_rd_present = YLeaf(YType.boolean, "valid-rd-present")

                    self.virtual_interface_count = YLeaf(YType.uint64, "virtual-interface-count")

                    self.virtual_mlc_interface_name = YLeaf(YType.str, "virtual-mlc-interface-name")

                    self.vpn_index = YLeaf(YType.uint32, "vpn-index")

                    self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                    self.remote_default_group = Pim.Standby.DefaultContext.Context.RemoteDefaultGroup()
                    self.remote_default_group.parent = self
                    self._children_name_map["remote_default_group"] = "remote-default-group"
                    self._children_yang_names.add("remote-default-group")

                    self.rpf_default_table = Pim.Standby.DefaultContext.Context.RpfDefaultTable()
                    self.rpf_default_table.parent = self
                    self._children_name_map["rpf_default_table"] = "rpf-default-table"
                    self._children_yang_names.add("rpf-default-table")

                    self.anycast_rp_range = YList(self)
                    self.export_route_target = YList(self)
                    self.import_route_target = YList(self)
                    self._segment_path = lambda: "context"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.Context, ['active_table_count', 'allow_rp_configured', 'allow_rp_group_list', 'allow_rp_rp_list', 'anycast_rp_configured', 'anycast_rp_policy_name', 'bgp_auto_discovery_configured', 'bgp_auto_discovery_type', 'bgp_i_pmsi_added', 'bgp_remote_address', 'bgp_remote_interface', 'bgp_remote_interface_name', 'bgp_remote_on', 'bgp_remote_state', 'bgp_source_active_announce', 'gin_b_and_mdt_data_announce_interval', 'gin_b_and_mdt_data_switchover_interval', 'gin_b_and_mdt_interface', 'gin_b_and_mdt_mtu', 'gin_b_and_mdt_name', 'gin_b_and_mdt_rpf_identifier', 'gin_band_maximum_mdt_aggregation', 'in_b_and_mdt_data_announce_interval', 'in_b_and_mdt_data_switchover_interval', 'in_b_and_mdt_interface', 'in_b_and_mdt_mtu', 'in_b_and_mdt_name', 'in_b_and_mdt_rpf_identifier', 'in_band_maximum_mdt_aggregation', 'in_band_signaling_local_enabled', 'in_band_signaling_remote_enabled', 'inter_autonomous_system_enabled', 'ir_maximum_mdt_aggregation', 'ir_mdt_data_announce_interval', 'ir_mdt_data_switchover_interval', 'ir_mdt_interface', 'ir_mdt_mtu', 'ir_mdt_name', 'ir_mdt_rpf_identifier', 'ir_mdt_tail_label', 'is_active', 'is_active_ital', 'is_all_interface_disable_operation', 'is_auto_rp_listen_enabled', 'is_auto_rp_listen_sock_add', 'is_create_gin_b_and_mdt_interface', 'is_create_in_b_and_mdt_interface', 'is_create_ir_mdt_interface', 'is_create_mdt_interface', 'is_create_mldp_mdt_interface', 'is_create_rsvp_te_mdt_interface', 'is_default_granges', 'is_gin_b_and_mdt_owner', 'is_in_b_and_mdt_owner', 'is_ir_mdt_owner', 'is_lpts_socket_add_required', 'is_lpts_socket_added', 'is_m_host_publish_pending', 'is_mdt_owner', 'is_mldp_mdt_owner', 'is_mrib_register', 'is_multicast_rib_registration', 'is_pim_nsf_rib_converge_received', 'is_pim_nsf_rib_converged', 'is_redistribution_reset', 'is_register_injection_lpts_socket_add_required', 'is_register_injection_lpts_socket_added', 'is_register_injection_socket_add_required', 'is_register_injection_socket_added', 'is_rib_multipath_enabled', 'is_rib_multipath_interface_hash', 'is_rib_multipath_source_hash', 'is_rib_multipath_source_next_hop_hash', 'is_routing_enabled', 'is_rsvp_te_mdt_owner', 'is_socket_add_required', 'is_socket_added', 'is_udp_socket_add_required', 'is_udp_socket_added', 'is_udp_socket_bind', 'is_udp_socket_bind_required', 'is_unicast_rib_registration', 'maximum_mdt_aggregation', 'mdt_data_announce_interval', 'mdt_data_switchover_interval', 'mdt_default_group', 'mdt_gre_remote_rpf_identifier', 'mdt_gre_rpf_identifier', 'mdt_immediate_switch', 'mdt_interface', 'mdt_mtu', 'mdt_neighbor_filter_name', 'mdt_partitioned_ir_control_identifier', 'mdt_partitioned_mdt_control_identifier', 'mdt_source', 'mdt_source_interface', 'mhost_default_interface_config', 'mhost_interface', 'mldp_auto_rp_announce_tree_added', 'mldp_auto_rp_discovery_tree_added', 'mldp_bsr_control_tree_added', 'mldp_control_head_lsm_identifier', 'mldp_head_local_label', 'mldp_head_lsm_identifier', 'mldp_maximum_mdt_aggregation', 'mldp_mdt_data_announce_interval', 'mldp_mdt_data_switchover_interval', 'mldp_mdt_interface', 'mldp_mdt_mtu', 'mldp_mdt_name', 'mldp_mdt_remote_rpf_identifier', 'mldp_mdt_rpf_identifier', 'mldp_partioned_mp2m_ptree', 'mldp_partitioned_head_lsm_identifier', 'mldp_partitioned_mdt_configured', 'mldp_partitioned_mdt_identifier', 'mldp_remote_head_lsm_identifier', 'mldp_remote_partitioned_mdt_configured', 'mldp_root_address', 'mldp_root_count', 'murib_id', 'neighbor_filter_name', 'non_default_vrf_count_on_socket', 'organization_unique_identifier', 'p2mpte_li_drop', 'physical_interface_count', 'redistribution_reset_count', 'remote_table_id', 'route_distinguisher', 'rpf_id', 'rpf_policy_name', 'rsvp_te_maximum_mdt_aggregation', 'rsvp_te_mdt_data_announce_interval', 'rsvp_te_mdt_data_switchover_interval', 'rsvp_te_mdt_interface', 'rsvp_te_mdt_mtu', 'rsvp_te_mdt_name', 'rsvp_te_mdt_rpf_identifier', 'rsvp_te_mdt_static_p2mp_count', 'rump_enabled', 'sg_expiry_time', 'sg_expiry_timer_configured', 'sg_expiry_timer_sg_list', 'stale_rd_present', 'suppress_pim_data_mdt_tlv', 'suppress_shared_tree_join', 'table_count', 'table_id', 'umh', 'valid_rd_present', 'virtual_interface_count', 'virtual_mlc_interface_name', 'vpn_index', 'vrf_id'], name, value)


                class AnycastRpRange(Entity):
                    """
                    Anycast\-RP Ranges
                    
                    .. attribute:: ancast_rp_marked
                    
                    	Anycast\-RP Range marked
                    	**type**\:  bool
                    
                    .. attribute:: prefix
                    
                    	Anycast\-RP Range Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Anycast\-RP Range Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Context.AnycastRpRange, self).__init__()

                        self.yang_name = "anycast-rp-range"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"prefix" : ("prefix", Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix)}
                        self._child_list_classes = {}

                        self.ancast_rp_marked = YLeaf(YType.boolean, "ancast-rp-marked")

                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                        self.prefix = Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._children_yang_names.add("prefix")
                        self._segment_path = lambda: "anycast-rp-range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Context.AnycastRpRange, ['ancast_rp_marked', 'prefix_length'], name, value)


                    class Prefix(Entity):
                        """
                        Anycast\-RP Range Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "anycast-rp-range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "prefix"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/context/anycast-rp-range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class ExportRouteTarget(Entity):
                    """
                    Export Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Context.ExportRouteTarget, self).__init__()

                        self.yang_name = "export-route-target"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                        self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                        self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                        self.configured = YLeaf(YType.boolean, "configured")

                        self.route_target = YLeaf(YType.str, "route-target")

                        self.segment_border = YLeaf(YType.boolean, "segment-border")

                        self.update_pending = YLeaf(YType.boolean, "update-pending")
                        self._segment_path = lambda: "export-route-target"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Context.ExportRouteTarget, ['anycast_rp', 'anycast_rp_marked', 'bgp_auto_discovery', 'configured', 'route_target', 'segment_border', 'update_pending'], name, value)


                class ImportRouteTarget(Entity):
                    """
                    Import Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Context.ImportRouteTarget, self).__init__()

                        self.yang_name = "import-route-target"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                        self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                        self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                        self.configured = YLeaf(YType.boolean, "configured")

                        self.route_target = YLeaf(YType.str, "route-target")

                        self.segment_border = YLeaf(YType.boolean, "segment-border")

                        self.update_pending = YLeaf(YType.boolean, "update-pending")
                        self._segment_path = lambda: "import-route-target"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Context.ImportRouteTarget, ['anycast_rp', 'anycast_rp_marked', 'bgp_auto_discovery', 'configured', 'route_target', 'segment_border', 'update_pending'], name, value)


                class RemoteDefaultGroup(Entity):
                    """
                    Remote Default Group
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Context.RemoteDefaultGroup, self).__init__()

                        self.yang_name = "remote-default-group"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.af_name = YLeaf(YType.enumeration, "af-name")

                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                        self._segment_path = lambda: "remote-default-group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Context.RemoteDefaultGroup, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class RpfDefaultTable(Entity):
                    """
                    RPF Default Table
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Context.RpfDefaultTable, self).__init__()

                        self.yang_name = "rpf-default-table"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.uint32, "afi")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                        self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.safi = YLeaf(YType.uint32, "safi")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.table_name = YLeaf(YType.str, "table-name")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")
                        self._segment_path = lambda: "rpf-default-table"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/context/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Context.RpfDefaultTable, ['afi', 'is_active', 'is_ital_registration_done', 'is_rib_convergence', 'is_rib_convergence_received', 'is_rib_registration_done', 'rpf_registrations', 'safi', 'table_id', 'table_name', 'vrf_id'], name, value)


            class GlobalInterfaces(Entity):
                """
                PIM global interface table
                
                .. attribute:: global_interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`GlobalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.GlobalInterfaces, self).__init__()

                    self.yang_name = "global-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"global-interface" : ("global_interface", Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface)}

                    self.global_interface = YList(self)
                    self._segment_path = lambda: "global-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.GlobalInterfaces, [], name, value)


                class GlobalInterface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface, self).__init__()

                        self.yang_name = "global-interface"
                        self.yang_parent_name = "global-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"dr-address" : ("dr_address", Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress)}
                        self._child_list_classes = {"interface-address" : ("interface_address", Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "global-interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/global-interfaces/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "global-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "dr-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "global-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "interface-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Gre(Entity):
                """
                GRE information
                
                .. attribute:: gre_hashes
                
                	GRE hash
                	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreHashes>`
                
                .. attribute:: gre_next_hops
                
                	GRE destination neighbor table
                	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Gre, self).__init__()

                    self.yang_name = "gre"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"gre-hashes" : ("gre_hashes", Pim.Standby.DefaultContext.Gre.GreHashes), "gre-next-hops" : ("gre_next_hops", Pim.Standby.DefaultContext.Gre.GreNextHops)}
                    self._child_list_classes = {}

                    self.gre_hashes = Pim.Standby.DefaultContext.Gre.GreHashes()
                    self.gre_hashes.parent = self
                    self._children_name_map["gre_hashes"] = "gre-hashes"
                    self._children_yang_names.add("gre-hashes")

                    self.gre_next_hops = Pim.Standby.DefaultContext.Gre.GreNextHops()
                    self.gre_next_hops.parent = self
                    self._children_name_map["gre_next_hops"] = "gre-next-hops"
                    self._children_yang_names.add("gre-next-hops")
                    self._segment_path = lambda: "gre"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()


                class GreHashes(Entity):
                    """
                    GRE hash
                    
                    .. attribute:: gre_hash
                    
                    	PIM GRE Hashed Underlying Interface
                    	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreHashes.GreHash>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Gre.GreHashes, self).__init__()

                        self.yang_name = "gre-hashes"
                        self.yang_parent_name = "gre"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"gre-hash" : ("gre_hash", Pim.Standby.DefaultContext.Gre.GreHashes.GreHash)}

                        self.gre_hash = YList(self)
                        self._segment_path = lambda: "gre-hashes"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/gre/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Gre.GreHashes, [], name, value)


                    class GreHash(Entity):
                        """
                        PIM GRE Hashed Underlying Interface
                        
                        .. attribute:: source_address  <key>
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: destination_address  <key>
                        
                        	Destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: ifname  <key>
                        
                        	GRE Tunnel Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: next_hop_interface
                        
                        	Next hop neighbor interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Gre.GreHashes.GreHash, self).__init__()

                            self.yang_name = "gre-hash"
                            self.yang_parent_name = "gre-hashes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.ifname = YLeaf(YType.str, "ifname")

                            self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")
                            self._segment_path = lambda: "gre-hash" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[ifname='" + self.ifname.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/gre/gre-hashes/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Gre.GreHashes.GreHash, ['source_address', 'destination_address', 'ifname', 'next_hop_interface'], name, value)


                class GreNextHops(Entity):
                    """
                    GRE destination neighbor table
                    
                    .. attribute:: gre_next_hop
                    
                    	PIM GRE address next\-hop information
                    	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Gre.GreNextHops, self).__init__()

                        self.yang_name = "gre-next-hops"
                        self.yang_parent_name = "gre"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"gre-next-hop" : ("gre_next_hop", Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop)}

                        self.gre_next_hop = YList(self)
                        self._segment_path = lambda: "gre-next-hops"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/gre/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Gre.GreNextHops, [], name, value)


                    class GreNextHop(Entity):
                        """
                        PIM GRE address next\-hop information
                        
                        .. attribute:: destination_address  <key>
                        
                        	GRE destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: gre_path
                        
                        	GRE Paths list
                        	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath>`
                        
                        .. attribute:: is_connected
                        
                        	Are we connected ?
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: registered_address
                        
                        	Address registered
                        	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop, self).__init__()

                            self.yang_name = "gre-next-hop"
                            self.yang_parent_name = "gre-next-hops"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"registered-address" : ("registered_address", Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress)}
                            self._child_list_classes = {"gre-path" : ("gre_path", Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath)}

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.is_connected = YLeaf(YType.uint8, "is-connected")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                            self.registered_address = Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                            self.registered_address.parent = self
                            self._children_name_map["registered_address"] = "registered-address"
                            self._children_yang_names.add("registered-address")

                            self.gre_path = YList(self)
                            self._segment_path = lambda: "gre-next-hop" + "[destination-address='" + self.destination_address.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/gre/gre-next-hops/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop, ['destination_address', 'is_connected', 'metric', 'metric_preference'], name, value)


                        class GrePath(Entity):
                            """
                            GRE Paths list
                            
                            .. attribute:: extranet_vrf_name
                            
                            	Extranet VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: gre_interface_name
                            
                            	GRE Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: gre_neighbor
                            
                            	GRE neighbor
                            	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                            
                            .. attribute:: gre_next_hop
                            
                            	GRE nexthop
                            	**type**\:   :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop>`
                            
                            .. attribute:: is_connector_attribute_present
                            
                            	Connector attribute present
                            	**type**\:  bool
                            
                            .. attribute:: is_gre_interface_disabled
                            
                            	Is the gre interface disabled ?
                            	**type**\:  bool
                            
                            .. attribute:: is_via_lsm
                            
                            	Via LSM
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                self.yang_name = "gre-path"
                                self.yang_parent_name = "gre-next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"gre-neighbor" : ("gre_neighbor", Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor), "gre-next-hop" : ("gre_next_hop", Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop)}
                                self._child_list_classes = {}

                                self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                self.gre_interface_name = YLeaf(YType.str, "gre-interface-name")

                                self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                self.is_gre_interface_disabled = YLeaf(YType.boolean, "is-gre-interface-disabled")

                                self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                self.gre_neighbor = Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                self.gre_neighbor.parent = self
                                self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                self._children_yang_names.add("gre-neighbor")

                                self.gre_next_hop = Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                self.gre_next_hop.parent = self
                                self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                self._children_yang_names.add("gre-next-hop")
                                self._segment_path = lambda: "gre-path"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, ['extranet_vrf_name', 'gre_interface_name', 'is_connector_attribute_present', 'is_gre_interface_disabled', 'is_via_lsm'], name, value)


                            class GreNeighbor(Entity):
                                """
                                GRE neighbor
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                    self.yang_name = "gre-neighbor"
                                    self.yang_parent_name = "gre-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "gre-neighbor"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class GreNextHop(Entity):
                                """
                                GRE nexthop
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__init__()

                                    self.yang_name = "gre-next-hop"
                                    self.yang_parent_name = "gre-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "gre-next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RegisteredAddress(Entity):
                            """
                            Address registered
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                self.yang_name = "registered-address"
                                self.yang_parent_name = "gre-next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "registered-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class GroupMapRpfs(Entity):
                """
                PIM group mapping information
                
                .. attribute:: group_map_rpf
                
                	PIM group mapping entry
                	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.GroupMapRpfs, self).__init__()

                    self.yang_name = "group-map-rpfs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"group-map-rpf" : ("group_map_rpf", Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf)}

                    self.group_map_rpf = YList(self)
                    self._segment_path = lambda: "group-map-rpfs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.GroupMapRpfs, [], name, value)


                class GroupMapRpf(Entity):
                    """
                    PIM group mapping entry
                    
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_priority
                    
                    	RP priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__init__()

                        self.yang_name = "group-map-rpf"
                        self.yang_parent_name = "group-map-rpfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-map-information" : ("group_map_information", Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation), "rpf-neighbor" : ("rpf_neighbor", Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor)}
                        self._child_list_classes = {}

                        self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                        self.client = YLeaf(YType.enumeration, "client")

                        self.prefix = YLeaf(YType.str, "prefix")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_priority = YLeaf(YType.int32, "rp-priority")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.group_map_information = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.rpf_neighbor = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")
                        self._segment_path = lambda: "group-map-rpf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-rpfs/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf, ['are_we_rp', 'client', 'prefix', 'prefix_length', 'protocol', 'rp_address', 'rp_priority', 'rpf_interface_name', 'rpf_vrf_name'], name, value)


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-rpf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"prefix" : ("prefix", Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix), "rp-address" : ("rp_address", Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress)}
                            self._child_list_classes = {}

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")
                            self._segment_path = lambda: "group-map-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-rpfs/group-map-rpf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, ['client', 'group_count', 'is_override', 'is_used', 'mrib_active', 'prefix_length', 'priority', 'protocol'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "group-map-rpf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-rpfs/group-map-rpf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class GroupMapSources(Entity):
                """
                PIM group\-mapping with source information
                
                .. attribute:: group_map_source
                
                	PIM Group Mapping Entry with source information
                	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.GroupMapSources, self).__init__()

                    self.yang_name = "group-map-sources"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"group-map-source" : ("group_map_source", Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource)}

                    self.group_map_source = YList(self)
                    self._segment_path = lambda: "group-map-sources"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.GroupMapSources, [], name, value)


                class GroupMapSource(Entity):
                    """
                    PIM Group Mapping Entry with source information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: priority
                    
                    	RP Priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource, self).__init__()

                        self.yang_name = "group-map-source"
                        self.yang_parent_name = "group-map-sources"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-map-information" : ("group_map_information", Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation), "source-of-information" : ("source_of_information", Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation)}
                        self._child_list_classes = {}

                        self.client = YLeaf(YType.enumeration, "client")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.holdtime = YLeaf(YType.int32, "holdtime")

                        self.prefix = YLeaf(YType.str, "prefix")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.priority = YLeaf(YType.int32, "priority")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_map_information = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.source_of_information = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")
                        self._segment_path = lambda: "group-map-source"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-sources/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource, ['client', 'expires', 'holdtime', 'prefix', 'prefix_length', 'priority', 'protocol', 'rp_address', 'uptime'], name, value)


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"prefix" : ("prefix", Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix), "rp-address" : ("rp_address", Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress)}
                            self._child_list_classes = {}

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")
                            self._segment_path = lambda: "group-map-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-sources/group-map-source/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, ['client', 'group_count', 'is_override', 'is_used', 'mrib_active', 'prefix_length', 'priority', 'protocol'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-sources/group-map-source/group-map-information/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-sources/group-map-source/group-map-information/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceOfInformation(Entity):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "group-map-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-of-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-sources/group-map-source/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class IfrsInterfaces(Entity):
                """
                PIM interfaces in forward reference store table
                
                .. attribute:: ifrs_interface
                
                	PIM IFRS interface information
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"ifrs-interface" : ("ifrs_interface", Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface)}

                    self.ifrs_interface = YList(self)
                    self._segment_path = lambda: "ifrs-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.IfrsInterfaces, [], name, value)


                class IfrsInterface(Entity):
                    """
                    PIM IFRS interface information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"dr-address" : ("dr_address", Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress)}
                        self._child_list_classes = {"interface-address" : ("interface_address", Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ifrs-interfaces/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "dr-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "interface-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class IfrsSummary(Entity):
                """
                PIM interfaces in forward reference store
                summary
                
                .. attribute:: configuration_count
                
                	Configuration counts
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Number of interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.IfrsSummary, self).__init__()

                    self.yang_name = "ifrs-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                    self.interface_count = YLeaf(YType.uint32, "interface-count")
                    self._segment_path = lambda: "ifrs-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.IfrsSummary, ['configuration_count', 'interface_count'], name, value)


            class InterfaceOldFormats(Entity):
                """
                PIM interfaces in old format
                
                .. attribute:: interface_old_format
                
                	PIM interface name
                	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.InterfaceOldFormats, self).__init__()

                    self.yang_name = "interface-old-formats"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-old-format" : ("interface_old_format", Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat)}

                    self.interface_old_format = YList(self)
                    self._segment_path = lambda: "interface-old-formats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.InterfaceOldFormats, [], name, value)


                class InterfaceOldFormat(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                        self.yang_name = "interface-old-format"
                        self.yang_parent_name = "interface-old-formats"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"dr-address" : ("dr_address", Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress)}
                        self._child_list_classes = {"interface-address" : ("interface_address", Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "interface-old-format" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/interface-old-formats/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "dr-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "interface-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceStatistics(Entity):
                """
                PIM interface statistics
                
                .. attribute:: interface_statistic
                
                	PIM interface statistics
                	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.InterfaceStatistics, self).__init__()

                    self.yang_name = "interface-statistics"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-statistic" : ("interface_statistic", Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic)}

                    self.interface_statistic = YList(self)
                    self._segment_path = lambda: "interface-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.InterfaceStatistics, [], name, value)


                class InterfaceStatistic(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_ack_message
                    
                    	Input Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_message
                    
                    	Input Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_miscellaneous
                    
                    	Miscellaneous packet in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register
                    
                    	Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_ack_message
                    
                    	Output Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_message
                    
                    	Output Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register
                    
                    	Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__init__()

                        self.yang_name = "interface-statistic"
                        self.yang_parent_name = "interface-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.input_assert = YLeaf(YType.uint32, "input-assert")

                        self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                        self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                        self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                        self.input_graft_ack_message = YLeaf(YType.uint32, "input-graft-ack-message")

                        self.input_graft_message = YLeaf(YType.uint32, "input-graft-message")

                        self.input_hello = YLeaf(YType.uint32, "input-hello")

                        self.input_jp = YLeaf(YType.uint32, "input-jp")

                        self.input_miscellaneous = YLeaf(YType.uint32, "input-miscellaneous")

                        self.input_register = YLeaf(YType.uint32, "input-register")

                        self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                        self.output_assert = YLeaf(YType.uint32, "output-assert")

                        self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                        self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                        self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                        self.output_graft_ack_message = YLeaf(YType.uint32, "output-graft-ack-message")

                        self.output_graft_message = YLeaf(YType.uint32, "output-graft-message")

                        self.output_hello = YLeaf(YType.uint32, "output-hello")

                        self.output_jp = YLeaf(YType.uint32, "output-jp")

                        self.output_register = YLeaf(YType.uint32, "output-register")

                        self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")
                        self._segment_path = lambda: "interface-statistic" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/interface-statistics/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic, ['interface_name', 'input_assert', 'input_bsr_message', 'input_candidate_rp_advertisement', 'input_df_election', 'input_graft_ack_message', 'input_graft_message', 'input_hello', 'input_jp', 'input_miscellaneous', 'input_register', 'input_register_stop', 'output_assert', 'output_bsr_message', 'output_candidate_rp_advertisement', 'output_df_election', 'output_graft_ack_message', 'output_graft_message', 'output_hello', 'output_jp', 'output_register', 'output_register_stop'], name, value)


            class Interfaces(Entity):
                """
                PIM interfaces
                
                .. attribute:: interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Interfaces.Interface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface" : ("interface", Pim.Standby.DefaultContext.Interfaces.Interface)}

                    self.interface = YList(self)
                    self._segment_path = lambda: "interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.Interfaces, [], name, value)


                class Interface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Interfaces.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"dr-address" : ("dr_address", Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress)}
                        self._child_list_classes = {"interface-address" : ("interface_address", Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/interfaces/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Interfaces.Interface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "dr-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "interface-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class JpStatistics(Entity):
                """
                PIM join prune statistics table
                
                .. attribute:: jp_statistic
                
                	PIM Join Prune Statistics
                	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.JpStatistics.JpStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.JpStatistics, self).__init__()

                    self.yang_name = "jp-statistics"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"jp-statistic" : ("jp_statistic", Pim.Standby.DefaultContext.JpStatistics.JpStatistic)}

                    self.jp_statistic = YList(self)
                    self._segment_path = lambda: "jp-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.JpStatistics, [], name, value)


                class JpStatistic(Entity):
                    """
                    PIM Join Prune Statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mtu
                    
                    	Interface MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received
                    
                    	Received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received100
                    
                    	Received 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_10k
                    
                    	Received 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_1k
                    
                    	Received 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_50k
                    
                    	Deprecated by Received100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted
                    
                    	Transmitted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted100
                    
                    	Transmitted 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_10k
                    
                    	Transmitted 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_1k
                    
                    	Transmitted 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_50k
                    
                    	Deprecated by Transmitted100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.JpStatistics.JpStatistic, self).__init__()

                        self.yang_name = "jp-statistic"
                        self.yang_parent_name = "jp-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.received = YLeaf(YType.uint32, "received")

                        self.received100 = YLeaf(YType.uint16, "received100")

                        self.received_10k = YLeaf(YType.uint16, "received-10k")

                        self.received_1k = YLeaf(YType.uint16, "received-1k")

                        self.received_50k = YLeaf(YType.uint16, "received-50k")

                        self.transmitted = YLeaf(YType.uint32, "transmitted")

                        self.transmitted100 = YLeaf(YType.uint16, "transmitted100")

                        self.transmitted_10k = YLeaf(YType.uint16, "transmitted-10k")

                        self.transmitted_1k = YLeaf(YType.uint16, "transmitted-1k")

                        self.transmitted_50k = YLeaf(YType.uint16, "transmitted-50k")
                        self._segment_path = lambda: "jp-statistic" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/jp-statistics/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.JpStatistics.JpStatistic, ['interface_name', 'interface_name_xr', 'mtu', 'received', 'received100', 'received_10k', 'received_1k', 'received_50k', 'transmitted', 'transmitted100', 'transmitted_10k', 'transmitted_1k', 'transmitted_50k'], name, value)


            class MibDatabases(Entity):
                """
                PIM group database for mroute mibs table
                
                .. attribute:: mib_database
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.MibDatabases, self).__init__()

                    self.yang_name = "mib-databases"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"mib-database" : ("mib_database", Pim.Standby.DefaultContext.MibDatabases.MibDatabase)}

                    self.mib_database = YList(self)
                    self._segment_path = lambda: "mib-databases"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.MibDatabases, [], name, value)


                class MibDatabase(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: assert_metric
                    
                    	Assert Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_metric_preference
                    
                    	Assert Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_rpt_bit
                    
                    	Assert RPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: bidirectional_route
                    
                    	Is this Bidir ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Multicast satic route group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr>`
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface name 
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: rpf_mask
                    
                    	Mask of the multicast root
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_neighbor
                    
                    	The RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: source_address
                    
                    	Multicast static route source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr>`
                    
                    .. attribute:: source_netmask
                    
                    	Source mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: spt_bit
                    
                    	Is SPT bit set ?
                    	**type**\:  bool
                    
                    .. attribute:: upstream_assert_timer
                    
                    	Upstream Assert Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime of route
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase, self).__init__()

                        self.yang_name = "mib-database"
                        self.yang_parent_name = "mib-databases"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr), "rpf-neighbor" : ("rpf_neighbor", Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor), "rpf-root" : ("rpf_root", Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot), "source-address-xr" : ("source_address_xr", Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr)}
                        self._child_list_classes = {}

                        self.assert_metric = YLeaf(YType.uint32, "assert-metric")

                        self.assert_metric_preference = YLeaf(YType.uint32, "assert-metric-preference")

                        self.assert_rpt_bit = YLeaf(YType.boolean, "assert-rpt-bit")

                        self.bidirectional_route = YLeaf(YType.boolean, "bidirectional-route")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                        self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_mask = YLeaf(YType.uint32, "rpf-mask")

                        self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                        self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.source_netmask = YLeaf(YType.int32, "source-netmask")

                        self.spt_bit = YLeaf(YType.boolean, "spt-bit")

                        self.upstream_assert_timer = YLeaf(YType.int32, "upstream-assert-timer")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_address_xr = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.rpf_neighbor = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                        self.rpf_root = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._children_yang_names.add("rpf-root")

                        self.source_address_xr = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"
                        self._children_yang_names.add("source-address-xr")
                        self._segment_path = lambda: "mib-database"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/mib-databases/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.MibDatabases.MibDatabase, ['assert_metric', 'assert_metric_preference', 'assert_rpt_bit', 'bidirectional_route', 'group_address', 'protocol', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_mask', 'rpf_safi', 'rpf_table_name', 'rpf_vrf_name', 'source_address', 'source_netmask', 'spt_bit', 'upstream_assert_timer', 'uptime'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/mib-databases/mib-database/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        The RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/mib-databases/mib-database/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-root"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/mib-databases/mib-database/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/mib-databases/mib-database/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class MulticastStaticRoutes(Entity):
                """
                PIM multicast static route table
                
                .. attribute:: multicast_static_route
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.MulticastStaticRoutes, self).__init__()

                    self.yang_name = "multicast-static-routes"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"multicast-static-route" : ("multicast_static_route", Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute)}

                    self.multicast_static_route = YList(self)
                    self._segment_path = lambda: "multicast-static-routes"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.MulticastStaticRoutes, [], name, value)


                class MulticastStaticRoute(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: address
                    
                    	Network address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: distance
                    
                    	Distance
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_via_lsm
                    
                    	LSM flag
                    	**type**\:  bool
                    
                    .. attribute:: nexthop
                    
                    	Next Hop
                    	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: prefix_length_xr
                    
                    	Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                        self.yang_name = "multicast-static-route"
                        self.yang_parent_name = "multicast-static-routes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"nexthop" : ("nexthop", Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop), "prefix" : ("prefix", Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix)}
                        self._child_list_classes = {}

                        self.address = YLeaf(YType.str, "address")

                        self.distance = YLeaf(YType.uint32, "distance")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                        self.nexthop = Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                        self.nexthop.parent = self
                        self._children_name_map["nexthop"] = "nexthop"
                        self._children_yang_names.add("nexthop")

                        self.prefix = Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._children_yang_names.add("prefix")
                        self._segment_path = lambda: "multicast-static-route"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/multicast-static-routes/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, ['address', 'distance', 'interface_name', 'is_via_lsm', 'prefix_length', 'prefix_length_xr'], name, value)


                    class Nexthop(Entity):
                        """
                        Next Hop
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                            self.yang_name = "nexthop"
                            self.yang_parent_name = "multicast-static-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "nexthop"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/multicast-static-routes/multicast-static-route/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Prefix(Entity):
                        """
                        Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "multicast-static-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "prefix"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/multicast-static-routes/multicast-static-route/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class NeighborOldFormats(Entity):
                """
                PIM neighbor table old format
                
                .. attribute:: neighbor_old_format
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.NeighborOldFormats, self).__init__()

                    self.yang_name = "neighbor-old-formats"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"neighbor-old-format" : ("neighbor_old_format", Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat)}

                    self.neighbor_old_format = YList(self)
                    self._segment_path = lambda: "neighbor-old-formats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.NeighborOldFormats, [], name, value)


                class NeighborOldFormat(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__init__()

                        self.yang_name = "neighbor-old-format"
                        self.yang_parent_name = "neighbor-old-formats"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr)}

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                        self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                        self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.neighbor_address_xr = YList(self)
                        self._segment_path = lambda: "neighbor-old-format"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/neighbor-old-formats/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat, ['dr_priority', 'expires', 'expiry_timer', 'interface_name', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bfd_state', 'is_bidirectional_capable', 'is_dr_priority_capable', 'is_ecmp_redirect_capable', 'is_proxy_capable', 'is_this_neighbor_dr', 'is_this_neighbor_us', 'neighbor_address', 'override_interval', 'propagation_delay', 'uptime'], name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "neighbor-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/neighbor-old-formats/neighbor-old-format/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class NeighborSummaries(Entity):
                """
                PIM neighbor summary table
                
                .. attribute:: neighbor_summary
                
                	PIM neighbor summary information
                	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.NeighborSummaries, self).__init__()

                    self.yang_name = "neighbor-summaries"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"neighbor-summary" : ("neighbor_summary", Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary)}

                    self.neighbor_summary = YList(self)
                    self._segment_path = lambda: "neighbor-summaries"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.NeighborSummaries, [], name, value)


                class NeighborSummary(Entity):
                    """
                    PIM neighbor summary information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: number_of_external_neighbors
                    
                    	Number of external neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary, self).__init__()

                        self.yang_name = "neighbor-summary"
                        self.yang_parent_name = "neighbor-summaries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.number_of_external_neighbors = YLeaf(YType.int32, "number-of-external-neighbors")

                        self.number_of_neighbors = YLeaf(YType.int32, "number-of-neighbors")
                        self._segment_path = lambda: "neighbor-summary" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/neighbor-summaries/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary, ['interface_name', 'number_of_external_neighbors', 'number_of_neighbors'], name, value)


            class Neighbors(Entity):
                """
                PIM neighbor table
                
                .. attribute:: neighbor
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Neighbors.Neighbor>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Neighbors, self).__init__()

                    self.yang_name = "neighbors"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"neighbor" : ("neighbor", Pim.Standby.DefaultContext.Neighbors.Neighbor)}

                    self.neighbor = YList(self)
                    self._segment_path = lambda: "neighbors"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.Neighbors, [], name, value)


                class Neighbor(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Neighbors.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "neighbors"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr)}

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                        self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                        self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.neighbor_address_xr = YList(self)
                        self._segment_path = lambda: "neighbor"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/neighbors/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Neighbors.Neighbor, ['dr_priority', 'expires', 'expiry_timer', 'interface_name', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bfd_state', 'is_bidirectional_capable', 'is_dr_priority_capable', 'is_ecmp_redirect_capable', 'is_proxy_capable', 'is_this_neighbor_dr', 'is_this_neighbor_us', 'neighbor_address', 'override_interval', 'propagation_delay', 'uptime'], name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "neighbor-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/neighbors/neighbor/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class NetIoTunnels(Entity):
                """
                Tunnel information that NETIO has 
                
                .. attribute:: net_io_tunnel
                
                	PIM netio tunnel information
                	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.NetIoTunnels, self).__init__()

                    self.yang_name = "net-io-tunnels"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"net-io-tunnel" : ("net_io_tunnel", Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel)}

                    self.net_io_tunnel = YList(self)
                    self._segment_path = lambda: "net-io-tunnels"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.NetIoTunnels, [], name, value)


                class NetIoTunnel(Entity):
                    """
                    PIM netio tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel, self).__init__()

                        self.yang_name = "net-io-tunnel"
                        self.yang_parent_name = "net-io-tunnels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-netio" : ("group_address_netio", Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio), "rp-address" : ("rp_address", Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress), "source-address" : ("source_address", Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress), "source-address-netio" : ("source_address_netio", Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio)}
                        self._child_list_classes = {}

                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.group_address_netio = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._children_yang_names.add("group-address-netio")

                        self.rp_address = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                        self.source_address_netio = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"
                        self._children_yang_names.add("source-address-netio")
                        self._segment_path = lambda: "net-io-tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/net-io-tunnels/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel, ['tunnel_name', 'vrf_name'], name, value)


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-netio"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address-netio"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Ranges(Entity):
                """
                PIM range list information
                
                .. attribute:: range
                
                	PIM range list information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"range" : ("range", Pim.Standby.DefaultContext.Ranges.Range)}

                    self.range = YList(self)
                    self._segment_path = lambda: "ranges"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.Ranges, [], name, value)


                class Range(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: client_xr
                    
                    	Client mapping learnt via
                    	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                    
                    .. attribute:: expires
                    
                    	When mapping expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: group_range
                    
                    	List of group ranges
                    	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.GroupRange>`
                    
                    .. attribute:: protocol
                    
                    	PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	Rendezvous point address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr>`
                    
                    .. attribute:: source_of_information
                    
                    	Source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rp-address-xr" : ("rp_address_xr", Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr), "source-of-information" : ("source_of_information", Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation)}
                        self._child_list_classes = {"group-range" : ("group_range", Pim.Standby.DefaultContext.Ranges.Range.GroupRange)}

                        self.client = YLeaf(YType.enumeration, "client")

                        self.client_xr = YLeaf(YType.enumeration, "client-xr")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_address_xr = Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")

                        self.source_of_information = Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")

                        self.group_range = YList(self)
                        self._segment_path = lambda: "range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ranges/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Ranges.Range, ['client', 'client_xr', 'expires', 'protocol', 'rp_address'], name, value)


                    class GroupRange(Entity):
                        """
                        List of group ranges
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Ranges.Range.GroupRange, self).__init__()

                            self.yang_name = "group-range"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"prefix" : ("prefix", Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix), "source-of-information" : ("source_of_information", Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation)}
                            self._child_list_classes = {}

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.prefix = Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.source_of_information = Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")
                            self._segment_path = lambda: "group-range"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ranges/range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Ranges.Range.GroupRange, ['expires', 'prefix_length', 'uptime'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ranges/range/group-range/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-of-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ranges/range/group-range/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddressXr(Entity):
                        """
                        Rendezvous point address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ranges/range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceOfInformation(Entity):
                        """
                        Source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-of-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ranges/range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class RoutePolicy(Entity):
                """
                PIM route policy
                
                .. attribute:: route_policy_statistics
                
                	PIM route policy statistics
                	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics>`
                
                .. attribute:: route_policy_tests
                
                	PIM route policy test run table
                	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.RoutePolicy, self).__init__()

                    self.yang_name = "route-policy"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"route-policy-statistics" : ("route_policy_statistics", Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics), "route-policy-tests" : ("route_policy_tests", Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests)}
                    self._child_list_classes = {}

                    self.route_policy_statistics = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                    self.route_policy_statistics.parent = self
                    self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                    self._children_yang_names.add("route-policy-statistics")

                    self.route_policy_tests = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests()
                    self.route_policy_tests.parent = self
                    self._children_name_map["route_policy_tests"] = "route-policy-tests"
                    self._children_yang_names.add("route-policy-tests")
                    self._segment_path = lambda: "route-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()


                class RoutePolicyStatistics(Entity):
                    """
                    PIM route policy statistics
                    
                    .. attribute:: any_table
                    
                    	Number of RPF lookup in any Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table
                    
                    	Number of RPF lookup in default\-only Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop
                    
                    	Number of RPF drops
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pass_
                    
                    	Number of RPF pass
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: policy_name
                    
                    	RPF policy name
                    	**type**\:  str
                    
                    .. attribute:: requests
                    
                    	Number of RPF lookup requests
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__init__()

                        self.yang_name = "route-policy-statistics"
                        self.yang_parent_name = "route-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.any_table = YLeaf(YType.uint32, "any-table")

                        self.default_table = YLeaf(YType.uint32, "default-table")

                        self.drop = YLeaf(YType.uint32, "drop")

                        self.pass_ = YLeaf(YType.uint32, "pass")

                        self.policy_name = YLeaf(YType.str, "policy-name")

                        self.requests = YLeaf(YType.uint32, "requests")
                        self._segment_path = lambda: "route-policy-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/route-policy/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics, ['any_table', 'default_table', 'drop', 'pass_', 'policy_name', 'requests'], name, value)


                class RoutePolicyTests(Entity):
                    """
                    PIM route policy test run table
                    
                    .. attribute:: route_policy_test
                    
                    	PIM route policy test run
                    	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests, self).__init__()

                        self.yang_name = "route-policy-tests"
                        self.yang_parent_name = "route-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"route-policy-test" : ("route_policy_test", Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest)}

                        self.route_policy_test = YList(self)
                        self._segment_path = lambda: "route-policy-tests"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/route-policy/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests, [], name, value)


                    class RoutePolicyTest(Entity):
                        """
                        PIM route policy test run
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Default table selected
                        	**type**\:  bool
                        
                        .. attribute:: ext_comm
                        
                        	Extended Community
                        	**type**\:  str
                        
                        	**length:** 1..8
                        
                        .. attribute:: extended_community_rt
                        
                        	Route Target
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                        
                        .. attribute:: pass_
                        
                        	Pass
                        	**type**\:  bool
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                        
                        .. attribute:: table_active
                        
                        	Table active
                        	**type**\:  bool
                        
                        .. attribute:: table_exists
                        
                        	Table exists
                        	**type**\:  bool
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_name
                        
                        	VRF name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                            self.yang_name = "route-policy-test"
                            self.yang_parent_name = "route-policy-tests"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr), "source-address-xr" : ("source_address_xr", Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr)}
                            self._child_list_classes = {}

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.default_table = YLeaf(YType.boolean, "default-table")

                            self.ext_comm = YLeaf(YType.str, "ext-comm")

                            self.extended_community_rt = YLeaf(YType.str, "extended-community-rt")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.pass_ = YLeaf(YType.boolean, "pass")

                            self.policy_name = YLeaf(YType.str, "policy-name")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.table_active = YLeaf(YType.boolean, "table-active")

                            self.table_exists = YLeaf(YType.boolean, "table-exists")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_xr = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.source_address_xr = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")
                            self._segment_path = lambda: "route-policy-test"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/route-policy/route-policy-tests/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, ['afi', 'default_table', 'ext_comm', 'extended_community_rt', 'group_address', 'pass_', 'policy_name', 'safi', 'source_address', 'table_active', 'table_exists', 'table_name', 'vrf_name'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "route-policy-test"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "route-policy-test"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class RpfRedirect(Entity):
                """
                PIM ECMP RPF\-redirect bundle
                
                .. attribute:: bundle_interfaces
                
                	PIM ECMP RPF\-redirect bundle information
                	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces>`
                
                .. attribute:: redirect_route_databases
                
                	PIM ECMP RPF\-redirect route database
                	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.RpfRedirect, self).__init__()

                    self.yang_name = "rpf-redirect"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"bundle-interfaces" : ("bundle_interfaces", Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces), "redirect-route-databases" : ("redirect_route_databases", Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases)}
                    self._child_list_classes = {}

                    self.bundle_interfaces = Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces()
                    self.bundle_interfaces.parent = self
                    self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                    self._children_yang_names.add("bundle-interfaces")

                    self.redirect_route_databases = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                    self.redirect_route_databases.parent = self
                    self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                    self._children_yang_names.add("redirect-route-databases")
                    self._segment_path = lambda: "rpf-redirect"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()


                class BundleInterfaces(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle information
                    
                    .. attribute:: bundle_interface
                    
                    	PIM ECMP RPF\-redirect bundle interface information
                    	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces, self).__init__()

                        self.yang_name = "bundle-interfaces"
                        self.yang_parent_name = "rpf-redirect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"bundle-interface" : ("bundle_interface", Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface)}

                        self.bundle_interface = YList(self)
                        self._segment_path = lambda: "bundle-interfaces"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces, [], name, value)


                    class BundleInterface(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle interface
                        information
                        
                        .. attribute:: allocated_bandwidth
                        
                        	Bandwidth allocated in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_threshold_bandwidth
                        
                        	Configured threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_threshold_bandwidth
                        
                        	Available threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: bundle_name
                        
                        	Bundle name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: interface_name
                        
                        	Bundle interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: rpf_redirect_bundle_name
                        
                        	RPF redirect bundle name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_redirect_interface_name
                        
                        	RPF redirect interface name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: snooping_bandwidth_used
                        
                        	Bandwidth used by snooped entries in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: topology_bandwidth_used
                        
                        	Bandwidth used by topology in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: total_bandwidth
                        
                        	Total bandwidth used in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                            self.yang_name = "bundle-interface"
                            self.yang_parent_name = "bundle-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.allocated_bandwidth = YLeaf(YType.int32, "allocated-bandwidth")

                            self.allocated_threshold_bandwidth = YLeaf(YType.int32, "allocated-threshold-bandwidth")

                            self.available_bandwidth = YLeaf(YType.int32, "available-bandwidth")

                            self.available_threshold_bandwidth = YLeaf(YType.int32, "available-threshold-bandwidth")

                            self.bundle_name = YLeaf(YType.str, "bundle-name")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.rpf_redirect_bundle_name = YLeaf(YType.str, "rpf-redirect-bundle-name")

                            self.rpf_redirect_interface_name = YLeaf(YType.str, "rpf-redirect-interface-name")

                            self.snooping_bandwidth_used = YLeaf(YType.int32, "snooping-bandwidth-used")

                            self.topology_bandwidth_used = YLeaf(YType.int32, "topology-bandwidth-used")

                            self.total_bandwidth = YLeaf(YType.int32, "total-bandwidth")
                            self._segment_path = lambda: "bundle-interface"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/bundle-interfaces/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, ['allocated_bandwidth', 'allocated_threshold_bandwidth', 'available_bandwidth', 'available_threshold_bandwidth', 'bundle_name', 'interface_name', 'rpf_redirect_bundle_name', 'rpf_redirect_interface_name', 'snooping_bandwidth_used', 'topology_bandwidth_used', 'total_bandwidth'], name, value)


                class RedirectRouteDatabases(Entity):
                    """
                    PIM ECMP RPF\-redirect route database
                    
                    .. attribute:: redirect_route_database
                    
                    	PIM ECMP RPF\-redirect route information
                    	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__init__()

                        self.yang_name = "redirect-route-databases"
                        self.yang_parent_name = "rpf-redirect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"redirect-route-database" : ("redirect_route_database", Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase)}

                        self.redirect_route_database = YList(self)
                        self._segment_path = lambda: "redirect-route-databases"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases, [], name, value)


                    class RedirectRouteDatabase(Entity):
                        """
                        PIM ECMP RPF\-redirect route information
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group ddress
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                        
                        .. attribute:: interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                            self.yang_name = "redirect-route-database"
                            self.yang_parent_name = "redirect-route-databases"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr), "source-address-xr" : ("source_address_xr", Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr)}
                            self._child_list_classes = {"interface" : ("interface", Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface)}

                            self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.source_address_xr = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                            self.interface = YList(self)
                            self._segment_path = lambda: "redirect-route-database"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/redirect-route-databases/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, ['bandwidth', 'group_address', 'source_address', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group ddress
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Interface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_outgoing_interface
                            
                            	Is outgoing Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_rpf_interface
                            
                            	Is RPF Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_snoop_interface
                            
                            	Is snooping Interface
                            	**type**\:  bool
                            
                            .. attribute:: rpf_address
                            
                            	RPF Address
                            	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"rpf-address" : ("rpf_address", Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress)}
                                self._child_list_classes = {}

                                self.expiry = YLeaf(YType.uint64, "expiry")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.is_outgoing_interface = YLeaf(YType.boolean, "is-outgoing-interface")

                                self.is_rpf_interface = YLeaf(YType.boolean, "is-rpf-interface")

                                self.is_snoop_interface = YLeaf(YType.boolean, "is-snoop-interface")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.rpf_address = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                self.rpf_address.parent = self
                                self._children_name_map["rpf_address"] = "rpf-address"
                                self._children_yang_names.add("rpf-address")
                                self._segment_path = lambda: "interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, ['expiry', 'interface_name', 'is_outgoing_interface', 'is_rpf_interface', 'is_snoop_interface', 'uptime'], name, value)


                            class RpfAddress(Entity):
                                """
                                RPF Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                    self.yang_name = "rpf-address"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "rpf-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class RpfSummary(Entity):
                """
                PIM RPF registration summary
                
                .. attribute:: default_safi
                
                	Default RPF Table SAFI
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: default_table_name
                
                	Default RPF Table Name
                	**type**\:  str
                
                .. attribute:: is_isis_mtr_configured
                
                	Is ISIS MTR configured?
                	**type**\:  bool
                
                .. attribute:: is_isis_te_configured
                
                	Is ISIS TE configured?
                	**type**\:  bool
                
                .. attribute:: is_mbgp_configured
                
                	Is MBGP configured?
                	**type**\:  bool
                
                .. attribute:: is_multipath_enabled
                
                	Is Multipath Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_interface_hash_enabled
                
                	Is Multipath Interface Hash Extension Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_hash_enabled
                
                	Is Multipath Source based Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_next_hop_hash_enabled
                
                	Is Multipath Source\-Nexthop Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_ospf_te_configured
                
                	Is OSPF TE configured?
                	**type**\:  bool
                
                .. attribute:: is_rib_convergence
                
                	RIB Convergence status
                	**type**\:  bool
                
                .. attribute:: mo_frr_configured
                
                	Is MoFRR configured?
                	**type**\:  bool
                
                .. attribute:: rib_convergence_time_left
                
                	RIB convergence time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_convergence_timeout
                
                	RIB convergence timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_mo_frr_configured
                
                	Is MoFRR RIB configured?
                	**type**\:  bool
                
                .. attribute:: rpf_registrations
                
                	RPF Registration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	Is RUMP MuRIB enabled?
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.RpfSummary, self).__init__()

                    self.yang_name = "rpf-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.default_safi = YLeaf(YType.uint32, "default-safi")

                    self.default_table_name = YLeaf(YType.str, "default-table-name")

                    self.is_isis_mtr_configured = YLeaf(YType.boolean, "is-isis-mtr-configured")

                    self.is_isis_te_configured = YLeaf(YType.boolean, "is-isis-te-configured")

                    self.is_mbgp_configured = YLeaf(YType.boolean, "is-mbgp-configured")

                    self.is_multipath_enabled = YLeaf(YType.boolean, "is-multipath-enabled")

                    self.is_multipath_interface_hash_enabled = YLeaf(YType.boolean, "is-multipath-interface-hash-enabled")

                    self.is_multipath_source_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-hash-enabled")

                    self.is_multipath_source_next_hop_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-next-hop-hash-enabled")

                    self.is_ospf_te_configured = YLeaf(YType.boolean, "is-ospf-te-configured")

                    self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                    self.mo_frr_configured = YLeaf(YType.boolean, "mo-frr-configured")

                    self.rib_convergence_time_left = YLeaf(YType.uint32, "rib-convergence-time-left")

                    self.rib_convergence_timeout = YLeaf(YType.uint32, "rib-convergence-timeout")

                    self.rib_mo_frr_configured = YLeaf(YType.boolean, "rib-mo-frr-configured")

                    self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                    self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")
                    self._segment_path = lambda: "rpf-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.RpfSummary, ['default_safi', 'default_table_name', 'is_isis_mtr_configured', 'is_isis_te_configured', 'is_mbgp_configured', 'is_multipath_enabled', 'is_multipath_interface_hash_enabled', 'is_multipath_source_hash_enabled', 'is_multipath_source_next_hop_hash_enabled', 'is_ospf_te_configured', 'is_rib_convergence', 'mo_frr_configured', 'rib_convergence_time_left', 'rib_convergence_timeout', 'rib_mo_frr_configured', 'rpf_registrations', 'rump_enabled'], name, value)


            class Safs(Entity):
                """
                SAFI table and type
                
                .. attribute:: saf
                
                	SAF name 
                	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Safs, self).__init__()

                    self.yang_name = "safs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"saf" : ("saf", Pim.Standby.DefaultContext.Safs.Saf)}

                    self.saf = YList(self)
                    self._segment_path = lambda: "safs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.Safs, [], name, value)


                class Saf(Entity):
                    """
                    SAF name 
                    
                    .. attribute:: rpf_hash_source_groups
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups>`
                    
                    .. attribute:: rpf_hash_sources
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources>`
                    
                    .. attribute:: rpfs
                    
                    	PIM RPF information table
                    	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs>`
                    
                    .. attribute:: saf_name
                    
                    	SAF name 
                    	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name 
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Safs.Saf, self).__init__()

                        self.yang_name = "saf"
                        self.yang_parent_name = "safs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rpf-hash-source-groups" : ("rpf_hash_source_groups", Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups), "rpf-hash-sources" : ("rpf_hash_sources", Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources), "rpfs" : ("rpfs", Pim.Standby.DefaultContext.Safs.Saf.Rpfs)}
                        self._child_list_classes = {}

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                        self.topology_name = YLeaf(YType.str, "topology-name")

                        self.rpf_hash_source_groups = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                        self.rpf_hash_source_groups.parent = self
                        self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                        self._children_yang_names.add("rpf-hash-source-groups")

                        self.rpf_hash_sources = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources()
                        self.rpf_hash_sources.parent = self
                        self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                        self._children_yang_names.add("rpf-hash-sources")

                        self.rpfs = Pim.Standby.DefaultContext.Safs.Saf.Rpfs()
                        self.rpfs.parent = self
                        self._children_name_map["rpfs"] = "rpfs"
                        self._children_yang_names.add("rpfs")
                        self._segment_path = lambda: "saf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf, ['saf_name', 'topology_name'], name, value)


                    class RpfHashSourceGroups(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source_group
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__init__()

                            self.yang_name = "rpf-hash-source-groups"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"rpf-hash-source-group" : ("rpf_hash_source_group", Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup)}

                            self.rpf_hash_source_group = YList(self)
                            self._segment_path = lambda: "rpf-hash-source-groups"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups, [], name, value)


                        class RpfHashSourceGroup(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: mask_length
                            
                            	Hash mask length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                self.yang_name = "rpf-hash-source-group"
                                self.yang_parent_name = "rpf-hash-source-groups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"next-hop-address" : ("next_hop_address", Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress), "secondary-next-hop-address" : ("secondary_next_hop_address", Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress)}
                                self._child_list_classes = {}

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.mask_length = YLeaf(YType.int32, "mask-length")

                                self.mofrr = YLeaf(YType.int32, "mofrr")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                self._children_yang_names.add("next-hop-address")

                                self.secondary_next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._children_yang_names.add("secondary-next-hop-address")
                                self._segment_path = lambda: "rpf-hash-source-group"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpf-hash-source-groups/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, ['group_address', 'mask_length', 'mofrr', 'next_hop_interface', 'next_hop_multipath_enabled', 'secondary_next_hop_interface', 'source_address'], name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "secondary-next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfHashSources(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources, self).__init__()

                            self.yang_name = "rpf-hash-sources"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"rpf-hash-source" : ("rpf_hash_source", Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource)}

                            self.rpf_hash_source = YList(self)
                            self._segment_path = lambda: "rpf-hash-sources"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources, [], name, value)


                        class RpfHashSource(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                self.yang_name = "rpf-hash-source"
                                self.yang_parent_name = "rpf-hash-sources"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"next-hop-address" : ("next_hop_address", Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress), "secondary-next-hop-address" : ("secondary_next_hop_address", Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress)}
                                self._child_list_classes = {}

                                self.mofrr = YLeaf(YType.int32, "mofrr")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                self._children_yang_names.add("next-hop-address")

                                self.secondary_next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._children_yang_names.add("secondary-next-hop-address")
                                self._segment_path = lambda: "rpf-hash-source"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpf-hash-sources/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, ['mofrr', 'next_hop_interface', 'next_hop_multipath_enabled', 'secondary_next_hop_interface', 'source_address'], name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "secondary-next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Rpfs(Entity):
                        """
                        PIM RPF information table
                        
                        .. attribute:: rpf
                        
                        	PIM RPF information
                        	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs, self).__init__()

                            self.yang_name = "rpfs"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"rpf" : ("rpf", Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf)}

                            self.rpf = YList(self)
                            self._segment_path = lambda: "rpfs"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.Rpfs, [], name, value)


                        class Rpf(Entity):
                            """
                            PIM RPF information
                            
                            .. attribute:: registered_address  <key>
                            
                            	Address for which RPF lookup
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_rpf_bgp_route
                            
                            	Is RPF through BGP route
                            	**type**\:  bool
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address_xr
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                            
                            .. attribute:: rpf_path
                            
                            	RPF Paths list
                            	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__init__()

                                self.yang_name = "rpf"
                                self.yang_parent_name = "rpfs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"registered-address-xr" : ("registered_address_xr", Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr)}
                                self._child_list_classes = {"rpf-path" : ("rpf_path", Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath)}

                                self.registered_address = YLeaf(YType.str, "registered-address")

                                self.is_connected = YLeaf(YType.uint8, "is-connected")

                                self.is_rpf_bgp_route = YLeaf(YType.boolean, "is-rpf-bgp-route")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                self.registered_address_xr = Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                self.registered_address_xr.parent = self
                                self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                self._children_yang_names.add("registered-address-xr")

                                self.rpf_path = YList(self)
                                self._segment_path = lambda: "rpf" + "[registered-address='" + self.registered_address.get() + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpfs/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf, ['registered_address', 'is_connected', 'is_rpf_bgp_route', 'metric', 'metric_preference'], name, value)


                            class RegisteredAddressXr(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                    self.yang_name = "registered-address-xr"
                                    self.yang_parent_name = "rpf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "registered-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class RpfPath(Entity):
                                """
                                RPF Paths list
                                
                                .. attribute:: connector
                                
                                	Connector Attribute
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface_disabled
                                
                                	Is the rpf interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                .. attribute:: is_via_mlsm
                                
                                	Via Mstatic LSM
                                	**type**\:  bool
                                
                                .. attribute:: rpf_interface_name
                                
                                	RPF Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: rpf_neighbor
                                
                                	RPF neighbor
                                	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                
                                .. attribute:: rpf_nexthop
                                
                                	RPF nexthop
                                	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                    self.yang_name = "rpf-path"
                                    self.yang_parent_name = "rpf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"rpf-neighbor" : ("rpf_neighbor", Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor), "rpf-nexthop" : ("rpf_nexthop", Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop)}
                                    self._child_list_classes = {}

                                    self.connector = YLeaf(YType.str, "connector")

                                    self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                    self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                    self.is_rpf_interface_disabled = YLeaf(YType.boolean, "is-rpf-interface-disabled")

                                    self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                    self.is_via_mlsm = YLeaf(YType.boolean, "is-via-mlsm")

                                    self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                                    self.rpf_neighbor = Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                    self._children_yang_names.add("rpf-neighbor")

                                    self.rpf_nexthop = Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                    self.rpf_nexthop.parent = self
                                    self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                    self._children_yang_names.add("rpf-nexthop")
                                    self._segment_path = lambda: "rpf-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, ['connector', 'extranet_vrf_name', 'is_connector_attribute_present', 'is_rpf_interface_disabled', 'is_via_lsm', 'is_via_mlsm', 'rpf_interface_name'], name, value)


                                class RpfNeighbor(Entity):
                                    """
                                    RPF neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                        self.yang_name = "rpf-neighbor"
                                        self.yang_parent_name = "rpf-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "rpf-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class RpfNexthop(Entity):
                                    """
                                    RPF nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                        self.yang_name = "rpf-nexthop"
                                        self.yang_parent_name = "rpf-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "rpf-nexthop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Summary(Entity):
                """
                PIM summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                    self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                    self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                    self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                    self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                    self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                    self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                    self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                    self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                    self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                    self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                    self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                    self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                    self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                    self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                    self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                    self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                    self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                    self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                    self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                    self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                    self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                    self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                    self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                    self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                    self.register_count = YLeaf(YType.uint32, "register-count")

                    self.register_limit = YLeaf(YType.uint32, "register-limit")

                    self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                    self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                    self.route_count = YLeaf(YType.uint32, "route-count")

                    self.route_limit = YLeaf(YType.uint32, "route-limit")

                    self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                    self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                    self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                    self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                    self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                    self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                    self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.Summary, ['bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_threshold', 'bsr_range_threshold', 'bsr_ranges_count', 'bsr_ranges_limit', 'global_auto_rp_ranges_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_threshold', 'global_bsr_ranges_count', 'global_bsr_ranges_limit', 'global_bsr_ranges_threshold', 'global_register_limit', 'is_bsr_ranges_threshold_reached', 'is_global_auto_rp_ranges_limit_reached', 'is_global_bsr_ranges_limit_reached', 'is_global_register_limit_reached', 'is_global_route_limit_reached', 'is_global_rxi_limit_reached', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'is_ranges_limit_reached', 'is_route_limit_reached', 'ranges_count', 'ranges_limit', 'ranges_threshold', 'register_count', 'register_limit', 'register_limit_reached', 'register_threshold', 'route_count', 'route_limit', 'route_low_water_mark', 'route_threshold', 'rxi_limit_reached', 'rxi_low_water_mark', 'topology_interface_state_count', 'topology_interface_state_limit', 'topology_interface_state_threshold'], name, value)


            class TableContexts(Entity):
                """
                PIM table context list
                
                .. attribute:: table_context
                
                	PIM table context information
                	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TableContexts.TableContext>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.TableContexts, self).__init__()

                    self.yang_name = "table-contexts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"table-context" : ("table_context", Pim.Standby.DefaultContext.TableContexts.TableContext)}

                    self.table_context = YList(self)
                    self._segment_path = lambda: "table-contexts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.TableContexts, [], name, value)


                class TableContext(Entity):
                    """
                    PIM table context information
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saf_name
                    
                    	SAF name
                    	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: topology_name
                    
                    	Topology name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.TableContexts.TableContext, self).__init__()

                        self.yang_name = "table-context"
                        self.yang_parent_name = "table-contexts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.uint32, "afi")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                        self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                        self.safi = YLeaf(YType.uint32, "safi")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.table_name = YLeaf(YType.str, "table-name")

                        self.topology_name = YLeaf(YType.str, "topology-name")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")
                        self._segment_path = lambda: "table-context"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/table-contexts/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.TableContexts.TableContext, ['afi', 'is_active', 'is_ital_registration_done', 'is_rib_convergence', 'is_rib_convergence_received', 'is_rib_registration_done', 'rpf_registrations', 'saf_name', 'safi', 'table_id', 'table_name', 'topology_name', 'vrf_id'], name, value)


            class Topologies(Entity):
                """
                PIM topology table
                
                .. attribute:: topology
                
                	PIM topology information
                	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Topologies, self).__init__()

                    self.yang_name = "topologies"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"topology" : ("topology", Pim.Standby.DefaultContext.Topologies.Topology)}

                    self.topology = YList(self)
                    self._segment_path = lambda: "topologies"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.Topologies, [], name, value)


                class Topology(Entity):
                    """
                    PIM topology information
                    
                    .. attribute:: alive
                    
                    	Alive time in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: anycast_rp_match
                    
                    	Group matches Anycast\-RP policy
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_route_target
                    
                    	Anycast\-RP RT
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: assume_alive
                    
                    	The Assume Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: bgp_join
                    
                    	BGP C JOIN
                    	**type**\:  bool
                    
                    .. attribute:: bgp_jp_time
                    
                    	BGP C JP Time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: connected
                    
                    	Is Connected ?
                    	**type**\:  bool
                    
                    .. attribute:: crossed_threshold
                    
                    	Incoming traffic crossed threshold. MT flag set
                    	**type**\:  bool
                    
                    .. attribute:: customer_routing_type
                    
                    	Type of Customer Routing in the MVPN
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: data_mdt_addr_assigned
                    
                    	PIM has assigned a Data MDT Address
                    	**type**\:  bool
                    
                    .. attribute:: dont_check_connected
                    
                    	Do we need to make the connected check on this route ?
                    	**type**\:  bool
                    
                    .. attribute:: expiry
                    
                    	When this entry expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: extranet_route
                    
                    	Is a Extranet route ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr>`
                    
                    .. attribute:: inherit_alive
                    
                    	The Inherit Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: inherit_spt
                    
                    	The Inherit SPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: is_via_lsm
                    
                    	Via LSM
                    	**type**\:  bool
                    
                    .. attribute:: jp_status
                    
                    	Join\-Prune Status
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: jp_timer
                    
                    	Join\-Prune Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: kat_state
                    
                    	Keep Alive Timer State
                    	**type**\:  bool
                    
                    .. attribute:: last_hop
                    
                    	Are we last hop ?
                    	**type**\:  bool
                    
                    .. attribute:: limit_reached
                    
                    	Have we throttled the creation of routes or interfaces ?
                    	**type**\:  bool
                    
                    .. attribute:: low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_active
                    
                    	Is MoFRR Active?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_backup
                    
                    	Is this Mofrr Backup?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_primary
                    
                    	Is this Mofrr Primary?
                    	**type**\:  bool
                    
                    .. attribute:: orig_src_address
                    
                    	Orig Src Address
                    	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress>`
                    
                    .. attribute:: outgoing_interface
                    
                    	Outgoing interface list
                    	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface>`
                    
                    .. attribute:: probe_alive
                    
                    	The Probe Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: proxy
                    
                    	Is the RPF target a proxy?
                    	**type**\:  bool
                    
                    .. attribute:: proxy_address
                    
                    	RPF Proxy address
                    	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress>`
                    
                    .. attribute:: really_alive
                    
                    	The Really Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: register_received
                    
                    	Have registers been received for this source ?
                    	**type**\:  bool
                    
                    .. attribute:: register_received_timer
                    
                    	Register Received Timer in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: remote_source
                    
                    	MSDP told us
                    	**type**\:  bool
                    
                    .. attribute:: rib_mo_frr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rp_address
                    
                    	RP Address (If rpt)
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.RpAddress>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor>`
                    
                    .. attribute:: rpf_proxy_enabled
                    
                    	Is rpf if proxy enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: rpt
                    
                    	RPT bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpt_xr
                    
                    	Is this on the RPT ?
                    	**type**\:  bool
                    
                    .. attribute:: sa_joined
                    
                    	BGP SA join
                    	**type**\:  bool
                    
                    .. attribute:: sa_received
                    
                    	BGP SA received
                    	**type**\:  bool
                    
                    .. attribute:: sa_sent
                    
                    	BGP SA sent
                    	**type**\:  bool
                    
                    .. attribute:: secondary_rpf_interface_name
                    
                    	Secondary Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: secondary_rpf_neighbor
                    
                    	Secondary RPF Neighbor
                    	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor>`
                    
                    .. attribute:: sending_null_registers
                    
                    	Are we sending null registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: sending_registers
                    
                    	Are we sending registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: signal_sources
                    
                    	Signal Sources on route?
                    	**type**\:  bool
                    
                    .. attribute:: source_address
                    
                    	Source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr>`
                    
                    .. attribute:: spt
                    
                    	Is this on the SPT ?
                    	**type**\:  bool
                    
                    .. attribute:: suppress_registers
                    
                    	When the Null register probe expires
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: vxlan
                    
                    	Is this VXLAN?
                    	**type**\:  bool
                    
                    .. attribute:: wildcard
                    
                    	WC \-Wildcard
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Topologies.Topology, self).__init__()

                        self.yang_name = "topology"
                        self.yang_parent_name = "topologies"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr), "orig-src-address" : ("orig_src_address", Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress), "proxy-address" : ("proxy_address", Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress), "rp-address" : ("rp_address", Pim.Standby.DefaultContext.Topologies.Topology.RpAddress), "rpf-neighbor" : ("rpf_neighbor", Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor), "rpf-root" : ("rpf_root", Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot), "secondary-rpf-neighbor" : ("secondary_rpf_neighbor", Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor), "source-address-xr" : ("source_address_xr", Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr)}
                        self._child_list_classes = {"outgoing-interface" : ("outgoing_interface", Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface)}

                        self.alive = YLeaf(YType.int32, "alive")

                        self.anycast_rp_match = YLeaf(YType.boolean, "anycast-rp-match")

                        self.anycast_rp_route_target = YLeaf(YType.str, "anycast-rp-route-target")

                        self.assume_alive = YLeaf(YType.boolean, "assume-alive")

                        self.bgp_join = YLeaf(YType.boolean, "bgp-join")

                        self.bgp_jp_time = YLeaf(YType.uint64, "bgp-jp-time")

                        self.connected = YLeaf(YType.boolean, "connected")

                        self.crossed_threshold = YLeaf(YType.boolean, "crossed-threshold")

                        self.customer_routing_type = YLeaf(YType.int32, "customer-routing-type")

                        self.data_mdt_addr_assigned = YLeaf(YType.boolean, "data-mdt-addr-assigned")

                        self.dont_check_connected = YLeaf(YType.boolean, "dont-check-connected")

                        self.expiry = YLeaf(YType.uint64, "expiry")

                        self.extranet_route = YLeaf(YType.boolean, "extranet-route")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.inherit_alive = YLeaf(YType.boolean, "inherit-alive")

                        self.inherit_spt = YLeaf(YType.boolean, "inherit-spt")

                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                        self.jp_status = YLeaf(YType.int32, "jp-status")

                        self.jp_timer = YLeaf(YType.int32, "jp-timer")

                        self.kat_state = YLeaf(YType.boolean, "kat-state")

                        self.last_hop = YLeaf(YType.boolean, "last-hop")

                        self.limit_reached = YLeaf(YType.boolean, "limit-reached")

                        self.low_memory = YLeaf(YType.boolean, "low-memory")

                        self.mofrr_active = YLeaf(YType.boolean, "mofrr-active")

                        self.mofrr_backup = YLeaf(YType.boolean, "mofrr-backup")

                        self.mofrr_enabled = YLeaf(YType.boolean, "mofrr-enabled")

                        self.mofrr_primary = YLeaf(YType.boolean, "mofrr-primary")

                        self.probe_alive = YLeaf(YType.boolean, "probe-alive")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.proxy = YLeaf(YType.boolean, "proxy")

                        self.really_alive = YLeaf(YType.boolean, "really-alive")

                        self.register_received = YLeaf(YType.boolean, "register-received")

                        self.register_received_timer = YLeaf(YType.int32, "register-received-timer")

                        self.remote_source = YLeaf(YType.boolean, "remote-source")

                        self.rib_mo_frr_enabled = YLeaf(YType.boolean, "rib-mo-frr-enabled")

                        self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                        self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_proxy_enabled = YLeaf(YType.boolean, "rpf-proxy-enabled")

                        self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                        self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.rpt = YLeaf(YType.int32, "rpt")

                        self.rpt_xr = YLeaf(YType.boolean, "rpt-xr")

                        self.sa_joined = YLeaf(YType.boolean, "sa-joined")

                        self.sa_received = YLeaf(YType.boolean, "sa-received")

                        self.sa_sent = YLeaf(YType.boolean, "sa-sent")

                        self.secondary_rpf_interface_name = YLeaf(YType.str, "secondary-rpf-interface-name")

                        self.sending_null_registers = YLeaf(YType.boolean, "sending-null-registers")

                        self.sending_registers = YLeaf(YType.boolean, "sending-registers")

                        self.signal_sources = YLeaf(YType.boolean, "signal-sources")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.spt = YLeaf(YType.boolean, "spt")

                        self.suppress_registers = YLeaf(YType.int32, "suppress-registers")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.vxlan = YLeaf(YType.boolean, "vxlan")

                        self.wildcard = YLeaf(YType.boolean, "wildcard")

                        self.group_address_xr = Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.orig_src_address = Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress()
                        self.orig_src_address.parent = self
                        self._children_name_map["orig_src_address"] = "orig-src-address"
                        self._children_yang_names.add("orig-src-address")

                        self.proxy_address = Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress()
                        self.proxy_address.parent = self
                        self._children_name_map["proxy_address"] = "proxy-address"
                        self._children_yang_names.add("proxy-address")

                        self.rp_address = Pim.Standby.DefaultContext.Topologies.Topology.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.rpf_neighbor = Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                        self.rpf_root = Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._children_yang_names.add("rpf-root")

                        self.secondary_rpf_neighbor = Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                        self.secondary_rpf_neighbor.parent = self
                        self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                        self._children_yang_names.add("secondary-rpf-neighbor")

                        self.source_address_xr = Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"
                        self._children_yang_names.add("source-address-xr")

                        self.outgoing_interface = YList(self)
                        self._segment_path = lambda: "topology"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology, ['alive', 'anycast_rp_match', 'anycast_rp_route_target', 'assume_alive', 'bgp_join', 'bgp_jp_time', 'connected', 'crossed_threshold', 'customer_routing_type', 'data_mdt_addr_assigned', 'dont_check_connected', 'expiry', 'extranet_route', 'group_address', 'inherit_alive', 'inherit_spt', 'is_via_lsm', 'jp_status', 'jp_timer', 'kat_state', 'last_hop', 'limit_reached', 'low_memory', 'mofrr_active', 'mofrr_backup', 'mofrr_enabled', 'mofrr_primary', 'probe_alive', 'protocol', 'proxy', 'really_alive', 'register_received', 'register_received_timer', 'remote_source', 'rib_mo_frr_enabled', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_proxy_enabled', 'rpf_safi', 'rpf_table_name', 'rpf_vrf_name', 'rpt', 'rpt_xr', 'sa_joined', 'sa_received', 'sa_sent', 'secondary_rpf_interface_name', 'sending_null_registers', 'sending_registers', 'signal_sources', 'source_address', 'spt', 'suppress_registers', 'uptime', 'vxlan', 'wildcard'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class OrigSrcAddress(Entity):
                        """
                        Orig Src Address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__init__()

                            self.yang_name = "orig-src-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "orig-src-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class OutgoingInterface(Entity):
                        """
                        Outgoing interface list
                        
                        .. attribute:: admin_boundary
                        
                        	Is this an administrative boundary ?
                        	**type**\:  bool
                        
                        .. attribute:: assert_state
                        
                        	Assert State
                        	**type**\:  bool
                        
                        .. attribute:: assert_timer
                        
                        	Assert Timer in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: assert_winner
                        
                        	Assert Winner
                        	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner>`
                        
                        .. attribute:: bgp_c_mcast_join
                        
                        	BGP C\-Mcast join
                        	**type**\:  bool
                        
                        .. attribute:: bgp_c_mcast_prune_delay_timer
                        
                        	BGP C\-MCAST Prune Suppression in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: data_mdt_join
                        
                        	Data MDT join
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	Expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: extranet_interface
                        
                        	Is this an Extranet Interface ?
                        	**type**\:  bool
                        
                        .. attribute:: forwarding_state
                        
                        	Forward or Prune
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: igmp_membership
                        
                        	IGMP membership
                        	**type**\:  bool
                        
                        .. attribute:: immediate_state
                        
                        	Immediate fwding state
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: internal_interest_info
                        
                        	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: internal_interest_information
                        
                        	Internal Interest. Replaces internal\-interest\-info
                        	**type**\:   :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                        
                        .. attribute:: jp_state
                        
                        	Join\-Prune State
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer (secs)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: local_mdt_join
                        
                        	Default MDT Join
                        	**type**\:  bool
                        
                        .. attribute:: local_members
                        
                        	Local Information. Deprecated \- use 'local\-members\-information' instead
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: local_members_information
                        
                        	Local Information. Replaces local\-members
                        	**type**\:   :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                        
                        .. attribute:: mdt_safi_join
                        
                        	MDT Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mldp_inband_mdt
                        
                        	MLDP Inband MDT interface
                        	**type**\:  bool
                        
                        .. attribute:: mldp_stale
                        
                        	OLE is stale
                        	**type**\:  bool
                        
                        .. attribute:: mvpn_safi_join
                        
                        	MVPN Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mvpnv6_safi_join
                        
                        	MVPN IPv6 Safi join
                        	**type**\:  bool
                        
                        .. attribute:: sa_prune
                        
                        	BGP SA Prune state
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vrf_name
                        
                        	VRF which physically owns
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface, self).__init__()

                            self.yang_name = "outgoing-interface"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"assert-winner" : ("assert_winner", Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner)}
                            self._child_list_classes = {}

                            self.admin_boundary = YLeaf(YType.boolean, "admin-boundary")

                            self.assert_state = YLeaf(YType.boolean, "assert-state")

                            self.assert_timer = YLeaf(YType.int32, "assert-timer")

                            self.bgp_c_mcast_join = YLeaf(YType.boolean, "bgp-c-mcast-join")

                            self.bgp_c_mcast_prune_delay_timer = YLeaf(YType.uint64, "bgp-c-mcast-prune-delay-timer")

                            self.data_mdt_join = YLeaf(YType.boolean, "data-mdt-join")

                            self.expiry = YLeaf(YType.uint64, "expiry")

                            self.extranet_interface = YLeaf(YType.boolean, "extranet-interface")

                            self.forwarding_state = YLeaf(YType.int32, "forwarding-state")

                            self.igmp_membership = YLeaf(YType.boolean, "igmp-membership")

                            self.immediate_state = YLeaf(YType.int32, "immediate-state")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.internal_interest_info = YLeaf(YType.int32, "internal-interest-info")

                            self.internal_interest_information = YLeaf(YType.enumeration, "internal-interest-information")

                            self.jp_state = YLeaf(YType.int32, "jp-state")

                            self.jp_timer = YLeaf(YType.int32, "jp-timer")

                            self.last_hop = YLeaf(YType.boolean, "last-hop")

                            self.local_mdt_join = YLeaf(YType.boolean, "local-mdt-join")

                            self.local_members = YLeaf(YType.int32, "local-members")

                            self.local_members_information = YLeaf(YType.enumeration, "local-members-information")

                            self.mdt_safi_join = YLeaf(YType.boolean, "mdt-safi-join")

                            self.mldp_inband_mdt = YLeaf(YType.boolean, "mldp-inband-mdt")

                            self.mldp_stale = YLeaf(YType.boolean, "mldp-stale")

                            self.mvpn_safi_join = YLeaf(YType.boolean, "mvpn-safi-join")

                            self.mvpnv6_safi_join = YLeaf(YType.boolean, "mvpnv6-safi-join")

                            self.sa_prune = YLeaf(YType.boolean, "sa-prune")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.assert_winner = Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                            self.assert_winner.parent = self
                            self._children_name_map["assert_winner"] = "assert-winner"
                            self._children_yang_names.add("assert-winner")
                            self._segment_path = lambda: "outgoing-interface"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface, ['admin_boundary', 'assert_state', 'assert_timer', 'bgp_c_mcast_join', 'bgp_c_mcast_prune_delay_timer', 'data_mdt_join', 'expiry', 'extranet_interface', 'forwarding_state', 'igmp_membership', 'immediate_state', 'interface_name', 'internal_interest_info', 'internal_interest_information', 'jp_state', 'jp_timer', 'last_hop', 'local_mdt_join', 'local_members', 'local_members_information', 'mdt_safi_join', 'mldp_inband_mdt', 'mldp_stale', 'mvpn_safi_join', 'mvpnv6_safi_join', 'sa_prune', 'uptime', 'vrf_name'], name, value)


                        class AssertWinner(Entity):
                            """
                            Assert Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                self.yang_name = "assert-winner"
                                self.yang_parent_name = "outgoing-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "assert-winner"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/outgoing-interface/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class ProxyAddress(Entity):
                        """
                        RPF Proxy address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress, self).__init__()

                            self.yang_name = "proxy-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "proxy-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address (If rpt)
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rpf-root"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SecondaryRpfNeighbor(Entity):
                        """
                        Secondary RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                            self.yang_name = "secondary-rpf-neighbor"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "secondary-rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class TopologyEntryFlagRouteCounts(Entity):
                """
                Route count for topology with entry flag set
                
                .. attribute:: topology_entry_flag_route_count
                
                	Route count for topology with entry flag set
                	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-entry-flag-route-counts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"topology-entry-flag-route-count" : ("topology_entry_flag_route_count", Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount)}

                    self.topology_entry_flag_route_count = YList(self)
                    self._segment_path = lambda: "topology-entry-flag-route-counts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts, [], name, value)


                class TopologyEntryFlagRouteCount(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: entry_flag  <key>
                    
                    	entry flag
                    	**type**\:   :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                        self.yang_name = "topology-entry-flag-route-count"
                        self.yang_parent_name = "topology-entry-flag-route-counts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.entry_flag = YLeaf(YType.enumeration, "entry-flag")

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                        self._segment_path = lambda: "topology-entry-flag-route-count" + "[entry-flag='" + self.entry_flag.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topology-entry-flag-route-counts/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, ['entry_flag', 'active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


            class TopologyInterfaceFlagRouteCounts(Entity):
                """
                Route count for topology with interface flag set
                
                .. attribute:: topology_interface_flag_route_count
                
                	Route count for topology with interface flag set
                	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-interface-flag-route-counts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"topology-interface-flag-route-count" : ("topology_interface_flag_route_count", Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount)}

                    self.topology_interface_flag_route_count = YList(self)
                    self._segment_path = lambda: "topology-interface-flag-route-counts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts, [], name, value)


                class TopologyInterfaceFlagRouteCount(Entity):
                    """
                    Route count for topology with interface flag
                    set
                    
                    .. attribute:: interface_flag  <key>
                    
                    	Interface flag
                    	**type**\:   :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                        self.yang_name = "topology-interface-flag-route-count"
                        self.yang_parent_name = "topology-interface-flag-route-counts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.interface_flag = YLeaf(YType.enumeration, "interface-flag")

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                        self._segment_path = lambda: "topology-interface-flag-route-count" + "[interface-flag='" + self.interface_flag.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topology-interface-flag-route-counts/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, ['interface_flag', 'active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


            class TopologyRouteCount(Entity):
                """
                Topology route count information from PIM
                topology table
                
                .. attribute:: active_group_ranges
                
                	No. of (\*,G/M) routes active in mrib
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_ranges
                
                	No. of (\*,G/M) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groute_count
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: sg_route_count
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sgr_route_count
                
                	No. of (S,G)RPT routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.TopologyRouteCount, self).__init__()

                    self.yang_name = "topology-route-count"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                    self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                    self.groute_count = YLeaf(YType.uint32, "groute-count")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                    self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                    self._segment_path = lambda: "topology-route-count"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.TopologyRouteCount, ['active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


            class TrafficCounters(Entity):
                """
                PIM message traffic counters
                
                .. attribute:: boundary_acl_rx_drop
                
                	Inc. JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_tx_drop
                
                	Out JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_error
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: format_error
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert
                
                	Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert_batched
                
                	Batched Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_bsr_message
                
                	Input BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_candidate_rp_advertisement
                
                	Input Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_data_register
                
                	Data Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_df_election
                
                	DF Election packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_ecmp_redirect
                
                	Input Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_hello
                
                	Hello packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_jp
                
                	Join Prune packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb_error
                
                	No IDB for intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_pim_error
                
                	PIM Disabled on intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_error
                
                	No VRF for idb error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_null_register
                
                	Null Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim_version_error
                
                	Invalid PIM version error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_register_stop
                
                	Register Stop packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: inputs
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_destination_packets
                
                	Control Packets with Invalid Destination
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_join_prunes
                
                	PIM invalid Join/Prunes received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_registers
                
                	PIM invalid registers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_local_source_address
                
                	Data MDT Join msgs dropped due to local source addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_idb
                
                	Data MDT Join msgs dropped due to idb missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_vrf
                
                	Data MDT Join msgs dropped due to vrf missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_null_local_address
                
                	Data MDT Join msgs dropped due to null local addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_bad_type
                
                	Data MDT TLV bad type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_received
                
                	Data MDT Join Msgs received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_sent
                
                	Data MDT Join Msgs sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_joins_drop_multiple_encapsulation
                
                	MDT Join msgs dropped due to multiple Encap limitation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_send_queue_full
                
                	Packets dropped since mdt send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_socket_error
                
                	MDT Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_invalid_lsm_identifier
                
                	 Invalid LSM ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_mdt_socket_connection
                
                	Packets dropped since no mdt socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_source_address
                
                	Packets dropped since no source address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: non_supported_packets
                
                	PIM non supported pckets
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert
                
                	Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert_batched
                
                	Batched Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_bsr_message
                
                	Output BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_candidate_rp_advertisement
                
                	Output Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_data_register
                
                	Data Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_df_election
                
                	DF Election packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_ecmp_redirect
                
                	Output Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello
                
                	Hello packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello_bytes
                
                	Output Hello Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_join_group
                
                	Output Join Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_prune_bytes
                
                	Output JP Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_jp
                
                	Join Prune packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_loop_error
                
                	Output on loopback error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_null_register
                
                	Null Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_prune_group
                
                	Output Prune Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_register_stop
                
                	Register Stop packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outputs
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_packman_error
                
                	Packets Dropped due to Pakman Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue
                
                	Packet queue state and statistics
                	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TrafficCounters.PacketQueue>`
                
                .. attribute:: packet_queue_last_clear
                
                	Time in seconds since the last clear of all packet queues stats
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: packet_read_socket_error
                
                	Packet Read Socket Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_standby
                
                	Packets Dropped due to Standby Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pakman_error
                
                	Pakman packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_queue_full
                
                	Packets dropped since send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_error
                
                	Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_packets_error
                
                	Packets received in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: truncated_pim_packets
                
                	Packets dropped due to truncated Joins or Prunes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"packet-queue" : ("packet_queue", Pim.Standby.DefaultContext.TrafficCounters.PacketQueue)}

                    self.boundary_acl_rx_drop = YLeaf(YType.uint32, "boundary-acl-rx-drop")

                    self.boundary_acl_tx_drop = YLeaf(YType.uint32, "boundary-acl-tx-drop")

                    self.checksum_error = YLeaf(YType.uint32, "checksum-error")

                    self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                    self.format_error = YLeaf(YType.uint32, "format-error")

                    self.input_assert = YLeaf(YType.uint32, "input-assert")

                    self.input_assert_batched = YLeaf(YType.uint32, "input-assert-batched")

                    self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                    self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                    self.input_data_register = YLeaf(YType.uint32, "input-data-register")

                    self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                    self.input_ecmp_redirect = YLeaf(YType.uint32, "input-ecmp-redirect")

                    self.input_hello = YLeaf(YType.uint32, "input-hello")

                    self.input_jp = YLeaf(YType.uint32, "input-jp")

                    self.input_no_idb_error = YLeaf(YType.uint32, "input-no-idb-error")

                    self.input_no_pim_error = YLeaf(YType.uint32, "input-no-pim-error")

                    self.input_no_vrf_error = YLeaf(YType.uint32, "input-no-vrf-error")

                    self.input_null_register = YLeaf(YType.uint32, "input-null-register")

                    self.input_pim_version_error = YLeaf(YType.uint32, "input-pim-version-error")

                    self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                    self.inputs = YLeaf(YType.uint32, "inputs")

                    self.invalid_destination_packets = YLeaf(YType.uint32, "invalid-destination-packets")

                    self.invalid_join_prunes = YLeaf(YType.uint32, "invalid-join-prunes")

                    self.invalid_registers = YLeaf(YType.uint32, "invalid-registers")

                    self.mdt_drop_local_source_address = YLeaf(YType.uint32, "mdt-drop-local-source-address")

                    self.mdt_drop_no_idb = YLeaf(YType.uint32, "mdt-drop-no-idb")

                    self.mdt_drop_no_vrf = YLeaf(YType.uint32, "mdt-drop-no-vrf")

                    self.mdt_drop_null_local_address = YLeaf(YType.uint32, "mdt-drop-null-local-address")

                    self.mdt_join_bad_type = YLeaf(YType.uint32, "mdt-join-bad-type")

                    self.mdt_join_tlv_received = YLeaf(YType.uint32, "mdt-join-tlv-received")

                    self.mdt_join_tlv_sent = YLeaf(YType.uint32, "mdt-join-tlv-sent")

                    self.mdt_joins_drop_multiple_encapsulation = YLeaf(YType.uint32, "mdt-joins-drop-multiple-encapsulation")

                    self.mdt_send_queue_full = YLeaf(YType.uint32, "mdt-send-queue-full")

                    self.mdt_socket_error = YLeaf(YType.uint32, "mdt-socket-error")

                    self.mldp_mdt_invalid_lsm_identifier = YLeaf(YType.uint32, "mldp-mdt-invalid-lsm-identifier")

                    self.no_mdt_socket_connection = YLeaf(YType.uint32, "no-mdt-socket-connection")

                    self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                    self.no_source_address = YLeaf(YType.uint32, "no-source-address")

                    self.non_supported_packets = YLeaf(YType.uint32, "non-supported-packets")

                    self.output_assert = YLeaf(YType.uint32, "output-assert")

                    self.output_assert_batched = YLeaf(YType.uint32, "output-assert-batched")

                    self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                    self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                    self.output_data_register = YLeaf(YType.uint32, "output-data-register")

                    self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                    self.output_ecmp_redirect = YLeaf(YType.uint32, "output-ecmp-redirect")

                    self.output_hello = YLeaf(YType.uint32, "output-hello")

                    self.output_hello_bytes = YLeaf(YType.uint32, "output-hello-bytes")

                    self.output_join_group = YLeaf(YType.uint32, "output-join-group")

                    self.output_join_prune_bytes = YLeaf(YType.uint32, "output-join-prune-bytes")

                    self.output_jp = YLeaf(YType.uint32, "output-jp")

                    self.output_loop_error = YLeaf(YType.uint32, "output-loop-error")

                    self.output_null_register = YLeaf(YType.uint32, "output-null-register")

                    self.output_prune_group = YLeaf(YType.uint32, "output-prune-group")

                    self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                    self.outputs = YLeaf(YType.uint32, "outputs")

                    self.packet_packman_error = YLeaf(YType.uint32, "packet-packman-error")

                    self.packet_queue_last_clear = YLeaf(YType.uint32, "packet-queue-last-clear")

                    self.packet_read_socket_error = YLeaf(YType.uint32, "packet-read-socket-error")

                    self.packets_standby = YLeaf(YType.uint32, "packets-standby")

                    self.pakman_error = YLeaf(YType.uint32, "pakman-error")

                    self.send_queue_full = YLeaf(YType.uint32, "send-queue-full")

                    self.socket_error = YLeaf(YType.uint32, "socket-error")

                    self.standby_packets_error = YLeaf(YType.uint32, "standby-packets-error")

                    self.truncated_pim_packets = YLeaf(YType.uint32, "truncated-pim-packets")

                    self.packet_queue = YList(self)
                    self._segment_path = lambda: "traffic-counters"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.TrafficCounters, ['boundary_acl_rx_drop', 'boundary_acl_tx_drop', 'checksum_error', 'elapsed_time', 'format_error', 'input_assert', 'input_assert_batched', 'input_bsr_message', 'input_candidate_rp_advertisement', 'input_data_register', 'input_df_election', 'input_ecmp_redirect', 'input_hello', 'input_jp', 'input_no_idb_error', 'input_no_pim_error', 'input_no_vrf_error', 'input_null_register', 'input_pim_version_error', 'input_register_stop', 'inputs', 'invalid_destination_packets', 'invalid_join_prunes', 'invalid_registers', 'mdt_drop_local_source_address', 'mdt_drop_no_idb', 'mdt_drop_no_vrf', 'mdt_drop_null_local_address', 'mdt_join_bad_type', 'mdt_join_tlv_received', 'mdt_join_tlv_sent', 'mdt_joins_drop_multiple_encapsulation', 'mdt_send_queue_full', 'mdt_socket_error', 'mldp_mdt_invalid_lsm_identifier', 'no_mdt_socket_connection', 'no_socket_connection', 'no_source_address', 'non_supported_packets', 'output_assert', 'output_assert_batched', 'output_bsr_message', 'output_candidate_rp_advertisement', 'output_data_register', 'output_df_election', 'output_ecmp_redirect', 'output_hello', 'output_hello_bytes', 'output_join_group', 'output_join_prune_bytes', 'output_jp', 'output_loop_error', 'output_null_register', 'output_prune_group', 'output_register_stop', 'outputs', 'packet_packman_error', 'packet_queue_last_clear', 'packet_read_socket_error', 'packets_standby', 'pakman_error', 'send_queue_full', 'socket_error', 'standby_packets_error', 'truncated_pim_packets'], name, value)


                class PacketQueue(Entity):
                    """
                    Packet queue state and statistics
                    
                    .. attribute:: packet_queue_priority
                    
                    	Priority of this packet queue
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_state
                    
                    	State of the queue
                    	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState>`
                    
                    .. attribute:: packet_queue_stats
                    
                    	Statistics about the queue
                    	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue, self).__init__()

                        self.yang_name = "packet-queue"
                        self.yang_parent_name = "traffic-counters"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"packet-queue-state" : ("packet_queue_state", Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState), "packet-queue-stats" : ("packet_queue_stats", Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats)}
                        self._child_list_classes = {}

                        self.packet_queue_priority = YLeaf(YType.uint32, "packet-queue-priority")

                        self.packet_queue_state = Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                        self.packet_queue_state.parent = self
                        self._children_name_map["packet_queue_state"] = "packet-queue-state"
                        self._children_yang_names.add("packet-queue-state")

                        self.packet_queue_stats = Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                        self.packet_queue_stats.parent = self
                        self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                        self._children_yang_names.add("packet-queue-stats")
                        self._segment_path = lambda: "packet-queue"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/traffic-counters/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue, ['packet_queue_priority'], name, value)


                    class PacketQueueState(Entity):
                        """
                        State of the queue
                        
                        .. attribute:: max_queue_size
                        
                        	Maximum size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_bytes
                        
                        	Size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_packets
                        
                        	Size of queue in number of packets
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                            self.yang_name = "packet-queue-state"
                            self.yang_parent_name = "packet-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.max_queue_size = YLeaf(YType.uint32, "max-queue-size")

                            self.queue_size_bytes = YLeaf(YType.uint32, "queue-size-bytes")

                            self.queue_size_packets = YLeaf(YType.uint32, "queue-size-packets")
                            self._segment_path = lambda: "packet-queue-state"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/traffic-counters/packet-queue/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, ['max_queue_size', 'queue_size_bytes', 'queue_size_packets'], name, value)


                    class PacketQueueStats(Entity):
                        """
                        Statistics about the queue
                        
                        .. attribute:: dequeued_packets
                        
                        	Total number of packets dequeued from this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: enqueued_packets
                        
                        	Total number of packets enqueued to this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_bytes
                        
                        	Highest number of bytes enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: high_water_mark_packets
                        
                        	Highest number of packets enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tail_drops
                        
                        	Number packets dropped from this queue due to max size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                            self.yang_name = "packet-queue-stats"
                            self.yang_parent_name = "packet-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.dequeued_packets = YLeaf(YType.uint32, "dequeued-packets")

                            self.enqueued_packets = YLeaf(YType.uint32, "enqueued-packets")

                            self.high_water_mark_bytes = YLeaf(YType.uint32, "high-water-mark-bytes")

                            self.high_water_mark_packets = YLeaf(YType.uint32, "high-water-mark-packets")

                            self.tail_drops = YLeaf(YType.uint32, "tail-drops")
                            self._segment_path = lambda: "packet-queue-stats"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/traffic-counters/packet-queue/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, ['dequeued_packets', 'enqueued_packets', 'high_water_mark_bytes', 'high_water_mark_packets', 'tail_drops'], name, value)


            class Tunnels(Entity):
                """
                Tunnels information that PIM has
                
                .. attribute:: tunnel
                
                	PIM tunnel information
                	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Tunnels, self).__init__()

                    self.yang_name = "tunnels"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"tunnel" : ("tunnel", Pim.Standby.DefaultContext.Tunnels.Tunnel)}

                    self.tunnel = YList(self)
                    self._segment_path = lambda: "tunnels"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.Tunnels, [], name, value)


                class Tunnel(Entity):
                    """
                    PIM tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Tunnels.Tunnel, self).__init__()

                        self.yang_name = "tunnel"
                        self.yang_parent_name = "tunnels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-netio" : ("group_address_netio", Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio), "rp-address" : ("rp_address", Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress), "source-address" : ("source_address", Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress), "source-address-netio" : ("source_address_netio", Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio)}
                        self._child_list_classes = {}

                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.group_address_netio = Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._children_yang_names.add("group-address-netio")

                        self.rp_address = Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                        self.source_address_netio = Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"
                        self._children_yang_names.add("source-address-netio")
                        self._segment_path = lambda: "tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/tunnels/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Tunnels.Tunnel, ['tunnel_name', 'vrf_name'], name, value)


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-netio"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address-netio"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


        class Process(Entity):
            """
            Process
            
            .. attribute:: issu
            
            	ISSU Information
            	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.Issu>`
            
            .. attribute:: nsf
            
            	PIM NSF information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.Nsr>`
            
            .. attribute:: summary
            
            	PIM Global Summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.Summary>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Pim.Standby.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"issu" : ("issu", Pim.Standby.Process.Issu), "nsf" : ("nsf", Pim.Standby.Process.Nsf), "nsr" : ("nsr", Pim.Standby.Process.Nsr), "summary" : ("summary", Pim.Standby.Process.Summary)}
                self._child_list_classes = {}

                self.issu = Pim.Standby.Process.Issu()
                self.issu.parent = self
                self._children_name_map["issu"] = "issu"
                self._children_yang_names.add("issu")

                self.nsf = Pim.Standby.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"
                self._children_yang_names.add("nsf")

                self.nsr = Pim.Standby.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
                self._children_yang_names.add("nsr")

                self.summary = Pim.Standby.Process.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")
                self._segment_path = lambda: "process"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/%s" % self._segment_path()


            class Issu(Entity):
                """
                ISSU Information
                
                .. attribute:: checkpoint_idt_timestamp
                
                	Time when Checkpoint IDT done
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: eoc_received_timestamp
                
                	Time when EOC was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: ihms_received_timestamp
                
                	Time when IHMS done was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: informationvalid
                
                	Is Information valid ?
                	**type**\:  bool
                
                .. attribute:: is_checkpoint_idt_done
                
                	Was Checkpoint IDT done ?
                	**type**\:  bool
                
                .. attribute:: is_eoc_received
                
                	Was EOC received ?
                	**type**\:  bool
                
                .. attribute:: is_ihms_done_received
                
                	Was IHMS done received ?
                	**type**\:  bool
                
                .. attribute:: is_nbr_sync_received
                
                	Was NBR Sync achieved ?
                	**type**\:  bool
                
                .. attribute:: is_rib_sync_received
                
                	Was RIB Sync received ?
                	**type**\:  bool
                
                .. attribute:: last_ha_role_notification_received
                
                	Time when last HA role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_phase_notification_received
                
                	Time when last ISSU Phase nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_role_notification_received
                
                	Time when last ISSU role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: nbr_sync_received_timestamp
                
                	Time when NBR Sync was achieved
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: phase_issu
                
                	ISSU Phase
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: rib_sync_received_timestamp
                
                	Time when RIB Sync was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: role_ha
                
                	HA role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: role_issu
                
                	ISSU role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.Process.Issu, self).__init__()

                    self.yang_name = "issu"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.checkpoint_idt_timestamp = YLeaf(YType.uint64, "checkpoint-idt-timestamp")

                    self.eoc_received_timestamp = YLeaf(YType.uint64, "eoc-received-timestamp")

                    self.ihms_received_timestamp = YLeaf(YType.uint64, "ihms-received-timestamp")

                    self.informationvalid = YLeaf(YType.boolean, "informationvalid")

                    self.is_checkpoint_idt_done = YLeaf(YType.boolean, "is-checkpoint-idt-done")

                    self.is_eoc_received = YLeaf(YType.boolean, "is-eoc-received")

                    self.is_ihms_done_received = YLeaf(YType.boolean, "is-ihms-done-received")

                    self.is_nbr_sync_received = YLeaf(YType.boolean, "is-nbr-sync-received")

                    self.is_rib_sync_received = YLeaf(YType.boolean, "is-rib-sync-received")

                    self.last_ha_role_notification_received = YLeaf(YType.uint64, "last-ha-role-notification-received")

                    self.last_issu_phase_notification_received = YLeaf(YType.uint64, "last-issu-phase-notification-received")

                    self.last_issu_role_notification_received = YLeaf(YType.uint64, "last-issu-role-notification-received")

                    self.nbr_sync_received_timestamp = YLeaf(YType.uint64, "nbr-sync-received-timestamp")

                    self.phase_issu = YLeaf(YType.int32, "phase-issu")

                    self.rib_sync_received_timestamp = YLeaf(YType.uint64, "rib-sync-received-timestamp")

                    self.role_ha = YLeaf(YType.int32, "role-ha")

                    self.role_issu = YLeaf(YType.int32, "role-issu")
                    self._segment_path = lambda: "issu"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.Process.Issu, ['checkpoint_idt_timestamp', 'eoc_received_timestamp', 'ihms_received_timestamp', 'informationvalid', 'is_checkpoint_idt_done', 'is_eoc_received', 'is_ihms_done_received', 'is_nbr_sync_received', 'is_rib_sync_received', 'last_ha_role_notification_received', 'last_issu_phase_notification_received', 'last_issu_role_notification_received', 'nbr_sync_received_timestamp', 'phase_issu', 'rib_sync_received_timestamp', 'role_ha', 'role_issu'], name, value)


            class Nsf(Entity):
                """
                PIM NSF information
                
                .. attribute:: configured_state
                
                	Is Multicast NSF Configured
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_sec
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_sec
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_sec
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: nsf_state
                
                	Are we currently in NSF
                	**type**\:  bool
                
                .. attribute:: nsf_time_left
                
                	Multicast NSF time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: nsf_timeout
                
                	Multicast NSF timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: waiting_membership
                
                	Waiting for IGMP/MLD
                	**type**\:  bool
                
                .. attribute:: waiting_timer
                
                	Waiting for NSF timer expiry
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.configured_state = YLeaf(YType.boolean, "configured-state")

                    self.last_icd_notif_recv = YLeaf(YType.int64, "last-icd-notif-recv")

                    self.last_icd_notif_recv_sec = YLeaf(YType.int32, "last-icd-notif-recv-sec")

                    self.last_nsf_off = YLeaf(YType.int64, "last-nsf-off")

                    self.last_nsf_off_sec = YLeaf(YType.int32, "last-nsf-off-sec")

                    self.last_nsf_on = YLeaf(YType.int64, "last-nsf-on")

                    self.last_nsf_on_sec = YLeaf(YType.int32, "last-nsf-on-sec")

                    self.nsf_state = YLeaf(YType.boolean, "nsf-state")

                    self.nsf_time_left = YLeaf(YType.uint32, "nsf-time-left")

                    self.nsf_timeout = YLeaf(YType.uint32, "nsf-timeout")

                    self.respawn_count = YLeaf(YType.uint32, "respawn-count")

                    self.waiting_membership = YLeaf(YType.boolean, "waiting-membership")

                    self.waiting_timer = YLeaf(YType.boolean, "waiting-timer")
                    self._segment_path = lambda: "nsf"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.Process.Nsf, ['configured_state', 'last_icd_notif_recv', 'last_icd_notif_recv_sec', 'last_nsf_off', 'last_nsf_off_sec', 'last_nsf_on', 'last_nsf_on_sec', 'nsf_state', 'nsf_time_left', 'nsf_timeout', 'respawn_count', 'waiting_membership', 'waiting_timer'], name, value)


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: count_connection_dn
                
                	No. of times connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_connection_up
                
                	No. of times connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_connection_dn
                
                	Time when connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_up
                
                	Time when connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: rmf_timer_expiry
                
                	Time for RMF timer to expire
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: rmf_timer_valid
                
                	Is RMF timer running ?
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.count_connection_dn = YLeaf(YType.uint32, "count-connection-dn")

                    self.count_connection_up = YLeaf(YType.uint32, "count-connection-up")

                    self.count_rmf_not_ready = YLeaf(YType.uint32, "count-rmf-not-ready")

                    self.count_rmf_ready = YLeaf(YType.uint32, "count-rmf-ready")

                    self.last_connection_dn = YLeaf(YType.uint64, "last-connection-dn")

                    self.last_connection_up = YLeaf(YType.uint64, "last-connection-up")

                    self.last_rmf_not_ready = YLeaf(YType.uint64, "last-rmf-not-ready")

                    self.last_rmf_ready = YLeaf(YType.uint64, "last-rmf-ready")

                    self.partner_connected = YLeaf(YType.boolean, "partner-connected")

                    self.rmf_notification_done = YLeaf(YType.boolean, "rmf-notification-done")

                    self.rmf_timer_expiry = YLeaf(YType.uint64, "rmf-timer-expiry")

                    self.rmf_timer_valid = YLeaf(YType.boolean, "rmf-timer-valid")

                    self.state = YLeaf(YType.uint8, "state")
                    self._segment_path = lambda: "nsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.Process.Nsr, ['count_connection_dn', 'count_connection_up', 'count_rmf_not_ready', 'count_rmf_ready', 'last_connection_dn', 'last_connection_up', 'last_rmf_not_ready', 'last_rmf_ready', 'partner_connected', 'rmf_notification_done', 'rmf_timer_expiry', 'rmf_timer_valid', 'state'], name, value)


            class Summary(Entity):
                """
                PIM Global Summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.Process.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                    self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                    self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                    self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                    self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                    self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                    self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                    self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                    self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                    self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                    self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                    self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                    self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                    self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                    self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                    self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                    self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                    self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                    self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                    self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                    self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                    self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                    self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                    self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                    self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                    self.register_count = YLeaf(YType.uint32, "register-count")

                    self.register_limit = YLeaf(YType.uint32, "register-limit")

                    self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                    self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                    self.route_count = YLeaf(YType.uint32, "route-count")

                    self.route_limit = YLeaf(YType.uint32, "route-limit")

                    self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                    self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                    self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                    self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                    self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                    self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                    self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.Process.Summary, ['bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_threshold', 'bsr_range_threshold', 'bsr_ranges_count', 'bsr_ranges_limit', 'global_auto_rp_ranges_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_threshold', 'global_bsr_ranges_count', 'global_bsr_ranges_limit', 'global_bsr_ranges_threshold', 'global_register_limit', 'is_bsr_ranges_threshold_reached', 'is_global_auto_rp_ranges_limit_reached', 'is_global_bsr_ranges_limit_reached', 'is_global_register_limit_reached', 'is_global_route_limit_reached', 'is_global_rxi_limit_reached', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'is_ranges_limit_reached', 'is_route_limit_reached', 'ranges_count', 'ranges_limit', 'ranges_threshold', 'register_count', 'register_limit', 'register_limit_reached', 'register_threshold', 'route_count', 'route_limit', 'route_low_water_mark', 'route_threshold', 'rxi_limit_reached', 'rxi_low_water_mark', 'topology_interface_state_count', 'topology_interface_state_limit', 'topology_interface_state_threshold'], name, value)


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF name
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Pim.Standby.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"vrf" : ("vrf", Pim.Standby.Vrfs.Vrf)}

                self.vrf = YList(self)
                self._segment_path = lambda: "vrfs"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Pim.Standby.Vrfs, [], name, value)


            class Vrf(Entity):
                """
                VRF name
                
                .. attribute:: vrf_name  <key>
                
                	VRF name 
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: auto_rp
                
                	PIM Auto\-RP information
                	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.AutoRp>`
                
                .. attribute:: bgp_afs
                
                	PIM BGP SAFI table
                	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs>`
                
                .. attribute:: bidir_df_states
                
                	Bidirectional PIM DF election state table
                	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfStates>`
                
                .. attribute:: bidir_df_winners
                
                	Bidirectional PIM DF election winner table
                	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfWinners>`
                
                .. attribute:: bsr
                
                	PIM BSR information
                	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr>`
                
                .. attribute:: context
                
                	PIM context information
                	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context>`
                
                .. attribute:: gre
                
                	GRE information
                	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre>`
                
                .. attribute:: group_map_rpfs
                
                	PIM group mapping information
                	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs>`
                
                .. attribute:: group_map_sources
                
                	PIM group\-mapping with source information
                	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources>`
                
                .. attribute:: ifrs_interfaces
                
                	PIM interfaces in forward reference store table
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: ifrs_summary
                
                	PIM interfaces in forward reference store summary
                	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsSummary>`
                
                .. attribute:: interface_old_formats
                
                	PIM interfaces in old format
                	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceOldFormats>`
                
                .. attribute:: interface_statistics
                
                	PIM interface statistics
                	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceStatistics>`
                
                .. attribute:: interfaces
                
                	PIM interfaces
                	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Interfaces>`
                
                .. attribute:: jp_statistics
                
                	PIM join prune statistics table
                	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.JpStatistics>`
                
                .. attribute:: mib_databases
                
                	PIM group database for mroute mibs table
                	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases>`
                
                .. attribute:: multicast_static_routes
                
                	PIM multicast static route table
                	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes>`
                
                .. attribute:: neighbor_old_formats
                
                	PIM neighbor table old format
                	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborOldFormats>`
                
                .. attribute:: neighbor_summaries
                
                	PIM neighbor summary table
                	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborSummaries>`
                
                .. attribute:: neighbors
                
                	PIM neighbor table
                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Neighbors>`
                
                .. attribute:: net_io_tunnels
                
                	Tunnel information that NETIO has 
                	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels>`
                
                .. attribute:: ranges
                
                	PIM range list information
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges>`
                
                .. attribute:: route_policy
                
                	PIM route policy
                	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy>`
                
                .. attribute:: rpf_redirect
                
                	PIM ECMP RPF\-redirect bundle
                	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect>`
                
                .. attribute:: rpf_summary
                
                	PIM RPF registration summary
                	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfSummary>`
                
                .. attribute:: safs
                
                	SAFI table and type
                	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs>`
                
                .. attribute:: summary
                
                	PIM summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Summary>`
                
                .. attribute:: table_contexts
                
                	PIM table context list
                	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TableContexts>`
                
                .. attribute:: topologies
                
                	PIM topology table
                	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies>`
                
                .. attribute:: topology_entry_flag_route_counts
                
                	Route count for topology with entry flag set
                	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts>`
                
                .. attribute:: topology_interface_flag_route_counts
                
                	Route count for topology with interface flag set
                	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts>`
                
                .. attribute:: topology_route_count
                
                	Topology route count information from PIM topology table
                	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyRouteCount>`
                
                .. attribute:: traffic_counters
                
                	PIM message traffic counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TrafficCounters>`
                
                .. attribute:: tunnels
                
                	Tunnels information that PIM has
                	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim.Standby.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"auto-rp" : ("auto_rp", Pim.Standby.Vrfs.Vrf.AutoRp), "bgp-afs" : ("bgp_afs", Pim.Standby.Vrfs.Vrf.BgpAfs), "bidir-df-states" : ("bidir_df_states", Pim.Standby.Vrfs.Vrf.BidirDfStates), "bidir-df-winners" : ("bidir_df_winners", Pim.Standby.Vrfs.Vrf.BidirDfWinners), "bsr" : ("bsr", Pim.Standby.Vrfs.Vrf.Bsr), "context" : ("context", Pim.Standby.Vrfs.Vrf.Context), "gre" : ("gre", Pim.Standby.Vrfs.Vrf.Gre), "group-map-rpfs" : ("group_map_rpfs", Pim.Standby.Vrfs.Vrf.GroupMapRpfs), "group-map-sources" : ("group_map_sources", Pim.Standby.Vrfs.Vrf.GroupMapSources), "ifrs-interfaces" : ("ifrs_interfaces", Pim.Standby.Vrfs.Vrf.IfrsInterfaces), "ifrs-summary" : ("ifrs_summary", Pim.Standby.Vrfs.Vrf.IfrsSummary), "interface-old-formats" : ("interface_old_formats", Pim.Standby.Vrfs.Vrf.InterfaceOldFormats), "interface-statistics" : ("interface_statistics", Pim.Standby.Vrfs.Vrf.InterfaceStatistics), "interfaces" : ("interfaces", Pim.Standby.Vrfs.Vrf.Interfaces), "jp-statistics" : ("jp_statistics", Pim.Standby.Vrfs.Vrf.JpStatistics), "mib-databases" : ("mib_databases", Pim.Standby.Vrfs.Vrf.MibDatabases), "multicast-static-routes" : ("multicast_static_routes", Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes), "neighbor-old-formats" : ("neighbor_old_formats", Pim.Standby.Vrfs.Vrf.NeighborOldFormats), "neighbor-summaries" : ("neighbor_summaries", Pim.Standby.Vrfs.Vrf.NeighborSummaries), "neighbors" : ("neighbors", Pim.Standby.Vrfs.Vrf.Neighbors), "net-io-tunnels" : ("net_io_tunnels", Pim.Standby.Vrfs.Vrf.NetIoTunnels), "ranges" : ("ranges", Pim.Standby.Vrfs.Vrf.Ranges), "route-policy" : ("route_policy", Pim.Standby.Vrfs.Vrf.RoutePolicy), "rpf-redirect" : ("rpf_redirect", Pim.Standby.Vrfs.Vrf.RpfRedirect), "rpf-summary" : ("rpf_summary", Pim.Standby.Vrfs.Vrf.RpfSummary), "safs" : ("safs", Pim.Standby.Vrfs.Vrf.Safs), "summary" : ("summary", Pim.Standby.Vrfs.Vrf.Summary), "table-contexts" : ("table_contexts", Pim.Standby.Vrfs.Vrf.TableContexts), "topologies" : ("topologies", Pim.Standby.Vrfs.Vrf.Topologies), "topology-entry-flag-route-counts" : ("topology_entry_flag_route_counts", Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts), "topology-interface-flag-route-counts" : ("topology_interface_flag_route_counts", Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts), "topology-route-count" : ("topology_route_count", Pim.Standby.Vrfs.Vrf.TopologyRouteCount), "traffic-counters" : ("traffic_counters", Pim.Standby.Vrfs.Vrf.TrafficCounters), "tunnels" : ("tunnels", Pim.Standby.Vrfs.Vrf.Tunnels)}
                    self._child_list_classes = {}

                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                    self.auto_rp = Pim.Standby.Vrfs.Vrf.AutoRp()
                    self.auto_rp.parent = self
                    self._children_name_map["auto_rp"] = "auto-rp"
                    self._children_yang_names.add("auto-rp")

                    self.bgp_afs = Pim.Standby.Vrfs.Vrf.BgpAfs()
                    self.bgp_afs.parent = self
                    self._children_name_map["bgp_afs"] = "bgp-afs"
                    self._children_yang_names.add("bgp-afs")

                    self.bidir_df_states = Pim.Standby.Vrfs.Vrf.BidirDfStates()
                    self.bidir_df_states.parent = self
                    self._children_name_map["bidir_df_states"] = "bidir-df-states"
                    self._children_yang_names.add("bidir-df-states")

                    self.bidir_df_winners = Pim.Standby.Vrfs.Vrf.BidirDfWinners()
                    self.bidir_df_winners.parent = self
                    self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                    self._children_yang_names.add("bidir-df-winners")

                    self.bsr = Pim.Standby.Vrfs.Vrf.Bsr()
                    self.bsr.parent = self
                    self._children_name_map["bsr"] = "bsr"
                    self._children_yang_names.add("bsr")

                    self.context = Pim.Standby.Vrfs.Vrf.Context()
                    self.context.parent = self
                    self._children_name_map["context"] = "context"
                    self._children_yang_names.add("context")

                    self.gre = Pim.Standby.Vrfs.Vrf.Gre()
                    self.gre.parent = self
                    self._children_name_map["gre"] = "gre"
                    self._children_yang_names.add("gre")

                    self.group_map_rpfs = Pim.Standby.Vrfs.Vrf.GroupMapRpfs()
                    self.group_map_rpfs.parent = self
                    self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                    self._children_yang_names.add("group-map-rpfs")

                    self.group_map_sources = Pim.Standby.Vrfs.Vrf.GroupMapSources()
                    self.group_map_sources.parent = self
                    self._children_name_map["group_map_sources"] = "group-map-sources"
                    self._children_yang_names.add("group-map-sources")

                    self.ifrs_interfaces = Pim.Standby.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    self._children_yang_names.add("ifrs-interfaces")

                    self.ifrs_summary = Pim.Standby.Vrfs.Vrf.IfrsSummary()
                    self.ifrs_summary.parent = self
                    self._children_name_map["ifrs_summary"] = "ifrs-summary"
                    self._children_yang_names.add("ifrs-summary")

                    self.interface_old_formats = Pim.Standby.Vrfs.Vrf.InterfaceOldFormats()
                    self.interface_old_formats.parent = self
                    self._children_name_map["interface_old_formats"] = "interface-old-formats"
                    self._children_yang_names.add("interface-old-formats")

                    self.interface_statistics = Pim.Standby.Vrfs.Vrf.InterfaceStatistics()
                    self.interface_statistics.parent = self
                    self._children_name_map["interface_statistics"] = "interface-statistics"
                    self._children_yang_names.add("interface-statistics")

                    self.interfaces = Pim.Standby.Vrfs.Vrf.Interfaces()
                    self.interfaces.parent = self
                    self._children_name_map["interfaces"] = "interfaces"
                    self._children_yang_names.add("interfaces")

                    self.jp_statistics = Pim.Standby.Vrfs.Vrf.JpStatistics()
                    self.jp_statistics.parent = self
                    self._children_name_map["jp_statistics"] = "jp-statistics"
                    self._children_yang_names.add("jp-statistics")

                    self.mib_databases = Pim.Standby.Vrfs.Vrf.MibDatabases()
                    self.mib_databases.parent = self
                    self._children_name_map["mib_databases"] = "mib-databases"
                    self._children_yang_names.add("mib-databases")

                    self.multicast_static_routes = Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes()
                    self.multicast_static_routes.parent = self
                    self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                    self._children_yang_names.add("multicast-static-routes")

                    self.neighbor_old_formats = Pim.Standby.Vrfs.Vrf.NeighborOldFormats()
                    self.neighbor_old_formats.parent = self
                    self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                    self._children_yang_names.add("neighbor-old-formats")

                    self.neighbor_summaries = Pim.Standby.Vrfs.Vrf.NeighborSummaries()
                    self.neighbor_summaries.parent = self
                    self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                    self._children_yang_names.add("neighbor-summaries")

                    self.neighbors = Pim.Standby.Vrfs.Vrf.Neighbors()
                    self.neighbors.parent = self
                    self._children_name_map["neighbors"] = "neighbors"
                    self._children_yang_names.add("neighbors")

                    self.net_io_tunnels = Pim.Standby.Vrfs.Vrf.NetIoTunnels()
                    self.net_io_tunnels.parent = self
                    self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                    self._children_yang_names.add("net-io-tunnels")

                    self.ranges = Pim.Standby.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"
                    self._children_yang_names.add("ranges")

                    self.route_policy = Pim.Standby.Vrfs.Vrf.RoutePolicy()
                    self.route_policy.parent = self
                    self._children_name_map["route_policy"] = "route-policy"
                    self._children_yang_names.add("route-policy")

                    self.rpf_redirect = Pim.Standby.Vrfs.Vrf.RpfRedirect()
                    self.rpf_redirect.parent = self
                    self._children_name_map["rpf_redirect"] = "rpf-redirect"
                    self._children_yang_names.add("rpf-redirect")

                    self.rpf_summary = Pim.Standby.Vrfs.Vrf.RpfSummary()
                    self.rpf_summary.parent = self
                    self._children_name_map["rpf_summary"] = "rpf-summary"
                    self._children_yang_names.add("rpf-summary")

                    self.safs = Pim.Standby.Vrfs.Vrf.Safs()
                    self.safs.parent = self
                    self._children_name_map["safs"] = "safs"
                    self._children_yang_names.add("safs")

                    self.summary = Pim.Standby.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.table_contexts = Pim.Standby.Vrfs.Vrf.TableContexts()
                    self.table_contexts.parent = self
                    self._children_name_map["table_contexts"] = "table-contexts"
                    self._children_yang_names.add("table-contexts")

                    self.topologies = Pim.Standby.Vrfs.Vrf.Topologies()
                    self.topologies.parent = self
                    self._children_name_map["topologies"] = "topologies"
                    self._children_yang_names.add("topologies")

                    self.topology_entry_flag_route_counts = Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                    self.topology_entry_flag_route_counts.parent = self
                    self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                    self._children_yang_names.add("topology-entry-flag-route-counts")

                    self.topology_interface_flag_route_counts = Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                    self.topology_interface_flag_route_counts.parent = self
                    self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                    self._children_yang_names.add("topology-interface-flag-route-counts")

                    self.topology_route_count = Pim.Standby.Vrfs.Vrf.TopologyRouteCount()
                    self.topology_route_count.parent = self
                    self._children_name_map["topology_route_count"] = "topology-route-count"
                    self._children_yang_names.add("topology-route-count")

                    self.traffic_counters = Pim.Standby.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"
                    self._children_yang_names.add("traffic-counters")

                    self.tunnels = Pim.Standby.Vrfs.Vrf.Tunnels()
                    self.tunnels.parent = self
                    self._children_name_map["tunnels"] = "tunnels"
                    self._children_yang_names.add("tunnels")
                    self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/vrfs/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.Vrfs.Vrf, ['vrf_name'], name, value)


                class AutoRp(Entity):
                    """
                    PIM Auto\-RP information
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.AutoRp, self).__init__()

                        self.yang_name = "auto-rp"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self._segment_path = lambda: "auto-rp"


                class BgpAfs(Entity):
                    """
                    PIM BGP SAFI table
                    
                    .. attribute:: bgp_af
                    
                    	PIM BGP SAFI information
                    	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.BgpAfs, self).__init__()

                        self.yang_name = "bgp-afs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"bgp-af" : ("bgp_af", Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf)}

                        self.bgp_af = YList(self)
                        self._segment_path = lambda: "bgp-afs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.BgpAfs, [], name, value)


                    class BgpAf(Entity):
                        """
                        PIM BGP SAFI information
                        
                        .. attribute:: extranet_path_count
                        
                        	Count of dependent extranet paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group
                        
                        	Group address
                        	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group>`
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: is_bgp_added
                        
                        	SAFI learnt from BGP
                        	**type**\:  bool
                        
                        .. attribute:: next_hop
                        
                        	Next hop address
                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop>`
                        
                        .. attribute:: route_distinguisher
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**length:** 0..256
                        
                        .. attribute:: source
                        
                        	Source address
                        	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf, self).__init__()

                            self.yang_name = "bgp-af"
                            self.yang_parent_name = "bgp-afs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group" : ("group", Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group), "next-hop" : ("next_hop", Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop), "source" : ("source", Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source)}
                            self._child_list_classes = {}

                            self.extranet_path_count = YLeaf(YType.uint32, "extranet-path-count")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.is_bgp_added = YLeaf(YType.boolean, "is-bgp-added")

                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group = Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                            self.group.parent = self
                            self._children_name_map["group"] = "group"
                            self._children_yang_names.add("group")

                            self.next_hop = Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"
                            self._children_yang_names.add("next-hop")

                            self.source = Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._children_yang_names.add("source")
                            self._segment_path = lambda: "bgp-af"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf, ['extranet_path_count', 'group_address', 'is_bgp_added', 'route_distinguisher', 'source_address'], name, value)


                        class Group(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__init__()

                                self.yang_name = "group"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class NextHop(Entity):
                            """
                            Next hop address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "next-hop"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Source(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class BidirDfStates(Entity):
                    """
                    Bidirectional PIM DF election state table
                    
                    .. attribute:: bidir_df_state
                    
                    	Bidirectional PIM DF Election Table Entry
                    	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.BidirDfStates, self).__init__()

                        self.yang_name = "bidir-df-states"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"bidir-df-state" : ("bidir_df_state", Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState)}

                        self.bidir_df_state = YList(self)
                        self._segment_path = lambda: "bidir-df-states"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.BidirDfStates, [], name, value)


                    class BidirDfState(Entity):
                        """
                        Bidirectional PIM DF Election Table Entry
                        
                        .. attribute:: election_state
                        
                        	DF Election State
                        	**type**\:  str
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: our_metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: our_metric_preference
                        
                        	MetricPreference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr>`
                        
                        .. attribute:: time_nano_seconds
                        
                        	Timer expires (nseconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: time_seconds
                        
                        	Timer expires (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__init__()

                            self.yang_name = "bidir-df-state"
                            self.yang_parent_name = "bidir-df-states"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"rp-address-xr" : ("rp_address_xr", Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr)}
                            self._child_list_classes = {}

                            self.election_state = YLeaf(YType.str, "election-state")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.our_metric = YLeaf(YType.uint32, "our-metric")

                            self.our_metric_preference = YLeaf(YType.uint32, "our-metric-preference")

                            self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.time_nano_seconds = YLeaf(YType.uint64, "time-nano-seconds")

                            self.time_seconds = YLeaf(YType.uint64, "time-seconds")

                            self.rp_address_xr = Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")
                            self._segment_path = lambda: "bidir-df-state"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState, ['election_state', 'interface_name', 'our_metric', 'our_metric_preference', 'pim_interface_name', 'rp_address', 'time_nano_seconds', 'time_seconds'], name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class BidirDfWinners(Entity):
                    """
                    Bidirectional PIM DF election winner table
                    
                    .. attribute:: bidir_df_winner
                    
                    	Bidirectional PIM DF election table entry
                    	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.BidirDfWinners, self).__init__()

                        self.yang_name = "bidir-df-winners"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"bidir-df-winner" : ("bidir_df_winner", Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner)}

                        self.bidir_df_winner = YList(self)
                        self._segment_path = lambda: "bidir-df-winners"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.BidirDfWinners, [], name, value)


                    class BidirDfWinner(Entity):
                        """
                        Bidirectional PIM DF election table entry
                        
                        .. attribute:: are_we_df
                        
                        	Are we DF
                        	**type**\:  bool
                        
                        .. attribute:: df_winner
                        
                        	DF Winner
                        	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner>`
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                        
                        .. attribute:: rp_lan
                        
                        	Is this the RP LAN
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__init__()

                            self.yang_name = "bidir-df-winner"
                            self.yang_parent_name = "bidir-df-winners"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"df-winner" : ("df_winner", Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner), "rp-address-xr" : ("rp_address_xr", Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr)}
                            self._child_list_classes = {}

                            self.are_we_df = YLeaf(YType.boolean, "are-we-df")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                            self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_lan = YLeaf(YType.boolean, "rp-lan")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.df_winner = Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                            self.df_winner.parent = self
                            self._children_name_map["df_winner"] = "df-winner"
                            self._children_yang_names.add("df-winner")

                            self.rp_address_xr = Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")
                            self._segment_path = lambda: "bidir-df-winner"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, ['are_we_df', 'interface_name', 'metric', 'metric_preference', 'pim_interface_name', 'rp_address', 'rp_lan', 'uptime'], name, value)


                        class DfWinner(Entity):
                            """
                            DF Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                                self.yang_name = "df-winner"
                                self.yang_parent_name = "bidir-df-winner"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "df-winner"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-winner"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Bsr(Entity):
                    """
                    PIM BSR information
                    
                    .. attribute:: bsr_elections
                    
                    	PIM BSR election state
                    	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.BsrElections>`
                    
                    .. attribute:: candidate_rps
                    
                    	PIM candidate\-RP
                    	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps>`
                    
                    .. attribute:: rp_caches
                    
                    	PIM BSR RP cache table
                    	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Bsr, self).__init__()

                        self.yang_name = "bsr"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"bsr-elections" : ("bsr_elections", Pim.Standby.Vrfs.Vrf.Bsr.BsrElections), "candidate-rps" : ("candidate_rps", Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps), "rp-caches" : ("rp_caches", Pim.Standby.Vrfs.Vrf.Bsr.RpCaches)}
                        self._child_list_classes = {}

                        self.bsr_elections = Pim.Standby.Vrfs.Vrf.Bsr.BsrElections()
                        self.bsr_elections.parent = self
                        self._children_name_map["bsr_elections"] = "bsr-elections"
                        self._children_yang_names.add("bsr-elections")

                        self.candidate_rps = Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps()
                        self.candidate_rps.parent = self
                        self._children_name_map["candidate_rps"] = "candidate-rps"
                        self._children_yang_names.add("candidate-rps")

                        self.rp_caches = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches()
                        self.rp_caches.parent = self
                        self._children_name_map["rp_caches"] = "rp-caches"
                        self._children_yang_names.add("rp-caches")
                        self._segment_path = lambda: "bsr"


                    class BsrElections(Entity):
                        """
                        PIM BSR election state
                        
                        .. attribute:: bsr_election
                        
                        	PIM BSR information
                        	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections, self).__init__()

                            self.yang_name = "bsr-elections"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"bsr-election" : ("bsr_election", Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection)}

                            self.bsr_election = YList(self)
                            self._segment_path = lambda: "bsr-elections"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections, [], name, value)


                        class BsrElection(Entity):
                            """
                            PIM BSR information
                            
                            .. attribute:: pim_scope  <key>
                            
                            	BSR information
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: bootstrap_timeout
                            
                            	Bootstrap Timeout
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_address
                            
                            	BSR address
                            	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress>`
                            
                            .. attribute:: bsr_election_state
                            
                            	BSR Election State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_mask_length
                            
                            	Hash Function Mask Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_priority
                            
                            	BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_scope
                            
                            	BSR Scope
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_up_time
                            
                            	BSR Uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_address
                            
                            	C\-BSR address
                            	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                            
                            .. attribute:: candidate_bsr_flag
                            
                            	BSR Candidate Config Flag
                            	**type**\:  bool
                            
                            .. attribute:: candidate_bsr_mask_length
                            
                            	C\-BSR Hash Func. Mask Len
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_priority
                            
                            	C\-BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_state
                            
                            	BSR Candidate State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__init__()

                                self.yang_name = "bsr-election"
                                self.yang_parent_name = "bsr-elections"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"bsr-address" : ("bsr_address", Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress), "candidate-bsr-address" : ("candidate_bsr_address", Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress)}
                                self._child_list_classes = {}

                                self.pim_scope = YLeaf(YType.int32, "pim-scope")

                                self.bootstrap_timeout = YLeaf(YType.uint16, "bootstrap-timeout")

                                self.bsr_election_state = YLeaf(YType.uint32, "bsr-election-state")

                                self.bsr_mask_length = YLeaf(YType.uint8, "bsr-mask-length")

                                self.bsr_priority = YLeaf(YType.uint8, "bsr-priority")

                                self.bsr_scope = YLeaf(YType.uint16, "bsr-scope")

                                self.bsr_up_time = YLeaf(YType.uint16, "bsr-up-time")

                                self.candidate_bsr_flag = YLeaf(YType.boolean, "candidate-bsr-flag")

                                self.candidate_bsr_mask_length = YLeaf(YType.uint8, "candidate-bsr-mask-length")

                                self.candidate_bsr_priority = YLeaf(YType.uint8, "candidate-bsr-priority")

                                self.candidate_bsr_state = YLeaf(YType.uint32, "candidate-bsr-state")

                                self.bsr_address = Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                self.bsr_address.parent = self
                                self._children_name_map["bsr_address"] = "bsr-address"
                                self._children_yang_names.add("bsr-address")

                                self.candidate_bsr_address = Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                self.candidate_bsr_address.parent = self
                                self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                self._children_yang_names.add("candidate-bsr-address")
                                self._segment_path = lambda: "bsr-election" + "[pim-scope='" + self.pim_scope.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection, ['pim_scope', 'bootstrap_timeout', 'bsr_election_state', 'bsr_mask_length', 'bsr_priority', 'bsr_scope', 'bsr_up_time', 'candidate_bsr_flag', 'candidate_bsr_mask_length', 'candidate_bsr_priority', 'candidate_bsr_state'], name, value)


                            class BsrAddress(Entity):
                                """
                                BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                    self.yang_name = "bsr-address"
                                    self.yang_parent_name = "bsr-election"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "bsr-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class CandidateBsrAddress(Entity):
                                """
                                C\-BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                    self.yang_name = "candidate-bsr-address"
                                    self.yang_parent_name = "bsr-election"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "candidate-bsr-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class CandidateRps(Entity):
                        """
                        PIM candidate\-RP
                        
                        .. attribute:: candidate_rp
                        
                        	PIM BSR candidate RP information
                        	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps, self).__init__()

                            self.yang_name = "candidate-rps"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"candidate-rp" : ("candidate_rp", Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp)}

                            self.candidate_rp = YList(self)
                            self._segment_path = lambda: "candidate-rps"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps, [], name, value)


                        class CandidateRp(Entity):
                            """
                            PIM BSR candidate RP information
                            
                            .. attribute:: rp_address  <key>
                            
                            	Candidate\-RP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp
                            
                            	Cand\-RP Address
                            	**type**\:   :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp>`
                            
                            .. attribute:: candidate_rp_advance_interval
                            
                            	Cand\-RP Adv Interval in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: candidate_rp_scope
                            
                            	Cand\-RP Scope
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: candidate_rp_uptime
                            
                            	Cand\-RP uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_access
                            
                            	Group Ranges Using this Cand\-RP
                            	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                            
                            .. attribute:: crp_holdtime
                            
                            	Cand\-RP Holdtime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_priority
                            
                            	Cand\-RP Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rps"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"candidate-rp" : ("candidate_rp", Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp)}
                                self._child_list_classes = {"crp-access" : ("crp_access", Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess)}

                                self.rp_address = YLeaf(YType.str, "rp-address")

                                self.acl_name = YLeaf(YType.str, "acl-name")

                                self.candidate_rp_advance_interval = YLeaf(YType.uint16, "candidate-rp-advance-interval")

                                self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                                self.candidate_rp_scope = YLeaf(YType.int32, "candidate-rp-scope")

                                self.candidate_rp_uptime = YLeaf(YType.uint16, "candidate-rp-uptime")

                                self.crp_holdtime = YLeaf(YType.uint16, "crp-holdtime")

                                self.crp_priority = YLeaf(YType.uint8, "crp-priority")

                                self.candidate_rp = Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp()
                                self.candidate_rp.parent = self
                                self._children_name_map["candidate_rp"] = "candidate-rp"
                                self._children_yang_names.add("candidate-rp")

                                self.crp_access = YList(self)
                                self._segment_path = lambda: "candidate-rp" + "[rp-address='" + self.rp_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, ['rp_address', 'acl_name', 'candidate_rp_advance_interval', 'candidate_rp_mode', 'candidate_rp_scope', 'candidate_rp_uptime', 'crp_holdtime', 'crp_priority'], name, value)


                            class CandidateRp(Entity):
                                """
                                Cand\-RP Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__init__()

                                    self.yang_name = "candidate-rp"
                                    self.yang_parent_name = "candidate-rp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "candidate-rp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class CrpAccess(Entity):
                                """
                                Group Ranges Using this Cand\-RP
                                
                                .. attribute:: acl_name
                                
                                	Group Access\-List Name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: candidate_rp_mode
                                
                                	Cand\-RP Mode
                                	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                    self.yang_name = "crp-access"
                                    self.yang_parent_name = "candidate-rp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.acl_name = YLeaf(YType.str, "acl-name")

                                    self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")
                                    self._segment_path = lambda: "crp-access"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, ['acl_name', 'candidate_rp_mode'], name, value)


                    class RpCaches(Entity):
                        """
                        PIM BSR RP cache table
                        
                        .. attribute:: rp_cache
                        
                        	PIM BSR RP cache
                        	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches, self).__init__()

                            self.yang_name = "rp-caches"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"rp-cache" : ("rp_cache", Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache)}

                            self.rp_cache = YList(self)
                            self._segment_path = lambda: "rp-caches"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches, [], name, value)


                        class RpCache(Entity):
                            """
                            PIM BSR RP cache
                            
                            .. attribute:: group_prefix  <key>
                            
                            	Group prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: candidate_rp_group_count
                            
                            	C\-RP count for this Prefix
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: candidate_rp_list
                            
                            	C\-RP list for this prefix
                            	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList>`
                            
                            .. attribute:: group_prefix_length
                            
                            	Group Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_prefix_xr
                            
                            	Group Prefix
                            	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__init__()

                                self.yang_name = "rp-cache"
                                self.yang_parent_name = "rp-caches"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"candidate-rp-list" : ("candidate_rp_list", Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList), "group-prefix-xr" : ("group_prefix_xr", Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr)}
                                self._child_list_classes = {}

                                self.group_prefix = YLeaf(YType.str, "group-prefix")

                                self.candidate_rp_group_count = YLeaf(YType.uint32, "candidate-rp-group-count")

                                self.group_prefix_length = YLeaf(YType.uint32, "group-prefix-length")

                                self.candidate_rp_list = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                self.candidate_rp_list.parent = self
                                self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                self._children_yang_names.add("candidate-rp-list")

                                self.group_prefix_xr = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                self.group_prefix_xr.parent = self
                                self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                                self._children_yang_names.add("group-prefix-xr")
                                self._segment_path = lambda: "rp-cache" + "[group-prefix='" + self.group_prefix.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache, ['group_prefix', 'candidate_rp_group_count', 'group_prefix_length'], name, value)


                            class CandidateRpList(Entity):
                                """
                                C\-RP list for this prefix
                                
                                .. attribute:: pim_bsr_crp_bag
                                
                                	pim bsr crp bag
                                	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                    self.yang_name = "candidate-rp-list"
                                    self.yang_parent_name = "rp-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"pim-bsr-crp-bag" : ("pim_bsr_crp_bag", Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag)}

                                    self.pim_bsr_crp_bag = YList(self)
                                    self._segment_path = lambda: "candidate-rp-list"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, [], name, value)


                                class PimBsrCrpBag(Entity):
                                    """
                                    pim bsr crp bag
                                    
                                    .. attribute:: candidate_rp_address
                                    
                                    	C\-RP address
                                    	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                    
                                    .. attribute:: candidate_rp_expires
                                    
                                    	C\-RP Expires
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_holdtime
                                    
                                    	C\-RP Holdtime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_priority
                                    
                                    	C\-RP Priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: candidate_rp_up_time
                                    
                                    	C\-RP Uptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protocol
                                    
                                    	PIM Protocol
                                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                        self.yang_name = "pim-bsr-crp-bag"
                                        self.yang_parent_name = "candidate-rp-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"candidate-rp-address" : ("candidate_rp_address", Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress)}
                                        self._child_list_classes = {}

                                        self.candidate_rp_expires = YLeaf(YType.uint16, "candidate-rp-expires")

                                        self.candidate_rp_holdtime = YLeaf(YType.uint16, "candidate-rp-holdtime")

                                        self.candidate_rp_priority = YLeaf(YType.uint8, "candidate-rp-priority")

                                        self.candidate_rp_up_time = YLeaf(YType.uint16, "candidate-rp-up-time")

                                        self.protocol = YLeaf(YType.enumeration, "protocol")

                                        self.candidate_rp_address = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                        self.candidate_rp_address.parent = self
                                        self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                        self._children_yang_names.add("candidate-rp-address")
                                        self._segment_path = lambda: "pim-bsr-crp-bag"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, ['candidate_rp_expires', 'candidate_rp_holdtime', 'candidate_rp_priority', 'candidate_rp_up_time', 'protocol'], name, value)


                                    class CandidateRpAddress(Entity):
                                        """
                                        C\-RP address
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                            self.yang_name = "candidate-rp-address"
                                            self.yang_parent_name = "pim-bsr-crp-bag"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                            self._segment_path = lambda: "candidate-rp-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class GroupPrefixXr(Entity):
                                """
                                Group Prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                    self.yang_name = "group-prefix-xr"
                                    self.yang_parent_name = "rp-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-prefix-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Context(Entity):
                    """
                    PIM context information
                    
                    .. attribute:: active_table_count
                    
                    	Number of active Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: allow_rp_configured
                    
                    	Allow RP Configured
                    	**type**\:  bool
                    
                    .. attribute:: allow_rp_group_list
                    
                    	Allow RP Group\-List ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: allow_rp_rp_list
                    
                    	Allow RP RP\-list ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: anycast_rp_configured
                    
                    	Anycast\-RP config
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_policy_name
                    
                    	Anycast\-RP Policy Name
                    	**type**\:  str
                    
                    .. attribute:: anycast_rp_range
                    
                    	Anycast\-RP Ranges
                    	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange>`
                    
                    .. attribute:: bgp_auto_discovery_configured
                    
                    	BGP Auto\-Discovery configured
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery_type
                    
                    	BGP Auto Discovery Type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_i_pmsi_added
                    
                    	BGP I\-PMSI Added
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_address
                    
                    	BGP remote interface address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_remote_interface
                    
                    	BGP remote interface handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: bgp_remote_interface_name
                    
                    	BGP remote interface name
                    	**type**\:  str
                    
                    .. attribute:: bgp_remote_on
                    
                    	BGP remote interface status
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_state
                    
                    	BGP remote interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_source_active_announce
                    
                    	Send BGP Source\-Active Announcements
                    	**type**\:  bool
                    
                    .. attribute:: export_route_target
                    
                    	Export Route Targets
                    	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget>`
                    
                    .. attribute:: gin_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: gin_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: gin_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: import_route_target
                    
                    	Import Route Targets
                    	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget>`
                    
                    .. attribute:: in_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: in_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: in_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_signaling_local_enabled
                    
                    	Inband signaling Local enabled
                    	**type**\:  bool
                    
                    .. attribute:: in_band_signaling_remote_enabled
                    
                    	Inband signaling Remote enabled
                    	**type**\:  bool
                    
                    .. attribute:: inter_autonomous_system_enabled
                    
                    	Inter\-AS Enabled
                    	**type**\:  bool
                    
                    .. attribute:: ir_maximum_mdt_aggregation
                    
                    	IR MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_announce_interval
                    
                    	IR Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_switchover_interval
                    
                    	IR Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_interface
                    
                    	IRMDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: ir_mdt_mtu
                    
                    	IRMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_name
                    
                    	IR MDT Name
                    	**type**\:  str
                    
                    .. attribute:: ir_mdt_rpf_identifier
                    
                    	IR RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_tail_label
                    
                    	IR Tail Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active
                    	**type**\:  bool
                    
                    .. attribute:: is_active_ital
                    
                    	Active ITAL
                    	**type**\:  bool
                    
                    .. attribute:: is_all_interface_disable_operation
                    
                    	PIM all interface disable operation
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_enabled
                    
                    	Auto RP Listen Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_sock_add
                    
                    	Auto RP listen sock add
                    	**type**\:  bool
                    
                    .. attribute:: is_create_gin_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_in_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_ir_mdt_interface
                    
                    	Create IR MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mdt_interface
                    
                    	Create MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mldp_mdt_interface
                    
                    	Create MLDP MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_rsvp_te_mdt_interface
                    
                    	Create RSVP\-TE MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_default_granges
                    
                    	Default granges
                    	**type**\:  bool
                    
                    .. attribute:: is_gin_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_in_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_ir_mdt_owner
                    
                    	IR MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_added
                    
                    	VRF LPTS filter added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_m_host_publish_pending
                    
                    	Publish pending for MHost Default interface
                    	**type**\:  bool
                    
                    .. attribute:: is_mdt_owner
                    
                    	MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mldp_mdt_owner
                    
                    	MLDP MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mrib_register
                    
                    	MRIB Register
                    	**type**\:  bool
                    
                    .. attribute:: is_multicast_rib_registration
                    
                    	Mcast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converge_received
                    
                    	PIM NSF RIB converge received
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converged
                    
                    	PIM NSF RIB converged
                    	**type**\:  bool
                    
                    .. attribute:: is_redistribution_reset
                    
                    	Pending redist reset
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_added
                    
                    	VRF LPTS filter added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_add_required
                    
                    	VRF required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_added
                    
                    	VRF added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_enabled
                    
                    	PIM RIB multiplath enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_interface_hash
                    
                    	PIM RIB multipath interface hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_hash
                    
                    	PIM RIB multipath source based hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_next_hop_hash
                    
                    	PIM RIB multipath source\-nexthop hash
                    	**type**\:  bool
                    
                    .. attribute:: is_routing_enabled
                    
                    	Routing Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rsvp_te_mdt_owner
                    
                    	RSVP\-TE MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_add_required
                    
                    	VRF required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_added
                    
                    	VRF added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_add_required
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_added
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind
                    
                    	VRF bound on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind_required
                    
                    	VRF bind required on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_unicast_rib_registration
                    
                    	Ucast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: maximum_mdt_aggregation
                    
                    	MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_announce_interval
                    
                    	Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_switchover_interval
                    
                    	Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_default_group
                    
                    	MDT Default group
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_gre_remote_rpf_identifier
                    
                    	GRE\-MDT Remote RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_gre_rpf_identifier
                    
                    	GRE\-MDT RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_immediate_switch
                    
                    	MDT Immediate Switch
                    	**type**\:  bool
                    
                    .. attribute:: mdt_interface
                    
                    	MDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mdt_mtu
                    
                    	MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_neighbor_filter_name
                    
                    	MDT Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: mdt_partitioned_ir_control_identifier
                    
                    	Partitioned IR MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_mdt_control_identifier
                    
                    	Partitioned MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_source
                    
                    	MDT source
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_source_interface
                    
                    	MDT Source Interface Name
                    	**type**\:  str
                    
                    .. attribute:: mhost_default_interface_config
                    
                    	Configured Mhost Defint
                    	**type**\:  str
                    
                    .. attribute:: mhost_interface
                    
                    	MHost handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mldp_auto_rp_announce_tree_added
                    
                    	MLDP Autorp Announce Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_auto_rp_discovery_tree_added
                    
                    	MLDP Autorp Discovery Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_bsr_control_tree_added
                    
                    	MLDP BSR Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_control_head_lsm_identifier
                    
                    	MLDP MVPN Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_local_label
                    
                    	Partitioned MDT Head local label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_lsm_identifier
                    
                    	MLDP Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_maximum_mdt_aggregation
                    
                    	MLDP MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_announce_interval
                    
                    	MLDP Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_switchover_interval
                    
                    	MLDP Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_interface
                    
                    	MLDP MDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mldp_mdt_mtu
                    
                    	MLDP MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_name
                    
                    	MLDP MDT Name
                    	**type**\:  str
                    
                    .. attribute:: mldp_mdt_remote_rpf_identifier
                    
                    	MLDP Remote RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_rpf_identifier
                    
                    	MLDP RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partioned_mp2m_ptree
                    
                    	MP2MP Partitioned MDT tree
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_head_lsm_identifier
                    
                    	Partitioned MDT Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_configured
                    
                    	MLDP Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_mdt_identifier
                    
                    	MLDP Partitioned MDT Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_head_lsm_identifier
                    
                    	MLDP Remote Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_partitioned_mdt_configured
                    
                    	MLDP Remote Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_root_address
                    
                    	MLDP Root addresses
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_root_count
                    
                    	MLDP Root count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: murib_id
                    
                    	MURIB ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: non_default_vrf_count_on_socket
                    
                    	Count of non\-default vrfs on raw socket
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: organization_unique_identifier
                    
                    	OUI for VPN\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mpte_li_drop
                    
                    	Route LI updates dropped for P2MP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: physical_interface_count
                    
                    	Enabled Physical Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: redistribution_reset_count
                    
                    	Redist reset count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_default_group
                    
                    	Remote Default Group
                    	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup>`
                    
                    .. attribute:: remote_table_id
                    
                    	Remote Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_distinguisher
                    
                    	RD value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: rpf_default_table
                    
                    	RPF Default Table
                    	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable>`
                    
                    .. attribute:: rpf_id
                    
                    	RPF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_policy_name
                    
                    	RPF topology selection route\-policy name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_maximum_mdt_aggregation
                    
                    	RSVP\-TE MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_announce_interval
                    
                    	RSVP\-TE Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_switchover_interval
                    
                    	RSVP\-TE Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_interface
                    
                    	RSVP\-TEMDT handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: rsvp_te_mdt_mtu
                    
                    	RSVP\-TEMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_name
                    
                    	RSVP\-TE MDT Name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_mdt_rpf_identifier
                    
                    	RSVP\-TE RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_static_p2mp_count
                    
                    	Number of Static P2MP\-TE MDT
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	PIM is using MuRIB
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_time
                    
                    	S,G Expiry Time Configured, in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sg_expiry_timer_configured
                    
                    	S,G Expiry Timer Configured
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_timer_sg_list
                    
                    	S,G expiry timer ACL name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: stale_rd_present
                    
                    	RD is stale
                    	**type**\:  bool
                    
                    .. attribute:: suppress_pim_data_mdt_tlv
                    
                    	Suppress PIM Data\-MDT TLV Announcements
                    	**type**\:  bool
                    
                    .. attribute:: suppress_shared_tree_join
                    
                    	Suppress Shared\-Tree Joins
                    	**type**\:  bool
                    
                    .. attribute:: table_count
                    
                    	Number of configured Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: umh
                    
                    	Join UMH Core\-Tree
                    	**type**\:  bool
                    
                    .. attribute:: valid_rd_present
                    
                    	RD is valid
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface_count
                    
                    	Enabled Virtual Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: virtual_mlc_interface_name
                    
                    	Virtual master line card Interface
                    	**type**\:  str
                    
                    .. attribute:: vpn_index
                    
                    	VPN Index
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Context, self).__init__()

                        self.yang_name = "context"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"remote-default-group" : ("remote_default_group", Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup), "rpf-default-table" : ("rpf_default_table", Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable)}
                        self._child_list_classes = {"anycast-rp-range" : ("anycast_rp_range", Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange), "export-route-target" : ("export_route_target", Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget), "import-route-target" : ("import_route_target", Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget)}

                        self.active_table_count = YLeaf(YType.uint32, "active-table-count")

                        self.allow_rp_configured = YLeaf(YType.boolean, "allow-rp-configured")

                        self.allow_rp_group_list = YLeaf(YType.str, "allow-rp-group-list")

                        self.allow_rp_rp_list = YLeaf(YType.str, "allow-rp-rp-list")

                        self.anycast_rp_configured = YLeaf(YType.boolean, "anycast-rp-configured")

                        self.anycast_rp_policy_name = YLeaf(YType.str, "anycast-rp-policy-name")

                        self.bgp_auto_discovery_configured = YLeaf(YType.boolean, "bgp-auto-discovery-configured")

                        self.bgp_auto_discovery_type = YLeaf(YType.uint32, "bgp-auto-discovery-type")

                        self.bgp_i_pmsi_added = YLeaf(YType.boolean, "bgp-i-pmsi-added")

                        self.bgp_remote_address = YLeaf(YType.str, "bgp-remote-address")

                        self.bgp_remote_interface = YLeaf(YType.str, "bgp-remote-interface")

                        self.bgp_remote_interface_name = YLeaf(YType.str, "bgp-remote-interface-name")

                        self.bgp_remote_on = YLeaf(YType.boolean, "bgp-remote-on")

                        self.bgp_remote_state = YLeaf(YType.uint32, "bgp-remote-state")

                        self.bgp_source_active_announce = YLeaf(YType.boolean, "bgp-source-active-announce")

                        self.gin_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-announce-interval")

                        self.gin_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-switchover-interval")

                        self.gin_b_and_mdt_interface = YLeaf(YType.str, "gin-b-and-mdt-interface")

                        self.gin_b_and_mdt_mtu = YLeaf(YType.uint32, "gin-b-and-mdt-mtu")

                        self.gin_b_and_mdt_name = YLeaf(YType.str, "gin-b-and-mdt-name")

                        self.gin_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "gin-b-and-mdt-rpf-identifier")

                        self.gin_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "gin-band-maximum-mdt-aggregation")

                        self.in_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-announce-interval")

                        self.in_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-switchover-interval")

                        self.in_b_and_mdt_interface = YLeaf(YType.str, "in-b-and-mdt-interface")

                        self.in_b_and_mdt_mtu = YLeaf(YType.uint32, "in-b-and-mdt-mtu")

                        self.in_b_and_mdt_name = YLeaf(YType.str, "in-b-and-mdt-name")

                        self.in_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "in-b-and-mdt-rpf-identifier")

                        self.in_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "in-band-maximum-mdt-aggregation")

                        self.in_band_signaling_local_enabled = YLeaf(YType.boolean, "in-band-signaling-local-enabled")

                        self.in_band_signaling_remote_enabled = YLeaf(YType.boolean, "in-band-signaling-remote-enabled")

                        self.inter_autonomous_system_enabled = YLeaf(YType.boolean, "inter-autonomous-system-enabled")

                        self.ir_maximum_mdt_aggregation = YLeaf(YType.uint32, "ir-maximum-mdt-aggregation")

                        self.ir_mdt_data_announce_interval = YLeaf(YType.uint32, "ir-mdt-data-announce-interval")

                        self.ir_mdt_data_switchover_interval = YLeaf(YType.uint32, "ir-mdt-data-switchover-interval")

                        self.ir_mdt_interface = YLeaf(YType.str, "ir-mdt-interface")

                        self.ir_mdt_mtu = YLeaf(YType.uint32, "ir-mdt-mtu")

                        self.ir_mdt_name = YLeaf(YType.str, "ir-mdt-name")

                        self.ir_mdt_rpf_identifier = YLeaf(YType.uint32, "ir-mdt-rpf-identifier")

                        self.ir_mdt_tail_label = YLeaf(YType.uint32, "ir-mdt-tail-label")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_active_ital = YLeaf(YType.boolean, "is-active-ital")

                        self.is_all_interface_disable_operation = YLeaf(YType.boolean, "is-all-interface-disable-operation")

                        self.is_auto_rp_listen_enabled = YLeaf(YType.boolean, "is-auto-rp-listen-enabled")

                        self.is_auto_rp_listen_sock_add = YLeaf(YType.boolean, "is-auto-rp-listen-sock-add")

                        self.is_create_gin_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-gin-b-and-mdt-interface")

                        self.is_create_in_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-in-b-and-mdt-interface")

                        self.is_create_ir_mdt_interface = YLeaf(YType.boolean, "is-create-ir-mdt-interface")

                        self.is_create_mdt_interface = YLeaf(YType.boolean, "is-create-mdt-interface")

                        self.is_create_mldp_mdt_interface = YLeaf(YType.boolean, "is-create-mldp-mdt-interface")

                        self.is_create_rsvp_te_mdt_interface = YLeaf(YType.boolean, "is-create-rsvp-te-mdt-interface")

                        self.is_default_granges = YLeaf(YType.boolean, "is-default-granges")

                        self.is_gin_b_and_mdt_owner = YLeaf(YType.boolean, "is-gin-b-and-mdt-owner")

                        self.is_in_b_and_mdt_owner = YLeaf(YType.boolean, "is-in-b-and-mdt-owner")

                        self.is_ir_mdt_owner = YLeaf(YType.boolean, "is-ir-mdt-owner")

                        self.is_lpts_socket_add_required = YLeaf(YType.boolean, "is-lpts-socket-add-required")

                        self.is_lpts_socket_added = YLeaf(YType.boolean, "is-lpts-socket-added")

                        self.is_m_host_publish_pending = YLeaf(YType.boolean, "is-m-host-publish-pending")

                        self.is_mdt_owner = YLeaf(YType.boolean, "is-mdt-owner")

                        self.is_mldp_mdt_owner = YLeaf(YType.boolean, "is-mldp-mdt-owner")

                        self.is_mrib_register = YLeaf(YType.boolean, "is-mrib-register")

                        self.is_multicast_rib_registration = YLeaf(YType.boolean, "is-multicast-rib-registration")

                        self.is_pim_nsf_rib_converge_received = YLeaf(YType.boolean, "is-pim-nsf-rib-converge-received")

                        self.is_pim_nsf_rib_converged = YLeaf(YType.boolean, "is-pim-nsf-rib-converged")

                        self.is_redistribution_reset = YLeaf(YType.boolean, "is-redistribution-reset")

                        self.is_register_injection_lpts_socket_add_required = YLeaf(YType.boolean, "is-register-injection-lpts-socket-add-required")

                        self.is_register_injection_lpts_socket_added = YLeaf(YType.boolean, "is-register-injection-lpts-socket-added")

                        self.is_register_injection_socket_add_required = YLeaf(YType.boolean, "is-register-injection-socket-add-required")

                        self.is_register_injection_socket_added = YLeaf(YType.boolean, "is-register-injection-socket-added")

                        self.is_rib_multipath_enabled = YLeaf(YType.boolean, "is-rib-multipath-enabled")

                        self.is_rib_multipath_interface_hash = YLeaf(YType.boolean, "is-rib-multipath-interface-hash")

                        self.is_rib_multipath_source_hash = YLeaf(YType.boolean, "is-rib-multipath-source-hash")

                        self.is_rib_multipath_source_next_hop_hash = YLeaf(YType.boolean, "is-rib-multipath-source-next-hop-hash")

                        self.is_routing_enabled = YLeaf(YType.boolean, "is-routing-enabled")

                        self.is_rsvp_te_mdt_owner = YLeaf(YType.boolean, "is-rsvp-te-mdt-owner")

                        self.is_socket_add_required = YLeaf(YType.boolean, "is-socket-add-required")

                        self.is_socket_added = YLeaf(YType.boolean, "is-socket-added")

                        self.is_udp_socket_add_required = YLeaf(YType.boolean, "is-udp-socket-add-required")

                        self.is_udp_socket_added = YLeaf(YType.boolean, "is-udp-socket-added")

                        self.is_udp_socket_bind = YLeaf(YType.boolean, "is-udp-socket-bind")

                        self.is_udp_socket_bind_required = YLeaf(YType.boolean, "is-udp-socket-bind-required")

                        self.is_unicast_rib_registration = YLeaf(YType.boolean, "is-unicast-rib-registration")

                        self.maximum_mdt_aggregation = YLeaf(YType.uint32, "maximum-mdt-aggregation")

                        self.mdt_data_announce_interval = YLeaf(YType.uint32, "mdt-data-announce-interval")

                        self.mdt_data_switchover_interval = YLeaf(YType.uint32, "mdt-data-switchover-interval")

                        self.mdt_default_group = YLeaf(YType.str, "mdt-default-group")

                        self.mdt_gre_remote_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-remote-rpf-identifier")

                        self.mdt_gre_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-rpf-identifier")

                        self.mdt_immediate_switch = YLeaf(YType.boolean, "mdt-immediate-switch")

                        self.mdt_interface = YLeaf(YType.str, "mdt-interface")

                        self.mdt_mtu = YLeaf(YType.uint32, "mdt-mtu")

                        self.mdt_neighbor_filter_name = YLeaf(YType.str, "mdt-neighbor-filter-name")

                        self.mdt_partitioned_ir_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-ir-control-identifier")

                        self.mdt_partitioned_mdt_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-mdt-control-identifier")

                        self.mdt_source = YLeaf(YType.str, "mdt-source")

                        self.mdt_source_interface = YLeaf(YType.str, "mdt-source-interface")

                        self.mhost_default_interface_config = YLeaf(YType.str, "mhost-default-interface-config")

                        self.mhost_interface = YLeaf(YType.str, "mhost-interface")

                        self.mldp_auto_rp_announce_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-announce-tree-added")

                        self.mldp_auto_rp_discovery_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-discovery-tree-added")

                        self.mldp_bsr_control_tree_added = YLeaf(YType.boolean, "mldp-bsr-control-tree-added")

                        self.mldp_control_head_lsm_identifier = YLeaf(YType.uint32, "mldp-control-head-lsm-identifier")

                        self.mldp_head_local_label = YLeaf(YType.uint32, "mldp-head-local-label")

                        self.mldp_head_lsm_identifier = YLeaf(YType.uint32, "mldp-head-lsm-identifier")

                        self.mldp_maximum_mdt_aggregation = YLeaf(YType.uint32, "mldp-maximum-mdt-aggregation")

                        self.mldp_mdt_data_announce_interval = YLeaf(YType.uint32, "mldp-mdt-data-announce-interval")

                        self.mldp_mdt_data_switchover_interval = YLeaf(YType.uint32, "mldp-mdt-data-switchover-interval")

                        self.mldp_mdt_interface = YLeaf(YType.str, "mldp-mdt-interface")

                        self.mldp_mdt_mtu = YLeaf(YType.uint32, "mldp-mdt-mtu")

                        self.mldp_mdt_name = YLeaf(YType.str, "mldp-mdt-name")

                        self.mldp_mdt_remote_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-remote-rpf-identifier")

                        self.mldp_mdt_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-rpf-identifier")

                        self.mldp_partioned_mp2m_ptree = YLeaf(YType.boolean, "mldp-partioned-mp2m-ptree")

                        self.mldp_partitioned_head_lsm_identifier = YLeaf(YType.uint32, "mldp-partitioned-head-lsm-identifier")

                        self.mldp_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-partitioned-mdt-configured")

                        self.mldp_partitioned_mdt_identifier = YLeaf(YType.uint32, "mldp-partitioned-mdt-identifier")

                        self.mldp_remote_head_lsm_identifier = YLeaf(YType.uint32, "mldp-remote-head-lsm-identifier")

                        self.mldp_remote_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-remote-partitioned-mdt-configured")

                        self.mldp_root_address = YLeafList(YType.uint32, "mldp-root-address")

                        self.mldp_root_count = YLeaf(YType.uint32, "mldp-root-count")

                        self.murib_id = YLeaf(YType.uint32, "murib-id")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.non_default_vrf_count_on_socket = YLeaf(YType.uint32, "non-default-vrf-count-on-socket")

                        self.organization_unique_identifier = YLeaf(YType.uint32, "organization-unique-identifier")

                        self.p2mpte_li_drop = YLeaf(YType.uint32, "p2mpte-li-drop")

                        self.physical_interface_count = YLeaf(YType.uint64, "physical-interface-count")

                        self.redistribution_reset_count = YLeaf(YType.uint32, "redistribution-reset-count")

                        self.remote_table_id = YLeaf(YType.uint32, "remote-table-id")

                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                        self.rpf_id = YLeaf(YType.uint32, "rpf-id")

                        self.rpf_policy_name = YLeaf(YType.str, "rpf-policy-name")

                        self.rsvp_te_maximum_mdt_aggregation = YLeaf(YType.uint32, "rsvp-te-maximum-mdt-aggregation")

                        self.rsvp_te_mdt_data_announce_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-announce-interval")

                        self.rsvp_te_mdt_data_switchover_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-switchover-interval")

                        self.rsvp_te_mdt_interface = YLeaf(YType.str, "rsvp-te-mdt-interface")

                        self.rsvp_te_mdt_mtu = YLeaf(YType.uint32, "rsvp-te-mdt-mtu")

                        self.rsvp_te_mdt_name = YLeaf(YType.str, "rsvp-te-mdt-name")

                        self.rsvp_te_mdt_rpf_identifier = YLeaf(YType.uint32, "rsvp-te-mdt-rpf-identifier")

                        self.rsvp_te_mdt_static_p2mp_count = YLeaf(YType.uint32, "rsvp-te-mdt-static-p2mp-count")

                        self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                        self.sg_expiry_time = YLeaf(YType.uint16, "sg-expiry-time")

                        self.sg_expiry_timer_configured = YLeaf(YType.boolean, "sg-expiry-timer-configured")

                        self.sg_expiry_timer_sg_list = YLeaf(YType.str, "sg-expiry-timer-sg-list")

                        self.stale_rd_present = YLeaf(YType.boolean, "stale-rd-present")

                        self.suppress_pim_data_mdt_tlv = YLeaf(YType.boolean, "suppress-pim-data-mdt-tlv")

                        self.suppress_shared_tree_join = YLeaf(YType.boolean, "suppress-shared-tree-join")

                        self.table_count = YLeaf(YType.uint32, "table-count")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.umh = YLeaf(YType.boolean, "umh")

                        self.valid_rd_present = YLeaf(YType.boolean, "valid-rd-present")

                        self.virtual_interface_count = YLeaf(YType.uint64, "virtual-interface-count")

                        self.virtual_mlc_interface_name = YLeaf(YType.str, "virtual-mlc-interface-name")

                        self.vpn_index = YLeaf(YType.uint32, "vpn-index")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.remote_default_group = Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup()
                        self.remote_default_group.parent = self
                        self._children_name_map["remote_default_group"] = "remote-default-group"
                        self._children_yang_names.add("remote-default-group")

                        self.rpf_default_table = Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable()
                        self.rpf_default_table.parent = self
                        self._children_name_map["rpf_default_table"] = "rpf-default-table"
                        self._children_yang_names.add("rpf-default-table")

                        self.anycast_rp_range = YList(self)
                        self.export_route_target = YList(self)
                        self.import_route_target = YList(self)
                        self._segment_path = lambda: "context"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Context, ['active_table_count', 'allow_rp_configured', 'allow_rp_group_list', 'allow_rp_rp_list', 'anycast_rp_configured', 'anycast_rp_policy_name', 'bgp_auto_discovery_configured', 'bgp_auto_discovery_type', 'bgp_i_pmsi_added', 'bgp_remote_address', 'bgp_remote_interface', 'bgp_remote_interface_name', 'bgp_remote_on', 'bgp_remote_state', 'bgp_source_active_announce', 'gin_b_and_mdt_data_announce_interval', 'gin_b_and_mdt_data_switchover_interval', 'gin_b_and_mdt_interface', 'gin_b_and_mdt_mtu', 'gin_b_and_mdt_name', 'gin_b_and_mdt_rpf_identifier', 'gin_band_maximum_mdt_aggregation', 'in_b_and_mdt_data_announce_interval', 'in_b_and_mdt_data_switchover_interval', 'in_b_and_mdt_interface', 'in_b_and_mdt_mtu', 'in_b_and_mdt_name', 'in_b_and_mdt_rpf_identifier', 'in_band_maximum_mdt_aggregation', 'in_band_signaling_local_enabled', 'in_band_signaling_remote_enabled', 'inter_autonomous_system_enabled', 'ir_maximum_mdt_aggregation', 'ir_mdt_data_announce_interval', 'ir_mdt_data_switchover_interval', 'ir_mdt_interface', 'ir_mdt_mtu', 'ir_mdt_name', 'ir_mdt_rpf_identifier', 'ir_mdt_tail_label', 'is_active', 'is_active_ital', 'is_all_interface_disable_operation', 'is_auto_rp_listen_enabled', 'is_auto_rp_listen_sock_add', 'is_create_gin_b_and_mdt_interface', 'is_create_in_b_and_mdt_interface', 'is_create_ir_mdt_interface', 'is_create_mdt_interface', 'is_create_mldp_mdt_interface', 'is_create_rsvp_te_mdt_interface', 'is_default_granges', 'is_gin_b_and_mdt_owner', 'is_in_b_and_mdt_owner', 'is_ir_mdt_owner', 'is_lpts_socket_add_required', 'is_lpts_socket_added', 'is_m_host_publish_pending', 'is_mdt_owner', 'is_mldp_mdt_owner', 'is_mrib_register', 'is_multicast_rib_registration', 'is_pim_nsf_rib_converge_received', 'is_pim_nsf_rib_converged', 'is_redistribution_reset', 'is_register_injection_lpts_socket_add_required', 'is_register_injection_lpts_socket_added', 'is_register_injection_socket_add_required', 'is_register_injection_socket_added', 'is_rib_multipath_enabled', 'is_rib_multipath_interface_hash', 'is_rib_multipath_source_hash', 'is_rib_multipath_source_next_hop_hash', 'is_routing_enabled', 'is_rsvp_te_mdt_owner', 'is_socket_add_required', 'is_socket_added', 'is_udp_socket_add_required', 'is_udp_socket_added', 'is_udp_socket_bind', 'is_udp_socket_bind_required', 'is_unicast_rib_registration', 'maximum_mdt_aggregation', 'mdt_data_announce_interval', 'mdt_data_switchover_interval', 'mdt_default_group', 'mdt_gre_remote_rpf_identifier', 'mdt_gre_rpf_identifier', 'mdt_immediate_switch', 'mdt_interface', 'mdt_mtu', 'mdt_neighbor_filter_name', 'mdt_partitioned_ir_control_identifier', 'mdt_partitioned_mdt_control_identifier', 'mdt_source', 'mdt_source_interface', 'mhost_default_interface_config', 'mhost_interface', 'mldp_auto_rp_announce_tree_added', 'mldp_auto_rp_discovery_tree_added', 'mldp_bsr_control_tree_added', 'mldp_control_head_lsm_identifier', 'mldp_head_local_label', 'mldp_head_lsm_identifier', 'mldp_maximum_mdt_aggregation', 'mldp_mdt_data_announce_interval', 'mldp_mdt_data_switchover_interval', 'mldp_mdt_interface', 'mldp_mdt_mtu', 'mldp_mdt_name', 'mldp_mdt_remote_rpf_identifier', 'mldp_mdt_rpf_identifier', 'mldp_partioned_mp2m_ptree', 'mldp_partitioned_head_lsm_identifier', 'mldp_partitioned_mdt_configured', 'mldp_partitioned_mdt_identifier', 'mldp_remote_head_lsm_identifier', 'mldp_remote_partitioned_mdt_configured', 'mldp_root_address', 'mldp_root_count', 'murib_id', 'neighbor_filter_name', 'non_default_vrf_count_on_socket', 'organization_unique_identifier', 'p2mpte_li_drop', 'physical_interface_count', 'redistribution_reset_count', 'remote_table_id', 'route_distinguisher', 'rpf_id', 'rpf_policy_name', 'rsvp_te_maximum_mdt_aggregation', 'rsvp_te_mdt_data_announce_interval', 'rsvp_te_mdt_data_switchover_interval', 'rsvp_te_mdt_interface', 'rsvp_te_mdt_mtu', 'rsvp_te_mdt_name', 'rsvp_te_mdt_rpf_identifier', 'rsvp_te_mdt_static_p2mp_count', 'rump_enabled', 'sg_expiry_time', 'sg_expiry_timer_configured', 'sg_expiry_timer_sg_list', 'stale_rd_present', 'suppress_pim_data_mdt_tlv', 'suppress_shared_tree_join', 'table_count', 'table_id', 'umh', 'valid_rd_present', 'virtual_interface_count', 'virtual_mlc_interface_name', 'vpn_index', 'vrf_id'], name, value)


                    class AnycastRpRange(Entity):
                        """
                        Anycast\-RP Ranges
                        
                        .. attribute:: ancast_rp_marked
                        
                        	Anycast\-RP Range marked
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Anycast\-RP Range Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Anycast\-RP Range Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange, self).__init__()

                            self.yang_name = "anycast-rp-range"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"prefix" : ("prefix", Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix)}
                            self._child_list_classes = {}

                            self.ancast_rp_marked = YLeaf(YType.boolean, "ancast-rp-marked")

                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                            self.prefix = Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")
                            self._segment_path = lambda: "anycast-rp-range"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange, ['ancast_rp_marked', 'prefix_length'], name, value)


                        class Prefix(Entity):
                            """
                            Anycast\-RP Range Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "anycast-rp-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class ExportRouteTarget(Entity):
                        """
                        Export Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget, self).__init__()

                            self.yang_name = "export-route-target"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                            self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                            self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                            self.configured = YLeaf(YType.boolean, "configured")

                            self.route_target = YLeaf(YType.str, "route-target")

                            self.segment_border = YLeaf(YType.boolean, "segment-border")

                            self.update_pending = YLeaf(YType.boolean, "update-pending")
                            self._segment_path = lambda: "export-route-target"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget, ['anycast_rp', 'anycast_rp_marked', 'bgp_auto_discovery', 'configured', 'route_target', 'segment_border', 'update_pending'], name, value)


                    class ImportRouteTarget(Entity):
                        """
                        Import Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget, self).__init__()

                            self.yang_name = "import-route-target"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                            self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                            self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                            self.configured = YLeaf(YType.boolean, "configured")

                            self.route_target = YLeaf(YType.str, "route-target")

                            self.segment_border = YLeaf(YType.boolean, "segment-border")

                            self.update_pending = YLeaf(YType.boolean, "update-pending")
                            self._segment_path = lambda: "import-route-target"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget, ['anycast_rp', 'anycast_rp_marked', 'bgp_auto_discovery', 'configured', 'route_target', 'segment_border', 'update_pending'], name, value)


                    class RemoteDefaultGroup(Entity):
                        """
                        Remote Default Group
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__init__()

                            self.yang_name = "remote-default-group"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "remote-default-group"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class RpfDefaultTable(Entity):
                        """
                        RPF Default Table
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable, self).__init__()

                            self.yang_name = "rpf-default-table"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                            self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                            self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                            self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                            self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.table_id = YLeaf(YType.uint32, "table-id")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")
                            self._segment_path = lambda: "rpf-default-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable, ['afi', 'is_active', 'is_ital_registration_done', 'is_rib_convergence', 'is_rib_convergence_received', 'is_rib_registration_done', 'rpf_registrations', 'safi', 'table_id', 'table_name', 'vrf_id'], name, value)


                class Gre(Entity):
                    """
                    GRE information
                    
                    .. attribute:: gre_hashes
                    
                    	GRE hash
                    	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreHashes>`
                    
                    .. attribute:: gre_next_hops
                    
                    	GRE destination neighbor table
                    	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Gre, self).__init__()

                        self.yang_name = "gre"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"gre-hashes" : ("gre_hashes", Pim.Standby.Vrfs.Vrf.Gre.GreHashes), "gre-next-hops" : ("gre_next_hops", Pim.Standby.Vrfs.Vrf.Gre.GreNextHops)}
                        self._child_list_classes = {}

                        self.gre_hashes = Pim.Standby.Vrfs.Vrf.Gre.GreHashes()
                        self.gre_hashes.parent = self
                        self._children_name_map["gre_hashes"] = "gre-hashes"
                        self._children_yang_names.add("gre-hashes")

                        self.gre_next_hops = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops()
                        self.gre_next_hops.parent = self
                        self._children_name_map["gre_next_hops"] = "gre-next-hops"
                        self._children_yang_names.add("gre-next-hops")
                        self._segment_path = lambda: "gre"


                    class GreHashes(Entity):
                        """
                        GRE hash
                        
                        .. attribute:: gre_hash
                        
                        	PIM GRE Hashed Underlying Interface
                        	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Gre.GreHashes, self).__init__()

                            self.yang_name = "gre-hashes"
                            self.yang_parent_name = "gre"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"gre-hash" : ("gre_hash", Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash)}

                            self.gre_hash = YList(self)
                            self._segment_path = lambda: "gre-hashes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Gre.GreHashes, [], name, value)


                        class GreHash(Entity):
                            """
                            PIM GRE Hashed Underlying Interface
                            
                            .. attribute:: source_address  <key>
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: destination_address  <key>
                            
                            	Destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: ifname  <key>
                            
                            	GRE Tunnel Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__init__()

                                self.yang_name = "gre-hash"
                                self.yang_parent_name = "gre-hashes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.ifname = YLeaf(YType.str, "ifname")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")
                                self._segment_path = lambda: "gre-hash" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[ifname='" + self.ifname.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash, ['source_address', 'destination_address', 'ifname', 'next_hop_interface'], name, value)


                    class GreNextHops(Entity):
                        """
                        GRE destination neighbor table
                        
                        .. attribute:: gre_next_hop
                        
                        	PIM GRE address next\-hop information
                        	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops, self).__init__()

                            self.yang_name = "gre-next-hops"
                            self.yang_parent_name = "gre"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"gre-next-hop" : ("gre_next_hop", Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop)}

                            self.gre_next_hop = YList(self)
                            self._segment_path = lambda: "gre-next-hops"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops, [], name, value)


                        class GreNextHop(Entity):
                            """
                            PIM GRE address next\-hop information
                            
                            .. attribute:: destination_address  <key>
                            
                            	GRE destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: gre_path
                            
                            	GRE Paths list
                            	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath>`
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__init__()

                                self.yang_name = "gre-next-hop"
                                self.yang_parent_name = "gre-next-hops"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"registered-address" : ("registered_address", Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress)}
                                self._child_list_classes = {"gre-path" : ("gre_path", Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath)}

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.is_connected = YLeaf(YType.uint8, "is-connected")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                self.registered_address = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                self.registered_address.parent = self
                                self._children_name_map["registered_address"] = "registered-address"
                                self._children_yang_names.add("registered-address")

                                self.gre_path = YList(self)
                                self._segment_path = lambda: "gre-next-hop" + "[destination-address='" + self.destination_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, ['destination_address', 'is_connected', 'metric', 'metric_preference'], name, value)


                            class GrePath(Entity):
                                """
                                GRE Paths list
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: gre_interface_name
                                
                                	GRE Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: gre_neighbor
                                
                                	GRE neighbor
                                	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                                
                                .. attribute:: gre_next_hop
                                
                                	GRE nexthop
                                	**type**\:   :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop>`
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_gre_interface_disabled
                                
                                	Is the gre interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                    self.yang_name = "gre-path"
                                    self.yang_parent_name = "gre-next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"gre-neighbor" : ("gre_neighbor", Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor), "gre-next-hop" : ("gre_next_hop", Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop)}
                                    self._child_list_classes = {}

                                    self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                    self.gre_interface_name = YLeaf(YType.str, "gre-interface-name")

                                    self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                    self.is_gre_interface_disabled = YLeaf(YType.boolean, "is-gre-interface-disabled")

                                    self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                    self.gre_neighbor = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                    self.gre_neighbor.parent = self
                                    self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                    self._children_yang_names.add("gre-neighbor")

                                    self.gre_next_hop = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                    self.gre_next_hop.parent = self
                                    self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                    self._children_yang_names.add("gre-next-hop")
                                    self._segment_path = lambda: "gre-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, ['extranet_vrf_name', 'gre_interface_name', 'is_connector_attribute_present', 'is_gre_interface_disabled', 'is_via_lsm'], name, value)


                                class GreNeighbor(Entity):
                                    """
                                    GRE neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                        self.yang_name = "gre-neighbor"
                                        self.yang_parent_name = "gre-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "gre-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class GreNextHop(Entity):
                                    """
                                    GRE nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__init__()

                                        self.yang_name = "gre-next-hop"
                                        self.yang_parent_name = "gre-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "gre-next-hop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class RegisteredAddress(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                    self.yang_name = "registered-address"
                                    self.yang_parent_name = "gre-next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "registered-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class GroupMapRpfs(Entity):
                    """
                    PIM group mapping information
                    
                    .. attribute:: group_map_rpf
                    
                    	PIM group mapping entry
                    	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs, self).__init__()

                        self.yang_name = "group-map-rpfs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"group-map-rpf" : ("group_map_rpf", Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf)}

                        self.group_map_rpf = YList(self)
                        self._segment_path = lambda: "group-map-rpfs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapRpfs, [], name, value)


                    class GroupMapRpf(Entity):
                        """
                        PIM group mapping entry
                        
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_priority
                        
                        	RP priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__init__()

                            self.yang_name = "group-map-rpf"
                            self.yang_parent_name = "group-map-rpfs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-map-information" : ("group_map_information", Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation), "rpf-neighbor" : ("rpf_neighbor", Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor)}
                            self._child_list_classes = {}

                            self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                            self.client = YLeaf(YType.enumeration, "client")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_priority = YLeaf(YType.int32, "rp-priority")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.group_map_information = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")
                            self._segment_path = lambda: "group-map-rpf"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, ['are_we_rp', 'client', 'prefix', 'prefix_length', 'protocol', 'rp_address', 'rp_priority', 'rpf_interface_name', 'rpf_vrf_name'], name, value)


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-rpf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"prefix" : ("prefix", Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix), "rp-address" : ("rp_address", Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress)}
                                self._child_list_classes = {}

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")
                                self._segment_path = lambda: "group-map-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, ['client', 'group_count', 'is_override', 'is_used', 'mrib_active', 'prefix_length', 'priority', 'protocol'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "prefix"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "rp-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "group-map-rpf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class GroupMapSources(Entity):
                    """
                    PIM group\-mapping with source information
                    
                    .. attribute:: group_map_source
                    
                    	PIM Group Mapping Entry with source information
                    	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.GroupMapSources, self).__init__()

                        self.yang_name = "group-map-sources"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"group-map-source" : ("group_map_source", Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource)}

                        self.group_map_source = YList(self)
                        self._segment_path = lambda: "group-map-sources"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapSources, [], name, value)


                    class GroupMapSource(Entity):
                        """
                        PIM Group Mapping Entry with source information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	RP Priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__init__()

                            self.yang_name = "group-map-source"
                            self.yang_parent_name = "group-map-sources"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-map-information" : ("group_map_information", Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation), "source-of-information" : ("source_of_information", Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation)}
                            self._child_list_classes = {}

                            self.client = YLeaf(YType.enumeration, "client")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.holdtime = YLeaf(YType.int32, "holdtime")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.int32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_map_information = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.source_of_information = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")
                            self._segment_path = lambda: "group-map-source"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource, ['client', 'expires', 'holdtime', 'prefix', 'prefix_length', 'priority', 'protocol', 'rp_address', 'uptime'], name, value)


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"prefix" : ("prefix", Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix), "rp-address" : ("rp_address", Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress)}
                                self._child_list_classes = {}

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")
                                self._segment_path = lambda: "group-map-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, ['client', 'group_count', 'is_override', 'is_used', 'mrib_active', 'prefix_length', 'priority', 'protocol'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "prefix"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "rp-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-map-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-of-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class IfrsInterfaces(Entity):
                    """
                    PIM interfaces in forward reference store table
                    
                    .. attribute:: ifrs_interface
                    
                    	PIM IFRS interface information
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ifrs-interface" : ("ifrs_interface", Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface)}

                        self.ifrs_interface = YList(self)
                        self._segment_path = lambda: "ifrs-interfaces"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.IfrsInterfaces, [], name, value)


                    class IfrsInterface(Entity):
                        """
                        PIM IFRS interface information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"dr-address" : ("dr_address", Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress)}
                            self._child_list_classes = {"interface-address" : ("interface_address", Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "dr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "interface-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class IfrsSummary(Entity):
                    """
                    PIM interfaces in forward reference store
                    summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration counts
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Number of interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.IfrsSummary, self).__init__()

                        self.yang_name = "ifrs-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                        self.interface_count = YLeaf(YType.uint32, "interface-count")
                        self._segment_path = lambda: "ifrs-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.IfrsSummary, ['configuration_count', 'interface_count'], name, value)


                class InterfaceOldFormats(Entity):
                    """
                    PIM interfaces in old format
                    
                    .. attribute:: interface_old_format
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats, self).__init__()

                        self.yang_name = "interface-old-formats"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-old-format" : ("interface_old_format", Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat)}

                        self.interface_old_format = YList(self)
                        self._segment_path = lambda: "interface-old-formats"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats, [], name, value)


                    class InterfaceOldFormat(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                            self.yang_name = "interface-old-format"
                            self.yang_parent_name = "interface-old-formats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"dr-address" : ("dr_address", Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress)}
                            self._child_list_classes = {"interface-address" : ("interface_address", Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "interface-old-format" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "dr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "interface-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceStatistics(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_statistic
                    
                    	PIM interface statistics
                    	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.InterfaceStatistics, self).__init__()

                        self.yang_name = "interface-statistics"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-statistic" : ("interface_statistic", Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic)}

                        self.interface_statistic = YList(self)
                        self._segment_path = lambda: "interface-statistics"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.InterfaceStatistics, [], name, value)


                    class InterfaceStatistic(Entity):
                        """
                        PIM interface statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: input_assert
                        
                        	Assert packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_bsr_message
                        
                        	Input BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_candidate_rp_advertisement
                        
                        	Input Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_df_election
                        
                        	DF Election packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_ack_message
                        
                        	Input Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_message
                        
                        	Input Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_hello
                        
                        	Hello packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_jp
                        
                        	Join Prune packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_miscellaneous
                        
                        	Miscellaneous packet in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register
                        
                        	Register packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register_stop
                        
                        	Register Stop packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_assert
                        
                        	Assert packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_bsr_message
                        
                        	Output BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_candidate_rp_advertisement
                        
                        	Output Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_df_election
                        
                        	DF Election packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_ack_message
                        
                        	Output Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_message
                        
                        	Output Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_hello
                        
                        	Hello packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_jp
                        
                        	Join Prune packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register
                        
                        	Register packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register_stop
                        
                        	Register Stop packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__init__()

                            self.yang_name = "interface-statistic"
                            self.yang_parent_name = "interface-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.input_assert = YLeaf(YType.uint32, "input-assert")

                            self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                            self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                            self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                            self.input_graft_ack_message = YLeaf(YType.uint32, "input-graft-ack-message")

                            self.input_graft_message = YLeaf(YType.uint32, "input-graft-message")

                            self.input_hello = YLeaf(YType.uint32, "input-hello")

                            self.input_jp = YLeaf(YType.uint32, "input-jp")

                            self.input_miscellaneous = YLeaf(YType.uint32, "input-miscellaneous")

                            self.input_register = YLeaf(YType.uint32, "input-register")

                            self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                            self.output_assert = YLeaf(YType.uint32, "output-assert")

                            self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                            self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                            self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                            self.output_graft_ack_message = YLeaf(YType.uint32, "output-graft-ack-message")

                            self.output_graft_message = YLeaf(YType.uint32, "output-graft-message")

                            self.output_hello = YLeaf(YType.uint32, "output-hello")

                            self.output_jp = YLeaf(YType.uint32, "output-jp")

                            self.output_register = YLeaf(YType.uint32, "output-register")

                            self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")
                            self._segment_path = lambda: "interface-statistic" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, ['interface_name', 'input_assert', 'input_bsr_message', 'input_candidate_rp_advertisement', 'input_df_election', 'input_graft_ack_message', 'input_graft_message', 'input_hello', 'input_jp', 'input_miscellaneous', 'input_register', 'input_register_stop', 'output_assert', 'output_bsr_message', 'output_candidate_rp_advertisement', 'output_df_election', 'output_graft_ack_message', 'output_graft_message', 'output_hello', 'output_jp', 'output_register', 'output_register_stop'], name, value)


                class Interfaces(Entity):
                    """
                    PIM interfaces
                    
                    .. attribute:: interface
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Interfaces, self).__init__()

                        self.yang_name = "interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface" : ("interface", Pim.Standby.Vrfs.Vrf.Interfaces.Interface)}

                        self.interface = YList(self)
                        self._segment_path = lambda: "interfaces"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Interfaces, [], name, value)


                    class Interface(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Interfaces.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"dr-address" : ("dr_address", Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress)}
                            self._child_list_classes = {"interface-address" : ("interface_address", Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Interfaces.Interface, ['interface_name', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'configured_override_interval', 'configured_propagation_delay', 'dr_priority', 'external_neighbor_count', 'generation_id', 'hello_expiry', 'hello_interval', 'idb_acl_name', 'idb_acl_provided', 'idb_current_count', 'idb_max_count', 'idb_oor_enabled', 'idb_threshold_count', 'interface_address_mask', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bidirectional_capable', 'is_enabled', 'is_proxy_capable', 'join_prune_interval', 'neighbor_count', 'neighbor_filter_name', 'override_interval', 'passive_interface', 'propagation_delay', 'prune_delay_enabled', 'virtual_interface'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "dr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "interface-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class JpStatistics(Entity):
                    """
                    PIM join prune statistics table
                    
                    .. attribute:: jp_statistic
                    
                    	PIM Join Prune Statistics
                    	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.JpStatistics, self).__init__()

                        self.yang_name = "jp-statistics"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"jp-statistic" : ("jp_statistic", Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic)}

                        self.jp_statistic = YList(self)
                        self._segment_path = lambda: "jp-statistics"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.JpStatistics, [], name, value)


                    class JpStatistic(Entity):
                        """
                        PIM Join Prune Statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received
                        
                        	Received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received100
                        
                        	Received 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_10k
                        
                        	Received 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_1k
                        
                        	Received 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_50k
                        
                        	Deprecated by Received100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted
                        
                        	Transmitted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted100
                        
                        	Transmitted 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_10k
                        
                        	Transmitted 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_1k
                        
                        	Transmitted 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_50k
                        
                        	Deprecated by Transmitted100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic, self).__init__()

                            self.yang_name = "jp-statistic"
                            self.yang_parent_name = "jp-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.received = YLeaf(YType.uint32, "received")

                            self.received100 = YLeaf(YType.uint16, "received100")

                            self.received_10k = YLeaf(YType.uint16, "received-10k")

                            self.received_1k = YLeaf(YType.uint16, "received-1k")

                            self.received_50k = YLeaf(YType.uint16, "received-50k")

                            self.transmitted = YLeaf(YType.uint32, "transmitted")

                            self.transmitted100 = YLeaf(YType.uint16, "transmitted100")

                            self.transmitted_10k = YLeaf(YType.uint16, "transmitted-10k")

                            self.transmitted_1k = YLeaf(YType.uint16, "transmitted-1k")

                            self.transmitted_50k = YLeaf(YType.uint16, "transmitted-50k")
                            self._segment_path = lambda: "jp-statistic" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic, ['interface_name', 'interface_name_xr', 'mtu', 'received', 'received100', 'received_10k', 'received_1k', 'received_50k', 'transmitted', 'transmitted100', 'transmitted_10k', 'transmitted_1k', 'transmitted_50k'], name, value)


                class MibDatabases(Entity):
                    """
                    PIM group database for mroute mibs table
                    
                    .. attribute:: mib_database
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.MibDatabases, self).__init__()

                        self.yang_name = "mib-databases"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"mib-database" : ("mib_database", Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase)}

                        self.mib_database = YList(self)
                        self._segment_path = lambda: "mib-databases"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.MibDatabases, [], name, value)


                    class MibDatabase(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: assert_metric
                        
                        	Assert Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_metric_preference
                        
                        	Assert Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_rpt_bit
                        
                        	Assert RPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: bidirectional_route
                        
                        	Is this Bidir ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Multicast satic route group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr>`
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface name 
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: rpf_mask
                        
                        	Mask of the multicast root
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_neighbor
                        
                        	The RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: source_address
                        
                        	Multicast static route source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr>`
                        
                        .. attribute:: source_netmask
                        
                        	Source mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: spt_bit
                        
                        	Is SPT bit set ?
                        	**type**\:  bool
                        
                        .. attribute:: upstream_assert_timer
                        
                        	Upstream Assert Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime of route
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase, self).__init__()

                            self.yang_name = "mib-database"
                            self.yang_parent_name = "mib-databases"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr), "rpf-neighbor" : ("rpf_neighbor", Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor), "rpf-root" : ("rpf_root", Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot), "source-address-xr" : ("source_address_xr", Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr)}
                            self._child_list_classes = {}

                            self.assert_metric = YLeaf(YType.uint32, "assert-metric")

                            self.assert_metric_preference = YLeaf(YType.uint32, "assert-metric-preference")

                            self.assert_rpt_bit = YLeaf(YType.boolean, "assert-rpt-bit")

                            self.bidirectional_route = YLeaf(YType.boolean, "bidirectional-route")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                            self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_mask = YLeaf(YType.uint32, "rpf-mask")

                            self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                            self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_netmask = YLeaf(YType.int32, "source-netmask")

                            self.spt_bit = YLeaf(YType.boolean, "spt-bit")

                            self.upstream_assert_timer = YLeaf(YType.int32, "upstream-assert-timer")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                            self.rpf_root = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._children_yang_names.add("rpf-root")

                            self.source_address_xr = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")
                            self._segment_path = lambda: "mib-database"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase, ['assert_metric', 'assert_metric_preference', 'assert_rpt_bit', 'bidirectional_route', 'group_address', 'protocol', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_mask', 'rpf_safi', 'rpf_table_name', 'rpf_vrf_name', 'source_address', 'source_netmask', 'spt_bit', 'upstream_assert_timer', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            The RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-root"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class MulticastStaticRoutes(Entity):
                    """
                    PIM multicast static route table
                    
                    .. attribute:: multicast_static_route
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes, self).__init__()

                        self.yang_name = "multicast-static-routes"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"multicast-static-route" : ("multicast_static_route", Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute)}

                        self.multicast_static_route = YList(self)
                        self._segment_path = lambda: "multicast-static-routes"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes, [], name, value)


                    class MulticastStaticRoute(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: address
                        
                        	Network address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: distance
                        
                        	Distance
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_via_lsm
                        
                        	LSM flag
                        	**type**\:  bool
                        
                        .. attribute:: nexthop
                        
                        	Next Hop
                        	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: prefix_length_xr
                        
                        	Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                            self.yang_name = "multicast-static-route"
                            self.yang_parent_name = "multicast-static-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"nexthop" : ("nexthop", Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop), "prefix" : ("prefix", Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix)}
                            self._child_list_classes = {}

                            self.address = YLeaf(YType.str, "address")

                            self.distance = YLeaf(YType.uint32, "distance")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                            self.nexthop = Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                            self.nexthop.parent = self
                            self._children_name_map["nexthop"] = "nexthop"
                            self._children_yang_names.add("nexthop")

                            self.prefix = Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")
                            self._segment_path = lambda: "multicast-static-route"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, ['address', 'distance', 'interface_name', 'is_via_lsm', 'prefix_length', 'prefix_length_xr'], name, value)


                        class Nexthop(Entity):
                            """
                            Next Hop
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                                self.yang_name = "nexthop"
                                self.yang_parent_name = "multicast-static-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "nexthop"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Prefix(Entity):
                            """
                            Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "multicast-static-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "prefix"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class NeighborOldFormats(Entity):
                    """
                    PIM neighbor table old format
                    
                    .. attribute:: neighbor_old_format
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.NeighborOldFormats, self).__init__()

                        self.yang_name = "neighbor-old-formats"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-old-format" : ("neighbor_old_format", Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat)}

                        self.neighbor_old_format = YList(self)
                        self._segment_path = lambda: "neighbor-old-formats"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.NeighborOldFormats, [], name, value)


                    class NeighborOldFormat(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__init__()

                            self.yang_name = "neighbor-old-format"
                            self.yang_parent_name = "neighbor-old-formats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr)}

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                            self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                            self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.neighbor_address_xr = YList(self)
                            self._segment_path = lambda: "neighbor-old-format"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, ['dr_priority', 'expires', 'expiry_timer', 'interface_name', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bfd_state', 'is_bidirectional_capable', 'is_dr_priority_capable', 'is_ecmp_redirect_capable', 'is_proxy_capable', 'is_this_neighbor_dr', 'is_this_neighbor_us', 'neighbor_address', 'override_interval', 'propagation_delay', 'uptime'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "neighbor-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class NeighborSummaries(Entity):
                    """
                    PIM neighbor summary table
                    
                    .. attribute:: neighbor_summary
                    
                    	PIM neighbor summary information
                    	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.NeighborSummaries, self).__init__()

                        self.yang_name = "neighbor-summaries"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-summary" : ("neighbor_summary", Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary)}

                        self.neighbor_summary = YList(self)
                        self._segment_path = lambda: "neighbor-summaries"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.NeighborSummaries, [], name, value)


                    class NeighborSummary(Entity):
                        """
                        PIM neighbor summary information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: number_of_external_neighbors
                        
                        	Number of external neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__init__()

                            self.yang_name = "neighbor-summary"
                            self.yang_parent_name = "neighbor-summaries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.number_of_external_neighbors = YLeaf(YType.int32, "number-of-external-neighbors")

                            self.number_of_neighbors = YLeaf(YType.int32, "number-of-neighbors")
                            self._segment_path = lambda: "neighbor-summary" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary, ['interface_name', 'number_of_external_neighbors', 'number_of_neighbors'], name, value)


                class Neighbors(Entity):
                    """
                    PIM neighbor table
                    
                    .. attribute:: neighbor
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Neighbors, self).__init__()

                        self.yang_name = "neighbors"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor" : ("neighbor", Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor)}

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "neighbors"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Neighbors, [], name, value)


                    class Neighbor(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbors"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr)}

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                            self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                            self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.neighbor_address_xr = YList(self)
                            self._segment_path = lambda: "neighbor"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor, ['dr_priority', 'expires', 'expiry_timer', 'interface_name', 'interface_name_xr', 'is_batch_asserts_capable', 'is_bfd_state', 'is_bidirectional_capable', 'is_dr_priority_capable', 'is_ecmp_redirect_capable', 'is_proxy_capable', 'is_this_neighbor_dr', 'is_this_neighbor_us', 'neighbor_address', 'override_interval', 'propagation_delay', 'uptime'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "neighbor-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class NetIoTunnels(Entity):
                    """
                    Tunnel information that NETIO has 
                    
                    .. attribute:: net_io_tunnel
                    
                    	PIM netio tunnel information
                    	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.NetIoTunnels, self).__init__()

                        self.yang_name = "net-io-tunnels"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"net-io-tunnel" : ("net_io_tunnel", Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel)}

                        self.net_io_tunnel = YList(self)
                        self._segment_path = lambda: "net-io-tunnels"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.NetIoTunnels, [], name, value)


                    class NetIoTunnel(Entity):
                        """
                        PIM netio tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__init__()

                            self.yang_name = "net-io-tunnel"
                            self.yang_parent_name = "net-io-tunnels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-netio" : ("group_address_netio", Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio), "rp-address" : ("rp_address", Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress), "source-address" : ("source_address", Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress), "source-address-netio" : ("source_address_netio", Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio)}
                            self._child_list_classes = {}

                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_netio = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._children_yang_names.add("group-address-netio")

                            self.rp_address = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.source_address = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                            self.source_address_netio = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"
                            self._children_yang_names.add("source-address-netio")
                            self._segment_path = lambda: "net-io-tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, ['tunnel_name', 'vrf_name'], name, value)


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-netio"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-netio"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Ranges(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: range
                    
                    	PIM range list information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"range" : ("range", Pim.Standby.Vrfs.Vrf.Ranges.Range)}

                        self.range = YList(self)
                        self._segment_path = lambda: "ranges"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Ranges, [], name, value)


                    class Range(Entity):
                        """
                        PIM range list information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: client_xr
                        
                        	Client mapping learnt via
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: group_range
                        
                        	List of group ranges
                        	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange>`
                        
                        .. attribute:: protocol
                        
                        	PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	Rendezvous point address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"rp-address-xr" : ("rp_address_xr", Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr), "source-of-information" : ("source_of_information", Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation)}
                            self._child_list_classes = {"group-range" : ("group_range", Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange)}

                            self.client = YLeaf(YType.enumeration, "client")

                            self.client_xr = YLeaf(YType.enumeration, "client-xr")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_address_xr = Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")

                            self.source_of_information = Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                            self.group_range = YList(self)
                            self._segment_path = lambda: "range"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Ranges.Range, ['client', 'client_xr', 'expires', 'protocol', 'rp_address'], name, value)


                        class GroupRange(Entity):
                            """
                            List of group ranges
                            
                            .. attribute:: expires
                            
                            	When mapping expires
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: source_of_information
                            
                            	Source of information
                            	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange, self).__init__()

                                self.yang_name = "group-range"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"prefix" : ("prefix", Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix), "source-of-information" : ("source_of_information", Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation)}
                                self._child_list_classes = {}

                                self.expires = YLeaf(YType.uint64, "expires")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.prefix = Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.source_of_information = Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                                self._children_yang_names.add("source-of-information")
                                self._segment_path = lambda: "group-range"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange, ['expires', 'prefix_length', 'uptime'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "prefix"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceOfInformation(Entity):
                                """
                                Source of information
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                    self.yang_name = "source-of-information"
                                    self.yang_parent_name = "group-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-of-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddressXr(Entity):
                            """
                            Rendezvous point address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-of-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class RoutePolicy(Entity):
                    """
                    PIM route policy
                    
                    .. attribute:: route_policy_statistics
                    
                    	PIM route policy statistics
                    	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics>`
                    
                    .. attribute:: route_policy_tests
                    
                    	PIM route policy test run table
                    	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.RoutePolicy, self).__init__()

                        self.yang_name = "route-policy"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"route-policy-statistics" : ("route_policy_statistics", Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics), "route-policy-tests" : ("route_policy_tests", Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests)}
                        self._child_list_classes = {}

                        self.route_policy_statistics = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                        self.route_policy_statistics.parent = self
                        self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                        self._children_yang_names.add("route-policy-statistics")

                        self.route_policy_tests = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                        self.route_policy_tests.parent = self
                        self._children_name_map["route_policy_tests"] = "route-policy-tests"
                        self._children_yang_names.add("route-policy-tests")
                        self._segment_path = lambda: "route-policy"


                    class RoutePolicyStatistics(Entity):
                        """
                        PIM route policy statistics
                        
                        .. attribute:: any_table
                        
                        	Number of RPF lookup in any Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Number of RPF lookup in default\-only Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop
                        
                        	Number of RPF drops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pass_
                        
                        	Number of RPF pass
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: requests
                        
                        	Number of RPF lookup requests
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__init__()

                            self.yang_name = "route-policy-statistics"
                            self.yang_parent_name = "route-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.any_table = YLeaf(YType.uint32, "any-table")

                            self.default_table = YLeaf(YType.uint32, "default-table")

                            self.drop = YLeaf(YType.uint32, "drop")

                            self.pass_ = YLeaf(YType.uint32, "pass")

                            self.policy_name = YLeaf(YType.str, "policy-name")

                            self.requests = YLeaf(YType.uint32, "requests")
                            self._segment_path = lambda: "route-policy-statistics"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, ['any_table', 'default_table', 'drop', 'pass_', 'policy_name', 'requests'], name, value)


                    class RoutePolicyTests(Entity):
                        """
                        PIM route policy test run table
                        
                        .. attribute:: route_policy_test
                        
                        	PIM route policy test run
                        	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__init__()

                            self.yang_name = "route-policy-tests"
                            self.yang_parent_name = "route-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"route-policy-test" : ("route_policy_test", Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest)}

                            self.route_policy_test = YList(self)
                            self._segment_path = lambda: "route-policy-tests"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, [], name, value)


                        class RoutePolicyTest(Entity):
                            """
                            PIM route policy test run
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_table
                            
                            	Default table selected
                            	**type**\:  bool
                            
                            .. attribute:: ext_comm
                            
                            	Extended Community
                            	**type**\:  str
                            
                            	**length:** 1..8
                            
                            .. attribute:: extended_community_rt
                            
                            	Route Target
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: group_address
                            
                            	Group IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                            
                            .. attribute:: pass_
                            
                            	Pass
                            	**type**\:  bool
                            
                            .. attribute:: policy_name
                            
                            	RPF policy name
                            	**type**\:  str
                            
                            .. attribute:: safi
                            
                            	SAFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_address
                            
                            	Source IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                            
                            .. attribute:: table_active
                            
                            	Table active
                            	**type**\:  bool
                            
                            .. attribute:: table_exists
                            
                            	Table exists
                            	**type**\:  bool
                            
                            .. attribute:: table_name
                            
                            	Table name
                            	**type**\:  str
                            
                            .. attribute:: vrf_name
                            
                            	VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                                self.yang_name = "route-policy-test"
                                self.yang_parent_name = "route-policy-tests"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr), "source-address-xr" : ("source_address_xr", Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr)}
                                self._child_list_classes = {}

                                self.afi = YLeaf(YType.uint32, "afi")

                                self.default_table = YLeaf(YType.boolean, "default-table")

                                self.ext_comm = YLeaf(YType.str, "ext-comm")

                                self.extended_community_rt = YLeaf(YType.str, "extended-community-rt")

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.pass_ = YLeaf(YType.boolean, "pass")

                                self.policy_name = YLeaf(YType.str, "policy-name")

                                self.safi = YLeaf(YType.uint32, "safi")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.table_active = YLeaf(YType.boolean, "table-active")

                                self.table_exists = YLeaf(YType.boolean, "table-exists")

                                self.table_name = YLeaf(YType.str, "table-name")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.group_address_xr = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.source_address_xr = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                                self._children_yang_names.add("source-address-xr")
                                self._segment_path = lambda: "route-policy-test"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, ['afi', 'default_table', 'ext_comm', 'extended_community_rt', 'group_address', 'pass_', 'policy_name', 'safi', 'source_address', 'table_active', 'table_exists', 'table_name', 'vrf_name'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "route-policy-test"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "route-policy-test"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class RpfRedirect(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle
                    
                    .. attribute:: bundle_interfaces
                    
                    	PIM ECMP RPF\-redirect bundle information
                    	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces>`
                    
                    .. attribute:: redirect_route_databases
                    
                    	PIM ECMP RPF\-redirect route database
                    	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.RpfRedirect, self).__init__()

                        self.yang_name = "rpf-redirect"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"bundle-interfaces" : ("bundle_interfaces", Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces), "redirect-route-databases" : ("redirect_route_databases", Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases)}
                        self._child_list_classes = {}

                        self.bundle_interfaces = Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                        self.bundle_interfaces.parent = self
                        self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                        self._children_yang_names.add("bundle-interfaces")

                        self.redirect_route_databases = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                        self.redirect_route_databases.parent = self
                        self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                        self._children_yang_names.add("redirect-route-databases")
                        self._segment_path = lambda: "rpf-redirect"


                    class BundleInterfaces(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle information
                        
                        .. attribute:: bundle_interface
                        
                        	PIM ECMP RPF\-redirect bundle interface information
                        	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__init__()

                            self.yang_name = "bundle-interfaces"
                            self.yang_parent_name = "rpf-redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"bundle-interface" : ("bundle_interface", Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface)}

                            self.bundle_interface = YList(self)
                            self._segment_path = lambda: "bundle-interfaces"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces, [], name, value)


                        class BundleInterface(Entity):
                            """
                            PIM ECMP RPF\-redirect bundle interface
                            information
                            
                            .. attribute:: allocated_bandwidth
                            
                            	Bandwidth allocated in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_threshold_bandwidth
                            
                            	Configured threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_bandwidth
                            
                            	Bandwidth available in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_threshold_bandwidth
                            
                            	Available threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\:  str
                            
                            	**length:** 1..32
                            
                            .. attribute:: interface_name
                            
                            	Bundle interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: rpf_redirect_bundle_name
                            
                            	RPF redirect bundle name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: rpf_redirect_interface_name
                            
                            	RPF redirect interface name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: snooping_bandwidth_used
                            
                            	Bandwidth used by snooped entries in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: topology_bandwidth_used
                            
                            	Bandwidth used by topology in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: total_bandwidth
                            
                            	Total bandwidth used in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                                self.yang_name = "bundle-interface"
                                self.yang_parent_name = "bundle-interfaces"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.allocated_bandwidth = YLeaf(YType.int32, "allocated-bandwidth")

                                self.allocated_threshold_bandwidth = YLeaf(YType.int32, "allocated-threshold-bandwidth")

                                self.available_bandwidth = YLeaf(YType.int32, "available-bandwidth")

                                self.available_threshold_bandwidth = YLeaf(YType.int32, "available-threshold-bandwidth")

                                self.bundle_name = YLeaf(YType.str, "bundle-name")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.rpf_redirect_bundle_name = YLeaf(YType.str, "rpf-redirect-bundle-name")

                                self.rpf_redirect_interface_name = YLeaf(YType.str, "rpf-redirect-interface-name")

                                self.snooping_bandwidth_used = YLeaf(YType.int32, "snooping-bandwidth-used")

                                self.topology_bandwidth_used = YLeaf(YType.int32, "topology-bandwidth-used")

                                self.total_bandwidth = YLeaf(YType.int32, "total-bandwidth")
                                self._segment_path = lambda: "bundle-interface"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, ['allocated_bandwidth', 'allocated_threshold_bandwidth', 'available_bandwidth', 'available_threshold_bandwidth', 'bundle_name', 'interface_name', 'rpf_redirect_bundle_name', 'rpf_redirect_interface_name', 'snooping_bandwidth_used', 'topology_bandwidth_used', 'total_bandwidth'], name, value)


                    class RedirectRouteDatabases(Entity):
                        """
                        PIM ECMP RPF\-redirect route database
                        
                        .. attribute:: redirect_route_database
                        
                        	PIM ECMP RPF\-redirect route information
                        	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__init__()

                            self.yang_name = "redirect-route-databases"
                            self.yang_parent_name = "rpf-redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"redirect-route-database" : ("redirect_route_database", Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase)}

                            self.redirect_route_database = YList(self)
                            self._segment_path = lambda: "redirect-route-databases"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, [], name, value)


                        class RedirectRouteDatabase(Entity):
                            """
                            PIM ECMP RPF\-redirect route information
                            
                            .. attribute:: bandwidth
                            
                            	Bandwidth in Kbps
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Group ddress
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                            
                            .. attribute:: interface
                            
                            	Outgoing interface list
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                                self.yang_name = "redirect-route-database"
                                self.yang_parent_name = "redirect-route-databases"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr), "source-address-xr" : ("source_address_xr", Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr)}
                                self._child_list_classes = {"interface" : ("interface", Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface)}

                                self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.source_address_xr = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                                self._children_yang_names.add("source-address-xr")

                                self.interface = YList(self)
                                self._segment_path = lambda: "redirect-route-database"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, ['bandwidth', 'group_address', 'source_address', 'uptime'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group ddress
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class Interface(Entity):
                                """
                                Outgoing interface list
                                
                                .. attribute:: expiry
                                
                                	Expiry in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: is_outgoing_interface
                                
                                	Is outgoing Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface
                                
                                	Is RPF Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_snoop_interface
                                
                                	Is snooping Interface
                                	**type**\:  bool
                                
                                .. attribute:: rpf_address
                                
                                	RPF Address
                                	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                                
                                .. attribute:: uptime
                                
                                	Uptime in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"rpf-address" : ("rpf_address", Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress)}
                                    self._child_list_classes = {}

                                    self.expiry = YLeaf(YType.uint64, "expiry")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.is_outgoing_interface = YLeaf(YType.boolean, "is-outgoing-interface")

                                    self.is_rpf_interface = YLeaf(YType.boolean, "is-rpf-interface")

                                    self.is_snoop_interface = YLeaf(YType.boolean, "is-snoop-interface")

                                    self.uptime = YLeaf(YType.uint64, "uptime")

                                    self.rpf_address = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                    self.rpf_address.parent = self
                                    self._children_name_map["rpf_address"] = "rpf-address"
                                    self._children_yang_names.add("rpf-address")
                                    self._segment_path = lambda: "interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, ['expiry', 'interface_name', 'is_outgoing_interface', 'is_rpf_interface', 'is_snoop_interface', 'uptime'], name, value)


                                class RpfAddress(Entity):
                                    """
                                    RPF Address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                        self.yang_name = "rpf-address"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "rpf-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class RpfSummary(Entity):
                    """
                    PIM RPF registration summary
                    
                    .. attribute:: default_safi
                    
                    	Default RPF Table SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table_name
                    
                    	Default RPF Table Name
                    	**type**\:  str
                    
                    .. attribute:: is_isis_mtr_configured
                    
                    	Is ISIS MTR configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_isis_te_configured
                    
                    	Is ISIS TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_mbgp_configured
                    
                    	Is MBGP configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_enabled
                    
                    	Is Multipath Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_interface_hash_enabled
                    
                    	Is Multipath Interface Hash Extension Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_hash_enabled
                    
                    	Is Multipath Source based Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_next_hop_hash_enabled
                    
                    	Is Multipath Source\-Nexthop Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ospf_te_configured
                    
                    	Is OSPF TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: mo_frr_configured
                    
                    	Is MoFRR configured?
                    	**type**\:  bool
                    
                    .. attribute:: rib_convergence_time_left
                    
                    	RIB convergence time left in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_convergence_timeout
                    
                    	RIB convergence timeout in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_mo_frr_configured
                    
                    	Is MoFRR RIB configured?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	Is RUMP MuRIB enabled?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.RpfSummary, self).__init__()

                        self.yang_name = "rpf-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.default_safi = YLeaf(YType.uint32, "default-safi")

                        self.default_table_name = YLeaf(YType.str, "default-table-name")

                        self.is_isis_mtr_configured = YLeaf(YType.boolean, "is-isis-mtr-configured")

                        self.is_isis_te_configured = YLeaf(YType.boolean, "is-isis-te-configured")

                        self.is_mbgp_configured = YLeaf(YType.boolean, "is-mbgp-configured")

                        self.is_multipath_enabled = YLeaf(YType.boolean, "is-multipath-enabled")

                        self.is_multipath_interface_hash_enabled = YLeaf(YType.boolean, "is-multipath-interface-hash-enabled")

                        self.is_multipath_source_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-hash-enabled")

                        self.is_multipath_source_next_hop_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-next-hop-hash-enabled")

                        self.is_ospf_te_configured = YLeaf(YType.boolean, "is-ospf-te-configured")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.mo_frr_configured = YLeaf(YType.boolean, "mo-frr-configured")

                        self.rib_convergence_time_left = YLeaf(YType.uint32, "rib-convergence-time-left")

                        self.rib_convergence_timeout = YLeaf(YType.uint32, "rib-convergence-timeout")

                        self.rib_mo_frr_configured = YLeaf(YType.boolean, "rib-mo-frr-configured")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")
                        self._segment_path = lambda: "rpf-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfSummary, ['default_safi', 'default_table_name', 'is_isis_mtr_configured', 'is_isis_te_configured', 'is_mbgp_configured', 'is_multipath_enabled', 'is_multipath_interface_hash_enabled', 'is_multipath_source_hash_enabled', 'is_multipath_source_next_hop_hash_enabled', 'is_ospf_te_configured', 'is_rib_convergence', 'mo_frr_configured', 'rib_convergence_time_left', 'rib_convergence_timeout', 'rib_mo_frr_configured', 'rpf_registrations', 'rump_enabled'], name, value)


                class Safs(Entity):
                    """
                    SAFI table and type
                    
                    .. attribute:: saf
                    
                    	SAF name 
                    	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Safs, self).__init__()

                        self.yang_name = "safs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"saf" : ("saf", Pim.Standby.Vrfs.Vrf.Safs.Saf)}

                        self.saf = YList(self)
                        self._segment_path = lambda: "safs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs, [], name, value)


                    class Saf(Entity):
                        """
                        SAF name 
                        
                        .. attribute:: rpf_hash_source_groups
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups>`
                        
                        .. attribute:: rpf_hash_sources
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources>`
                        
                        .. attribute:: rpfs
                        
                        	PIM RPF information table
                        	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs>`
                        
                        .. attribute:: saf_name
                        
                        	SAF name 
                        	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name 
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Safs.Saf, self).__init__()

                            self.yang_name = "saf"
                            self.yang_parent_name = "safs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"rpf-hash-source-groups" : ("rpf_hash_source_groups", Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups), "rpf-hash-sources" : ("rpf_hash_sources", Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources), "rpfs" : ("rpfs", Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs)}
                            self._child_list_classes = {}

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                            self.topology_name = YLeaf(YType.str, "topology-name")

                            self.rpf_hash_source_groups = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                            self.rpf_hash_source_groups.parent = self
                            self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                            self._children_yang_names.add("rpf-hash-source-groups")

                            self.rpf_hash_sources = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                            self.rpf_hash_sources.parent = self
                            self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                            self._children_yang_names.add("rpf-hash-sources")

                            self.rpfs = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs()
                            self.rpfs.parent = self
                            self._children_name_map["rpfs"] = "rpfs"
                            self._children_yang_names.add("rpfs")
                            self._segment_path = lambda: "saf"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf, ['saf_name', 'topology_name'], name, value)


                        class RpfHashSourceGroups(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source_group
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__init__()

                                self.yang_name = "rpf-hash-source-groups"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"rpf-hash-source-group" : ("rpf_hash_source_group", Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup)}

                                self.rpf_hash_source_group = YList(self)
                                self._segment_path = lambda: "rpf-hash-source-groups"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, [], name, value)


                            class RpfHashSourceGroup(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: group_address
                                
                                	Group address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: mask_length
                                
                                	Hash mask length
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                    self.yang_name = "rpf-hash-source-group"
                                    self.yang_parent_name = "rpf-hash-source-groups"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress), "secondary-next-hop-address" : ("secondary_next_hop_address", Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress)}
                                    self._child_list_classes = {}

                                    self.group_address = YLeaf(YType.str, "group-address")

                                    self.mask_length = YLeaf(YType.int32, "mask-length")

                                    self.mofrr = YLeaf(YType.int32, "mofrr")

                                    self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                    self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                    self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                    self._children_yang_names.add("next-hop-address")

                                    self.secondary_next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._children_yang_names.add("secondary-next-hop-address")
                                    self._segment_path = lambda: "rpf-hash-source-group"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, ['group_address', 'mask_length', 'mofrr', 'next_hop_interface', 'next_hop_multipath_enabled', 'secondary_next_hop_interface', 'source_address'], name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "next-hop-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "secondary-next-hop-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfHashSources(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__init__()

                                self.yang_name = "rpf-hash-sources"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"rpf-hash-source" : ("rpf_hash_source", Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource)}

                                self.rpf_hash_source = YList(self)
                                self._segment_path = lambda: "rpf-hash-sources"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources, [], name, value)


                            class RpfHashSource(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                    self.yang_name = "rpf-hash-source"
                                    self.yang_parent_name = "rpf-hash-sources"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress), "secondary-next-hop-address" : ("secondary_next_hop_address", Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress)}
                                    self._child_list_classes = {}

                                    self.mofrr = YLeaf(YType.int32, "mofrr")

                                    self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                    self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                    self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                    self._children_yang_names.add("next-hop-address")

                                    self.secondary_next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._children_yang_names.add("secondary-next-hop-address")
                                    self._segment_path = lambda: "rpf-hash-source"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, ['mofrr', 'next_hop_interface', 'next_hop_multipath_enabled', 'secondary_next_hop_interface', 'source_address'], name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "next-hop-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "secondary-next-hop-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Rpfs(Entity):
                            """
                            PIM RPF information table
                            
                            .. attribute:: rpf
                            
                            	PIM RPF information
                            	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs, self).__init__()

                                self.yang_name = "rpfs"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"rpf" : ("rpf", Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf)}

                                self.rpf = YList(self)
                                self._segment_path = lambda: "rpfs"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs, [], name, value)


                            class Rpf(Entity):
                                """
                                PIM RPF information
                                
                                .. attribute:: registered_address  <key>
                                
                                	Address for which RPF lookup
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: is_connected
                                
                                	Are we connected ?
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_rpf_bgp_route
                                
                                	Is RPF through BGP route
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_preference
                                
                                	Metric preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: registered_address_xr
                                
                                	Address registered
                                	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                                
                                .. attribute:: rpf_path
                                
                                	RPF Paths list
                                	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__init__()

                                    self.yang_name = "rpf"
                                    self.yang_parent_name = "rpfs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"registered-address-xr" : ("registered_address_xr", Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr)}
                                    self._child_list_classes = {"rpf-path" : ("rpf_path", Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath)}

                                    self.registered_address = YLeaf(YType.str, "registered-address")

                                    self.is_connected = YLeaf(YType.uint8, "is-connected")

                                    self.is_rpf_bgp_route = YLeaf(YType.boolean, "is-rpf-bgp-route")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                    self.registered_address_xr = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                    self.registered_address_xr.parent = self
                                    self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                    self._children_yang_names.add("registered-address-xr")

                                    self.rpf_path = YList(self)
                                    self._segment_path = lambda: "rpf" + "[registered-address='" + self.registered_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, ['registered_address', 'is_connected', 'is_rpf_bgp_route', 'metric', 'metric_preference'], name, value)


                                class RegisteredAddressXr(Entity):
                                    """
                                    Address registered
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                        self.yang_name = "registered-address-xr"
                                        self.yang_parent_name = "rpf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                        self._segment_path = lambda: "registered-address-xr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                class RpfPath(Entity):
                                    """
                                    RPF Paths list
                                    
                                    .. attribute:: connector
                                    
                                    	Connector Attribute
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: extranet_vrf_name
                                    
                                    	Extranet VRF name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    .. attribute:: is_connector_attribute_present
                                    
                                    	Connector attribute present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rpf_interface_disabled
                                    
                                    	Is the rpf interface disabled ?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_lsm
                                    
                                    	Via LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_mlsm
                                    
                                    	Via Mstatic LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpf_interface_name
                                    
                                    	RPF Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: rpf_neighbor
                                    
                                    	RPF neighbor
                                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                    
                                    .. attribute:: rpf_nexthop
                                    
                                    	RPF nexthop
                                    	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                        self.yang_name = "rpf-path"
                                        self.yang_parent_name = "rpf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rpf-neighbor" : ("rpf_neighbor", Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor), "rpf-nexthop" : ("rpf_nexthop", Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop)}
                                        self._child_list_classes = {}

                                        self.connector = YLeaf(YType.str, "connector")

                                        self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                        self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                        self.is_rpf_interface_disabled = YLeaf(YType.boolean, "is-rpf-interface-disabled")

                                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                        self.is_via_mlsm = YLeaf(YType.boolean, "is-via-mlsm")

                                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                                        self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                        self.rpf_neighbor.parent = self
                                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                        self._children_yang_names.add("rpf-neighbor")

                                        self.rpf_nexthop = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                        self.rpf_nexthop.parent = self
                                        self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                        self._children_yang_names.add("rpf-nexthop")
                                        self._segment_path = lambda: "rpf-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, ['connector', 'extranet_vrf_name', 'is_connector_attribute_present', 'is_rpf_interface_disabled', 'is_via_lsm', 'is_via_mlsm', 'rpf_interface_name'], name, value)


                                    class RpfNeighbor(Entity):
                                        """
                                        RPF neighbor
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                            self.yang_name = "rpf-neighbor"
                                            self.yang_parent_name = "rpf-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                            self._segment_path = lambda: "rpf-neighbor"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                                    class RpfNexthop(Entity):
                                        """
                                        RPF nexthop
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                            self.yang_name = "rpf-nexthop"
                                            self.yang_parent_name = "rpf-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                            self._segment_path = lambda: "rpf-nexthop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Summary(Entity):
                    """
                    PIM summary
                    
                    .. attribute:: bsr_candidate_rp_set_count
                    
                    	Current crp\-set count from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_limit
                    
                    	Maximum crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_threshold
                    
                    	Threshold crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_range_threshold
                    
                    	Threshold group range from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_count
                    
                    	Current group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_limit
                    
                    	Maximum group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_auto_rp_ranges_limit
                    
                    	Global Auto\-RP maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_count
                    
                    	Global BSR current crp\-set count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_limit
                    
                    	Global BSR maximum crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_threshold
                    
                    	Global BSR Threshold crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_count
                    
                    	Global BSR current group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_limit
                    
                    	Global BSR maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_threshold
                    
                    	Global BSR Threshold group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_register_limit
                    
                    	Maximum global registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bsr_ranges_threshold_reached
                    
                    	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_auto_rp_ranges_limit_reached
                    
                    	Is global AutoRP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_bsr_ranges_limit_reached
                    
                    	Is global BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_register_limit_reached
                    
                    	Is global PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_route_limit_reached
                    
                    	Is global route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_rxi_limit_reached
                    
                    	Is global interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_maximum_enforcement_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: is_ranges_limit_reached
                    
                    	Is Auto\-RP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_route_limit_reached
                    
                    	Is route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: ranges_count
                    
                    	Current group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_limit
                    
                    	Maximum group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_threshold
                    
                    	OOR theshold of grange ranges from AutoRP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_count
                    
                    	Current registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit
                    
                    	Maximum registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit_reached
                    
                    	Is PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: register_threshold
                    
                    	Threshold registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_count
                    
                    	Current routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_limit
                    
                    	Maximum routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_low_water_mark
                    
                    	The number of routes below which the throttle on route creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_threshold
                    
                    	Threshold routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_limit_reached
                    
                    	Is interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: rxi_low_water_mark
                    
                    	The rxi below which the throttle on interface creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_count
                    
                    	Current Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_limit
                    
                    	Maximum Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_threshold
                    
                    	Topology Interface State threshold
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                        self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                        self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                        self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                        self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                        self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                        self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                        self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                        self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                        self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                        self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                        self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                        self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                        self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                        self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                        self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                        self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                        self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                        self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                        self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                        self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                        self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                        self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                        self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                        self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                        self.register_count = YLeaf(YType.uint32, "register-count")

                        self.register_limit = YLeaf(YType.uint32, "register-limit")

                        self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                        self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                        self.route_count = YLeaf(YType.uint32, "route-count")

                        self.route_limit = YLeaf(YType.uint32, "route-limit")

                        self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                        self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                        self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                        self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                        self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                        self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                        self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")
                        self._segment_path = lambda: "summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Summary, ['bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_threshold', 'bsr_range_threshold', 'bsr_ranges_count', 'bsr_ranges_limit', 'global_auto_rp_ranges_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_threshold', 'global_bsr_ranges_count', 'global_bsr_ranges_limit', 'global_bsr_ranges_threshold', 'global_register_limit', 'is_bsr_ranges_threshold_reached', 'is_global_auto_rp_ranges_limit_reached', 'is_global_bsr_ranges_limit_reached', 'is_global_register_limit_reached', 'is_global_route_limit_reached', 'is_global_rxi_limit_reached', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'is_ranges_limit_reached', 'is_route_limit_reached', 'ranges_count', 'ranges_limit', 'ranges_threshold', 'register_count', 'register_limit', 'register_limit_reached', 'register_threshold', 'route_count', 'route_limit', 'route_low_water_mark', 'route_threshold', 'rxi_limit_reached', 'rxi_low_water_mark', 'topology_interface_state_count', 'topology_interface_state_limit', 'topology_interface_state_threshold'], name, value)


                class TableContexts(Entity):
                    """
                    PIM table context list
                    
                    .. attribute:: table_context
                    
                    	PIM table context information
                    	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TableContexts.TableContext>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.TableContexts, self).__init__()

                        self.yang_name = "table-contexts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"table-context" : ("table_context", Pim.Standby.Vrfs.Vrf.TableContexts.TableContext)}

                        self.table_context = YList(self)
                        self._segment_path = lambda: "table-contexts"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.TableContexts, [], name, value)


                    class TableContext(Entity):
                        """
                        PIM table context information
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: saf_name
                        
                        	SAF name
                        	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: topology_name
                        
                        	Topology name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.TableContexts.TableContext, self).__init__()

                            self.yang_name = "table-context"
                            self.yang_parent_name = "table-contexts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                            self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                            self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                            self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                            self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.table_id = YLeaf(YType.uint32, "table-id")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.topology_name = YLeaf(YType.str, "topology-name")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")
                            self._segment_path = lambda: "table-context"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.TableContexts.TableContext, ['afi', 'is_active', 'is_ital_registration_done', 'is_rib_convergence', 'is_rib_convergence_received', 'is_rib_registration_done', 'rpf_registrations', 'saf_name', 'safi', 'table_id', 'table_name', 'topology_name', 'vrf_id'], name, value)


                class Topologies(Entity):
                    """
                    PIM topology table
                    
                    .. attribute:: topology
                    
                    	PIM topology information
                    	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Topologies, self).__init__()

                        self.yang_name = "topologies"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"topology" : ("topology", Pim.Standby.Vrfs.Vrf.Topologies.Topology)}

                        self.topology = YList(self)
                        self._segment_path = lambda: "topologies"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies, [], name, value)


                    class Topology(Entity):
                        """
                        PIM topology information
                        
                        .. attribute:: alive
                        
                        	Alive time in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: anycast_rp_match
                        
                        	Group matches Anycast\-RP policy
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_route_target
                        
                        	Anycast\-RP RT
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: assume_alive
                        
                        	The Assume Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: bgp_join
                        
                        	BGP C JOIN
                        	**type**\:  bool
                        
                        .. attribute:: bgp_jp_time
                        
                        	BGP C JP Time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: connected
                        
                        	Is Connected ?
                        	**type**\:  bool
                        
                        .. attribute:: crossed_threshold
                        
                        	Incoming traffic crossed threshold. MT flag set
                        	**type**\:  bool
                        
                        .. attribute:: customer_routing_type
                        
                        	Type of Customer Routing in the MVPN
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: data_mdt_addr_assigned
                        
                        	PIM has assigned a Data MDT Address
                        	**type**\:  bool
                        
                        .. attribute:: dont_check_connected
                        
                        	Do we need to make the connected check on this route ?
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	When this entry expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: extranet_route
                        
                        	Is a Extranet route ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr>`
                        
                        .. attribute:: inherit_alive
                        
                        	The Inherit Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: inherit_spt
                        
                        	The Inherit SPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: is_via_lsm
                        
                        	Via LSM
                        	**type**\:  bool
                        
                        .. attribute:: jp_status
                        
                        	Join\-Prune Status
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: kat_state
                        
                        	Keep Alive Timer State
                        	**type**\:  bool
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: limit_reached
                        
                        	Have we throttled the creation of routes or interfaces ?
                        	**type**\:  bool
                        
                        .. attribute:: low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_active
                        
                        	Is MoFRR Active?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_backup
                        
                        	Is this Mofrr Backup?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_primary
                        
                        	Is this Mofrr Primary?
                        	**type**\:  bool
                        
                        .. attribute:: orig_src_address
                        
                        	Orig Src Address
                        	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress>`
                        
                        .. attribute:: outgoing_interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface>`
                        
                        .. attribute:: probe_alive
                        
                        	The Probe Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: proxy
                        
                        	Is the RPF target a proxy?
                        	**type**\:  bool
                        
                        .. attribute:: proxy_address
                        
                        	RPF Proxy address
                        	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress>`
                        
                        .. attribute:: really_alive
                        
                        	The Really Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: register_received
                        
                        	Have registers been received for this source ?
                        	**type**\:  bool
                        
                        .. attribute:: register_received_timer
                        
                        	Register Received Timer in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: remote_source
                        
                        	MSDP told us
                        	**type**\:  bool
                        
                        .. attribute:: rib_mo_frr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rp_address
                        
                        	RP Address (If rpt)
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor>`
                        
                        .. attribute:: rpf_proxy_enabled
                        
                        	Is rpf if proxy enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpt
                        
                        	RPT bit
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpt_xr
                        
                        	Is this on the RPT ?
                        	**type**\:  bool
                        
                        .. attribute:: sa_joined
                        
                        	BGP SA join
                        	**type**\:  bool
                        
                        .. attribute:: sa_received
                        
                        	BGP SA received
                        	**type**\:  bool
                        
                        .. attribute:: sa_sent
                        
                        	BGP SA sent
                        	**type**\:  bool
                        
                        .. attribute:: secondary_rpf_interface_name
                        
                        	Secondary Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: secondary_rpf_neighbor
                        
                        	Secondary RPF Neighbor
                        	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor>`
                        
                        .. attribute:: sending_null_registers
                        
                        	Are we sending null registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: sending_registers
                        
                        	Are we sending registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: signal_sources
                        
                        	Signal Sources on route?
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr>`
                        
                        .. attribute:: spt
                        
                        	Is this on the SPT ?
                        	**type**\:  bool
                        
                        .. attribute:: suppress_registers
                        
                        	When the Null register probe expires
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vxlan
                        
                        	Is this VXLAN?
                        	**type**\:  bool
                        
                        .. attribute:: wildcard
                        
                        	WC \-Wildcard
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Topologies.Topology, self).__init__()

                            self.yang_name = "topology"
                            self.yang_parent_name = "topologies"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr), "orig-src-address" : ("orig_src_address", Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress), "proxy-address" : ("proxy_address", Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress), "rp-address" : ("rp_address", Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress), "rpf-neighbor" : ("rpf_neighbor", Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor), "rpf-root" : ("rpf_root", Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot), "secondary-rpf-neighbor" : ("secondary_rpf_neighbor", Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor), "source-address-xr" : ("source_address_xr", Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr)}
                            self._child_list_classes = {"outgoing-interface" : ("outgoing_interface", Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface)}

                            self.alive = YLeaf(YType.int32, "alive")

                            self.anycast_rp_match = YLeaf(YType.boolean, "anycast-rp-match")

                            self.anycast_rp_route_target = YLeaf(YType.str, "anycast-rp-route-target")

                            self.assume_alive = YLeaf(YType.boolean, "assume-alive")

                            self.bgp_join = YLeaf(YType.boolean, "bgp-join")

                            self.bgp_jp_time = YLeaf(YType.uint64, "bgp-jp-time")

                            self.connected = YLeaf(YType.boolean, "connected")

                            self.crossed_threshold = YLeaf(YType.boolean, "crossed-threshold")

                            self.customer_routing_type = YLeaf(YType.int32, "customer-routing-type")

                            self.data_mdt_addr_assigned = YLeaf(YType.boolean, "data-mdt-addr-assigned")

                            self.dont_check_connected = YLeaf(YType.boolean, "dont-check-connected")

                            self.expiry = YLeaf(YType.uint64, "expiry")

                            self.extranet_route = YLeaf(YType.boolean, "extranet-route")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.inherit_alive = YLeaf(YType.boolean, "inherit-alive")

                            self.inherit_spt = YLeaf(YType.boolean, "inherit-spt")

                            self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                            self.jp_status = YLeaf(YType.int32, "jp-status")

                            self.jp_timer = YLeaf(YType.int32, "jp-timer")

                            self.kat_state = YLeaf(YType.boolean, "kat-state")

                            self.last_hop = YLeaf(YType.boolean, "last-hop")

                            self.limit_reached = YLeaf(YType.boolean, "limit-reached")

                            self.low_memory = YLeaf(YType.boolean, "low-memory")

                            self.mofrr_active = YLeaf(YType.boolean, "mofrr-active")

                            self.mofrr_backup = YLeaf(YType.boolean, "mofrr-backup")

                            self.mofrr_enabled = YLeaf(YType.boolean, "mofrr-enabled")

                            self.mofrr_primary = YLeaf(YType.boolean, "mofrr-primary")

                            self.probe_alive = YLeaf(YType.boolean, "probe-alive")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.proxy = YLeaf(YType.boolean, "proxy")

                            self.really_alive = YLeaf(YType.boolean, "really-alive")

                            self.register_received = YLeaf(YType.boolean, "register-received")

                            self.register_received_timer = YLeaf(YType.int32, "register-received-timer")

                            self.remote_source = YLeaf(YType.boolean, "remote-source")

                            self.rib_mo_frr_enabled = YLeaf(YType.boolean, "rib-mo-frr-enabled")

                            self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                            self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_proxy_enabled = YLeaf(YType.boolean, "rpf-proxy-enabled")

                            self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                            self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.rpt = YLeaf(YType.int32, "rpt")

                            self.rpt_xr = YLeaf(YType.boolean, "rpt-xr")

                            self.sa_joined = YLeaf(YType.boolean, "sa-joined")

                            self.sa_received = YLeaf(YType.boolean, "sa-received")

                            self.sa_sent = YLeaf(YType.boolean, "sa-sent")

                            self.secondary_rpf_interface_name = YLeaf(YType.str, "secondary-rpf-interface-name")

                            self.sending_null_registers = YLeaf(YType.boolean, "sending-null-registers")

                            self.sending_registers = YLeaf(YType.boolean, "sending-registers")

                            self.signal_sources = YLeaf(YType.boolean, "signal-sources")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.spt = YLeaf(YType.boolean, "spt")

                            self.suppress_registers = YLeaf(YType.int32, "suppress-registers")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.vxlan = YLeaf(YType.boolean, "vxlan")

                            self.wildcard = YLeaf(YType.boolean, "wildcard")

                            self.group_address_xr = Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.orig_src_address = Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                            self.orig_src_address.parent = self
                            self._children_name_map["orig_src_address"] = "orig-src-address"
                            self._children_yang_names.add("orig-src-address")

                            self.proxy_address = Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                            self.proxy_address.parent = self
                            self._children_name_map["proxy_address"] = "proxy-address"
                            self._children_yang_names.add("proxy-address")

                            self.rp_address = Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                            self.rpf_root = Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._children_yang_names.add("rpf-root")

                            self.secondary_rpf_neighbor = Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                            self.secondary_rpf_neighbor.parent = self
                            self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                            self._children_yang_names.add("secondary-rpf-neighbor")

                            self.source_address_xr = Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                            self.outgoing_interface = YList(self)
                            self._segment_path = lambda: "topology"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology, ['alive', 'anycast_rp_match', 'anycast_rp_route_target', 'assume_alive', 'bgp_join', 'bgp_jp_time', 'connected', 'crossed_threshold', 'customer_routing_type', 'data_mdt_addr_assigned', 'dont_check_connected', 'expiry', 'extranet_route', 'group_address', 'inherit_alive', 'inherit_spt', 'is_via_lsm', 'jp_status', 'jp_timer', 'kat_state', 'last_hop', 'limit_reached', 'low_memory', 'mofrr_active', 'mofrr_backup', 'mofrr_enabled', 'mofrr_primary', 'probe_alive', 'protocol', 'proxy', 'really_alive', 'register_received', 'register_received_timer', 'remote_source', 'rib_mo_frr_enabled', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_proxy_enabled', 'rpf_safi', 'rpf_table_name', 'rpf_vrf_name', 'rpt', 'rpt_xr', 'sa_joined', 'sa_received', 'sa_sent', 'secondary_rpf_interface_name', 'sending_null_registers', 'sending_registers', 'signal_sources', 'source_address', 'spt', 'suppress_registers', 'uptime', 'vxlan', 'wildcard'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class OrigSrcAddress(Entity):
                            """
                            Orig Src Address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__init__()

                                self.yang_name = "orig-src-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "orig-src-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class OutgoingInterface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: admin_boundary
                            
                            	Is this an administrative boundary ?
                            	**type**\:  bool
                            
                            .. attribute:: assert_state
                            
                            	Assert State
                            	**type**\:  bool
                            
                            .. attribute:: assert_timer
                            
                            	Assert Timer in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: assert_winner
                            
                            	Assert Winner
                            	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner>`
                            
                            .. attribute:: bgp_c_mcast_join
                            
                            	BGP C\-Mcast join
                            	**type**\:  bool
                            
                            .. attribute:: bgp_c_mcast_prune_delay_timer
                            
                            	BGP C\-MCAST Prune Suppression in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: data_mdt_join
                            
                            	Data MDT join
                            	**type**\:  bool
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: extranet_interface
                            
                            	Is this an Extranet Interface ?
                            	**type**\:  bool
                            
                            .. attribute:: forwarding_state
                            
                            	Forward or Prune
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: igmp_membership
                            
                            	IGMP membership
                            	**type**\:  bool
                            
                            .. attribute:: immediate_state
                            
                            	Immediate fwding state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: interface_name
                            
                            	Interface Identifier
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: internal_interest_info
                            
                            	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: internal_interest_information
                            
                            	Internal Interest. Replaces internal\-interest\-info
                            	**type**\:   :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                            
                            .. attribute:: jp_state
                            
                            	Join\-Prune State
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: jp_timer
                            
                            	Join\-Prune Timer (secs)
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: last_hop
                            
                            	Are we last hop ?
                            	**type**\:  bool
                            
                            .. attribute:: local_mdt_join
                            
                            	Default MDT Join
                            	**type**\:  bool
                            
                            .. attribute:: local_members
                            
                            	Local Information. Deprecated \- use 'local\-members\-information' instead
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: local_members_information
                            
                            	Local Information. Replaces local\-members
                            	**type**\:   :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                            
                            .. attribute:: mdt_safi_join
                            
                            	MDT Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mldp_inband_mdt
                            
                            	MLDP Inband MDT interface
                            	**type**\:  bool
                            
                            .. attribute:: mldp_stale
                            
                            	OLE is stale
                            	**type**\:  bool
                            
                            .. attribute:: mvpn_safi_join
                            
                            	MVPN Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mvpnv6_safi_join
                            
                            	MVPN IPv6 Safi join
                            	**type**\:  bool
                            
                            .. attribute:: sa_prune
                            
                            	BGP SA Prune state
                            	**type**\:  bool
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: vrf_name
                            
                            	VRF which physically owns
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__init__()

                                self.yang_name = "outgoing-interface"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"assert-winner" : ("assert_winner", Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner)}
                                self._child_list_classes = {}

                                self.admin_boundary = YLeaf(YType.boolean, "admin-boundary")

                                self.assert_state = YLeaf(YType.boolean, "assert-state")

                                self.assert_timer = YLeaf(YType.int32, "assert-timer")

                                self.bgp_c_mcast_join = YLeaf(YType.boolean, "bgp-c-mcast-join")

                                self.bgp_c_mcast_prune_delay_timer = YLeaf(YType.uint64, "bgp-c-mcast-prune-delay-timer")

                                self.data_mdt_join = YLeaf(YType.boolean, "data-mdt-join")

                                self.expiry = YLeaf(YType.uint64, "expiry")

                                self.extranet_interface = YLeaf(YType.boolean, "extranet-interface")

                                self.forwarding_state = YLeaf(YType.int32, "forwarding-state")

                                self.igmp_membership = YLeaf(YType.boolean, "igmp-membership")

                                self.immediate_state = YLeaf(YType.int32, "immediate-state")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.internal_interest_info = YLeaf(YType.int32, "internal-interest-info")

                                self.internal_interest_information = YLeaf(YType.enumeration, "internal-interest-information")

                                self.jp_state = YLeaf(YType.int32, "jp-state")

                                self.jp_timer = YLeaf(YType.int32, "jp-timer")

                                self.last_hop = YLeaf(YType.boolean, "last-hop")

                                self.local_mdt_join = YLeaf(YType.boolean, "local-mdt-join")

                                self.local_members = YLeaf(YType.int32, "local-members")

                                self.local_members_information = YLeaf(YType.enumeration, "local-members-information")

                                self.mdt_safi_join = YLeaf(YType.boolean, "mdt-safi-join")

                                self.mldp_inband_mdt = YLeaf(YType.boolean, "mldp-inband-mdt")

                                self.mldp_stale = YLeaf(YType.boolean, "mldp-stale")

                                self.mvpn_safi_join = YLeaf(YType.boolean, "mvpn-safi-join")

                                self.mvpnv6_safi_join = YLeaf(YType.boolean, "mvpnv6-safi-join")

                                self.sa_prune = YLeaf(YType.boolean, "sa-prune")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.assert_winner = Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                self.assert_winner.parent = self
                                self._children_name_map["assert_winner"] = "assert-winner"
                                self._children_yang_names.add("assert-winner")
                                self._segment_path = lambda: "outgoing-interface"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, ['admin_boundary', 'assert_state', 'assert_timer', 'bgp_c_mcast_join', 'bgp_c_mcast_prune_delay_timer', 'data_mdt_join', 'expiry', 'extranet_interface', 'forwarding_state', 'igmp_membership', 'immediate_state', 'interface_name', 'internal_interest_info', 'internal_interest_information', 'jp_state', 'jp_timer', 'last_hop', 'local_mdt_join', 'local_members', 'local_members_information', 'mdt_safi_join', 'mldp_inband_mdt', 'mldp_stale', 'mvpn_safi_join', 'mvpnv6_safi_join', 'sa_prune', 'uptime', 'vrf_name'], name, value)


                            class AssertWinner(Entity):
                                """
                                Assert Winner
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                    self.yang_name = "assert-winner"
                                    self.yang_parent_name = "outgoing-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "assert-winner"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class ProxyAddress(Entity):
                            """
                            RPF Proxy address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__init__()

                                self.yang_name = "proxy-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "proxy-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP Address (If rpt)
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rpf-root"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SecondaryRpfNeighbor(Entity):
                            """
                            Secondary RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                                self.yang_name = "secondary-rpf-neighbor"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "secondary-rpf-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class TopologyEntryFlagRouteCounts(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: topology_entry_flag_route_count
                    
                    	Route count for topology with entry flag set
                    	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-entry-flag-route-counts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"topology-entry-flag-route-count" : ("topology_entry_flag_route_count", Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount)}

                        self.topology_entry_flag_route_count = YList(self)
                        self._segment_path = lambda: "topology-entry-flag-route-counts"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts, [], name, value)


                    class TopologyEntryFlagRouteCount(Entity):
                        """
                        Route count for topology with entry flag set
                        
                        .. attribute:: entry_flag  <key>
                        
                        	entry flag
                        	**type**\:   :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                            self.yang_name = "topology-entry-flag-route-count"
                            self.yang_parent_name = "topology-entry-flag-route-counts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.entry_flag = YLeaf(YType.enumeration, "entry-flag")

                            self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                            self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                            self.groute_count = YLeaf(YType.uint32, "groute-count")

                            self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                            self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                            self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                            self._segment_path = lambda: "topology-entry-flag-route-count" + "[entry-flag='" + self.entry_flag.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, ['entry_flag', 'active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


                class TopologyInterfaceFlagRouteCounts(Entity):
                    """
                    Route count for topology with interface flag set
                    
                    .. attribute:: topology_interface_flag_route_count
                    
                    	Route count for topology with interface flag set
                    	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-interface-flag-route-counts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"topology-interface-flag-route-count" : ("topology_interface_flag_route_count", Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount)}

                        self.topology_interface_flag_route_count = YList(self)
                        self._segment_path = lambda: "topology-interface-flag-route-counts"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, [], name, value)


                    class TopologyInterfaceFlagRouteCount(Entity):
                        """
                        Route count for topology with interface flag
                        set
                        
                        .. attribute:: interface_flag  <key>
                        
                        	Interface flag
                        	**type**\:   :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                            self.yang_name = "topology-interface-flag-route-count"
                            self.yang_parent_name = "topology-interface-flag-route-counts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interface_flag = YLeaf(YType.enumeration, "interface-flag")

                            self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                            self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                            self.groute_count = YLeaf(YType.uint32, "groute-count")

                            self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                            self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                            self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                            self._segment_path = lambda: "topology-interface-flag-route-count" + "[interface-flag='" + self.interface_flag.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, ['interface_flag', 'active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


                class TopologyRouteCount(Entity):
                    """
                    Topology route count information from PIM
                    topology table
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.TopologyRouteCount, self).__init__()

                        self.yang_name = "topology-route-count"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")
                        self._segment_path = lambda: "topology-route-count"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.TopologyRouteCount, ['active_group_ranges', 'group_ranges', 'groute_count', 'is_node_low_memory', 'sg_route_count', 'sgr_route_count'], name, value)


                class TrafficCounters(Entity):
                    """
                    PIM message traffic counters
                    
                    .. attribute:: boundary_acl_rx_drop
                    
                    	Inc. JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_tx_drop
                    
                    	Out JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_error
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: format_error
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert_batched
                    
                    	Batched Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_data_register
                    
                    	Data Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_ecmp_redirect
                    
                    	Input Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb_error
                    
                    	No IDB for intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_pim_error
                    
                    	PIM Disabled on intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_error
                    
                    	No VRF for idb error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_null_register
                    
                    	Null Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim_version_error
                    
                    	Invalid PIM version error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inputs
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_destination_packets
                    
                    	Control Packets with Invalid Destination
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_join_prunes
                    
                    	PIM invalid Join/Prunes received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_registers
                    
                    	PIM invalid registers received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_local_source_address
                    
                    	Data MDT Join msgs dropped due to local source addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_idb
                    
                    	Data MDT Join msgs dropped due to idb missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_vrf
                    
                    	Data MDT Join msgs dropped due to vrf missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_null_local_address
                    
                    	Data MDT Join msgs dropped due to null local addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_bad_type
                    
                    	Data MDT TLV bad type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_received
                    
                    	Data MDT Join Msgs received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_sent
                    
                    	Data MDT Join Msgs sent
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_joins_drop_multiple_encapsulation
                    
                    	MDT Join msgs dropped due to multiple Encap limitation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_send_queue_full
                    
                    	Packets dropped since mdt send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_socket_error
                    
                    	MDT Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_invalid_lsm_identifier
                    
                    	 Invalid LSM ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_mdt_socket_connection
                    
                    	Packets dropped since no mdt socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_source_address
                    
                    	Packets dropped since no source address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: non_supported_packets
                    
                    	PIM non supported pckets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert_batched
                    
                    	Batched Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_data_register
                    
                    	Data Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_ecmp_redirect
                    
                    	Output Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello_bytes
                    
                    	Output Hello Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_join_group
                    
                    	Output Join Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_prune_bytes
                    
                    	Output JP Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_loop_error
                    
                    	Output on loopback error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_null_register
                    
                    	Null Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_prune_group
                    
                    	Output Prune Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: outputs
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_packman_error
                    
                    	Packets Dropped due to Pakman Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue
                    
                    	Packet queue state and statistics
                    	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue>`
                    
                    .. attribute:: packet_queue_last_clear
                    
                    	Time in seconds since the last clear of all packet queues stats
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: packet_read_socket_error
                    
                    	Packet Read Socket Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_standby
                    
                    	Packets Dropped due to Standby Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pakman_error
                    
                    	Pakman packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: send_queue_full
                    
                    	Packets dropped since send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_error
                    
                    	Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: standby_packets_error
                    
                    	Packets received in standby state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: truncated_pim_packets
                    
                    	Packets dropped due to truncated Joins or Prunes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"packet-queue" : ("packet_queue", Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue)}

                        self.boundary_acl_rx_drop = YLeaf(YType.uint32, "boundary-acl-rx-drop")

                        self.boundary_acl_tx_drop = YLeaf(YType.uint32, "boundary-acl-tx-drop")

                        self.checksum_error = YLeaf(YType.uint32, "checksum-error")

                        self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                        self.format_error = YLeaf(YType.uint32, "format-error")

                        self.input_assert = YLeaf(YType.uint32, "input-assert")

                        self.input_assert_batched = YLeaf(YType.uint32, "input-assert-batched")

                        self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                        self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                        self.input_data_register = YLeaf(YType.uint32, "input-data-register")

                        self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                        self.input_ecmp_redirect = YLeaf(YType.uint32, "input-ecmp-redirect")

                        self.input_hello = YLeaf(YType.uint32, "input-hello")

                        self.input_jp = YLeaf(YType.uint32, "input-jp")

                        self.input_no_idb_error = YLeaf(YType.uint32, "input-no-idb-error")

                        self.input_no_pim_error = YLeaf(YType.uint32, "input-no-pim-error")

                        self.input_no_vrf_error = YLeaf(YType.uint32, "input-no-vrf-error")

                        self.input_null_register = YLeaf(YType.uint32, "input-null-register")

                        self.input_pim_version_error = YLeaf(YType.uint32, "input-pim-version-error")

                        self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                        self.inputs = YLeaf(YType.uint32, "inputs")

                        self.invalid_destination_packets = YLeaf(YType.uint32, "invalid-destination-packets")

                        self.invalid_join_prunes = YLeaf(YType.uint32, "invalid-join-prunes")

                        self.invalid_registers = YLeaf(YType.uint32, "invalid-registers")

                        self.mdt_drop_local_source_address = YLeaf(YType.uint32, "mdt-drop-local-source-address")

                        self.mdt_drop_no_idb = YLeaf(YType.uint32, "mdt-drop-no-idb")

                        self.mdt_drop_no_vrf = YLeaf(YType.uint32, "mdt-drop-no-vrf")

                        self.mdt_drop_null_local_address = YLeaf(YType.uint32, "mdt-drop-null-local-address")

                        self.mdt_join_bad_type = YLeaf(YType.uint32, "mdt-join-bad-type")

                        self.mdt_join_tlv_received = YLeaf(YType.uint32, "mdt-join-tlv-received")

                        self.mdt_join_tlv_sent = YLeaf(YType.uint32, "mdt-join-tlv-sent")

                        self.mdt_joins_drop_multiple_encapsulation = YLeaf(YType.uint32, "mdt-joins-drop-multiple-encapsulation")

                        self.mdt_send_queue_full = YLeaf(YType.uint32, "mdt-send-queue-full")

                        self.mdt_socket_error = YLeaf(YType.uint32, "mdt-socket-error")

                        self.mldp_mdt_invalid_lsm_identifier = YLeaf(YType.uint32, "mldp-mdt-invalid-lsm-identifier")

                        self.no_mdt_socket_connection = YLeaf(YType.uint32, "no-mdt-socket-connection")

                        self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                        self.no_source_address = YLeaf(YType.uint32, "no-source-address")

                        self.non_supported_packets = YLeaf(YType.uint32, "non-supported-packets")

                        self.output_assert = YLeaf(YType.uint32, "output-assert")

                        self.output_assert_batched = YLeaf(YType.uint32, "output-assert-batched")

                        self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                        self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                        self.output_data_register = YLeaf(YType.uint32, "output-data-register")

                        self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                        self.output_ecmp_redirect = YLeaf(YType.uint32, "output-ecmp-redirect")

                        self.output_hello = YLeaf(YType.uint32, "output-hello")

                        self.output_hello_bytes = YLeaf(YType.uint32, "output-hello-bytes")

                        self.output_join_group = YLeaf(YType.uint32, "output-join-group")

                        self.output_join_prune_bytes = YLeaf(YType.uint32, "output-join-prune-bytes")

                        self.output_jp = YLeaf(YType.uint32, "output-jp")

                        self.output_loop_error = YLeaf(YType.uint32, "output-loop-error")

                        self.output_null_register = YLeaf(YType.uint32, "output-null-register")

                        self.output_prune_group = YLeaf(YType.uint32, "output-prune-group")

                        self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                        self.outputs = YLeaf(YType.uint32, "outputs")

                        self.packet_packman_error = YLeaf(YType.uint32, "packet-packman-error")

                        self.packet_queue_last_clear = YLeaf(YType.uint32, "packet-queue-last-clear")

                        self.packet_read_socket_error = YLeaf(YType.uint32, "packet-read-socket-error")

                        self.packets_standby = YLeaf(YType.uint32, "packets-standby")

                        self.pakman_error = YLeaf(YType.uint32, "pakman-error")

                        self.send_queue_full = YLeaf(YType.uint32, "send-queue-full")

                        self.socket_error = YLeaf(YType.uint32, "socket-error")

                        self.standby_packets_error = YLeaf(YType.uint32, "standby-packets-error")

                        self.truncated_pim_packets = YLeaf(YType.uint32, "truncated-pim-packets")

                        self.packet_queue = YList(self)
                        self._segment_path = lambda: "traffic-counters"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.TrafficCounters, ['boundary_acl_rx_drop', 'boundary_acl_tx_drop', 'checksum_error', 'elapsed_time', 'format_error', 'input_assert', 'input_assert_batched', 'input_bsr_message', 'input_candidate_rp_advertisement', 'input_data_register', 'input_df_election', 'input_ecmp_redirect', 'input_hello', 'input_jp', 'input_no_idb_error', 'input_no_pim_error', 'input_no_vrf_error', 'input_null_register', 'input_pim_version_error', 'input_register_stop', 'inputs', 'invalid_destination_packets', 'invalid_join_prunes', 'invalid_registers', 'mdt_drop_local_source_address', 'mdt_drop_no_idb', 'mdt_drop_no_vrf', 'mdt_drop_null_local_address', 'mdt_join_bad_type', 'mdt_join_tlv_received', 'mdt_join_tlv_sent', 'mdt_joins_drop_multiple_encapsulation', 'mdt_send_queue_full', 'mdt_socket_error', 'mldp_mdt_invalid_lsm_identifier', 'no_mdt_socket_connection', 'no_socket_connection', 'no_source_address', 'non_supported_packets', 'output_assert', 'output_assert_batched', 'output_bsr_message', 'output_candidate_rp_advertisement', 'output_data_register', 'output_df_election', 'output_ecmp_redirect', 'output_hello', 'output_hello_bytes', 'output_join_group', 'output_join_prune_bytes', 'output_jp', 'output_loop_error', 'output_null_register', 'output_prune_group', 'output_register_stop', 'outputs', 'packet_packman_error', 'packet_queue_last_clear', 'packet_read_socket_error', 'packets_standby', 'pakman_error', 'send_queue_full', 'socket_error', 'standby_packets_error', 'truncated_pim_packets'], name, value)


                    class PacketQueue(Entity):
                        """
                        Packet queue state and statistics
                        
                        .. attribute:: packet_queue_priority
                        
                        	Priority of this packet queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: packet_queue_state
                        
                        	State of the queue
                        	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState>`
                        
                        .. attribute:: packet_queue_stats
                        
                        	Statistics about the queue
                        	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__init__()

                            self.yang_name = "packet-queue"
                            self.yang_parent_name = "traffic-counters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"packet-queue-state" : ("packet_queue_state", Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState), "packet-queue-stats" : ("packet_queue_stats", Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats)}
                            self._child_list_classes = {}

                            self.packet_queue_priority = YLeaf(YType.uint32, "packet-queue-priority")

                            self.packet_queue_state = Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                            self.packet_queue_state.parent = self
                            self._children_name_map["packet_queue_state"] = "packet-queue-state"
                            self._children_yang_names.add("packet-queue-state")

                            self.packet_queue_stats = Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                            self.packet_queue_stats.parent = self
                            self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                            self._children_yang_names.add("packet-queue-stats")
                            self._segment_path = lambda: "packet-queue"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue, ['packet_queue_priority'], name, value)


                        class PacketQueueState(Entity):
                            """
                            State of the queue
                            
                            .. attribute:: max_queue_size
                            
                            	Maximum size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_bytes
                            
                            	Size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_packets
                            
                            	Size of queue in number of packets
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                                self.yang_name = "packet-queue-state"
                                self.yang_parent_name = "packet-queue"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.max_queue_size = YLeaf(YType.uint32, "max-queue-size")

                                self.queue_size_bytes = YLeaf(YType.uint32, "queue-size-bytes")

                                self.queue_size_packets = YLeaf(YType.uint32, "queue-size-packets")
                                self._segment_path = lambda: "packet-queue-state"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, ['max_queue_size', 'queue_size_bytes', 'queue_size_packets'], name, value)


                        class PacketQueueStats(Entity):
                            """
                            Statistics about the queue
                            
                            .. attribute:: dequeued_packets
                            
                            	Total number of packets dequeued from this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: enqueued_packets
                            
                            	Total number of packets enqueued to this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_bytes
                            
                            	Highest number of bytes enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: high_water_mark_packets
                            
                            	Highest number of packets enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tail_drops
                            
                            	Number packets dropped from this queue due to max size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                                self.yang_name = "packet-queue-stats"
                                self.yang_parent_name = "packet-queue"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.dequeued_packets = YLeaf(YType.uint32, "dequeued-packets")

                                self.enqueued_packets = YLeaf(YType.uint32, "enqueued-packets")

                                self.high_water_mark_bytes = YLeaf(YType.uint32, "high-water-mark-bytes")

                                self.high_water_mark_packets = YLeaf(YType.uint32, "high-water-mark-packets")

                                self.tail_drops = YLeaf(YType.uint32, "tail-drops")
                                self._segment_path = lambda: "packet-queue-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, ['dequeued_packets', 'enqueued_packets', 'high_water_mark_bytes', 'high_water_mark_packets', 'tail_drops'], name, value)


                class Tunnels(Entity):
                    """
                    Tunnels information that PIM has
                    
                    .. attribute:: tunnel
                    
                    	PIM tunnel information
                    	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Tunnels, self).__init__()

                        self.yang_name = "tunnels"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"tunnel" : ("tunnel", Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel)}

                        self.tunnel = YList(self)
                        self._segment_path = lambda: "tunnels"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Tunnels, [], name, value)


                    class Tunnel(Entity):
                        """
                        PIM tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel, self).__init__()

                            self.yang_name = "tunnel"
                            self.yang_parent_name = "tunnels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-netio" : ("group_address_netio", Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio), "rp-address" : ("rp_address", Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress), "source-address" : ("source_address", Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress), "source-address-netio" : ("source_address_netio", Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio)}
                            self._child_list_classes = {}

                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_netio = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._children_yang_names.add("group-address-netio")

                            self.rp_address = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.source_address = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                            self.source_address_netio = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"
                            self._children_yang_names.add("source-address-netio")
                            self._segment_path = lambda: "tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel, ['tunnel_name', 'vrf_name'], name, value)


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-netio"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "rp-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address-netio"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)

    def clone_ptr(self):
        self._top_entity = Pim()
        return self._top_entity

class Pim6Ma(Entity):
    """
    pim6 ma
    
    .. attribute:: active
    
    	Active Process
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active>`
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby>`
    
    

    """

    _prefix = 'ipv4-pim-oper'
    _revision = '2017-06-26'

    def __init__(self):
        super(Pim6Ma, self).__init__()
        self._top_entity = None

        self.yang_name = "pim6-ma"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-pim-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"active" : ("active", Pim6Ma.Active), "standby" : ("standby", Pim6Ma.Standby)}
        self._child_list_classes = {}

        self.active = Pim6Ma.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"
        self._children_yang_names.add("active")

        self.standby = Pim6Ma.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"
        self._children_yang_names.add("standby")
        self._segment_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma"


    class Active(Entity):
        """
        Active Process
        
        .. attribute:: interface_table
        
        	Interface Table
        	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable>`
        
        .. attribute:: pim_ma_summary
        
        	PIM MA summary
        	**type**\:   :py:class:`PimMaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.PimMaSummary>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2017-06-26'

        def __init__(self):
            super(Pim6Ma.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "pim6-ma"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"interface-table" : ("interface_table", Pim6Ma.Active.InterfaceTable), "pim-ma-summary" : ("pim_ma_summary", Pim6Ma.Active.PimMaSummary)}
            self._child_list_classes = {}

            self.interface_table = Pim6Ma.Active.InterfaceTable()
            self.interface_table.parent = self
            self._children_name_map["interface_table"] = "interface-table"
            self._children_yang_names.add("interface-table")

            self.pim_ma_summary = Pim6Ma.Active.PimMaSummary()
            self.pim_ma_summary.parent = self
            self._children_name_map["pim_ma_summary"] = "pim-ma-summary"
            self._children_yang_names.add("pim-ma-summary")
            self._segment_path = lambda: "active"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/%s" % self._segment_path()


        class InterfaceTable(Entity):
            """
            Interface Table
            
            .. attribute:: interface_by_handles
            
            	Table of PIM MA interfaces indexed by handle
            	**type**\:   :py:class:`InterfaceByHandles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByHandles>`
            
            .. attribute:: interface_by_names
            
            	Table of PIM MA interfaces indexed by name
            	**type**\:   :py:class:`InterfaceByNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByNames>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Pim6Ma.Active.InterfaceTable, self).__init__()

                self.yang_name = "interface-table"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"interface-by-handles" : ("interface_by_handles", Pim6Ma.Active.InterfaceTable.InterfaceByHandles), "interface-by-names" : ("interface_by_names", Pim6Ma.Active.InterfaceTable.InterfaceByNames)}
                self._child_list_classes = {}

                self.interface_by_handles = Pim6Ma.Active.InterfaceTable.InterfaceByHandles()
                self.interface_by_handles.parent = self
                self._children_name_map["interface_by_handles"] = "interface-by-handles"
                self._children_yang_names.add("interface-by-handles")

                self.interface_by_names = Pim6Ma.Active.InterfaceTable.InterfaceByNames()
                self.interface_by_names.parent = self
                self._children_name_map["interface_by_names"] = "interface-by-names"
                self._children_yang_names.add("interface-by-names")
                self._segment_path = lambda: "interface-table"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/active/%s" % self._segment_path()


            class InterfaceByHandles(Entity):
                """
                Table of PIM MA interfaces indexed by handle
                
                .. attribute:: interface_by_handle
                
                	PIM MA interface referenced by handle
                	**type**\: list of    :py:class:`InterfaceByHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles, self).__init__()

                    self.yang_name = "interface-by-handles"
                    self.yang_parent_name = "interface-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-by-handle" : ("interface_by_handle", Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle)}

                    self.interface_by_handle = YList(self)
                    self._segment_path = lambda: "interface-by-handles"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/active/interface-table/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim6Ma.Active.InterfaceTable.InterfaceByHandles, [], name, value)


                class InterfaceByHandle(Entity):
                    """
                    PIM MA interface referenced by handle
                    
                    .. attribute:: interface_handle  <key>
                    
                    	Interface handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__init__()

                        self.yang_name = "interface-by-handle"
                        self.yang_parent_name = "interface-by-handles"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rp-address" : ("rp_address", Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress), "source-address" : ("source_address", Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress)}
                        self._child_list_classes = {}

                        self.interface_handle = YLeaf(YType.int32, "interface-handle")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.rp_address = Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")
                        self._segment_path = lambda: "interface-by-handle" + "[interface-handle='" + self.interface_handle.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/active/interface-table/interface-by-handles/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle, ['interface_handle', 'interface_name_xr', 'interface_type', 'vrf_name'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-handle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-handle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceByNames(Entity):
                """
                Table of PIM MA interfaces indexed by name
                
                .. attribute:: interface_by_name
                
                	PIM MA interface referenced by name
                	**type**\: list of    :py:class:`InterfaceByName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim6Ma.Active.InterfaceTable.InterfaceByNames, self).__init__()

                    self.yang_name = "interface-by-names"
                    self.yang_parent_name = "interface-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-by-name" : ("interface_by_name", Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName)}

                    self.interface_by_name = YList(self)
                    self._segment_path = lambda: "interface-by-names"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/active/interface-table/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim6Ma.Active.InterfaceTable.InterfaceByNames, [], name, value)


                class InterfaceByName(Entity):
                    """
                    PIM MA interface referenced by name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName, self).__init__()

                        self.yang_name = "interface-by-name"
                        self.yang_parent_name = "interface-by-names"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rp-address" : ("rp_address", Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress), "source-address" : ("source_address", Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.rp_address = Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")
                        self._segment_path = lambda: "interface-by-name" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/active/interface-table/interface-by-names/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName, ['interface_name', 'interface_name_xr', 'interface_type', 'vrf_name'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-name"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-name"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


        class PimMaSummary(Entity):
            """
            PIM MA summary
            
            .. attribute:: decap_interface_count
            
            	Decap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: encap_interface_count
            
            	Encap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: is_edm_connection_open
            
            	EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_im_connection_open
            
            	IM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_netio_connection_open
            
            	Netio Connection Open
            	**type**\:  bool
            
            .. attribute:: is_standby_edm_connection_open
            
            	Standby EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: mdt_interface_count
            
            	MDT Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Pim6Ma.Active.PimMaSummary, self).__init__()

                self.yang_name = "pim-ma-summary"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.decap_interface_count = YLeaf(YType.uint32, "decap-interface-count")

                self.encap_interface_count = YLeaf(YType.uint32, "encap-interface-count")

                self.is_edm_connection_open = YLeaf(YType.boolean, "is-edm-connection-open")

                self.is_im_connection_open = YLeaf(YType.boolean, "is-im-connection-open")

                self.is_netio_connection_open = YLeaf(YType.boolean, "is-netio-connection-open")

                self.is_standby_edm_connection_open = YLeaf(YType.boolean, "is-standby-edm-connection-open")

                self.mdt_interface_count = YLeaf(YType.uint32, "mdt-interface-count")
                self._segment_path = lambda: "pim-ma-summary"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Pim6Ma.Active.PimMaSummary, ['decap_interface_count', 'encap_interface_count', 'is_edm_connection_open', 'is_im_connection_open', 'is_netio_connection_open', 'is_standby_edm_connection_open', 'mdt_interface_count'], name, value)


    class Standby(Entity):
        """
        Standby Process
        
        .. attribute:: interface_table
        
        	Interface Table
        	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable>`
        
        .. attribute:: pim_ma_summary
        
        	PIM MA summary
        	**type**\:   :py:class:`PimMaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.PimMaSummary>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2017-06-26'

        def __init__(self):
            super(Pim6Ma.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "pim6-ma"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"interface-table" : ("interface_table", Pim6Ma.Standby.InterfaceTable), "pim-ma-summary" : ("pim_ma_summary", Pim6Ma.Standby.PimMaSummary)}
            self._child_list_classes = {}

            self.interface_table = Pim6Ma.Standby.InterfaceTable()
            self.interface_table.parent = self
            self._children_name_map["interface_table"] = "interface-table"
            self._children_yang_names.add("interface-table")

            self.pim_ma_summary = Pim6Ma.Standby.PimMaSummary()
            self.pim_ma_summary.parent = self
            self._children_name_map["pim_ma_summary"] = "pim-ma-summary"
            self._children_yang_names.add("pim-ma-summary")
            self._segment_path = lambda: "standby"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/%s" % self._segment_path()


        class InterfaceTable(Entity):
            """
            Interface Table
            
            .. attribute:: interface_by_handles
            
            	Table of PIM MA interfaces indexed by handle
            	**type**\:   :py:class:`InterfaceByHandles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByHandles>`
            
            .. attribute:: interface_by_names
            
            	Table of PIM MA interfaces indexed by name
            	**type**\:   :py:class:`InterfaceByNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByNames>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Pim6Ma.Standby.InterfaceTable, self).__init__()

                self.yang_name = "interface-table"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"interface-by-handles" : ("interface_by_handles", Pim6Ma.Standby.InterfaceTable.InterfaceByHandles), "interface-by-names" : ("interface_by_names", Pim6Ma.Standby.InterfaceTable.InterfaceByNames)}
                self._child_list_classes = {}

                self.interface_by_handles = Pim6Ma.Standby.InterfaceTable.InterfaceByHandles()
                self.interface_by_handles.parent = self
                self._children_name_map["interface_by_handles"] = "interface-by-handles"
                self._children_yang_names.add("interface-by-handles")

                self.interface_by_names = Pim6Ma.Standby.InterfaceTable.InterfaceByNames()
                self.interface_by_names.parent = self
                self._children_name_map["interface_by_names"] = "interface-by-names"
                self._children_yang_names.add("interface-by-names")
                self._segment_path = lambda: "interface-table"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/standby/%s" % self._segment_path()


            class InterfaceByHandles(Entity):
                """
                Table of PIM MA interfaces indexed by handle
                
                .. attribute:: interface_by_handle
                
                	PIM MA interface referenced by handle
                	**type**\: list of    :py:class:`InterfaceByHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles, self).__init__()

                    self.yang_name = "interface-by-handles"
                    self.yang_parent_name = "interface-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-by-handle" : ("interface_by_handle", Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle)}

                    self.interface_by_handle = YList(self)
                    self._segment_path = lambda: "interface-by-handles"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/standby/interface-table/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles, [], name, value)


                class InterfaceByHandle(Entity):
                    """
                    PIM MA interface referenced by handle
                    
                    .. attribute:: interface_handle  <key>
                    
                    	Interface handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__init__()

                        self.yang_name = "interface-by-handle"
                        self.yang_parent_name = "interface-by-handles"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rp-address" : ("rp_address", Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress), "source-address" : ("source_address", Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress)}
                        self._child_list_classes = {}

                        self.interface_handle = YLeaf(YType.int32, "interface-handle")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.rp_address = Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")
                        self._segment_path = lambda: "interface-by-handle" + "[interface-handle='" + self.interface_handle.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/standby/interface-table/interface-by-handles/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle, ['interface_handle', 'interface_name_xr', 'interface_type', 'vrf_name'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-handle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-handle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceByNames(Entity):
                """
                Table of PIM MA interfaces indexed by name
                
                .. attribute:: interface_by_name
                
                	PIM MA interface referenced by name
                	**type**\: list of    :py:class:`InterfaceByName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames, self).__init__()

                    self.yang_name = "interface-by-names"
                    self.yang_parent_name = "interface-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-by-name" : ("interface_by_name", Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName)}

                    self.interface_by_name = YList(self)
                    self._segment_path = lambda: "interface-by-names"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/standby/interface-table/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim6Ma.Standby.InterfaceTable.InterfaceByNames, [], name, value)


                class InterfaceByName(Entity):
                    """
                    PIM MA interface referenced by name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName, self).__init__()

                        self.yang_name = "interface-by-name"
                        self.yang_parent_name = "interface-by-names"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rp-address" : ("rp_address", Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress), "source-address" : ("source_address", Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.rp_address = Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")
                        self._segment_path = lambda: "interface-by-name" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/standby/interface-table/interface-by-names/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName, ['interface_name', 'interface_name_xr', 'interface_type', 'vrf_name'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-name"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-name"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


        class PimMaSummary(Entity):
            """
            PIM MA summary
            
            .. attribute:: decap_interface_count
            
            	Decap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: encap_interface_count
            
            	Encap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: is_edm_connection_open
            
            	EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_im_connection_open
            
            	IM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_netio_connection_open
            
            	Netio Connection Open
            	**type**\:  bool
            
            .. attribute:: is_standby_edm_connection_open
            
            	Standby EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: mdt_interface_count
            
            	MDT Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Pim6Ma.Standby.PimMaSummary, self).__init__()

                self.yang_name = "pim-ma-summary"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.decap_interface_count = YLeaf(YType.uint32, "decap-interface-count")

                self.encap_interface_count = YLeaf(YType.uint32, "encap-interface-count")

                self.is_edm_connection_open = YLeaf(YType.boolean, "is-edm-connection-open")

                self.is_im_connection_open = YLeaf(YType.boolean, "is-im-connection-open")

                self.is_netio_connection_open = YLeaf(YType.boolean, "is-netio-connection-open")

                self.is_standby_edm_connection_open = YLeaf(YType.boolean, "is-standby-edm-connection-open")

                self.mdt_interface_count = YLeaf(YType.uint32, "mdt-interface-count")
                self._segment_path = lambda: "pim-ma-summary"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Pim6Ma.Standby.PimMaSummary, ['decap_interface_count', 'encap_interface_count', 'is_edm_connection_open', 'is_im_connection_open', 'is_netio_connection_open', 'is_standby_edm_connection_open', 'mdt_interface_count'], name, value)

    def clone_ptr(self):
        self._top_entity = Pim6Ma()
        return self._top_entity

class PimMa(Entity):
    """
    PIM MA operational data
    
    .. attribute:: active
    
    	Active Process
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active>`
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby>`
    
    

    """

    _prefix = 'ipv4-pim-oper'
    _revision = '2017-06-26'

    def __init__(self):
        super(PimMa, self).__init__()
        self._top_entity = None

        self.yang_name = "pim-ma"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-pim-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"active" : ("active", PimMa.Active), "standby" : ("standby", PimMa.Standby)}
        self._child_list_classes = {}

        self.active = PimMa.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"
        self._children_yang_names.add("active")

        self.standby = PimMa.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"
        self._children_yang_names.add("standby")
        self._segment_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma"


    class Active(Entity):
        """
        Active Process
        
        .. attribute:: interface_table
        
        	Interface Table
        	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable>`
        
        .. attribute:: pim_ma_summary
        
        	PIM MA summary
        	**type**\:   :py:class:`PimMaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.PimMaSummary>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2017-06-26'

        def __init__(self):
            super(PimMa.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "pim-ma"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"interface-table" : ("interface_table", PimMa.Active.InterfaceTable), "pim-ma-summary" : ("pim_ma_summary", PimMa.Active.PimMaSummary)}
            self._child_list_classes = {}

            self.interface_table = PimMa.Active.InterfaceTable()
            self.interface_table.parent = self
            self._children_name_map["interface_table"] = "interface-table"
            self._children_yang_names.add("interface-table")

            self.pim_ma_summary = PimMa.Active.PimMaSummary()
            self.pim_ma_summary.parent = self
            self._children_name_map["pim_ma_summary"] = "pim-ma-summary"
            self._children_yang_names.add("pim-ma-summary")
            self._segment_path = lambda: "active"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/%s" % self._segment_path()


        class InterfaceTable(Entity):
            """
            Interface Table
            
            .. attribute:: interface_by_handles
            
            	Table of PIM MA interfaces indexed by handle
            	**type**\:   :py:class:`InterfaceByHandles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByHandles>`
            
            .. attribute:: interface_by_names
            
            	Table of PIM MA interfaces indexed by name
            	**type**\:   :py:class:`InterfaceByNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByNames>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(PimMa.Active.InterfaceTable, self).__init__()

                self.yang_name = "interface-table"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"interface-by-handles" : ("interface_by_handles", PimMa.Active.InterfaceTable.InterfaceByHandles), "interface-by-names" : ("interface_by_names", PimMa.Active.InterfaceTable.InterfaceByNames)}
                self._child_list_classes = {}

                self.interface_by_handles = PimMa.Active.InterfaceTable.InterfaceByHandles()
                self.interface_by_handles.parent = self
                self._children_name_map["interface_by_handles"] = "interface-by-handles"
                self._children_yang_names.add("interface-by-handles")

                self.interface_by_names = PimMa.Active.InterfaceTable.InterfaceByNames()
                self.interface_by_names.parent = self
                self._children_name_map["interface_by_names"] = "interface-by-names"
                self._children_yang_names.add("interface-by-names")
                self._segment_path = lambda: "interface-table"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/active/%s" % self._segment_path()


            class InterfaceByHandles(Entity):
                """
                Table of PIM MA interfaces indexed by handle
                
                .. attribute:: interface_by_handle
                
                	PIM MA interface referenced by handle
                	**type**\: list of    :py:class:`InterfaceByHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(PimMa.Active.InterfaceTable.InterfaceByHandles, self).__init__()

                    self.yang_name = "interface-by-handles"
                    self.yang_parent_name = "interface-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-by-handle" : ("interface_by_handle", PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle)}

                    self.interface_by_handle = YList(self)
                    self._segment_path = lambda: "interface-by-handles"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/active/interface-table/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(PimMa.Active.InterfaceTable.InterfaceByHandles, [], name, value)


                class InterfaceByHandle(Entity):
                    """
                    PIM MA interface referenced by handle
                    
                    .. attribute:: interface_handle  <key>
                    
                    	Interface handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__init__()

                        self.yang_name = "interface-by-handle"
                        self.yang_parent_name = "interface-by-handles"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rp-address" : ("rp_address", PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress), "source-address" : ("source_address", PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress)}
                        self._child_list_classes = {}

                        self.interface_handle = YLeaf(YType.int32, "interface-handle")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.rp_address = PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")
                        self._segment_path = lambda: "interface-by-handle" + "[interface-handle='" + self.interface_handle.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/active/interface-table/interface-by-handles/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle, ['interface_handle', 'interface_name_xr', 'interface_type', 'vrf_name'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-handle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-handle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceByNames(Entity):
                """
                Table of PIM MA interfaces indexed by name
                
                .. attribute:: interface_by_name
                
                	PIM MA interface referenced by name
                	**type**\: list of    :py:class:`InterfaceByName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(PimMa.Active.InterfaceTable.InterfaceByNames, self).__init__()

                    self.yang_name = "interface-by-names"
                    self.yang_parent_name = "interface-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-by-name" : ("interface_by_name", PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName)}

                    self.interface_by_name = YList(self)
                    self._segment_path = lambda: "interface-by-names"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/active/interface-table/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(PimMa.Active.InterfaceTable.InterfaceByNames, [], name, value)


                class InterfaceByName(Entity):
                    """
                    PIM MA interface referenced by name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName, self).__init__()

                        self.yang_name = "interface-by-name"
                        self.yang_parent_name = "interface-by-names"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rp-address" : ("rp_address", PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress), "source-address" : ("source_address", PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.rp_address = PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")
                        self._segment_path = lambda: "interface-by-name" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/active/interface-table/interface-by-names/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName, ['interface_name', 'interface_name_xr', 'interface_type', 'vrf_name'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-name"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-name"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


        class PimMaSummary(Entity):
            """
            PIM MA summary
            
            .. attribute:: decap_interface_count
            
            	Decap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: encap_interface_count
            
            	Encap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: is_edm_connection_open
            
            	EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_im_connection_open
            
            	IM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_netio_connection_open
            
            	Netio Connection Open
            	**type**\:  bool
            
            .. attribute:: is_standby_edm_connection_open
            
            	Standby EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: mdt_interface_count
            
            	MDT Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(PimMa.Active.PimMaSummary, self).__init__()

                self.yang_name = "pim-ma-summary"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.decap_interface_count = YLeaf(YType.uint32, "decap-interface-count")

                self.encap_interface_count = YLeaf(YType.uint32, "encap-interface-count")

                self.is_edm_connection_open = YLeaf(YType.boolean, "is-edm-connection-open")

                self.is_im_connection_open = YLeaf(YType.boolean, "is-im-connection-open")

                self.is_netio_connection_open = YLeaf(YType.boolean, "is-netio-connection-open")

                self.is_standby_edm_connection_open = YLeaf(YType.boolean, "is-standby-edm-connection-open")

                self.mdt_interface_count = YLeaf(YType.uint32, "mdt-interface-count")
                self._segment_path = lambda: "pim-ma-summary"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(PimMa.Active.PimMaSummary, ['decap_interface_count', 'encap_interface_count', 'is_edm_connection_open', 'is_im_connection_open', 'is_netio_connection_open', 'is_standby_edm_connection_open', 'mdt_interface_count'], name, value)


    class Standby(Entity):
        """
        Standby Process
        
        .. attribute:: interface_table
        
        	Interface Table
        	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable>`
        
        .. attribute:: pim_ma_summary
        
        	PIM MA summary
        	**type**\:   :py:class:`PimMaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.PimMaSummary>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2017-06-26'

        def __init__(self):
            super(PimMa.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "pim-ma"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"interface-table" : ("interface_table", PimMa.Standby.InterfaceTable), "pim-ma-summary" : ("pim_ma_summary", PimMa.Standby.PimMaSummary)}
            self._child_list_classes = {}

            self.interface_table = PimMa.Standby.InterfaceTable()
            self.interface_table.parent = self
            self._children_name_map["interface_table"] = "interface-table"
            self._children_yang_names.add("interface-table")

            self.pim_ma_summary = PimMa.Standby.PimMaSummary()
            self.pim_ma_summary.parent = self
            self._children_name_map["pim_ma_summary"] = "pim-ma-summary"
            self._children_yang_names.add("pim-ma-summary")
            self._segment_path = lambda: "standby"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/%s" % self._segment_path()


        class InterfaceTable(Entity):
            """
            Interface Table
            
            .. attribute:: interface_by_handles
            
            	Table of PIM MA interfaces indexed by handle
            	**type**\:   :py:class:`InterfaceByHandles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByHandles>`
            
            .. attribute:: interface_by_names
            
            	Table of PIM MA interfaces indexed by name
            	**type**\:   :py:class:`InterfaceByNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByNames>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(PimMa.Standby.InterfaceTable, self).__init__()

                self.yang_name = "interface-table"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"interface-by-handles" : ("interface_by_handles", PimMa.Standby.InterfaceTable.InterfaceByHandles), "interface-by-names" : ("interface_by_names", PimMa.Standby.InterfaceTable.InterfaceByNames)}
                self._child_list_classes = {}

                self.interface_by_handles = PimMa.Standby.InterfaceTable.InterfaceByHandles()
                self.interface_by_handles.parent = self
                self._children_name_map["interface_by_handles"] = "interface-by-handles"
                self._children_yang_names.add("interface-by-handles")

                self.interface_by_names = PimMa.Standby.InterfaceTable.InterfaceByNames()
                self.interface_by_names.parent = self
                self._children_name_map["interface_by_names"] = "interface-by-names"
                self._children_yang_names.add("interface-by-names")
                self._segment_path = lambda: "interface-table"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/standby/%s" % self._segment_path()


            class InterfaceByHandles(Entity):
                """
                Table of PIM MA interfaces indexed by handle
                
                .. attribute:: interface_by_handle
                
                	PIM MA interface referenced by handle
                	**type**\: list of    :py:class:`InterfaceByHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(PimMa.Standby.InterfaceTable.InterfaceByHandles, self).__init__()

                    self.yang_name = "interface-by-handles"
                    self.yang_parent_name = "interface-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-by-handle" : ("interface_by_handle", PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle)}

                    self.interface_by_handle = YList(self)
                    self._segment_path = lambda: "interface-by-handles"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/standby/interface-table/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(PimMa.Standby.InterfaceTable.InterfaceByHandles, [], name, value)


                class InterfaceByHandle(Entity):
                    """
                    PIM MA interface referenced by handle
                    
                    .. attribute:: interface_handle  <key>
                    
                    	Interface handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__init__()

                        self.yang_name = "interface-by-handle"
                        self.yang_parent_name = "interface-by-handles"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rp-address" : ("rp_address", PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress), "source-address" : ("source_address", PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress)}
                        self._child_list_classes = {}

                        self.interface_handle = YLeaf(YType.int32, "interface-handle")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.rp_address = PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")
                        self._segment_path = lambda: "interface-by-handle" + "[interface-handle='" + self.interface_handle.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/standby/interface-table/interface-by-handles/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle, ['interface_handle', 'interface_name_xr', 'interface_type', 'vrf_name'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-handle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-handle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceByNames(Entity):
                """
                Table of PIM MA interfaces indexed by name
                
                .. attribute:: interface_by_name
                
                	PIM MA interface referenced by name
                	**type**\: list of    :py:class:`InterfaceByName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(PimMa.Standby.InterfaceTable.InterfaceByNames, self).__init__()

                    self.yang_name = "interface-by-names"
                    self.yang_parent_name = "interface-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-by-name" : ("interface_by_name", PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName)}

                    self.interface_by_name = YList(self)
                    self._segment_path = lambda: "interface-by-names"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/standby/interface-table/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(PimMa.Standby.InterfaceTable.InterfaceByNames, [], name, value)


                class InterfaceByName(Entity):
                    """
                    PIM MA interface referenced by name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName, self).__init__()

                        self.yang_name = "interface-by-name"
                        self.yang_parent_name = "interface-by-names"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"rp-address" : ("rp_address", PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress), "source-address" : ("source_address", PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.rp_address = PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")
                        self._segment_path = lambda: "interface-by-name" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/standby/interface-table/interface-by-names/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName, ['interface_name', 'interface_name_xr', 'interface_type', 'vrf_name'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-name"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "rp-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-name"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


        class PimMaSummary(Entity):
            """
            PIM MA summary
            
            .. attribute:: decap_interface_count
            
            	Decap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: encap_interface_count
            
            	Encap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: is_edm_connection_open
            
            	EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_im_connection_open
            
            	IM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_netio_connection_open
            
            	Netio Connection Open
            	**type**\:  bool
            
            .. attribute:: is_standby_edm_connection_open
            
            	Standby EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: mdt_interface_count
            
            	MDT Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(PimMa.Standby.PimMaSummary, self).__init__()

                self.yang_name = "pim-ma-summary"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.decap_interface_count = YLeaf(YType.uint32, "decap-interface-count")

                self.encap_interface_count = YLeaf(YType.uint32, "encap-interface-count")

                self.is_edm_connection_open = YLeaf(YType.boolean, "is-edm-connection-open")

                self.is_im_connection_open = YLeaf(YType.boolean, "is-im-connection-open")

                self.is_netio_connection_open = YLeaf(YType.boolean, "is-netio-connection-open")

                self.is_standby_edm_connection_open = YLeaf(YType.boolean, "is-standby-edm-connection-open")

                self.mdt_interface_count = YLeaf(YType.uint32, "mdt-interface-count")
                self._segment_path = lambda: "pim-ma-summary"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(PimMa.Standby.PimMaSummary, ['decap_interface_count', 'encap_interface_count', 'is_edm_connection_open', 'is_im_connection_open', 'is_netio_connection_open', 'is_standby_edm_connection_open', 'mdt_interface_count'], name, value)

    def clone_ptr(self):
        self._top_entity = PimMa()
        return self._top_entity

